PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-08-07-10:52:41','2023-08-07-10:56:02',1691398361,1691398562,'month',1,0,1,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "JOBS": {"TEST": {"FILE": "test.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "DEFAULT": {"EXPID": "a013", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/local_project/include.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(2,'2023-08-07-10:56:02','2023-08-07-13:30:56',1691398562,1691407856,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-a.yml", "POST": "~/platforms.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-A": "value a", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(3,'2023-08-07-13:30:56','2023-08-07-13:34:52',1691407856,1691408092,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-a.yml", "POST": "~/platforms.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-A": "value a", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(4,'2023-08-07-13:34:52','2023-08-07-13:35:02',1691408092,1691408102,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-a.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-A": "value a", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(5,'2023-08-07-13:35:02','2023-08-07-13:36:39',1691408102,1691408199,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-a.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-A": "value a", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(6,'2023-08-07-13:36:39','2023-08-07-13:37:19',1691408199,1691408239,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-b.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-B": "value b", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(7,'2023-08-07-13:37:19','2023-08-07-13:37:43',1691408239,1691408263,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-b.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-B": "value b", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(8,'2023-08-07-13:37:43','2023-08-07-13:45:51',1691408263,1691408751,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-a.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-A": "value a", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(9,'2023-08-07-13:45:51','2023-08-07-13:45:56',1691408751,1691408756,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-a.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-A": "value a", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(10,'2023-08-07-13:45:56','2023-08-07-15:09:01',1691408756,1691413741,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-a.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-A": "value a", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(11,'2023-08-07-15:09:01','2023-08-07-16:30:41',1691413741,1691418641,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-a.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-A": "value a", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(12,'2023-08-07-16:30:41','2023-08-07-16:30:41',1691418641,0,'hour',1,0,1,0,0,0,0,0,'{"DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a013/proj/project_files/conf-a.yml"}, "EXPID": "a013", "HPCARCH": "local"}, "TEST-A": "value a", "JOBS": {"WAIT": {"FILE": "wait-long.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PLATFORMS": {"DUMMY": {"TYPE": "ps", "HOST": "dummy.host", "USER": "dummy", "SCRATCH_DIR": "/home"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a013", "PROJDIR": "/home/dbeltran/new_autosubmit/a013/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/dbeltran/new_autosubmit/a013/proj/local_project"}, "STORAGE": {}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',12);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
