PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-09-29-11:48:44','2023-09-29-11:48:55',1695980924,1695980935,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(2,'2023-09-29-11:48:55','2023-09-29-11:50:49',1695980935,1695981049,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(3,'2023-09-29-11:50:49','2023-09-29-11:51:11',1695981049,1695981071,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(4,'2023-09-29-11:51:11','2023-09-29-11:51:42',1695981071,1695981102,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(5,'2023-09-29-11:51:42','2023-09-29-11:52:56',1695981102,1695981176,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(6,'2023-09-29-11:52:56','2023-09-29-11:53:03',1695981176,1695981183,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(7,'2023-09-29-11:53:03','2023-09-29-11:55:26',1695981183,1695981326,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(8,'2023-09-29-11:55:26','2023-09-29-11:55:34',1695981326,1695981334,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(9,'2023-09-29-11:55:34','2023-09-29-11:55:51',1695981334,1695981351,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(10,'2023-09-29-11:55:51','2023-09-29-11:56:01',1695981351,1695981361,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(11,'2023-09-29-11:56:01','2023-09-29-11:56:31',1695981361,1695981391,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(12,'2023-09-29-11:56:31','2023-09-29-11:56:31',1695981391,0,'day',1,0,6,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a0bo", "HPCARCH": "lumi", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01m/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "lumi-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_icon.sh", "PLATFORM": "lumi", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0, 0], "NODES": [84, 16, 1], "TASKS": [8, 8, 1], "THREADS": [1, 7, 1], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'', ''#SBATCH --gpus-per-node=8''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive''], [''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "WALLCLOCK": "01:00", "NODES": 1, "PROCESSORS": 16, "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'']"}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "PARTITION": "standard-g", "MAX_WALLCLOCK": "02:00"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "WALLCLOCK": "08:00", "NODES": 200, "TASKS_PER_NODE": 32, "CPUS_PER_TASK": 8, "PROCESSORS": 25600, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL --distribution=block:cyclic'']", "OCEAN_NODES": 10}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"NAME": "control-r2b8-icon-1950", "RUNSCRIPT": "icon/control/control-1950-r2b8-hetjobs.run", "HETJOB": "TRUE", "INPROOT": "/projappl/project_465000454/models/icon/inidata", "TIMEFORMAT": "+%FT%TZ", "CHECKPOINT_INTERVAL": "P1Y", "RESTART_INTERVAL": "P1D", "RAD_TSTEP": "PT30M", "ATM_TSTEP": "PT75S", "OCE_TSTEP": "PT300S", "COUPLING_TSTEP": "PT30M"}, "EXPERIMENT": {"DATELIST": 19500101, "MEMBERS": "default", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "git@gitlab.dkrz.de:icon/icon-mpim.git", "BRANCH": "feature-destine-ngc3-wo-hiopy", "VERSION": "icon-mpim", "NAME": "icon"}, "CONFIGURATION": {"ICON": {"ATM_GID": "0033", "ATM_REF": "R02B08", "OCE_GID": "0034", "OCE_REF": "R02B08", "ATM_NPROMA": 500, "OCE_NPROMA": 32}}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "RUN": {"SIMULATION": "control-r2b8-icon-1950", "PARAMETER": "default", "MODEL": "icon", "APPLICATION": "none", "GRID_ATM": "r2b8_hetjobs", "GRID_OCEAN": "r2b8_hetjobs", "MODEL_VERSION": "feature-collection-destine-v.0.1", "ENVIRONMENT": "cray", "CLEAN_RUN": "true"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01m", "PROJDIR": "/home/dbeltran/new_autosubmit/a01m/proj/project_files", "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "dev-icon-hetjobs", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "icon-mpim", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',12);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
