PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-07-20-15:39:40','2023-07-20-15:59:12',1689860380,1689861552,'day',1,0,9,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a00v", "HPCARCH": "LUMI", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a00v/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "02:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "small", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "main", "ENVIRONMENT": "cray"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00v", "PROJDIR": "/home/dbeltran/new_autosubmit/a00v/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": ""}, "LOCAL": {"PROJECT_PATH": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(2,'2023-07-20-15:59:12','2023-07-20-15:59:33',1689861552,1689861573,'day',1,0,9,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a00v", "HPCARCH": "LUMI", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a00v/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "02:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "small", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "main", "ENVIRONMENT": "cray"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00v", "PROJDIR": "/home/dbeltran/new_autosubmit/a00v/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": ""}, "LOCAL": {"PROJECT_PATH": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(3,'2023-07-20-15:59:33','2023-07-20-16:01:48',1689861573,1689861708,'day',1,0,9,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a00v", "HPCARCH": "LUMI", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a00v/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "02:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "small", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "main", "ENVIRONMENT": "cray"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00v", "PROJDIR": "/home/dbeltran/new_autosubmit/a00v/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": ""}, "LOCAL": {"PROJECT_PATH": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(4,'2023-07-20-16:01:48','2023-07-20-16:04:45',1689861708,1689861885,'day',1,0,9,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a00v", "HPCARCH": "LUMI", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a00v/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "02:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "small", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "main", "ENVIRONMENT": "cray"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00v", "PROJDIR": "/home/dbeltran/new_autosubmit/a00v/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": ""}, "LOCAL": {"PROJECT_PATH": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(5,'2023-07-20-16:04:45','2023-07-20-16:04:45',1689861885,0,'day',1,0,9,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a00v", "HPCARCH": "LUMI", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a00v/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "02:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "small", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "main", "ENVIRONMENT": "cray"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00v", "PROJDIR": "/home/dbeltran/new_autosubmit/a00v/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": ""}, "LOCAL": {"PROJECT_PATH": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow"}, "STORAGE": {}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',5);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
