PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-08-08-09:49:04','2023-08-08-09:49:14',1691480944,1691480954,'month',1,0,364,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.85", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"EXPID": "a015", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms_credentials.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 360}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": ""}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "Lumi-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "Lumi", "RETRIALS": 2, "RUNNING": "chunk", "WALLCLOCK": "02:30"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'', ''#SBATCH --reservation=DT_264CPU'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "24:00", "NODES": 240, "PARTITION": "standard", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "iwagner"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "iwagner", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28713"}, "MARENOSTRUM0": {"USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a015/proj/none_project", "PROJECT": {"PROJECT_DESTINATION": "none_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a015", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "HISTORICAL_RUNS", "PARAMETER": "default", "SIMULATION": "longrun-ifs-nemo-1990"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(2,'2023-08-08-09:49:14','2023-08-08-09:49:25',1691480954,1691480965,'month',1,0,364,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.85", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"EXPID": "a015", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms_credentials.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 360}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": ""}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "Lumi-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "Lumi", "RETRIALS": 2, "RUNNING": "chunk", "WALLCLOCK": "02:30"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'', ''#SBATCH --reservation=DT_264CPU'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "24:00", "NODES": 240, "PARTITION": "standard", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "iwagner"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "iwagner", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28713"}, "MARENOSTRUM0": {"USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a015/proj/none_project", "PROJECT": {"PROJECT_DESTINATION": "none_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a015", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "HISTORICAL_RUNS", "PARAMETER": "default", "SIMULATION": "longrun-ifs-nemo-1990"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(3,'2023-08-08-09:49:25','2023-08-08-09:49:56',1691480965,1691480996,'month',1,0,364,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.85", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"EXPID": "a015", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms_credentials.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 360}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": ""}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "Lumi-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "Lumi", "RETRIALS": 2, "RUNNING": "chunk", "WALLCLOCK": "02:30"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'', ''#SBATCH --reservation=DT_264CPU'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "24:00", "NODES": 240, "PARTITION": "standard", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "iwagner"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "iwagner", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28713"}, "MARENOSTRUM0": {"USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a015/proj/none_project", "PROJECT": {"PROJECT_DESTINATION": "none_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a015", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "HISTORICAL_RUNS", "PARAMETER": "default", "SIMULATION": "longrun-ifs-nemo-1990"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(4,'2023-08-08-09:49:56','2023-08-08-09:52:07',1691480996,1691481127,'month',1,0,364,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.85", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"EXPID": "a015", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 360}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": ""}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "Lumi-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "Lumi", "RETRIALS": 2, "RUNNING": "chunk", "WALLCLOCK": "02:30"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'', ''#SBATCH --reservation=DT_264CPU'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "24:00", "NODES": 240, "PARTITION": "standard", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "iwagner"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "iwagner", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28713"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28713"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a015/proj/none_project", "PROJECT": {"PROJECT_DESTINATION": "none_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a015", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "HISTORICAL_RUNS", "PARAMETER": "default", "SIMULATION": "longrun-ifs-nemo-1990"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(5,'2023-08-08-09:52:07','2023-08-08-09:52:16',1691481127,1691481136,'month',1,0,364,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.85", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"EXPID": "a015", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 360}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": ""}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "Lumi-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "Lumi", "RETRIALS": 2, "RUNNING": "chunk", "WALLCLOCK": "02:30"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'', ''#SBATCH --reservation=DT_264CPU'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "24:00", "NODES": 240, "PARTITION": "standard", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "iwagner"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "iwagner", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28713"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28713"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a015/proj/none_project", "PROJECT": {"PROJECT_DESTINATION": "none_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a015", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "HISTORICAL_RUNS", "PARAMETER": "default", "SIMULATION": "longrun-ifs-nemo-1990"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER_0": null, "TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM"}}');
INSERT INTO experiment_run VALUES(6,'2023-08-08-09:52:16','2023-08-08-09:52:51',1691481136,1691481171,'month',1,0,364,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.85", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"EXPID": "a015", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 360}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": ""}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "Lumi-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "Lumi", "RETRIALS": 2, "RUNNING": "chunk", "WALLCLOCK": "02:30"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'', ''#SBATCH --reservation=DT_264CPU'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "24:00", "NODES": 240, "PARTITION": "standard", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "iwagner"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "iwagner", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28713"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28713"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a015/proj/none_project", "PROJECT": {"PROJECT_DESTINATION": "none_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a015", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "HISTORICAL_RUNS", "PARAMETER": "default", "SIMULATION": "longrun-ifs-nemo-1990"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER_0": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM"}}}');
INSERT INTO experiment_run VALUES(7,'2023-08-08-09:52:51','2023-08-08-09:55:35',1691481171,1691481335,'month',1,0,364,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.85", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"EXPID": "a015", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 360}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": ""}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "Lumi-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "Lumi", "RETRIALS": 2, "RUNNING": "chunk", "WALLCLOCK": "02:30"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'', ''#SBATCH --reservation=DT_264CPU'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "24:00", "NODES": 240, "PARTITION": "standard", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "iwagner"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "iwagner", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28713"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28713"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a015/proj/none_project", "PROJECT": {"PROJECT_DESTINATION": "none_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a015", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "HISTORICAL_RUNS", "PARAMETER": "default", "SIMULATION": "longrun-ifs-nemo-1990"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER_0": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']"}}}');
INSERT INTO experiment_run VALUES(8,'2023-08-08-09:55:35','2023-08-08-10:08:27',1691481335,0,'month',1,14,14,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.85", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"EXPID": "a015", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms_credentials.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 10}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": ""}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "Lumi-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "Lumi", "RETRIALS": 2, "RUNNING": "chunk", "WALLCLOCK": "02:30"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'', ''#SBATCH --reservation=DT_264CPU'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "24:00", "NODES": 240, "PARTITION": "standard", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "iwagner"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "iwagner", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28713"}, "MARENOSTRUM0": {"USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a015/proj/none_project", "PROJECT": {"PROJECT_DESTINATION": "none_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a015", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "HISTORICAL_RUNS", "PARAMETER": "default", "SIMULATION": "longrun-ifs-nemo-1990"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER_0": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']"}}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a015_LOCAL_SETUP','2023-08-08-10:00:08','2023-08-08-10:00:20',1691481608,1691481608,1691481613,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,1,'LOCAL',25794,'',0,8,0.0,0.0,'a015_LOCAL_SETUP.20230808100020.out','a015_LOCAL_SETUP.20230808100020.err',5,'a015_SYNCHRONIZE','');
INSERT INTO job_data VALUES(2,0,'a015_SYNCHRONIZE','2023-08-08-10:00:20','2023-08-08-10:00:32',1691481620,1691481620,1691481625,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,1,'LOCAL',25932,'',0,8,0.0,0.0,'a015_SYNCHRONIZE.20230808100032.out','a015_SYNCHRONIZE.20230808100032.err',5,'a015_REMOTE_SETUP','');
INSERT INTO job_data VALUES(3,0,'a015_REMOTE_SETUP','2023-08-08-10:04:12','2023-08-08-10:05:54',1691481852,1691481877,1691481882,'COMPLETED',2,1,'00:30','debug',911,'','REMOTE_SETUP','',0,1,'MARENOSTRUM4',29876017,'',1,8,0.0,0.0,'a015_REMOTE_SETUP.20230808100451.out','a015_REMOTE_SETUP.20230808100451.err',2,'a015_19900101_fc0_INI',replace('                 29876017  COMPLETED          1        1 2023-08-08T10:04:12 2023-08-08T10:04:35 2023-08-08T10:04:42            911                                                     \n           29876017.batch  COMPLETED          1        1 2023-08-08T10:04:35 2023-08-08T10:04:35 2023-08-08T10:04:42            889                      916K                      916K \n          29876017.extern  COMPLETED          1        1 2023-08-08T10:04:35 2023-08-08T10:04:35 2023-08-08T10:04:42            911                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(4,0,'a015_19900101_fc0_INI','2023-08-08-10:04:56','2023-08-08-10:05:45',1691481896,1691481919,1691481924,'COMPLETED',2,1,'00:30','debug',0,'1990-01-01 00:00:00','INI','fc0',0,1,'MARENOSTRUM4',29876018,'',0,8,0.0,0.0,'a015_19900101_fc0_INI.20230808100528.out','a015_19900101_fc0_INI.20230808100528.err',5,'a015_19900101_fc0_1_SIM','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',8);
INSERT INTO sqlite_sequence VALUES('job_data',4);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
