PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-04-28-10:05:24','2023-04-28-10:05:35',1682669124,1682669135,'month',1,0,1,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a009/proj/project_files", "ROOTDIR": "/home/dbeltran/new_autosubmit/a009", "DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon/config/common", "POST": "~/config/platforms_user.yml"}, "EXPID": "a009", "HPCARCH": "levante"}, "JOBS": {"COPY_NAMELIST": {"FILE": "jobscripts/copy_namelist.sh", "RUNNING": "once"}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "", "PROJECT": "", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "CUSTOM_DIRECTIVES": "#SBATCH --partition=compute"}}, "EXPERIMENT": {"DATELIST": 20000101, "MEMBERS": "default", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard"}, "NAMELIST": {"MASTER": "icon_master.namelist", "EXP": "%DEFAULT.TEMPLATE%.nml"}, "DIRECTORIES": {"ICONDIR": "%HPCROOTDIR%/icon", "INDIR": "", "OUTDIR": ""}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-icon"}, "GIT": {"PROJECT_ORIGIN": "git@gitlab.dkrz.de:auto-icon/auto-icon.git", "PROJECT_BRANCH": "refactor-config-loading", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(2,'2023-04-28-10:05:35','2023-04-28-10:32:27',1682669135,1682670747,'month',1,0,1,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a009/proj/project_files", "ROOTDIR": "/home/dbeltran/new_autosubmit/a009", "DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon/config/common", "POST": "~/config/platforms_user.yml"}, "EXPID": "a009", "HPCARCH": "levante"}, "JOBS": {"COPY_NAMELIST": {"FILE": "jobscripts/copy_namelist.sh", "RUNNING": "once"}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "", "PROJECT": "", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "CUSTOM_DIRECTIVES": "#SBATCH --partition=compute"}}, "EXPERIMENT": {"DATELIST": 20000101, "MEMBERS": "default", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard"}, "NAMELIST": {"MASTER": "icon_master.namelist", "EXP": "%DEFAULT.TEMPLATE%.nml"}, "DIRECTORIES": {"ICONDIR": "%HPCROOTDIR%/icon", "INDIR": "", "OUTDIR": ""}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-icon"}, "GIT": {"PROJECT_ORIGIN": "git@gitlab.dkrz.de:auto-icon/auto-icon.git", "PROJECT_BRANCH": "refactor-config-loading", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(3,'2023-04-28-10:32:27','2023-04-28-15:58:42',1682670747,1682690322,'month',1,0,2,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a009/proj/project_files", "ROOTDIR": "/home/dbeltran/new_autosubmit/a009", "DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon/config/common", "POST": "~/config/platforms_user.yml"}, "EXPID": "a009", "HPCARCH": "levante"}, "JOBS": {"COPY_NAMELIST_SERIAL": {"FILE": "jobscripts/copy_namelist.sh"}, "COPY_NAMELIST_MULTICORE": {"FILE": "jobscripts/copy_namelist.sh", "RUNNING": "once", "PROCESSORS": 2}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "", "PROJECT": "", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "CUSTOM_DIRECTIVES": "#SBATCH --partition=compute", "QUEUE": "p", "SERIAL_QUEUE": "s"}}, "EXPERIMENT": {"DATELIST": 20000101, "MEMBERS": "default", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard"}, "NAMELIST": {"MASTER": "icon_master.namelist", "EXP": "%DEFAULT.TEMPLATE%.nml"}, "DIRECTORIES": {"ICONDIR": "%HPCROOTDIR%/icon", "INDIR": "", "OUTDIR": ""}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "None", "PROJECT_DESTINATION": "auto-icon"}, "GIT": {"PROJECT_ORIGIN": "git@gitlab.dkrz.de:auto-icon/auto-icon.git", "PROJECT_BRANCH": "refactor-config-loading", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(4,'2023-04-28-15:58:42','2023-04-28-16:07:24',1682690322,1682690844,'month',1,0,2,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon", "ROOTDIR": "/home/dbeltran/new_autosubmit/a009", "DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon/config/common", "POST": "~/platforms.yml"}, "EXPID": "a009", "HPCARCH": "levante"}, "JOBS": {"COPY_NAMELIST_SERIAL": {"FILE": "jobscripts/copy_namelist.sh", "PROCESSORS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["jobscripts/namelist.tmpl"]}, "COPY_NAMELIST_MULTI": {"FILE": "jobscripts/copy_namelist.sh", "PROCESSORS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["jobscripts/namelist.tmpl"]}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "p", "PARTITION": "compute", "SERIAL_PLATFORM": "LEVANTE-SERIAL"}, "LEVANTE-SERIAL": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "", "PROJECT": "", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "s", "PARTITION": "shared"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "EXPERIMENT": {"DATELIST": 20000101, "MEMBERS": "default", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard"}, "NAMELIST": {"MASTER": "icon_master.namelist", "EXP": "%DEFAULT.TEMPLATE%.nml"}, "DIRECTORIES": {"ICONDIR": "%HPCROOTDIR%/icon", "INDIR": "", "OUTDIR": ""}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-icon"}, "GIT": {"PROJECT_ORIGIN": "git@gitlab.dkrz.de:auto-icon/auto-icon.git", "PROJECT_BRANCH": "refactor-config-loading", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(5,'2023-04-28-16:07:24','2023-04-28-16:08:27',1682690844,1682690907,'month',1,0,2,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon", "ROOTDIR": "/home/dbeltran/new_autosubmit/a009", "DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon/config/common", "POST": "~/platforms.yml"}, "EXPID": "a009", "HPCARCH": "levante"}, "JOBS": {"COPY_NAMELIST_SERIAL": {"FILE": "jobscripts/copy_namelist.sh", "PROCESSORS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["jobscripts/namelist.tmpl"]}, "COPY_NAMELIST_MULTI": {"FILE": "jobscripts/copy_namelist.sh", "PROCESSORS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["jobscripts/namelist.tmpl"]}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "p", "PARTITION": "compute", "SERIAL_PLATFORM": "LEVANTE-SERIAL"}, "LEVANTE-SERIAL": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "", "PROJECT": "", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "s", "PARTITION": "shared"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "EXPERIMENT": {"DATELIST": 20000101, "MEMBERS": "default", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard"}, "NAMELIST": {"MASTER": "icon_master.namelist", "EXP": "%DEFAULT.TEMPLATE%.nml"}, "DIRECTORIES": {"ICONDIR": "%HPCROOTDIR%/icon", "INDIR": "", "OUTDIR": ""}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-icon"}, "GIT": {"PROJECT_ORIGIN": "git@gitlab.dkrz.de:auto-icon/auto-icon.git", "PROJECT_BRANCH": "refactor-config-loading", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(6,'2023-04-28-16:08:27','2023-04-28-16:08:42',1682690907,1682690922,'month',1,0,2,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon", "ROOTDIR": "/home/dbeltran/new_autosubmit/a009", "DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon/config/common", "POST": "~/platforms.yml"}, "EXPID": "a009", "HPCARCH": "levante"}, "JOBS": {"COPY_NAMELIST_SERIAL": {"FILE": "jobscripts/copy_namelist.sh", "PROCESSORS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["jobscripts/namelist.tmpl"]}, "COPY_NAMELIST_MULTI": {"FILE": "jobscripts/copy_namelist.sh", "PROCESSORS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["jobscripts/namelist.tmpl"]}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "p", "PARTITION": "compute", "SERIAL_PLATFORM": "LEVANTE-SERIAL"}, "LEVANTE-SERIAL": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "", "PROJECT": "", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "s", "PARTITION": "shared"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "EXPERIMENT": {"DATELIST": 20000101, "MEMBERS": "default", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard"}, "NAMELIST": {"MASTER": "icon_master.namelist", "EXP": "%DEFAULT.TEMPLATE%.nml"}, "DIRECTORIES": {"ICONDIR": "%HPCROOTDIR%/icon", "INDIR": "", "OUTDIR": ""}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-icon"}, "GIT": {"PROJECT_ORIGIN": "git@gitlab.dkrz.de:auto-icon/auto-icon.git", "PROJECT_BRANCH": "refactor-config-loading", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(7,'2023-04-28-16:08:42','2023-05-05-13:44:20',1682690922,1683287060,'month',1,0,2,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon", "ROOTDIR": "/home/dbeltran/new_autosubmit/a009", "DEFAULT": {"CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon/config/common", "POST": "~/platforms.yml"}, "EXPID": "a009", "HPCARCH": "levante"}, "JOBS": {"COPY_NAMELIST_SERIAL": {"FILE": "jobscripts/copy_namelist.sh", "PROCESSORS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["jobscripts/namelist.tmpl"]}, "COPY_NAMELIST_MULTI": {"FILE": "jobscripts/copy_namelist.sh", "PROCESSORS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["jobscripts/namelist.tmpl"]}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "p", "PARTITION": "compute", "SERIAL_PLATFORM": "LEVANTE-SERIAL"}, "LEVANTE-SERIAL": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "", "PROJECT": "", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "s", "PARTITION": "shared"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "EXPERIMENT": {"DATELIST": 20000101, "MEMBERS": "default", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard"}, "NAMELIST": {"MASTER": "icon_master.namelist", "EXP": "%DEFAULT.TEMPLATE%.nml"}, "DIRECTORIES": {"ICONDIR": "%HPCROOTDIR%/icon", "INDIR": "", "OUTDIR": ""}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-icon"}, "GIT": {"PROJECT_ORIGIN": "git@gitlab.dkrz.de:auto-icon/auto-icon.git", "PROJECT_BRANCH": "refactor-config-loading", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(8,'2023-05-05-13:44:20','2023-05-05-13:45:50',1683287060,1683287150,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.76", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "DIRECTORIES": {"TEST_FILE": "from_main", "OUTDIR": "from_main", "ICONDIR": "%HPCROOTDIR%/icon", "INDIR": "my-updated-indir", "TESTDIR": "another-dir"}, "DEFAULT": {"EXPID": "a009", "HPCARCH": "levante"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-icon"}, "GIT": {"PROJECT_ORIGIN": "git@gitlab.dkrz.de:auto-icon/auto-icon.git", "PROJECT_BRANCH": "refactor-config-loading", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a009", "PROJDIR": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon", "JOBS": {"COPY_NAMELIST": {"FILE": "jobscripts/copy_namelist.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "p", "PARTITION": "compute", "SERIAL_PLATFORM": "LEVANTE-SERIAL"}, "LEVANTE-SERIAL": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "", "PROJECT": "", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "s", "PARTITION": "shared"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "EXPERIMENT": {"DATELIST": 20000101, "MEMBERS": "default", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard"}, "NAMELIST": {"MASTER": "icon_master.namelist", "EXP": "%DEFAULT.TEMPLATE%.nml"}, "TESTKEY": "abcd", "TESTKEY-TWO": "HPCARCH is levante", "TESTKEY-LEVANTE": "L-abcd", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon/config/include"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(9,'2023-05-05-13:45:50','2023-05-05-13:46:00',1683287150,1683287160,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.76", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "DIRECTORIES": {"TEST_FILE": "from_main", "OUTDIR": "from_main", "ICONDIR": "%HPCROOTDIR%/icon", "INDIR": "my-updated-indir", "TESTDIR": "another-dir"}, "DEFAULT": {"EXPID": "a009", "HPCARCH": "levante"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-icon"}, "GIT": {"PROJECT_ORIGIN": "git@gitlab.dkrz.de:auto-icon/auto-icon.git", "PROJECT_BRANCH": "refactor-config-loading", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a009", "PROJDIR": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon", "JOBS": {"COPY_NAMELIST": {"FILE": "jobscripts/copy_namelist.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "p", "PARTITION": "compute", "SERIAL_PLATFORM": "LEVANTE-SERIAL"}, "LEVANTE-SERIAL": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "", "PROJECT": "", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "s", "PARTITION": "shared"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "EXPERIMENT": {"DATELIST": 20000101, "MEMBERS": "default", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard"}, "NAMELIST": {"MASTER": "icon_master.namelist", "EXP": "%DEFAULT.TEMPLATE%.nml"}, "TESTKEY": "abcd", "TESTKEY-TWO": "HPCARCH is levante", "TESTKEY-LEVANTE": "L-abcd", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon/config/include"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(10,'2023-05-05-13:46:00','2023-05-05-13:46:03',1683287160,0,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.76", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "DIRECTORIES": {"TEST_FILE": "from_main", "OUTDIR": "from_main", "ICONDIR": "%HPCROOTDIR%/icon", "INDIR": "my-updated-indir", "TESTDIR": "another-dir"}, "DEFAULT": {"EXPID": "a009", "HPCARCH": "levante"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-icon"}, "GIT": {"PROJECT_ORIGIN": "git@gitlab.dkrz.de:auto-icon/auto-icon.git", "PROJECT_BRANCH": "refactor-config-loading", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a009", "PROJDIR": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon", "JOBS": {"COPY_NAMELIST": {"FILE": "jobscripts/copy_namelist.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "p", "PARTITION": "compute", "SERIAL_PLATFORM": "LEVANTE-SERIAL"}, "LEVANTE-SERIAL": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "", "PROJECT": "", "SCRATCH_DIR": "/work", "MAX_WALLCLOCK": "08:00", "PROCESSORS_PER_NODE": 128, "QUEUE": "s", "PARTITION": "shared"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "EXPERIMENT": {"DATELIST": 20000101, "MEMBERS": "default", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard"}, "NAMELIST": {"MASTER": "icon_master.namelist", "EXP": "%DEFAULT.TEMPLATE%.nml"}, "TESTKEY": "abcd", "TESTKEY-TWO": "HPCARCH is levante", "TESTKEY-LEVANTE": "L-abcd", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/new_autosubmit/a009/proj/auto-icon/config/include"}, "STORAGE": {}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',10);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
