PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-08-03-11:14:05','2023-09-06-12:08:16',1691054045,1693994896,'month',12,30,15285,0,0,0,0,0,'{"platforms": {"nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord4.bsc.es", "USER": "bsc32663", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "rmahmood", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32663", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32663", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "3:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "15", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "MONITOR": {"EXECUTABLE": "%PROJDIR%/es-esmvaltool/common-tools/auto-ecearth/nord3v2_launcher", "PROCESSORS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH --constraint=highmem\", \"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true", "SKIPPABLE": "TRUE"}, "CMORATM": {"QUEUE": "bsc_es", "CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "1:30", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "PERFORMANCE_METRICS": {"PROCESSORS": "1", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": "CLEAN", "FILE": "templates/performance_metrics.tmpl.sh", "CHECK": "true"}, "LOCAL_SETUP": {"NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "CHECK": "true", "FILE": "templates/localsetup.tmpl.sh"}, "CMOROCE": {"QUEUE": "bsc_es", "TASKS": "8", "CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:30", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "SYNCHRONIZE": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node", "DEPENDENCIES": "LOCAL_SETUP", "CHECK": "true", "FILE": "templates/synchronize.tmpl.sh"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node", "RUNNING": "member", "DEPENDENCIES": "CLEAN PERFORMANCE_METRICS SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "INI": {"NOTIFY_ON": "FAILED", "WALLCLOCK": "00:10", "QUEUE": "debug", "RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "FILE": "templates/ini.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "REMOTE_SETUP": {"PROCESSORS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "DEPENDENCIES": "SYNCHRONIZE", "FILE": "sources/runtime/autosubmit/compilation.sh", "CHECK": "true"}, "POST": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"NOTIFY_ON": "FAILED", "TASKS": "48", "PROCESSORS": "768", "WALLCLOCK": "2:00", "QUEUE": "bsc_es", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-15", "THREADS": "1", "FILE": "sources/runtime/autosubmit/ece-esm.sh", "CHECK": "on_submission"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a5ok", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a5ok", "PROJECT_BRANCH": "3.3.4", "PROJECT_SUBMODULES_DEPTH": "1000", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a5ok", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "git"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "30", "DATELIST": "19601101 19651101 19701101 19751101 19801101 19851101 19901101 19951101", "EXPID": "a5ok", "MEMBERS": "fc00 fc01 fc02 fc03 fc04 fc05 fc06 fc07 fc08 fc09", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a5ok", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a5ok", "RERUN": "FALSE"}, "local": {"EXPID": "a5ok", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": "rashed.mahmood@bsc.es"}, "config": {"EXPID": "a00z", "TOTALJOBS": "30", "MAXWAITINGJOBS": "30", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "FALSE", "LPJG_FIXLUAFTER": "-1", "LPJG_ini_member": "", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "-1", "LPJG_ini_date": "", "LPJG_ini": "", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "a2c0", "TM5": "FALSE", "TM5_ini_member": "fc0", "TM5_ISTART": "33", "TM5_NLEVS": "34", "TM5_EMISS_FIXYEAR": "0", "TM5_CONFIG": "tm5:chem,o3fb,ch4fb,aerfb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc00", "ATM_SH_LEVELS": "", "ATM_ini": "a2k7", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "FALSE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "TRUE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "0", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "FALSE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "FALSE", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a3t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc00 fc01 fc02 fc03 fc04 fc00 fc01 fc02 fc03 fc04", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "TRUE"}, "ice": {"ICE_ini": "a3t4", "ICE_ini_date": "", "ICE": "LIM3", "ICE_ini_member": "fc00 fc01 fc02 fc03 fc04 fc00 fc01 fc02 fc03 fc04"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "", "OASIS_nproc": "", "OASIS_ini_date": "", "OASIS_ini_member": ""}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "TRUE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "DCPP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-LR", "PRODUCTION_EXP": "TRUE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "TRUE", "LPJG_NUMPROC": "", "USE_MACHINEFILE": "FALSE", "ASSOCIATED_EXPERIMENT": "", "CMOR_ADD_STARTDATE_YEAR_ONLY": "TRUE", "IFS_NUMPROC": "574", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "", "TM5_NUMPROC_X": "", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "v3.3.4", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "1", "BSC_OUTCLASS": "dcpp", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "4", "CMOR_EXP": "dcppA-hindcast", "LUCIA": "0", "CMOR_ADD_STARTDATE": "TRUE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS SEAICE"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "", "PISCES_ini": "", "PISCES_OFF_DYN": "", "PISCES_ini_date": "", "PISCES": "FALSE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(2,'2023-09-06-12:08:16','2023-09-06-12:08:51',1693994896,1693994931,'month',1,0,364,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a09k/proj/git_project/conf/bootstrap/", "EXPID": "a09k", "HPCARCH": "MARENOSTRUM4"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 360}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "test/marenostrum4", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "MARENOSTRUM4-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "MARENOSTRUM4-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "MARENOSTRUM4", "RUNNING": "chunk", "WALLCLOCK": "04:00"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "00:30", "NODES": 240, "PARTITION": "small", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "bjimenez"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bjimenez", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 200, "PROCESSORS": 1600, "PROJECT": "dese28", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 8, "TEMP_DIR": "", "THREADS": 6, "TYPE": "slurm", "USER": "dese28535"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28535"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00z/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00z", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "intel", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "DE340_feature_historical", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(3,'2023-09-06-12:08:51','2023-09-06-12:10:44',1693994931,1693995044,'month',1,0,364,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a09k/proj/git_project/conf/bootstrap/", "EXPID": "a09k", "HPCARCH": "MARENOSTRUM4"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 360}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "test/marenostrum4", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "MARENOSTRUM4-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "MARENOSTRUM4-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "MARENOSTRUM4", "RUNNING": "chunk", "WALLCLOCK": "04:00"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "00:30", "NODES": 240, "PARTITION": "small", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "bjimenez"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bjimenez", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 200, "PROCESSORS": 1600, "PROJECT": "dese28", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 8, "TEMP_DIR": "", "THREADS": 6, "TYPE": "slurm", "USER": "dese28535"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28535"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00z/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00z", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "intel", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "DE340_feature_historical", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(4,'2023-09-06-12:10:44','2023-09-06-12:11:12',1693995044,1693995072,'month',1,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a09k/proj/git_project/conf/bootstrap/", "EXPID": "a09k", "HPCARCH": "MARENOSTRUM4"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 1}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "test/marenostrum4", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "MARENOSTRUM4-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "MARENOSTRUM4-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "MARENOSTRUM4", "RUNNING": "chunk", "WALLCLOCK": "04:00"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "00:30", "NODES": 240, "PARTITION": "small", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "bjimenez"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bjimenez", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 200, "PROCESSORS": 1600, "PROJECT": "dese28", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 8, "TEMP_DIR": "", "THREADS": 6, "TYPE": "slurm", "USER": "dese28535"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28535"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00z/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00z", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "intel", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "DE340_feature_historical", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(5,'2023-09-06-12:11:12','2023-09-06-12:12:00',1693995072,1693995120,'month',1,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a09k/proj/git_project/conf/bootstrap/", "EXPID": "a09k", "HPCARCH": "MARENOSTRUM4"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 2}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "test/marenostrum4", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "MARENOSTRUM4-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "MARENOSTRUM4-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "MARENOSTRUM4", "RUNNING": "chunk", "WALLCLOCK": "04:00"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "00:30", "NODES": 240, "PARTITION": "small", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "bjimenez"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bjimenez", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 200, "PROCESSORS": 1600, "PROJECT": "dese28", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 8, "TEMP_DIR": "", "THREADS": 6, "TYPE": "slurm", "USER": "dese28535"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28535"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00z/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00z", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "intel", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "DE340_feature_historical", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(6,'2023-09-06-12:12:00','2023-09-06-12:12:11',1693995120,1693995131,'month',1,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a09k/proj/git_project/conf/bootstrap/", "EXPID": "a09k", "HPCARCH": "MARENOSTRUM4"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 2}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "test/marenostrum4", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "MARENOSTRUM4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "MARENOSTRUM4-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/local_setup.sh", "PLATFORM": "MARENOSTRUM4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "ADDITIONAL_FILES": []}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "00:30", "NODES": 240, "PARTITION": "small", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "bjimenez"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bjimenez", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 200, "PROCESSORS": 1600, "PROJECT": "dese28", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 8, "TEMP_DIR": "", "THREADS": 6, "TYPE": "slurm", "USER": "dese28535"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28535"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00z/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00z", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "intel", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "DE340_feature_historical", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(7,'2023-09-06-12:12:11','2023-09-06-12:12:11',1693995131,0,'month',1,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9o", "GTYPE": "tco", "IO_NODES": 40, "LABEL": "LWDA", "LEVELS": 137, "RESOL": 1279}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a09k/proj/git_project/conf/bootstrap/", "EXPID": "a09k", "HPCARCH": "MARENOSTRUM4"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 1990010100, "MEMBERS": "fc0", "NUMCHUNKS": 2}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "test/marenostrum4", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "MARENOSTRUM4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "MARENOSTRUM4-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/local_setup.sh", "PLATFORM": "MARENOSTRUM4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "ADDITIONAL_FILES": []}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<PROJECT>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<PROJECT>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "00:30", "NODES": 240, "PARTITION": "small", "PROCESSORS": 3840, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "bjimenez"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bjimenez", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 200, "PROCESSORS": 1600, "PROJECT": "dese28", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 8, "TEMP_DIR": "", "THREADS": 6, "TYPE": "slurm", "USER": "dese28535"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28535"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00z/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00z", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "intel", "GRID_ATM": "tco1279l137", "GRID_OCEAN": "eORCA12_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "DE340_feature_historical", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',7);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
