CREATE VIEW ofb_43 AS
SELECT   
  expver                   as expver                ,    
  class                    as class                 ,    
  stream                   as stream                ,    
  type                     as type                  ,    
  andate                   as andate                ,    
  antime                   as antime                ,    
  reportype                as reportype             ,    
  restricted                                        ,

  mxup_traj                                         ,
  numtsl                                            , 

  timeslot@timeslot_index                           ,

  seqno                                             ,
  bufrtype                                          ,
  subtype                                           ,
  groupid                                           ,
  obstype                                           ,
  codetype                                          ,
  sensor                                            ,
  date                                              ,
  time                                              ,
  rdbdate                                           ,
  rdbtime                                           ,
  report_status                                     ,    
  report_event1                                     ,    
  degrees(lat)             as lat@hdr               ,    
  degrees(lon)             as lon@hdr               ,    

  distribtype                                    ,
  distribid                                         ,
  gp_dist                                           ,
  gp_number                                         ,

  satellite_identifier                              ,
  satellite_instrument@sat                          ,

  lsm                                            ,
  orography                                      ,
  windspeed10m                                   ,
  tsfc                                           ,
  albedo                                         ,
  seaice                                         ,
  snow_depth                                     ,
  t2m                                            ,
  u10m                                           ,
  v10m                                           ,
  
  
  fg_rain_rate                                      ,
  fg_snow_rate                                      ,
  fg_tcwv                                           ,
  fg_cwp                                            ,
  fg_iwp                                            ,
  fg_rwp                                            ,
  fg_swp                                            ,
  fg_rttov_cld_fraction                             ,
  fg_theta700,
 fg_thetasfc,
 fg_uth,
  an_rain_rate                                      ,
  an_snow_rate                                      ,
  an_tcwv                                           ,
  an_cwp                                            ,
  an_iwp                                            ,
  an_rwp                                            ,
  an_swp                                            ,
  an_rttov_cld_fraction                             ,
  an_theta700,
 an_thetasfc,
 an_uth,
  gnorm_10mwind                                     ,
  gnorm_skintemp                                    ,
  gnorm_temp                                        ,
  gnorm_q                                           ,
  gnorm_rainflux                                    ,
  gnorm_snowflux                                    ,
  gnorm_clw                                         ,
  gnorm_ciw                                         ,
  gnorm_cc                                          ,
  ob_p19                                            ,
  fg_p19                                            ,
  an_p19                                            ,
  ob_p37                                            ,
  fg_p37                                            ,
  an_p37                                            ,
  report_tbcloud                                    ,
  zenith                                         ,
  zenith_by_channel@radiance_body                ,
  azimuth                                        ,
  scanline,
  scanpos,

  datum_tbflag                                      ,
  tbclear                                           ,

  entryno                                           ,
  obsvalue                                          ,
  varno                                             ,
  vertco_type                                       ,
  vertco_reference_1                                ,
  datum_status                                      ,    
  datum_event1                                      ,    
  datum_anflag                                      ,
  biascorr                                          ,
  biascorr_fg                                       ,
  qc_pge                                            ,
  an_depar                                          ,
  fg_depar                                          ,
  datum_status_hires@update_1                        ,

  final_obs_error                                   ,
  obs_error                                         ,
  fg_error                                          ,
  eda_spread,
  emis_rtin                                ,
  emis_fg                                  ,
  emis_retr                                ,
  emis_atlas                               ,
  tausfc                                   ,

  hires@update_1           ,
  lores@update_1           ,
  hires@update_2           ,
  lores@update_2           ,
  hires@update_3           ,
  lores@update_3           ,

  skintemp_1                                   ,
  skintemp_2                                   ,
  skintemp_3                                   ,
  skintemp_4                                   ,
  skintemper                                   ,

  vertco_reference_2, 
  an_sens_obs, 
  report_rdbflag, 
  fc_sens_obs, 
  datum_rdbflag, 
FROM desc, timeslot_index, index, hdr, sat, radiance, radiance_body, modsurf, allsky, allsky_body, body, errstat, update_1, update_2, update_3
WHERE reportype is not null
AND groupid=43;
