PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-10-17-11:43:30','2023-10-17-11:48:28',1697535810,1697536108,'day',1,0,4425,0,0,0,0,0,'{"platforms": {"marenostrum4": {"MAX_WALLCLOCK": "72:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "cns44", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn3.bsc.es", "TEST_SUITE": "False", "USER": "cns44501", "MAX_PROCESSORS": "9600", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "marenostrum_archive": {"PROJECT": "cns44", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt02.bsc.es,dt01.bsc.es", "TEST_SUITE": "False", "USER": "cns44501", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "False"}}, "jobs": {"LOCAL_SEND_INITIAL_DA": {"NOTIFY_ON": "FAILED", "SYNCHRONIZE": "member", "DELAY": "0", "PLATFORM": "marenostrum_archive", "RUNNING": "chunk", "DEPENDENCIES": "LOCAL_SEND_INITIAL_DA-10", "FILE": "templates/00b_local_send_initial_DA.sh"}, "LOCAL_SEND_SPINUP": {"NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum_archive", "RUNNING": "member", "FILE": "templates/00d_local_send_spinup.sh"}, "REDUCE": {"PROCESSORS": "4", "MAX_WRAPPED": "12", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM DA", "FILE": "templates/07_reduce.sh"}, "LOCAL_SEND_STATIC": {"NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum_archive", "RUNNING": "once", "FILE": "templates/01b_local_send_static.sh"}, "DA": {"NOTIFY_ON": "FAILED", "PROCESSORS": "576", "WALLCLOCK": "00:40", "DELAY": "0", "SYNCHRONIZE": "member", "RUNNING": "chunk", "DEPENDENCIES": "SIM LOCAL_SEND_INITIAL_DA", "FILE": "templates/05c_da.sh"}, "CALCSTATS": {"PROCESSORS": "48", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "SYNCHRONIZE": "member", "RUNNING": "chunk", "DEPENDENCIES": "REDUCE", "FILE": "templates/07b_calc_stats_split.sh", "SPLITS": "10"}, "REMOTE_COMPILE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "RUNNING": "once", "DEPENDENCIES": "LOCAL_SEND_SOURCE", "FILE": "templates/02_compile.sh"}, "LOCAL_SEND_SOURCE": {"NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum_archive", "RUNNING": "once", "FILE": "templates/01_local_send_source.sh"}, "ARCHIVE_REDUCE": {"SYNCHRONIZE": "member", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum_archive", "RUNNING": "chunk", "DEPENDENCIES": "CALCSTATS", "FILE": "templates/06c_archive_reduce.sh"}, "ARCHIVE": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum_archive", "RUNNING": "chunk", "DEPENDENCIES": "REDUCE ARCHIVE-1", "FILE": "templates/06_archive.sh"}, "SIM": {"PROCESSORS": "768", "WALLCLOCK": "00:40", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "LOCAL_SEND_SPINUP LOCAL_SEND_STATIC REMOTE_COMPILE SIM-1 DA-1", "FILE": "templates/05b_sim.sh"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01t", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01t", "PROJECT_BRANCH": "399-dust-reanalysis-aemet", "PROJECT_COMMIT": "3e76156e5defdf9950d6ff510411d358669f15e3", "PROJECT_SUBMODULES": "sources/nmmb-monarch sources/MONARCH_Reduce sources/monarch-DA", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-monarch.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01t", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": "1", "CHUNKINI": "1", "NUMCHUNKS": "90", "DATELIST": "20180101", "EXPID": "a01t", "MEMBERS": "000 001 002 003 004 005 006 007 008 009 010 011", "CALENDAR": "standard", "TWO_STEP_START": "a60c_LOCAL_SEND_SOURCE,a60c_LOCAL_SEND_STATIC,a60c_REMOTE_COMPILE&LOCAL_SEND_SPINUP,LOCAL_SEND_INITIAL_DA"}, "project_files": {"EXPID": "a01t", "HPCARCH": "marenostrum4", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "templates/conf/proj_dustclim.conf"}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01t", "RERUN": "FALSE"}, "local": {"EXPID": "a01t", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"migrate": {"TO_USER": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "wrapper": {"JOBS_IN_WRAPPER": "SIM&DA", "TYPE": "horizontal-vertical", "MACHINEFILES": "STANDARD", "RETRIALS": "3", "MAX_WRAPPED_H": "12", "CHECK_TIME_WRAPPER": "60", "MIN_WRAPPED_V": "10"}, "communications": {"API": "paramiko"}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01t", "TOTALJOBS": "100", "MAXWAITINGJOBS": "100", "RETRIALS": "3", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}}, "proj": {"monarch": {"NCEP_PROC": ".false.", "SPINUP": "0", "CENLON": "20.0 45.0 46.4", "USE_DT_COMMANDS": "TRUE", "INPES": "20", "nradsnps": "180 180 540", "BOCO": "6", "LOCSIG_VER": "1.0", "AGE_FOLDER_HPC": "", "NCEP_PROC_GRIB2": ".true.", "MOZART_FOLDER_HPC": "/gpfs/scratch/bsc32/bsc32771/tmp/PREPARE_REGIONAL_RUNS/DATA_required/BC-MOZART", "HERMES_ANTHRO_RES": "''hourly''", "BCL_MP_C": "50.            # tuning factor for coarse dust below cloud scavenging (grid scale clouds)", "BCL_MP_F": "100.            # tuning factor for fine dust below cloud scavenging (grid scale clouds)", "TPH0D": "35.0", "NCEPLIBS_CONFIG": "5", "NPATCH": "30", "MIN_SLOT": "-7", "MOZART_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ucar/mozart/original_files", "ERA5_FOLDER_HPC": "", "VERSION_PREPROC": "1", "FNL_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ncep/ds083.2/original_files", "MERRA2_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/nasa/merra_v2/original_files/i584", "CONSTANT_REPO_FOLDER_NPS": "/gpfs/archive/bsc32/esarchive/exp/monarch/static_v2.0", "REDUCE_OUTPUT_DIRECTORY": "/gpfs/projects/cns44/cns44702", "DCAL": "2.65 0.61 0.004 2.65 0.61 0.004 3.4 0.70 0.004 3.4 0.70 0.004", "WRTSK": "8", "INIT_CHEM": "0                 # 0. IC from ideal conditions", "DMASK": "1                # 0 Standard desert mask based on monthly vegetation fraction (Perez et al. 2011)", "INFLATION": "0.0", "dt_num": "0 0 2", "NDUST": "8                   # 0 (No dust) or 8", "FCST": "false", "ERA_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ecmwf/erainterim-monarch/original_files", "LNSH": "1", "BCL_BMJ_C": "50.           # tuning factor for coarse dust below cloud scavenging (convective clouds)", "STATIC_HPC_FOLDER_NPS": "/gpfs/projects/bsc32/models/monarch/data/static_v2.0", "ARCHIVE_ROOT_FOLDER": "/gpfs/archive/bsc32/esarchive/exp", "HERMES_AUXFILES": "/gpfs/projects/bsc32/models/hermesv3", "LOCSIG_HOR": "15.0", "LNSV": "1", "DRAG_PART": "3            # 0 no drag partition scheme in the emission", "NHOURS": "24", "spectral": ".false.", "NRADS": "180", "DT_INT": "20", "HIST": "3", "VEGF_UNI": "1             # 0 Use default USGS climatological vegetation for meteorology and land-surface while using vegetation from DMASK/DRAG_PART for dust", "NRADL": "180", "VSED7": "0.2               # correction factor of sedimentation velocity for bin 7 to correct for diffusive scheme", "VSED6": "0.3               # correction factor of sedimentation velocity for bin 6 to correct for diffusive scheme", "VSED5": "0.5               # correction factor of sedimentation velocity for bin 5 to correct for diffusive scheme", "BCL_BMJ_F": "100.           # tuning factor for fine dust below cloud scavenging (convective clouds)", "dt_int": "20 20 6", "BCL_BMJ_M": "100.           # tuning factor for medium dust below cloud scavenging (convective clouds)", "XMLC": "1                 # flag for multiple call (mlcari in configfile)", "VSED8": "0.1               # correction factor of sedimentation velocity for bin 8 to correct for diffusive scheme", "VEG_COR_01": "0           # use vegetation correction for momentum flux distribution, yes(1)/no(0); only for DUSCHEME=7", "AGE_FOLDER_ARCHIVE": "", "jnpesnps": "38 32 32", "ERA_FOLDER_HPC": "/gpfs/projects/bsc32/models/monarch/data/initial/era-interim", "DUSCHEME": "0 1 3 0 1 3 0 1 3 0 1 3", "XMDL": "3                 # flag for ARI module (mdlari in configfile)", "HERMES_DATA_ANTHRO": "/gpfs/projects/bsc32/models/hermesv3/data", "NHOURS_INIT": "24", "nproc_geogrid": "8", "FNL_FOLDER_HPC": "", "GFS_DEGREE_RES": "0p50", "direct_temp": ".true.", "PTOP": "5000.", "TYPE_GFSINIT": "ERA ERA ERA ERA ERA ERA FNL FNL FNL FNL FNL FNL", "DCALBIN2": "1.098947 0.998531 1.074797 1.472015 0.850205 1.430319 1.299753 0.828486 1.002254 1.524329 0.830391 0.479323", "DA_NSLOTS": "8", "GFAS_FOLDER_HPC": "", "GFS_FOLDER_HPC": "", "JUST_LAST": ".false.", "MOIST_COR_01": "0         # use moisture correction for cohesive force distribution, yes(1)/no(0); only for DUSCHEME=7", "LEVELS": "", "dustclimset": "dustclim_min", "DATAMEGAN": "/gpfs/projects/bsc32/models/monarch/data/static/emissions/DATA_megan_v2.04", "CATAERO": "2                 # 2 output dod (all sky and clear sky) (only 2 works)", "CONSTANT_REPO_FOLDER": "/gpfs/archive/bsc32/esarchive/exp/monarch/static", "CASE": "regional", "DCALBIN8": "0.548321 1.006390 0.886486 1.102514 1.394948 1.286722 1.174099 1.009974 0.945916 0.930637 1.395042 1.018455", "HOUR": "00", "SPINUP_FOLDER": "/gpfs/archive/bsc32/esarchive/exp/monarch/a60c/original_files/", "DCALBIN1": "1.106343 1.000612 1.082477 1.475536 0.843028 1.423721 1.309229 0.811747 0.995270 1.524607 0.823556 0.475334", "DCALBIN3": "1.097245 0.987129 1.093450 1.487424 0.828624 1.437714 1.325002 0.839012 1.009480 1.547502 0.882344 0.468367", "INTERP2": "1 0 0", "DCALBIN5": "1.116009 0.935082 1.101794 1.365402 0.785977 1.493562 1.390100 0.629129 1.101997 1.638613 0.739484 0.426551", "DCALBIN4": "1.165611 0.948493 1.082074 1.426227 0.866220 1.381353 1.371184 0.793838 1.048545 1.510950 0.816682 0.387790", "DCALBIN7": "1.126951 0.882573 1.407303 0.662187 0.865147 0.802836 1.357229 1.397023 0.811385 0.815051 1.133981 1.124143", "DCALBIN6": "1.080891 0.776795 1.287324 1.364965 0.912424 1.331407 1.327775 0.962559 0.923016 1.219089 0.897321 0.764757", "NX": "1021 341 201", "NY": "701 351 201", "NZ": "40", "CAMS_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/scratch/ojorba/tmp/transfer-prace/BC-CAMS", "STATIC_HPC_FOLDER": "/gpfs/projects/bsc32/models/monarch/data/static", "COUPLE_DUST_INIT": "1", "JNPES": "38", "dt_den": "1 1 3", "TYPE_BCCHEM": "", "nproc_ungrib": "1", "SRC": "3                  # 0 Old topographic source from Ginoux et al. (2001) derived at 0.25 degrees (DUSCHEME=0,1,2,3)", "ARE_FOLDER_ARCHIVE": "", "ICL_MP": "1.              # tuning factor for dust incloud scavenging (grid scale clouds)", "SRC_GRIB": "ERA ERA ERA ERA ERA ERA MERRA2_ERA5soil MERRA2_ERA5soil MERRA2_ERA5soil MERRA2_ERA5soil MERRA2_ERA5soil MERRA2_ERA5soil", "DO_CLOUDS": ".false. #.false.", "MAX_SLOT": "0", "DO_PARTMC": "0", "BC_INTERVAL": "21600", "NPROC_LON": "24", "REMOVE_ORIGINAL_FILES": "1", "nproc_nemsinterp": "8", "PTOP_NPS": "5000.", "SZDSTR": "1               # 0 Emitted size distribution from D''Almeida", "BCL_MP_M": "100.            # tuning factor for medium dust below cloud scavenging (grid scale clouds)", "GFAS_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ecmwf/gfas/daily_mean/multivar/", "SBD": "-35.0", "DA_FOLDER_HPC": "/gpfs/scratch/bsc32/bsc32137/PREOBS_2023/obs_deepblue6p1_coarse_dod_balance_05_flatter/", "ICL_BMJ": "4.             # tuning factor for dust incloud scavenging (convective clouds)", "DA_IOSTEP": "3", "VCOORD_OPT": "1", "MAXILEVE": "38", "DO_GWD": ".false. .false. .false.", "CENLAT": "35.0 27.5 29.3", "INTERP": "0 0 0", "WBD": "-51.0", "DPHD": "0.1", "DX": "0.1", "DY": "0.1", "ERA5_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ecmwf/era5/original_files", "XKOK": "0                 # flag for shape (only for XTBL=1 or XTBL=2)", "wtpgnps": "8 8 8", "ARE_FOLDER_HPC": "", "DA_FOLDER_ARCHIVE": "", "LM": "40", "nproc_metgrid": "8", "FECAN": "1.75             # Fecan coefficient", "TLM0D": "20.0", "MODE": "DUST_DA_NPS", "COUPLE_DUST": "1", "CHEMIC": "", "PERTURB_USTH": "0.839108 1.064186 0.994903 1.128865 0.939841 1.077895 0.978513 0.904003 1.119007 0.907066 1.133456 0.838777", "SPINUP_SAVE_FREQ": "30", "NEST1RATIO": "1 3 3", "XTBL": "2                 # flag for optical table (tblari in configfile)", "inpesnps": "20 16 31", "USE_IGBP": "0", "NPROC_LAT": "24", "VSLAYER": "0              # 0 NMMB default with viscous sublayer", "NPS_CONFIG": "18", "LOCSIG_TEMP": "7.0", "IFSFCST_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/exp/ecmwf/ifs/original_files", "IFSFCST_FOLDER_HPC": "", "NCHEM": "", "VDRY": "0.5                # tuning factor for dry deposition velocity (excluding gravitational settling", "PREVAR_FOLDER_HPC": "/gpfs/projects/cns44/cns44702/BDRCre-preproc/", "REDUCE_CSV_FILE": "monarch_reduce_DUST_DA_dustclim_min.csv", "GFS_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ncep/gfs/original_files", "NUM_DOMAINS": "1", "PTSGM": "30000.", "DLMD": "0.1", "MERRA2_FOLDER_HPC": "", "QC": "1.4", "moving_nests": ".false.", "GLOBAL_NPS": "0", "CAMS_FOLDER_HPC": "/gpfs/scratch/bsc32/bsc32771/tmp/PREPARE_REGIONAL_RUNS/DATA_required/BC-CAMS", "SEDIM_TYPE": "1            # sedimentation scheme (0-implicit,1 explicit) both upwind (pretty diffusive)"}}}');
INSERT INTO experiment_run VALUES(2,'2023-10-17-11:48:28','2023-10-17-11:48:28',1697536108,0,'day',1,0,4425,0,0,0,0,0,'{"platforms": {"marenostrum4": {"MAX_WALLCLOCK": "72:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "cns44", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn3.bsc.es", "TEST_SUITE": "False", "USER": "cns44501", "MAX_PROCESSORS": "9600", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "marenostrum_archive": {"PROJECT": "cns44", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt02.bsc.es,dt01.bsc.es", "TEST_SUITE": "False", "USER": "cns44501", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "False"}}, "jobs": {"LOCAL_SEND_INITIAL_DA": {"NOTIFY_ON": "FAILED", "SYNCHRONIZE": "member", "DELAY": "0", "PLATFORM": "marenostrum_archive", "RUNNING": "chunk", "DEPENDENCIES": "LOCAL_SEND_INITIAL_DA-10", "FILE": "templates/00b_local_send_initial_DA.sh"}, "LOCAL_SEND_SPINUP": {"NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum_archive", "RUNNING": "member", "FILE": "templates/00d_local_send_spinup.sh"}, "REDUCE": {"PROCESSORS": "4", "MAX_WRAPPED": "12", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM DA", "FILE": "templates/07_reduce.sh"}, "LOCAL_SEND_STATIC": {"NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum_archive", "RUNNING": "once", "FILE": "templates/01b_local_send_static.sh"}, "DA": {"NOTIFY_ON": "FAILED", "PROCESSORS": "576", "WALLCLOCK": "00:40", "DELAY": "0", "SYNCHRONIZE": "member", "RUNNING": "chunk", "DEPENDENCIES": "SIM LOCAL_SEND_INITIAL_DA", "FILE": "templates/05c_da.sh"}, "CALCSTATS": {"PROCESSORS": "48", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "SYNCHRONIZE": "member", "RUNNING": "chunk", "DEPENDENCIES": "REDUCE", "FILE": "templates/07b_calc_stats_split.sh", "SPLITS": "10"}, "REMOTE_COMPILE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "RUNNING": "once", "DEPENDENCIES": "LOCAL_SEND_SOURCE", "FILE": "templates/02_compile.sh"}, "LOCAL_SEND_SOURCE": {"NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum_archive", "RUNNING": "once", "FILE": "templates/01_local_send_source.sh"}, "ARCHIVE_REDUCE": {"SYNCHRONIZE": "member", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum_archive", "RUNNING": "chunk", "DEPENDENCIES": "CALCSTATS", "FILE": "templates/06c_archive_reduce.sh"}, "ARCHIVE": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum_archive", "RUNNING": "chunk", "DEPENDENCIES": "REDUCE ARCHIVE-1", "FILE": "templates/06_archive.sh"}, "SIM": {"PROCESSORS": "768", "WALLCLOCK": "00:40", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "LOCAL_SEND_SPINUP LOCAL_SEND_STATIC REMOTE_COMPILE SIM-1 DA-1", "FILE": "templates/05b_sim.sh"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01t", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01t", "PROJECT_BRANCH": "399-dust-reanalysis-aemet", "PROJECT_COMMIT": "3e76156e5defdf9950d6ff510411d358669f15e3", "PROJECT_SUBMODULES": "sources/nmmb-monarch sources/MONARCH_Reduce sources/monarch-DA", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-monarch.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01t", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": "1", "CHUNKINI": "1", "NUMCHUNKS": "90", "DATELIST": "20180101", "EXPID": "a01t", "MEMBERS": "000 001 002 003 004 005 006 007 008 009 010 011", "CALENDAR": "standard", "TWO_STEP_START": "a60c_LOCAL_SEND_SOURCE,a60c_LOCAL_SEND_STATIC,a60c_REMOTE_COMPILE&LOCAL_SEND_SPINUP,LOCAL_SEND_INITIAL_DA"}, "project_files": {"EXPID": "a01t", "HPCARCH": "marenostrum4", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "templates/conf/proj_dustclim.conf"}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01t", "RERUN": "FALSE"}, "local": {"EXPID": "a01t", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"migrate": {"TO_USER": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "wrapper": {"JOBS_IN_WRAPPER": "SIM&DA", "TYPE": "horizontal-vertical", "MACHINEFILES": "STANDARD", "RETRIALS": "3", "MAX_WRAPPED_H": "12", "CHECK_TIME_WRAPPER": "60", "MIN_WRAPPED_V": "10"}, "communications": {"API": "paramiko"}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01t", "TOTALJOBS": "100", "MAXWAITINGJOBS": "100", "RETRIALS": "3", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}}, "proj": {"monarch": {"NCEP_PROC": ".false.", "SPINUP": "0", "CENLON": "20.0 45.0 46.4", "USE_DT_COMMANDS": "TRUE", "INPES": "20", "nradsnps": "180 180 540", "BOCO": "6", "LOCSIG_VER": "1.0", "AGE_FOLDER_HPC": "", "NCEP_PROC_GRIB2": ".true.", "MOZART_FOLDER_HPC": "/gpfs/scratch/bsc32/bsc32771/tmp/PREPARE_REGIONAL_RUNS/DATA_required/BC-MOZART", "HERMES_ANTHRO_RES": "''hourly''", "BCL_MP_C": "50.            # tuning factor for coarse dust below cloud scavenging (grid scale clouds)", "BCL_MP_F": "100.            # tuning factor for fine dust below cloud scavenging (grid scale clouds)", "TPH0D": "35.0", "NCEPLIBS_CONFIG": "5", "NPATCH": "30", "MIN_SLOT": "-7", "MOZART_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ucar/mozart/original_files", "ERA5_FOLDER_HPC": "", "VERSION_PREPROC": "1", "FNL_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ncep/ds083.2/original_files", "MERRA2_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/nasa/merra_v2/original_files/i584", "CONSTANT_REPO_FOLDER_NPS": "/gpfs/archive/bsc32/esarchive/exp/monarch/static_v2.0", "REDUCE_OUTPUT_DIRECTORY": "/gpfs/projects/cns44/cns44702", "DCAL": "2.65 0.61 0.004 2.65 0.61 0.004 3.4 0.70 0.004 3.4 0.70 0.004", "WRTSK": "8", "INIT_CHEM": "0                 # 0. IC from ideal conditions", "DMASK": "1                # 0 Standard desert mask based on monthly vegetation fraction (Perez et al. 2011)", "INFLATION": "0.0", "dt_num": "0 0 2", "NDUST": "8                   # 0 (No dust) or 8", "FCST": "false", "ERA_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ecmwf/erainterim-monarch/original_files", "LNSH": "1", "BCL_BMJ_C": "50.           # tuning factor for coarse dust below cloud scavenging (convective clouds)", "STATIC_HPC_FOLDER_NPS": "/gpfs/projects/bsc32/models/monarch/data/static_v2.0", "ARCHIVE_ROOT_FOLDER": "/gpfs/archive/bsc32/esarchive/exp", "HERMES_AUXFILES": "/gpfs/projects/bsc32/models/hermesv3", "LOCSIG_HOR": "15.0", "LNSV": "1", "DRAG_PART": "3            # 0 no drag partition scheme in the emission", "NHOURS": "24", "spectral": ".false.", "NRADS": "180", "DT_INT": "20", "HIST": "3", "VEGF_UNI": "1             # 0 Use default USGS climatological vegetation for meteorology and land-surface while using vegetation from DMASK/DRAG_PART for dust", "NRADL": "180", "VSED7": "0.2               # correction factor of sedimentation velocity for bin 7 to correct for diffusive scheme", "VSED6": "0.3               # correction factor of sedimentation velocity for bin 6 to correct for diffusive scheme", "VSED5": "0.5               # correction factor of sedimentation velocity for bin 5 to correct for diffusive scheme", "BCL_BMJ_F": "100.           # tuning factor for fine dust below cloud scavenging (convective clouds)", "dt_int": "20 20 6", "BCL_BMJ_M": "100.           # tuning factor for medium dust below cloud scavenging (convective clouds)", "XMLC": "1                 # flag for multiple call (mlcari in configfile)", "VSED8": "0.1               # correction factor of sedimentation velocity for bin 8 to correct for diffusive scheme", "VEG_COR_01": "0           # use vegetation correction for momentum flux distribution, yes(1)/no(0); only for DUSCHEME=7", "AGE_FOLDER_ARCHIVE": "", "jnpesnps": "38 32 32", "ERA_FOLDER_HPC": "/gpfs/projects/bsc32/models/monarch/data/initial/era-interim", "DUSCHEME": "0 1 3 0 1 3 0 1 3 0 1 3", "XMDL": "3                 # flag for ARI module (mdlari in configfile)", "HERMES_DATA_ANTHRO": "/gpfs/projects/bsc32/models/hermesv3/data", "NHOURS_INIT": "24", "nproc_geogrid": "8", "FNL_FOLDER_HPC": "", "GFS_DEGREE_RES": "0p50", "direct_temp": ".true.", "PTOP": "5000.", "TYPE_GFSINIT": "ERA ERA ERA ERA ERA ERA FNL FNL FNL FNL FNL FNL", "DCALBIN2": "1.098947 0.998531 1.074797 1.472015 0.850205 1.430319 1.299753 0.828486 1.002254 1.524329 0.830391 0.479323", "DA_NSLOTS": "8", "GFAS_FOLDER_HPC": "", "GFS_FOLDER_HPC": "", "JUST_LAST": ".false.", "MOIST_COR_01": "0         # use moisture correction for cohesive force distribution, yes(1)/no(0); only for DUSCHEME=7", "LEVELS": "", "dustclimset": "dustclim_min", "DATAMEGAN": "/gpfs/projects/bsc32/models/monarch/data/static/emissions/DATA_megan_v2.04", "CATAERO": "2                 # 2 output dod (all sky and clear sky) (only 2 works)", "CONSTANT_REPO_FOLDER": "/gpfs/archive/bsc32/esarchive/exp/monarch/static", "CASE": "regional", "DCALBIN8": "0.548321 1.006390 0.886486 1.102514 1.394948 1.286722 1.174099 1.009974 0.945916 0.930637 1.395042 1.018455", "HOUR": "00", "SPINUP_FOLDER": "/gpfs/archive/bsc32/esarchive/exp/monarch/a60c/original_files/", "DCALBIN1": "1.106343 1.000612 1.082477 1.475536 0.843028 1.423721 1.309229 0.811747 0.995270 1.524607 0.823556 0.475334", "DCALBIN3": "1.097245 0.987129 1.093450 1.487424 0.828624 1.437714 1.325002 0.839012 1.009480 1.547502 0.882344 0.468367", "INTERP2": "1 0 0", "DCALBIN5": "1.116009 0.935082 1.101794 1.365402 0.785977 1.493562 1.390100 0.629129 1.101997 1.638613 0.739484 0.426551", "DCALBIN4": "1.165611 0.948493 1.082074 1.426227 0.866220 1.381353 1.371184 0.793838 1.048545 1.510950 0.816682 0.387790", "DCALBIN7": "1.126951 0.882573 1.407303 0.662187 0.865147 0.802836 1.357229 1.397023 0.811385 0.815051 1.133981 1.124143", "DCALBIN6": "1.080891 0.776795 1.287324 1.364965 0.912424 1.331407 1.327775 0.962559 0.923016 1.219089 0.897321 0.764757", "NX": "1021 341 201", "NY": "701 351 201", "NZ": "40", "CAMS_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/scratch/ojorba/tmp/transfer-prace/BC-CAMS", "STATIC_HPC_FOLDER": "/gpfs/projects/bsc32/models/monarch/data/static", "COUPLE_DUST_INIT": "1", "JNPES": "38", "dt_den": "1 1 3", "TYPE_BCCHEM": "", "nproc_ungrib": "1", "SRC": "3                  # 0 Old topographic source from Ginoux et al. (2001) derived at 0.25 degrees (DUSCHEME=0,1,2,3)", "ARE_FOLDER_ARCHIVE": "", "ICL_MP": "1.              # tuning factor for dust incloud scavenging (grid scale clouds)", "SRC_GRIB": "ERA ERA ERA ERA ERA ERA MERRA2_ERA5soil MERRA2_ERA5soil MERRA2_ERA5soil MERRA2_ERA5soil MERRA2_ERA5soil MERRA2_ERA5soil", "DO_CLOUDS": ".false. #.false.", "MAX_SLOT": "0", "DO_PARTMC": "0", "BC_INTERVAL": "21600", "NPROC_LON": "24", "REMOVE_ORIGINAL_FILES": "1", "nproc_nemsinterp": "8", "PTOP_NPS": "5000.", "SZDSTR": "1               # 0 Emitted size distribution from D''Almeida", "BCL_MP_M": "100.            # tuning factor for medium dust below cloud scavenging (grid scale clouds)", "GFAS_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ecmwf/gfas/daily_mean/multivar/", "SBD": "-35.0", "DA_FOLDER_HPC": "/gpfs/scratch/bsc32/bsc32137/PREOBS_2023/obs_deepblue6p1_coarse_dod_balance_05_flatter/", "ICL_BMJ": "4.             # tuning factor for dust incloud scavenging (convective clouds)", "DA_IOSTEP": "3", "VCOORD_OPT": "1", "MAXILEVE": "38", "DO_GWD": ".false. .false. .false.", "CENLAT": "35.0 27.5 29.3", "INTERP": "0 0 0", "WBD": "-51.0", "DPHD": "0.1", "DX": "0.1", "DY": "0.1", "ERA5_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ecmwf/era5/original_files", "XKOK": "0                 # flag for shape (only for XTBL=1 or XTBL=2)", "wtpgnps": "8 8 8", "ARE_FOLDER_HPC": "", "DA_FOLDER_ARCHIVE": "", "LM": "40", "nproc_metgrid": "8", "FECAN": "1.75             # Fecan coefficient", "TLM0D": "20.0", "MODE": "DUST_DA_NPS", "COUPLE_DUST": "1", "CHEMIC": "", "PERTURB_USTH": "0.839108 1.064186 0.994903 1.128865 0.939841 1.077895 0.978513 0.904003 1.119007 0.907066 1.133456 0.838777", "SPINUP_SAVE_FREQ": "30", "NEST1RATIO": "1 3 3", "XTBL": "2                 # flag for optical table (tblari in configfile)", "inpesnps": "20 16 31", "USE_IGBP": "0", "NPROC_LAT": "24", "VSLAYER": "0              # 0 NMMB default with viscous sublayer", "NPS_CONFIG": "18", "LOCSIG_TEMP": "7.0", "IFSFCST_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/exp/ecmwf/ifs/original_files", "IFSFCST_FOLDER_HPC": "", "NCHEM": "", "VDRY": "0.5                # tuning factor for dry deposition velocity (excluding gravitational settling", "PREVAR_FOLDER_HPC": "/gpfs/projects/cns44/cns44702/BDRCre-preproc/", "REDUCE_CSV_FILE": "monarch_reduce_DUST_DA_dustclim_min.csv", "GFS_FOLDER_ARCHIVE": "/gpfs/archive/bsc32/esarchive/recon/ncep/gfs/original_files", "NUM_DOMAINS": "1", "PTSGM": "30000.", "DLMD": "0.1", "MERRA2_FOLDER_HPC": "", "QC": "1.4", "moving_nests": ".false.", "GLOBAL_NPS": "0", "CAMS_FOLDER_HPC": "/gpfs/scratch/bsc32/bsc32771/tmp/PREPARE_REGIONAL_RUNS/DATA_required/BC-CAMS", "SEDIM_TYPE": "1            # sedimentation scheme (0-implicit,1 explicit) both upwind (pretty diffusive)"}}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',2);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
