  SELECT entryno, varno, datum_anflag, datum_event1@body, datum_status@body, an_depar, fg_depar, hires@update_1, lores@update_1, qc_a, qc_l, qc_pge,  obsvalue, final_obs_error,   fg_error,  vertco_reference_1,   varbc_ix,   biascorr  WHERE timeslot@index=10 AND kset=2107
;
