CREATE VIEW ofb_14 AS 

SELECT 

// Insert constant columns here 
expver@desc as expver, 
class@desc as class, 
stream@desc as stream, 
type@desc as type, 
andate@desc as andate, 
antime@desc as antime, 
reportype@hdr as reportype, 
mxup_traj@desc, 
numtsl@desc, 

// Insert hdr-aligned columns here 
date@hdr, 
rdbdate@hdr, 
lsm@modsurf, 
seaice@modsurf, 
restricted@hdr, 
timeslot@timeslot_index, 
seqno@hdr, 
bufrtype@hdr, 
subtype@hdr, 
groupid@hdr, 
obstype@hdr, 
codetype@hdr, 
sensor@hdr, 
time@hdr, 
rdbtime@hdr, 
report_status@hdr, 
report_event1@hdr, 
degrees(lat@hdr) as lat@hdr, 
degrees(lon@hdr) as lon@hdr, 
distribtype@hdr, 
distribid@hdr, 
gp_dist@hdr, 
gp_number@hdr, 
satellite_identifier@sat, 
satellite_instrument@sat, 
orography@modsurf, 
windspeed10m@modsurf, 
tsfc@modsurf, 
albedo@modsurf, 
snow_depth@modsurf, 
t2m@modsurf, 
u10m@modsurf, 
v10m@modsurf, 
fg_rain_rate@allsky, 
fg_snow_rate@allsky, 
fg_tcwv@allsky, 
fg_cwp@allsky, 
fg_iwp@allsky, 
fg_rwp@allsky, 
fg_swp@allsky, 
fg_rttov_cld_fraction@allsky, 
fg_theta700@allsky, 
fg_thetasfc@allsky, 
fg_uth@allsky, 
fg_pbl@allsky, 
fg_conv@allsky, 
an_rain_rate@allsky, 
an_snow_rate@allsky, 
an_tcwv@allsky, 
an_cwp@allsky, 
an_iwp@allsky, 
an_rwp@allsky, 
an_swp@allsky, 
an_rttov_cld_fraction@allsky, 
an_theta700@allsky, 
an_thetasfc@allsky, 
an_uth@allsky, 
an_pbl@allsky, 
an_conv@allsky, 
gnorm_10mwind@allsky, 
gnorm_skintemp@allsky, 
gnorm_temp@allsky, 
gnorm_q@allsky, 
gnorm_rainflux@allsky, 
gnorm_snowflux@allsky, 
gnorm_clw@allsky, 
gnorm_ciw@allsky, 
gnorm_cc@allsky, 
ob_p19@allsky, 
fg_p19@allsky, 
an_p19@allsky, 
ob_p37@allsky, 
fg_p37@allsky, 
an_p37@allsky, 
report_tbcloud@allsky, 
zenith@sat, 
azimuth@sat, 
lsm_fov@sat, 
scanline@radiance, 
scanpos@radiance, 
skintemp_1@radiance, 
skintemp_2@radiance, 
skintemp_3@radiance, 
skintemp_4@radiance, 
skintemper@radiance, 
report_rdbflag@hdr, 

// Insert body-aligned columns here 
entryno@body, 
vertco_reference_1@body, 
emis_rtin@radiance_body, 
emis_fg@radiance_body, 
emis_retr@radiance_body, 
emis_atlas@radiance_body, 
zenith_by_channel@radiance_body, 
datum_tbflag@allsky_body, 
tbclear@radiance_body, 
obsvalue@body, 
varno@body, 
vertco_type@body, 
datum_status@body, 
datum_event1@body, 
datum_anflag@body, 
biascorr@body, 
biascorr_fg@body, 
qc_pge@body, 
an_depar@body, 
fg_depar@body, 
datum_status_hires@update_1, 
final_obs_error@errstat, 
obs_error@errstat, 
fg_error@errstat, 
eda_spread@errstat, 
tausfc@radiance_body, 
hires@update_1, 
lores@update_1, 
hires@update_2, 
lores@update_2, 
hires@update_3, 
lores@update_3, 
vertco_reference_2@body, 
an_sens_obs@body, 
fc_sens_obs@body, 
datum_rdbflag@body

WHERE groupid@hdr == 14 ;
