CREATE VIEW ofb_19 AS
SELECT   
  expver                         as expver   ,    
  class                          as class    ,    
  stream                         as stream   ,    
  type                           as type     ,    
  andate                         as andate   ,    
  antime                         as antime   ,    
  reportype                      as reportype,    
  restricted                                 ,

  mxup_traj                                      ,
  numtsl                                         ,

  timeslot                                       ,

  seqno                  ,    
  bufrtype               ,    
  subtype                ,    
  groupid                ,    
  obstype                ,    
  codetype               ,    
  date                   ,    
  time                   ,    
  rdbdate                                           ,
  rdbtime                                           ,
  gp_dist                ,
  report_status          ,    
  report_event1          ,    
  degrees(lat)           as lat@hdr                  ,    
  degrees(lon)           as lon@hdr                  ,    
  distribtype            ,
  distribid              ,
  gp_number              ,
  gp_dist                ,

  satellite_identifier   , 
  satellite_instrument   ,

  entryno                                        ,
  obsvalue                                       ,
  varno                                          ,
  vertco_type                                    ,
  vertco_reference_1                             ,

  datum_status                                   ,    
  datum_event1                                   ,    
  datum_rdbflag                                  ,    
  fg_depar                                       ,
  datum_status_hires@update_1                        ,

  snapshot_id            ,
  grid_point_id          ,
  electron_count         ,
  sun_bt                 ,
  snapshot_acc           ,
  rad_acc_pure           ,
  rad_acc_cross          ,
  footprint_axis_1       ,
  footprint_axis_2       ,
  polarisation           ,
  water_fraction         ,
  incidence_angle        ,
  faradey_rot_angle      ,
  pixel_rot_angle        ,
  info                   ,
  snapshot_quality       ,
  report_tbflag          ,
  tbvalue                ,
  lsm                    ,
  sensor,
  vertco_reference_2, 
  an_sens_obs, 
  report_rdbflag, 
  fc_sens_obs, 
  final_obs_error, 
  an_depar, 
  qc_pge, 
  biascorr, 
  biascorr_fg, 
  eda_spread, 
  hires@update_2, 
  fg_error, 
  datum_anflag, 
  obs_error
FROM desc, timeslot_index, hdr, sat, smos, body, modsurf, errstat, update_1, update_2
WHERE reportype is not null
AND groupid=19;
