PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-07-26-09:36:51','2023-07-26-09:37:44',1690357011,1690357064,'month',12,0,724,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200125", "SCRATCH_DIR": "/project/home", "HOST": "meluxa", "USER": "u100501", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200125", "SCRATCH_DIR": "/project/home", "HOST": "meluxa", "USER": "u100501", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "debug", "MAX_WALLCLOCK": "02:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "02:30", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "20", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "CMORATM": {"EXECUTABLE": "/bin/bash -l", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "meluxina_data_transfer", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "LOCAL_SETUP": {"NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "CHECK": "true", "FILE": "templates/localsetup.tmpl.sh"}, "CMOROCE": {"EXECUTABLE": "/bin/bash -l", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "SYNCHRONIZE": {"WALLCLOCK": "0:30", "NOTIFY_ON": "FAILED", "PLATFORM": "meluxina_data_transfer", "DEPENDENCIES": "LOCAL_SETUP", "FILE": "templates/synchronize.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"NOTIFY_ON": "FAILED", "WALLCLOCK": "01:00", "QUEUE": "debug", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "meluxina_data_transfer", "RUNNING": "member", "DEPENDENCIES": "CLEAN PERFORMANCE_METRICS SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "INI": {"EXECUTABLE": "/bin/bash -l", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "FILE": "templates/ini.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "meluxina_data_transfer", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "REMOTE_SETUP": {"EXECUTABLE": "/bin/bash -l", "PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "DEPENDENCIES": "SYNCHRONIZE", "FILE": "sources/runtime/autosubmit/compilation.sh", "CHECK": "true"}, "SAVEIC": {"EXECUTABLE": "/bin/bash -l", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "00:40", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"EXECUTABLE": "/bin/bash -l", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"EXECUTABLE": "/bin/bash -l", "PROCESSORS": "1280", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 10\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:30", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-20 NCTIME-20", "THREADS": "1", "FILE": "sources/runtime/autosubmit/ece-esm.sh", "CHECK": "on_submission"}}, "exp": {"svn": {"HPCARCH": "meluxina", "EXPID": "a00y", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "meluxina", "EXPID": "a00y", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "meluxina", "EXPID": "a00y", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "meluxina", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "19900201 20000201", "EXPID": "a00y", "MEMBERS": "fc00 fc01", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "meluxina", "EXPID": "a00y", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "meluxina", "CHUNKLIST": "", "EXPID": "a00y", "RERUN": "FALSE"}, "local": {"EXPID": "a00y", "HPCARCH": "meluxina", "PROJECT_PATH": ""}}, "conf": {"CMOR_WRAPPER": {"POLICY": "mixed #default is flexible. Values: flexible,strict,mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "4"}, "migrate": {"TO_USER": ""}, "SIM_WRAPPER": {"POLICY": "flexible #default is flexible. Values: flexible,strict,mixed", "JOBS_IN_WRAPPER": "SIM", "MAX_WRAPPED": "10", "TYPE": "vertical", "MIN_WRAPPED": "3"}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "wrapper": {"WRAPPER_LIST": "SIM_WRAPPER,CMOR_WRAPPER", "TYPE": "multi"}, "communications": {"API": "paramiko"}, "mail": {"NOTIFICATIONS": "False", "NOTIFY_ON_REMOTE_FAIL": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a00y", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "10"}}, "proj": {}}');
INSERT INTO experiment_run VALUES(2,'2023-07-26-09:37:44','2023-07-26-13:27:21',1690357064,1690370841,'month',12,0,724,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200125", "SCRATCH_DIR": "/project/home", "HOST": "meluxa", "USER": "u100501", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200125", "SCRATCH_DIR": "/project/home", "HOST": "meluxa", "USER": "u100501", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "02:30", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "20", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "CMORATM": {"EXECUTABLE": "/bin/bash -l", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "meluxina_data_transfer", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "LOCAL_SETUP": {"NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "CHECK": "true", "FILE": "templates/localsetup.tmpl.sh"}, "CMOROCE": {"EXECUTABLE": "/bin/bash -l", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "SYNCHRONIZE": {"WALLCLOCK": "0:30", "NOTIFY_ON": "FAILED", "PLATFORM": "meluxina_data_transfer", "DEPENDENCIES": "LOCAL_SETUP", "FILE": "templates/synchronize.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"NOTIFY_ON": "FAILED", "WALLCLOCK": "01:00", "QUEUE": "debug", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "meluxina_data_transfer", "RUNNING": "member", "DEPENDENCIES": "CLEAN PERFORMANCE_METRICS SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "INI": {"EXECUTABLE": "/bin/bash -l", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "FILE": "templates/ini.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "meluxina_data_transfer", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "REMOTE_SETUP": {"EXECUTABLE": "/bin/bash -l", "PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "DEPENDENCIES": "SYNCHRONIZE", "FILE": "sources/runtime/autosubmit/compilation.sh", "CHECK": "true"}, "SAVEIC": {"EXECUTABLE": "/bin/bash -l", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "00:40", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"EXECUTABLE": "/bin/bash -l", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"EXECUTABLE": "/bin/bash -l", "PROCESSORS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 10\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-20 NCTIME-20", "THREADS": "1", "FILE": "sources/runtime/autosubmit/ece-esm.sh"}}, "exp": {"svn": {"HPCARCH": "meluxina", "EXPID": "a00y", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "meluxina", "EXPID": "a00y", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "meluxina", "EXPID": "a00y", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "meluxina", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "19900201 20000201", "EXPID": "a00y", "MEMBERS": "fc00 fc01", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "meluxina", "EXPID": "a00y", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "meluxina", "CHUNKLIST": "", "EXPID": "a00y", "RERUN": "FALSE"}, "local": {"EXPID": "a00y", "HPCARCH": "meluxina", "PROJECT_PATH": ""}}, "conf": {"CMOR_WRAPPER": {"POLICY": "mixed #default is flexible. Values: flexible,strict,mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "4"}, "migrate": {"TO_USER": ""}, "SIM_WRAPPER": {"POLICY": "flexible #default is flexible. Values: flexible,strict,mixed", "JOBS_IN_WRAPPER": "SIM", "MAX_WRAPPED": "10", "TYPE": "vertical", "MIN_WRAPPED": "3"}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "wrapper": {"WRAPPER_LIST": "SIM_WRAPPER,CMOR_WRAPPER", "TYPE": "multi"}, "communications": {"API": "paramiko"}, "mail": {"NOTIFICATIONS": "False", "NOTIFY_ON_REMOTE_FAIL": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a00y", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "10"}}, "proj": {}}');
INSERT INTO experiment_run VALUES(3,'2023-07-26-13:27:21','2023-07-27-09:15:43',1690370841,1690442143,'month',12,0,20,0,0,0,0,0,'{"platforms": {"nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord4.bsc.es", "USER": "bsc32371", "TEMP_DIR": "", "USER_TO": "bsc32841", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "mgimenez", "TEMP_DIR": "", "USER_TO": "bdepaula", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "USER_TO": "bsc32841", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32371", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32371", "TEMP_DIR": "", "USER_TO": "bsc32841", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"SIM": {"PROCESSORS": "1", "WALLCLOCK": "0:01", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "sources/runtime/autosubmit/ece-esm.sh", "CHECK": "on_submission"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a00y", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a00y", "PROJECT_BRANCH": "trunk", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a00y", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "20", "DATELIST": "18500101", "EXPID": "a00y", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a00y", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a00y", "RERUN": "FALSE"}, "local": {"EXPID": "a00y", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a667", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "SIM", "MAX_WRAPPED": "25000", "TYPE": "vertical", "MIN_WRAPPED": "2500"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "FALSE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "TRUE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "FALSE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "", "PROJ_TYPE": "STANDARD", "DIAGS": "", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": ""}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(4,'2023-07-27-09:15:43','2023-07-27-09:22:35',1690442143,0,'month',12,0,25,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200125", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32627", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200125", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100501", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "eferre1", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32627", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"SIM": {"EXECUTABLE": "/bin/bash -l", "PROCESSORS": "1280", "CUSTOM_DIRECTIVES": "\"[#SBATCH -N 10, #SBATCH --hint=nomultithread\"]\"", "WALLCLOCK": "1:30", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-20 NCTIME-20", "THREADS": "1", "FILE": "sources/runtime/autosubmit/ece-esm.sh", "CHECK": "on_submission"}}, "exp": {"svn": {"HPCARCH": "meluxina", "EXPID": "a5ls", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "meluxina", "EXPID": "a5ls", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "meluxina", "EXPID": "a5ls", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "meluxina", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "19900201", "EXPID": "a5ls", "MEMBERS": "fc00", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "meluxina", "EXPID": "a5ls", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "meluxina", "CHUNKLIST": "", "EXPID": "a5ls", "RERUN": "FALSE"}, "local": {"EXPID": "a5ls", "HPCARCH": "meluxina", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "SIM_WRAPPER": {"POLICY": "flexible", "JOBS_IN_WRAPPER": "SIM", "MAX_WRAPPED": "10", "TYPE": "vertical", "MIN_WRAPPED": "3"}, "CMOR_WRAPPER": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "4"}, "config": {"EXPID": "a5ls", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {"WRAPPER_LIST": "SIM_WRAPPER,CMOR_WRAPPER", "TYPE": "multi"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "FALSE", "LPJG_FIXLUAFTER": "-1", "LPJG_ini_member": "", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "-1", "LPJG_ini_date": "", "LPJG_ini": "", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "FALSE", "TM5_ini_member": "", "TM5_ISTART": "33", "TM5_NLEVS": "34", "TM5_EMISS_FIXYEAR": "0", "TM5_CONFIG": "tm5:chem,o3fb,ch4fb,aerfb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "dt01.bsc.es", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": "bsc32627"}, "ifs": {"ATM_ini_member": "all_members", "ATM_SH_LEVELS": "", "ATM_ini": "t0nf", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "FALSE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "0", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "end_leg", "SAVE_IC_OFFSET": "", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "t0nf", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "all_members", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "t0nf", "ICE_ini_date": "", "ICE": "LIM3", "ICE_ini_member": "all_members"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "", "OASIS_nproc": "", "OASIS_ini_date": "", "OASIS_ini_member": ""}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "DCPP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-AOGCM", "PRODUCTION_EXP": "TRUE", "PRECOMPILED_VERSION": "NONE", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "", "USE_MACHINEFILE": "FALSE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "1000", "NEM_NUMPROC": "275", "TM5_NUMPROC_Y": "", "TM5_NUMPROC_X": "", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "TRUE", "XIO_NUMPROC": "1", "BSC_OUTCLASS": "CMIP6/ScenarioMIP/EC-EARTH-CC/cmip6-experiment-ScenarioMIP-ssp245", "SAVE_RESTARTS": "TRUE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "dcppA-hindcast", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "TRUE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS SEAICE"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "", "PISCES_ini": "", "PISCES_OFF_DYN": "", "PISCES_ini_date": "", "PISCES": "FALSE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',4);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
