CREATE VIEW ofb_46 AS 

SELECT 

// Insert constant columns here 
expver@desc as expver, 
class@desc as class, 
stream@desc as stream, 
type@desc as type, 
andate@desc as andate, 
antime@desc as antime, 
reportype@hdr as reportype, 
enda_member@desc, 
numtsl@desc, 
mxup_traj@desc, 

// Insert hdr-aligned columns here 
date@hdr, 
rdbdate@hdr, 
lsm@modsurf, 
seaice@modsurf, 
restricted@hdr, 
timeslot@timeslot_index, 
seqno@hdr, 
bufrtype@hdr, 
subtype@hdr, 
groupid@hdr, 
obstype@hdr, 
codetype@hdr, 
sensor@hdr, 
time@hdr, 
rdbtime@hdr, 
report_status@hdr, 
report_event1@hdr, 
report_rdbflag@hdr, 
degrees(lat@hdr) as lat@hdr, 
degrees(lon@hdr) as lon@hdr, 
azimuth@sat, 
retrtype@hdr, 
zenith@sat, 
range@sat, 
arg_lat@sat, 
satellite_identifier@sat, 

// Insert body-aligned columns here 
entryno@body, 
vertco_reference_1@body, 
obsvalue@body, 
varno@body, 
vertco_type@body, 
datum_anflag@body, 
datum_status@body, 
datum_event1@body, 
datum_rdbflag@body, 
biascorr@body, 
biascorr_fg@body, 
qc_pge@body, 
an_depar@body, 
fg_depar@body, 
obs_error@errstat, 
final_obs_error@errstat, 
fg_error@errstat, 
eda_spread@errstat, 
t_ref@aeolus_l2b, 
p_ref@aeolus_l2b, 
beta@aeolus_l2b, 
dhlos_dt@aeolus_l2b, 
dhlos_dp@aeolus_l2b, 
dhlos_dbeta@aeolus_l2b, 
horiz_length@aeolus_l2b, 
vert_length@aeolus_l2b, 
conf_flag@aeolus_l2b, 
vertco_reference_2@body, 
an_sens_obs@body, 
fc_sens_obs@body, 
hires@update_2, 
datum_status_hires@update_1

WHERE groupid@hdr == 46 ;
