CREATE VIEW ofb_30 AS
SELECT   
  expver                         as expver   ,    
  class                          as class    ,    
  stream                         as stream   ,    
  type                           as type     ,    
  andate                         as andate   ,    
  antime                         as antime   ,    
  reportype                      as reportype,    
  restricted                                 ,

  numtsl                ,    

  timeslot              ,

  seqno                 ,    
  groupid               ,    
  codetype              ,    
  sensor                ,    
  date                  ,    
  time                  ,    
  rdbdate                                           ,
  rdbtime                                           ,
  report_status         ,    
  report_event1         ,    
  degrees(lat)          as lat@hdr,    
  degrees(lon)          as lon@hdr,    

  satellite_identifier  ,
  solar_zenith          ,
  zenith                                         ,
  azimuth                                        ,
  datastream            ,

  lsm                                                ,
  orography                                          ,
  windspeed10m                                       ,
  tsfc                                               ,
  
  scanline              ,
  scanpos               ,
  skintemp_1            ,
  skintemp_2            ,
  skintemp_3            ,
  skintemp_4            ,     
  skintemper                                         ,

  entryno               ,    
  obsvalue              ,    
  varno                 ,    
  vertco_type           ,    
  vertco_reference_1    ,    

  datum_anflag                                       ,    
  datum_status                                       ,    
  datum_event1                                       ,    
  datum_rdbflag                                      ,    
  biascorr                                           ,
  biascorr_fg                                           ,
  an_depar                                           ,
  fg_depar                                           ,
  qc_pge                                             ,
  datum_status_hires@update_1                        ,

  obs_error             ,
  final_obs_error             ,
  fg_error              ,
  eda_spread            ,

  hires@update_2         ,
  cldptop_2                                          ,
  cldne_2                                            ,
  jacobian_peak                                  ,
  jacobian_peakl                                 ,
  jacobian_hpeak                                 ,
  jacobian_hpeakl                                ,
  an_sens_obs, 
  report_rdbflag, 
  fc_sens_obs, 
  emis_rtin, 
  tausfc, 
  subtype, 
  mxup_traj, 
  obstype, 
  emis_fg, 
  bufrtype
FROM desc, timeslot_index, hdr, sat, radiance, modsurf, radiance_body, body, errstat, update_1, update_2
WHERE reportype is not null
AND groupid=30;
