PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-06-30-10:25:32','2023-06-30-10:28:35',1688113532,1688113715,'hour',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00p", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"STATUS": "COMPLETED", "SPLITS_FROM": {"1": {"SPLITS_TO": ""}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "SETTINGS": {"CHUNKS": "1"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": 0, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(2,'2023-06-30-10:28:35','2023-06-30-10:29:17',1688113715,1688113757,'hour',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00p", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"STATUS": "COMPLETED", "SPLITS_FROM": {"1": {"SPLITS_TO": ""}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "SETTINGS": {"CHUNKS": "1"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": 0, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(3,'2023-06-30-10:29:17','2023-06-30-10:30:24',1688113757,1688113824,'hour',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00p", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"STATUS": "COMPLETED", "SPLITS_FROM": {"1": {"SPLITS_TO": ""}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "SETTINGS": {"CHUNKS": "1"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": 0, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(4,'2023-06-30-10:30:24','2023-06-30-10:30:58',1688113824,1688113858,'hour',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00p", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"STATUS": "COMPLETED", "SPLITS_FROM": {"1": {"SPLITS_TO": ""}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "SETTINGS": {"CHUNKS": "1"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": 0, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(5,'2023-06-30-10:30:58','2023-06-30-10:31:21',1688113858,1688113881,'hour',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00p", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "JOBS": {"INI": {"FILE": "INI.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "SETTINGS": {"CHUNKS": "1"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": 0, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(6,'2023-06-30-10:31:21','2023-06-30-10:37:58',1688113881,1688114278,'hour',1,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00p", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "JOBS": {"INI": {"FILE": "INI.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"STATUS": "COMPLETED", "SPLITS_FROM": {"1": {"SPLITS_TO": ""}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "SETTINGS": {"CHUNKS": "2"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(7,'2023-06-30-10:37:58','2023-06-30-10:38:13',1688114278,1688114293,'hour',1,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00p", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "SETTINGS": {"CHUNKS": "2"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": 0, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(8,'2023-06-30-10:38:13','2023-06-30-10:54:47',1688114293,1688115287,'hour',1,0,9,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00p", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "9", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "SETTINGS": {"CHUNKS": "9"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 9, "CHUNKINI": 0, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(9,'2023-06-30-10:54:47','2023-06-30-10:54:54',1688115287,1688115294,'hour',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b"}, "SETTINGS": {"CHUNKS": "1"}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "dummy"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": 0, "CALENDAR": "standard"}, "JOBS": {"DUMMY": {"FILE": "dummy.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"DUMMY": {"TYPE": "slurm", "HOSTNAME": "dummy"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/project_files", "STORAGE": {}}');
INSERT INTO experiment_run VALUES(10,'2023-06-30-10:54:54','2023-06-30-10:55:09',1688115294,1688115309,'hour',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b"}, "SETTINGS": {"CHUNKS": "4"}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "dummy"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": 0, "CALENDAR": "standard"}, "JOBS": {"DUMMY": {"FILE": "dummy.sh", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"DUMMY": {"TYPE": "slurm", "HOSTNAME": "dummy"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/project_files", "STORAGE": {}}');
INSERT INTO experiment_run VALUES(11,'2023-06-30-10:55:09','2023-06-30-10:55:52',1688115309,1688115352,'hour',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b"}, "SETTINGS": {"CHUNKS": "4"}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "dummy"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": 0, "CALENDAR": "standard"}, "JOBS": {"DUMMY": {"FILE": "dummy.sh", "RUNNING": "chunks", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"DUMMY": {"TYPE": "slurm", "HOSTNAME": "dummy"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/project_files", "STORAGE": {}}');
INSERT INTO experiment_run VALUES(12,'2023-06-30-10:55:52','2023-06-30-10:59:01',1688115352,1688115541,'hour',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b"}, "SETTINGS": {"CHUNKS": "4"}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "dummy"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": 0, "CALENDAR": "standard"}, "JOBS": {"DUMMY": {"FILE": "dummy.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"DUMMY": {"TYPE": "slurm", "HOSTNAME": "dummy"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/project_files", "STORAGE": {}}');
INSERT INTO experiment_run VALUES(13,'2023-06-30-10:59:01','2023-06-30-12:21:36',1688115541,1688120496,'hour',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b"}, "SETTINGS": {"CHUNKS": "4"}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "dummy"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": 0, "CALENDAR": "standard"}, "JOBS": {"DUMMY": {"FILE": "dummy.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"DUMMY": {"TYPE": "slurm", "HOSTNAME": "dummy"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/project_files", "STORAGE": {}}');
INSERT INTO experiment_run VALUES(14,'2023-06-30-12:21:36','2023-06-30-12:28:54',1688120496,1688120934,'hour',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.80"}, "SETTINGS": {"CHUNKS": "4"}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "dummy"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": 0, "CALENDAR": "standard"}, "JOBS": {"DUMMY": {"FILE": "dummy.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"DUMMY": {"TYPE": "slurm", "HOSTNAME": "dummy"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/project_files", "STORAGE": {}}');
INSERT INTO experiment_run VALUES(15,'2023-06-30-12:28:54','2023-06-30-12:28:54',1688120934,0,'hour',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00p", "PROJDIR": "/home/dbeltran/new_autosubmit/a00p/proj/project_files", "SETTINGS": {"CHUNKS": "4"}, "DEFAULT": {"EXPID": "a00p", "HPCARCH": "dummy"}, "EXPERIMENT": {"DATELIST": 20201001, "MEMBERS": "m1", "CHUNKSIZEUNIT": "hour", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": 0, "CALENDAR": "standard"}, "JOBS": {"DUMMY": {"FILE": "dummy.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"DUMMY": {"TYPE": "slurm", "HOSTNAME": "dummy"}}, "STORAGE": {}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',15);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
