PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-09-19-11:37:52','2023-09-19-11:41:12',1695116272,1695116472,'month',12,0,226,0,0,0,0,0,'{"platforms": {"nord3v2": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord3", "USER": "bsc32019", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "yruprich", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "False"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-paolo", "USER": "bsc32507", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-dt-paolo", "USER": "bsc32507", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "False"}}, "jobs": {"NCTIME": {"PROCESSORS": "16", "WALLCLOCK": "2:00", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/common/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3 CLEAN-4 CLEAN-5 CLEAN-6 CLEAN-7 CLEAN-8 CLEAN-9"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:15", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/common/cmoratm.tmpl.sh", "CHECK": "true"}, "PERFORMANCE_METRICS": {"PROCESSORS": "1", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": "CLEAN", "FILE": "templates/common/performance_metrics.tmpl.sh", "CHECK": "true"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "CHECK": "true", "FILE": "templates/common/localsetup.tmpl.sh"}, "CMOROCE": {"TASKS": "8", "CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:15", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/common/cmoroce.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/common/earthdiags.tmpl.sh", "CHECK": "true"}, "SYNCHRONIZE": {"PLATFORM": "transfer_node", "DEPENDENCIES": "LOCAL_SETUP", "CHECK": "true", "FILE": "templates/common/synchronize.tmpl.sh"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:20", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/common/cmorlpjg.tmpl.sh", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "PLATFORM": "transfer_node", "RUNNING": "member", "DEPENDENCIES": "CLEAN PERFORMANCE_METRICS SAVEIC", "FILE": "templates/common/clean_member.tmpl.sh", "CHECK": "true"}, "INI": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "00:30", "RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "FILE": "templates/common/ini.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "PLATFORM": "transfer_node", "RUNNING": "chunk", "DEPENDENCIES": "POST SIM SIM+1 CMOROCE CMORATM CMORATM+1 CMORLPJG CLEAN-1", "FILE": "templates/common/clean.tmpl.sh", "CHECK": "true"}, "REMOTE_SETUP": {"PROCESSORS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "2:00", "DEPENDENCIES": "SYNCHRONIZE", "FILE": "sources/runtime/autosubmit/compilation.sh", "CHECK": "true"}, "SAVEIC": {"WALLCLOCK": "02:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "THREADS": "6", "FILE": "templates/common/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "00:30", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG SAVEIC SIM SIM+1 POST-1", "FILE": "templates/common/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"PLATFORM": "transfer_node", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "CHECK": "true", "FILE": "templates/common/transfer_member.tmpl.sh"}, "SIM": {"TASKS": "48", "PROCESSORS": "768", "WALLCLOCK": "2:00", "QUEUE": "debug", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-26 NCTIME-26", "THREADS": "1", "FILE": "sources/runtime/autosubmit/ece-esm.sh", "CHECK": "on_submission"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_BRANCH": "3.3.3_c4mip_production", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "27", "DATELIST": "19000101", "EXPID": "a01d", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01d", "FILE_PROJECT_CONF": "templates/common/proj.conf"}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01d", "RERUN": "FALSE"}, "local": {"EXPID": "a01d", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01d", "TOTALJOBS": "100", "MAXWAITINGJOBS": "100", "RETRIALS": "4", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "60"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "-1", "LPJG_ini_member": "fc0", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "-1", "LPJG_ini_date": "", "LPJG_ini": "a3o1", "LPJG_SAVE_ICMCL": "TRUE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "FALSE", "TM5_ini_member": "", "TM5_ISTART": "33", "TM5_NUMPROC_Y": "45", "TM5_NUMPROC_X": "1", "TM5_NLEVS": "34", "TM5_EMISS_FIXYEAR": "0", "TM5_CONFIG": "tm5:chem,o3fb,ch4fb,aerfb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"XLCOR_SPPT": "", "ATM_ini_member": "fc0", "ATM_SH_LEVELS": "", "LTAPER_SPPT": "", "ATM_ini": "a3o1", "LHVOLCA": "TRUE", "NS_SPPT": "", "LCMIP5": "", "PTAPER_BOT": "", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "", "SAVEDDA": "TRUE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "PTAPER_TOP": "", "LWRITE_ARP": "", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "SDEV_SPPT": "", "ATM_GG_CODES": "39.128 40.128 41.128 42.128 139.128 167.128 170.128 183.128 236.128 228.128 144.128 176.128 177.128 165.128 166.128 168.128 201.128 202.128", "TAU_SPPT": "", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "0", "CMIP5_RCP": "0", "XCLIP_SPPT": ""}, "save_ic": {"SAVE_IC": "end_leg", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "fc00", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a3o1", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "troppacatl-pacemaker", "OCEAN_ini_member": "fc0", "SURF_RESTO_DATA": "PCMDI-AMIP-1-1-9_for_pacemaker_with_EC-Earth3-CC", "SURF_RESTO": "TRUE"}, "transfer": {"USE_DT_COMMANDS": "TRUE"}, "ice": {"ICE_ini": "a3o1", "ICE_ini_date": "", "ICE": "LIM3", "ICE_ini_member": "fc0"}, "oasis": {"OASIS_ini_member": "fc0", "OASIS_flds": "", "OASIS3": "yes", "OASIS_ini": "a3o1", "OASIS_nproc": "", "OASIS_ini_date": ""}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "FALSE", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "FORCING": "", "CMOR_MODEL_ID": "EC-EARTH-CC", "MODEL_output_remove": "TRUE", "PRODUCTION_EXP": "TRUE", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "40", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "336", "NEM_NUMPROC": "380", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "v3.3.3_c-cycle", "CMIP6_OUTCLASS": "", "ADD_PROJECT_TO_HOST": "false", "XIO_NUMPROC": "5", "BSC_OUTCLASS": "C4MIP_reduced", "CMOR_REALIZATION_INDEX": "10", "CMOR_EXP": "troppacatl-pacemaker", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR"}, "diagnostics": {"ECE3_POSTPROC": "TRUE", "DIAGS": "BASIC_OCEAN BASIC_SEAICE", "DIAGS_FREQ": "mon", "PROJ_TYPE": "STANDARD"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc0", "PISCES_ini": "a3o1", "PISCES_OFF_DYN": "", "PISCES_ini_date": "", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_CONFIG": "osm:post_all", "OSM_IFS_OUTPUT_DIR": "", "OSM_NUMPROC": "", "OSM_FORCING_TYPE": "erai", "OSM_THREADS": "", "OSM": "FALSE", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(2,'2023-09-19-11:41:12','2023-09-19-12:13:44',1695116472,1695118424,'month',12,0,226,0,0,0,0,0,'{"platforms": {"nord3v2": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord3", "USER": "bsc32019", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "yruprich", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "False"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-paolo", "USER": "bsc32507", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-dt-paolo", "USER": "bsc32507", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "False"}}, "jobs": {"NCTIME": {"PROCESSORS": "16", "WALLCLOCK": "2:00", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/common/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3 CLEAN-4 CLEAN-5 CLEAN-6 CLEAN-7 CLEAN-8 CLEAN-9"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:15", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/common/cmoratm.tmpl.sh", "CHECK": "true"}, "PERFORMANCE_METRICS": {"PROCESSORS": "1", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": "CLEAN", "FILE": "templates/common/performance_metrics.tmpl.sh", "CHECK": "true"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "CHECK": "true", "FILE": "templates/common/localsetup.tmpl.sh"}, "CMOROCE": {"TASKS": "8", "CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:15", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/common/cmoroce.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/common/earthdiags.tmpl.sh", "CHECK": "true"}, "SYNCHRONIZE": {"PLATFORM": "transfer_node", "DEPENDENCIES": "LOCAL_SETUP", "CHECK": "true", "FILE": "templates/common/synchronize.tmpl.sh"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:20", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/common/cmorlpjg.tmpl.sh", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "PLATFORM": "transfer_node", "RUNNING": "member", "DEPENDENCIES": "CLEAN PERFORMANCE_METRICS SAVEIC", "FILE": "templates/common/clean_member.tmpl.sh", "CHECK": "true"}, "INI": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "00:30", "RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "FILE": "templates/common/ini.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "PLATFORM": "transfer_node", "RUNNING": "chunk", "DEPENDENCIES": "POST SIM SIM+1 CMOROCE CMORATM CMORATM+1 CMORLPJG CLEAN-1", "FILE": "templates/common/clean.tmpl.sh", "CHECK": "true"}, "REMOTE_SETUP": {"PROCESSORS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "2:00", "DEPENDENCIES": "SYNCHRONIZE", "FILE": "sources/runtime/autosubmit/compilation.sh", "CHECK": "true"}, "SAVEIC": {"WALLCLOCK": "02:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "THREADS": "6", "FILE": "templates/common/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "00:30", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG SAVEIC SIM SIM+1 POST-1", "FILE": "templates/common/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"PLATFORM": "transfer_node", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "CHECK": "true", "FILE": "templates/common/transfer_member.tmpl.sh"}, "SIM": {"TASKS": "48", "PROCESSORS": "768", "WALLCLOCK": "2:00", "QUEUE": "debug", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-26 NCTIME-26", "THREADS": "1", "FILE": "sources/runtime/autosubmit/ece-esm.sh", "CHECK": "on_submission"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_BRANCH": "3.3.3_c4mip_production", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "27", "DATELIST": "19000101", "EXPID": "a01d", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01d", "FILE_PROJECT_CONF": "templates/common/proj.conf"}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01d", "RERUN": "FALSE"}, "local": {"EXPID": "a01d", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01d", "TOTALJOBS": "100", "MAXWAITINGJOBS": "100", "RETRIALS": "4", "AUTOSUBMIT_VERSION": "3.14.0", "SAFETYSLEEPTIME": "60"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "-1", "LPJG_ini_member": "fc0", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "-1", "LPJG_ini_date": "", "LPJG_ini": "a3o1", "LPJG_SAVE_ICMCL": "TRUE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "FALSE", "TM5_ini_member": "", "TM5_ISTART": "33", "TM5_NUMPROC_Y": "45", "TM5_NUMPROC_X": "1", "TM5_NLEVS": "34", "TM5_EMISS_FIXYEAR": "0", "TM5_CONFIG": "tm5:chem,o3fb,ch4fb,aerfb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"XLCOR_SPPT": "", "ATM_ini_member": "fc0", "ATM_SH_LEVELS": "", "LTAPER_SPPT": "", "ATM_ini": "a3o1", "LHVOLCA": "TRUE", "NS_SPPT": "", "LCMIP5": "", "PTAPER_BOT": "", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "", "SAVEDDA": "TRUE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "PTAPER_TOP": "", "LWRITE_ARP": "", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "SDEV_SPPT": "", "ATM_GG_CODES": "39.128 40.128 41.128 42.128 139.128 167.128 170.128 183.128 236.128 228.128 144.128 176.128 177.128 165.128 166.128 168.128 201.128 202.128", "TAU_SPPT": "", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "0", "CMIP5_RCP": "0", "XCLIP_SPPT": ""}, "save_ic": {"SAVE_IC": "end_leg", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "fc00", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a3o1", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "troppacatl-pacemaker", "OCEAN_ini_member": "fc0", "SURF_RESTO_DATA": "PCMDI-AMIP-1-1-9_for_pacemaker_with_EC-Earth3-CC", "SURF_RESTO": "TRUE"}, "transfer": {"USE_DT_COMMANDS": "TRUE"}, "ice": {"ICE_ini": "a3o1", "ICE_ini_date": "", "ICE": "LIM3", "ICE_ini_member": "fc0"}, "oasis": {"OASIS_ini_member": "fc0", "OASIS_flds": "", "OASIS3": "yes", "OASIS_ini": "a3o1", "OASIS_nproc": "", "OASIS_ini_date": ""}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "FALSE", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "FORCING": "", "CMOR_MODEL_ID": "EC-EARTH-CC", "MODEL_output_remove": "TRUE", "PRODUCTION_EXP": "TRUE", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "40", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "336", "NEM_NUMPROC": "380", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "v3.3.3_c-cycle", "CMIP6_OUTCLASS": "", "ADD_PROJECT_TO_HOST": "false", "XIO_NUMPROC": "5", "BSC_OUTCLASS": "C4MIP_reduced", "CMOR_REALIZATION_INDEX": "10", "CMOR_EXP": "troppacatl-pacemaker", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR"}, "diagnostics": {"ECE3_POSTPROC": "TRUE", "DIAGS": "BASIC_OCEAN BASIC_SEAICE", "DIAGS_FREQ": "mon", "PROJ_TYPE": "STANDARD"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc0", "PISCES_ini": "a3o1", "PISCES_OFF_DYN": "", "PISCES_ini_date": "", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_CONFIG": "osm:post_all", "OSM_IFS_OUTPUT_DIR": "", "OSM_NUMPROC": "", "OSM_FORCING_TYPE": "erai", "OSM_THREADS": "", "OSM": "FALSE", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(3,'2023-09-19-12:13:44','2023-09-19-14:49:00',1695118424,1695127740,'month',12,0,226,1,0,0,0,0,'{"platforms": {"nord3v2": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord3", "USER": "bsc32019", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "yruprich", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "False"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-paolo", "USER": "bsc32507", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-dt-paolo", "USER": "bsc32507", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "False"}}, "jobs": {"NCTIME": {"PROCESSORS": "16", "WALLCLOCK": "2:00", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/common/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3 CLEAN-4 CLEAN-5 CLEAN-6 CLEAN-7 CLEAN-8 CLEAN-9"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:15", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/common/cmoratm.tmpl.sh", "CHECK": "true"}, "PERFORMANCE_METRICS": {"PROCESSORS": "1", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": "CLEAN", "FILE": "templates/common/performance_metrics.tmpl.sh", "CHECK": "true"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "CHECK": "true", "FILE": "templates/common/localsetup.tmpl.sh"}, "CMOROCE": {"TASKS": "8", "CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:15", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/common/cmoroce.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/common/earthdiags.tmpl.sh", "CHECK": "true"}, "SYNCHRONIZE": {"PLATFORM": "transfer_node", "DEPENDENCIES": "LOCAL_SETUP", "CHECK": "true", "FILE": "templates/common/synchronize.tmpl.sh"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:20", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/common/cmorlpjg.tmpl.sh", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "PLATFORM": "transfer_node", "RUNNING": "member", "DEPENDENCIES": "CLEAN PERFORMANCE_METRICS SAVEIC", "FILE": "templates/common/clean_member.tmpl.sh", "CHECK": "true"}, "INI": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "00:30", "RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "FILE": "templates/common/ini.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "PLATFORM": "transfer_node", "RUNNING": "chunk", "DEPENDENCIES": "POST SIM SIM+1 CMOROCE CMORATM CMORATM+1 CMORLPJG CLEAN-1", "FILE": "templates/common/clean.tmpl.sh", "CHECK": "true"}, "REMOTE_SETUP": {"PROCESSORS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "2:00", "DEPENDENCIES": "SYNCHRONIZE", "FILE": "sources/runtime/autosubmit/compilation.sh", "CHECK": "true"}, "SAVEIC": {"WALLCLOCK": "02:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "THREADS": "6", "FILE": "templates/common/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "00:30", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG SAVEIC SIM SIM+1 POST-1", "FILE": "templates/common/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"PLATFORM": "transfer_node", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "CHECK": "true", "FILE": "templates/common/transfer_member.tmpl.sh"}, "SIM": {"TASKS": "48", "PROCESSORS": "768", "WALLCLOCK": "2:00", "QUEUE": "debug", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-26 NCTIME-26", "THREADS": "1", "FILE": "sources/runtime/autosubmit/ece-esm.sh", "CHECK": "on_submission"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_BRANCH": "3.3.3_c4mip_production", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "27", "DATELIST": "19000101", "EXPID": "a01d", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01d", "FILE_PROJECT_CONF": "templates/common/proj.conf"}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01d", "RERUN": "FALSE"}, "local": {"EXPID": "a01d", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01d", "TOTALJOBS": "100", "MAXWAITINGJOBS": "100", "RETRIALS": "4", "AUTOSUBMIT_VERSION": "3.14.0", "SAFETYSLEEPTIME": "60"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "-1", "LPJG_ini_member": "fc0", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "-1", "LPJG_ini_date": "", "LPJG_ini": "a3o1", "LPJG_SAVE_ICMCL": "TRUE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "FALSE", "TM5_ini_member": "", "TM5_ISTART": "33", "TM5_NUMPROC_Y": "45", "TM5_NUMPROC_X": "1", "TM5_NLEVS": "34", "TM5_EMISS_FIXYEAR": "0", "TM5_CONFIG": "tm5:chem,o3fb,ch4fb,aerfb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"XLCOR_SPPT": "", "ATM_ini_member": "fc0", "ATM_SH_LEVELS": "", "LTAPER_SPPT": "", "ATM_ini": "a3o1", "LHVOLCA": "TRUE", "NS_SPPT": "", "LCMIP5": "", "PTAPER_BOT": "", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "", "SAVEDDA": "TRUE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "PTAPER_TOP": "", "LWRITE_ARP": "", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "SDEV_SPPT": "", "ATM_GG_CODES": "39.128 40.128 41.128 42.128 139.128 167.128 170.128 183.128 236.128 228.128 144.128 176.128 177.128 165.128 166.128 168.128 201.128 202.128", "TAU_SPPT": "", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "0", "CMIP5_RCP": "0", "XCLIP_SPPT": ""}, "save_ic": {"SAVE_IC": "end_leg", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "fc00", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a3o1", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "troppacatl-pacemaker", "OCEAN_ini_member": "fc0", "SURF_RESTO_DATA": "PCMDI-AMIP-1-1-9_for_pacemaker_with_EC-Earth3-CC", "SURF_RESTO": "TRUE"}, "transfer": {"USE_DT_COMMANDS": "TRUE"}, "ice": {"ICE_ini": "a3o1", "ICE_ini_date": "", "ICE": "LIM3", "ICE_ini_member": "fc0"}, "oasis": {"OASIS_ini_member": "fc0", "OASIS_flds": "", "OASIS3": "yes", "OASIS_ini": "a3o1", "OASIS_nproc": "", "OASIS_ini_date": ""}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "FALSE", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "FORCING": "", "CMOR_MODEL_ID": "EC-EARTH-CC", "MODEL_output_remove": "TRUE", "PRODUCTION_EXP": "TRUE", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "40", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "336", "NEM_NUMPROC": "380", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "v3.3.3_c-cycle", "CMIP6_OUTCLASS": "", "ADD_PROJECT_TO_HOST": "false", "XIO_NUMPROC": "5", "BSC_OUTCLASS": "C4MIP_reduced", "CMOR_REALIZATION_INDEX": "10", "CMOR_EXP": "troppacatl-pacemaker", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR"}, "diagnostics": {"ECE3_POSTPROC": "TRUE", "DIAGS": "BASIC_OCEAN BASIC_SEAICE", "DIAGS_FREQ": "mon", "PROJ_TYPE": "STANDARD"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc0", "PISCES_ini": "a3o1", "PISCES_OFF_DYN": "", "PISCES_ini_date": "", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_CONFIG": "osm:post_all", "OSM_IFS_OUTPUT_DIR": "", "OSM_NUMPROC": "", "OSM_FORCING_TYPE": "erai", "OSM_THREADS": "", "OSM": "FALSE", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(4,'2023-09-19-14:49:00','2023-09-19-14:49:28',1695127740,0,'month',12,0,226,0,0,0,0,0,'{"platforms": {"nord3v2": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord3.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "False"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "False"}}, "jobs": {"NCTIME": {"PROCESSORS": "16", "WALLCLOCK": "2:00", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/common/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3 CLEAN-4 CLEAN-5 CLEAN-6 CLEAN-7 CLEAN-8 CLEAN-9"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:15", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/common/cmoratm.tmpl.sh", "CHECK": "true"}, "PERFORMANCE_METRICS": {"PROCESSORS": "1", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": "CLEAN", "FILE": "templates/common/performance_metrics.tmpl.sh", "CHECK": "true"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "RETRIALS": "1", "CHECK": "true", "FILE": "templates/common/localsetup.tmpl.sh"}, "CMOROCE": {"TASKS": "8", "CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:15", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/common/cmoroce.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/common/earthdiags.tmpl.sh", "CHECK": "true"}, "SYNCHRONIZE": {"PLATFORM": "transfer_node", "DEPENDENCIES": "LOCAL_SETUP", "CHECK": "true", "FILE": "templates/common/synchronize.tmpl.sh"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "0:20", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/common/cmorlpjg.tmpl.sh", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "PLATFORM": "transfer_node", "RUNNING": "member", "DEPENDENCIES": "CLEAN PERFORMANCE_METRICS SAVEIC", "FILE": "templates/common/clean_member.tmpl.sh", "CHECK": "true"}, "INI": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "00:30", "RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "FILE": "templates/common/ini.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "PLATFORM": "transfer_node", "RUNNING": "chunk", "DEPENDENCIES": "POST SIM SIM+1 CMOROCE CMORATM CMORATM+1 CMORLPJG CLEAN-1", "FILE": "templates/common/clean.tmpl.sh", "CHECK": "true"}, "REMOTE_SETUP": {"PROCESSORS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p interactive\"]", "WALLCLOCK": "2:00", "DEPENDENCIES": "SYNCHRONIZE", "FILE": "sources/runtime/autosubmit/compilation.sh", "CHECK": "true"}, "SAVEIC": {"WALLCLOCK": "02:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "THREADS": "6", "FILE": "templates/common/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "00:30", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG SAVEIC SIM SIM+1 POST-1", "FILE": "templates/common/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"PLATFORM": "transfer_node", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "CHECK": "true", "FILE": "templates/common/transfer_member.tmpl.sh"}, "SIM": {"TASKS": "48", "PROCESSORS": "768", "WALLCLOCK": "2:00", "QUEUE": "debug", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-26 NCTIME-26", "THREADS": "1", "FILE": "sources/runtime/autosubmit/ece-esm.sh", "CHECK": "on_submission"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_BRANCH": "3.3.3_c4mip_production", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01d", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "27", "DATELIST": "19000101", "EXPID": "a01d", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01d", "FILE_PROJECT_CONF": "templates/common/proj.conf"}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01d", "RERUN": "FALSE"}, "local": {"EXPID": "a01d", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01d", "TOTALJOBS": "100", "MAXWAITINGJOBS": "100", "RETRIALS": "4", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "60"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "-1", "LPJG_ini_member": "fc0", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "-1", "LPJG_ini_date": "", "LPJG_ini": "a3o1", "LPJG_SAVE_ICMCL": "TRUE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "FALSE", "TM5_ini_member": "", "TM5_ISTART": "33", "TM5_NUMPROC_Y": "45", "TM5_NUMPROC_X": "1", "TM5_NLEVS": "34", "TM5_EMISS_FIXYEAR": "0", "TM5_CONFIG": "tm5:chem,o3fb,ch4fb,aerfb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"XLCOR_SPPT": "", "ATM_ini_member": "fc0", "ATM_SH_LEVELS": "", "LTAPER_SPPT": "", "ATM_ini": "a3o1", "LHVOLCA": "TRUE", "NS_SPPT": "", "LCMIP5": "", "PTAPER_BOT": "", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "", "SAVEDDA": "TRUE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "PTAPER_TOP": "", "LWRITE_ARP": "", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "SDEV_SPPT": "", "ATM_GG_CODES": "39.128 40.128 41.128 42.128 139.128 167.128 170.128 183.128 236.128 228.128 144.128 176.128 177.128 165.128 166.128 168.128 201.128 202.128", "TAU_SPPT": "", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "0", "CMIP5_RCP": "0", "XCLIP_SPPT": ""}, "save_ic": {"SAVE_IC": "end_leg", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "fc00", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a3o1", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "troppacatl-pacemaker", "OCEAN_ini_member": "fc0", "SURF_RESTO_DATA": "PCMDI-AMIP-1-1-9_for_pacemaker_with_EC-Earth3-CC", "SURF_RESTO": "TRUE"}, "transfer": {"USE_DT_COMMANDS": "TRUE"}, "ice": {"ICE_ini": "a3o1", "ICE_ini_date": "", "ICE": "LIM3", "ICE_ini_member": "fc0"}, "oasis": {"OASIS_ini_member": "fc0", "OASIS_flds": "", "OASIS3": "yes", "OASIS_ini": "a3o1", "OASIS_nproc": "", "OASIS_ini_date": ""}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "FALSE", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "FORCING": "", "CMOR_MODEL_ID": "EC-EARTH-CC", "MODEL_output_remove": "TRUE", "PRODUCTION_EXP": "TRUE", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "40", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "336", "NEM_NUMPROC": "380", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "v3.3.3_c-cycle", "CMIP6_OUTCLASS": "", "ADD_PROJECT_TO_HOST": "false", "XIO_NUMPROC": "5", "BSC_OUTCLASS": "C4MIP_reduced", "CMOR_REALIZATION_INDEX": "10", "CMOR_EXP": "troppacatl-pacemaker", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR"}, "diagnostics": {"ECE3_POSTPROC": "TRUE", "DIAGS": "BASIC_OCEAN BASIC_SEAICE", "DIAGS_FREQ": "mon", "PROJ_TYPE": "STANDARD"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc0", "PISCES_ini": "a3o1", "PISCES_OFF_DYN": "", "PISCES_ini_date": "", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_CONFIG": "osm:post_all", "OSM_IFS_OUTPUT_DIR": "", "OSM_NUMPROC": "", "OSM_FORCING_TYPE": "erai", "OSM_THREADS": "", "OSM": "FALSE", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a01d_LOCAL_SETUP','2023-09-19-12:17:48','2023-09-19-12:19:51',1695118668,1695118668,1695118790,'FAILED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',47664,'',0,3,0.0,0.0,'a01d_LOCAL_SETUP.20230919121950.out','a01d_LOCAL_SETUP.20230919121950.err',5,'a01d_SYNCHRONIZE','');
INSERT INTO job_data VALUES(2,1,'a01d_LOCAL_SETUP','2023-09-19-12:19:51','2023-09-19-12:21:53',1695118791,1695118791,1695118913,'FAILED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',47874,'',0,3,0.0,0.0,'a01d_LOCAL_SETUP.20230919122153.out','a01d_LOCAL_SETUP.20230919122153.err',5,'a01d_SYNCHRONIZE','');
INSERT INTO job_data VALUES(3,2,'a01d_LOCAL_SETUP','2023-09-19-12:21:53','2023-09-19-12:23:55',1695118913,1695118913,1695119035,'FAILED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',47964,'',0,3,0.0,0.0,'a01d_LOCAL_SETUP.20230919122355.out','a01d_LOCAL_SETUP.20230919122355.err',5,'a01d_SYNCHRONIZE','');
INSERT INTO job_data VALUES(4,3,'a01d_LOCAL_SETUP','2023-09-19-12:23:55','2023-09-19-12:25:58',1695119035,1695119035,1695119158,'FAILED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',48356,'',0,3,0.0,0.0,'a01d_LOCAL_SETUP.20230919122558.out','a01d_LOCAL_SETUP.20230919122558.err',5,'a01d_SYNCHRONIZE','');
INSERT INTO job_data VALUES(5,4,'a01d_LOCAL_SETUP','2023-09-19-12:25:58','2023-09-19-12:27:41',1695119158,1695119158,1695119261,'FAILED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,1,'LOCAL',48650,'',0,3,0.0,0.0,'a01d_LOCAL_SETUP.20230919122741.out','a01d_LOCAL_SETUP.20230919122741.err',5,'a01d_SYNCHRONIZE','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',4);
INSERT INTO sqlite_sequence VALUES('job_data',5);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
