PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-09-19-08:58:09','2023-09-19-09:15:19',1695106689,1695107719,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 3, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"JOBA": {"FILE": "a", "PLATFORM": "marenostrum4", "QUEUE": "debug", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:02", "MEMORY": 0, "NODES": 1, "TASKS": 1, "THREADS": 1, "PROCESSORS": 2, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/t004", "PROJDIR": "/home/dbeltran/new_autosubmit/t004/proj/"}');
INSERT INTO experiment_run VALUES(2,'2023-09-19-09:15:19','2023-09-19-09:15:37',1695107719,1695107737,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 3, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"JOBA": {"FILE": "a", "PLATFORM": "marenostrum4", "QUEUE": "debug", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:02", "MEMORY": 0, "NODES": 1, "TASKS": 1, "THREADS": 1, "PROCESSORS": 2, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/t004", "PROJDIR": "/home/dbeltran/new_autosubmit/t004/proj/"}');
INSERT INTO experiment_run VALUES(3,'2023-09-19-09:15:37','2023-09-19-09:17:10',1695107737,1695107830,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 3, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"JOBA": {"FILE": "a", "PLATFORM": "marenostrum4", "QUEUE": "debug", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:02", "MEMORY": 0, "NODES": 1, "TASKS": 1, "THREADS": 1, "PROCESSORS": 2, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/t004", "PROJDIR": "/home/dbeltran/new_autosubmit/t004/proj/"}');
INSERT INTO experiment_run VALUES(4,'2023-09-19-09:17:10','2023-09-19-09:30:59',1695107830,1695108659,'month',4,3,3,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 3, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"JOBA": {"FILE": "a", "PLATFORM": "marenostrum4", "QUEUE": "debug", "DEPENDENCIES": {"JOBA-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:02", "MEMORY": 0, "NODES": 1, "TASKS": 1, "THREADS": 1, "PROCESSORS": 2, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/t004", "PROJDIR": "/home/dbeltran/new_autosubmit/t004/proj/"}');
INSERT INTO experiment_run VALUES(5,'2023-09-19-09:31:00','2023-09-19-09:34:29',1695108660,1695108869,'month',4,3,3,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "t004", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 3, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"JOBA": {"FILE": "a", "PLATFORM": "marenostrum4", "QUEUE": "debug", "DEPENDENCIES": {"JOBA-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:02", "MEMORY": 0, "NODES": 1, "TASKS": 1, "THREADS": 1, "PROCESSORS": 2, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/t004", "PROJDIR": "/home/dbeltran/new_autosubmit/t004/proj/"}');
INSERT INTO experiment_run VALUES(6,'2023-09-19-09:34:29','2023-09-19-10:52:17',1695108869,1695113537,'month',4,1,3,0,0,0,1,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "t004", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 3, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"JOBA": {"FILE": "a", "PLATFORM": "marenostrum4", "QUEUE": "debug", "DEPENDENCIES": {"JOBA-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:02", "MEMORY": 0, "TASKS": 1, "THREADS": 1, "PROCESSORS": 2, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/t004", "PROJDIR": "/home/dbeltran/new_autosubmit/t004/proj/"}');
INSERT INTO experiment_run VALUES(7,'2023-09-19-10:52:17','2023-09-26-15:37:06',1695113537,1695735426,'month',4,3,3,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "t004", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 3, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"JOBA": {"FILE": "a", "PLATFORM": "marenostrum4", "QUEUE": "debug", "DEPENDENCIES": {"JOBA-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:02", "MEMORY": 0, "TASKS": 1, "THREADS": 1, "PROCESSORS": 2, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/t004", "PROJDIR": "/home/dbeltran/new_autosubmit/t004/proj/"}');
INSERT INTO experiment_run VALUES(8,'2023-09-26-15:37:06','2023-09-27-11:04:02',1695735426,1695805442,'month',4,3,3,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "t004", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 3, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"JOBA": {"FILE": "a", "PLATFORM": "marenostrum4", "QUEUE": "debug", "DEPENDENCIES": {"JOBA-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:02", "MEMORY": 0, "TASKS": 1, "THREADS": 1, "PROCESSORS": 2, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/t004", "PROJDIR": "/home/dbeltran/new_autosubmit/t004/proj/"}');
INSERT INTO experiment_run VALUES(9,'2023-09-27-11:04:02','2023-09-27-11:10:15',1695805442,0,'month',4,3,3,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "t004", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 3, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"JOBA": {"FILE": "a", "PLATFORM": "marenostrum4", "QUEUE": "debug", "DEPENDENCIES": {"JOBA-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:02", "MEMORY": 0, "TASKS": 1, "THREADS": 1, "PROCESSORS": 2, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/t004", "PROJDIR": "/home/dbeltran/new_autosubmit/t004/proj/"}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'t004_20000101_fc0_1_JOBA','2023-09-19-09:17:20','2023-09-19-09:31:06',1695107840,1695107844,1695107849,'COMPLETED',2,2,'00:02','debug',2080,'2000-01-01 00:00:00','JOBA','fc0',1,0,'MARENOSTRUM4',30217473,'',1,4,0.0,0.0,'t004_20000101_fc0_1_JOBA.20230919091738.out','t004_20000101_fc0_1_JOBA.20230919091738.err',2,'t004_20000101_fc0_2_JOBA',replace('                 30217473  COMPLETED          2        1 2023-09-19T09:17:20 2023-09-19T09:17:21 2023-09-19T09:17:31          2.08K                                                     \n           30217473.batch  COMPLETED          2        1 2023-09-19T09:17:21 2023-09-19T09:17:21 2023-09-19T09:17:31          1.57K                      831K                      831K \n          30217473.extern  COMPLETED          2        1 2023-09-19T09:17:21 2023-09-19T09:17:21 2023-09-19T09:17:31          2.08K                       20K                       20K \n','\n',char(10)));
INSERT INTO job_data VALUES(2,0,'t004_20000101_fc0_2_JOBA','2023-09-19-09:17:41','2023-09-19-09:31:27',1695107861,1695107869,1695107874,'COMPLETED',2,2,'00:02','debug',2040,'2000-01-01 00:00:00','JOBA','fc0',2,0,'MARENOSTRUM4',30217474,'',1,4,0.0,0.0,'t004_20000101_fc0_2_JOBA.20230919091759.out','t004_20000101_fc0_2_JOBA.20230919091759.err',2,'t004_20000101_fc0_3_JOBA',replace('                 30217474  COMPLETED          2        1 2023-09-19T09:17:41 2023-09-19T09:17:44 2023-09-19T09:17:56          2.04K                                                     \n           30217474.batch  COMPLETED          2        1 2023-09-19T09:17:44 2023-09-19T09:17:44 2023-09-19T09:17:56          1.53K                      829K                      829K \n          30217474.extern  COMPLETED          2        1 2023-09-19T09:17:44 2023-09-19T09:17:44 2023-09-19T09:17:56          2.04K                       24K                       24K \n','\n',char(10)));
INSERT INTO job_data VALUES(3,0,'t004_20000101_fc0_3_JOBA','2023-09-19-09:18:04','2023-09-19-09:31:48',1695107884,1695107890,1695107895,'COMPLETED',2,2,'00:02','debug',1850,'2000-01-01 00:00:00','JOBA','fc0',3,0,'MARENOSTRUM4',30217475,'',1,4,0.0,0.0,'t004_20000101_fc0_3_JOBA.20230919091821.out','t004_20000101_fc0_3_JOBA.20230919091821.err',2,'',replace('                 30217475  COMPLETED          2        1 2023-09-19T09:18:04 2023-09-19T09:18:06 2023-09-19T09:18:16          1.85K                                                     \n           30217475.batch  COMPLETED          2        1 2023-09-19T09:18:06 2023-09-19T09:18:06 2023-09-19T09:18:16          1.47K                      852K                      852K \n          30217475.extern  COMPLETED          2        1 2023-09-19T09:18:06 2023-09-19T09:18:06 2023-09-19T09:18:16          1.85K                       29K                       29K \n','\n',char(10)));
INSERT INTO job_data VALUES(4,1,'t004_20000101_fc0_1_JOBA','2023-09-19-09:31:06','2023-09-19-09:34:37',1695108666,1695108674,1695108679,'COMPLETED',2,2,'00:02','debug',1470,'2000-01-01 00:00:00','JOBA','fc0',1,0,'MARENOSTRUM4',30217558,'',1,5,0.0,0.0,'t004_20000101_fc0_1_JOBA.20230919093124.out','t004_20000101_fc0_1_JOBA.20230919093124.err',2,'t004_20000101_fc0_2_JOBA',replace('                 30217558  COMPLETED          2        1 2023-09-19T09:31:06 2023-09-19T09:31:11 2023-09-19T09:31:19          1.47K                                                     \n           30217558.batch  COMPLETED          2        1 2023-09-19T09:31:11 2023-09-19T09:31:11 2023-09-19T09:31:19          1.42K                      864K                      864K \n          30217558.extern  COMPLETED          2        1 2023-09-19T09:31:11 2023-09-19T09:31:11 2023-09-19T09:31:19          1.47K                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(5,1,'t004_20000101_fc0_2_JOBA','2023-09-19-09:31:27','2023-09-19-09:35:15',1695108687,1695108691,1695108696,'COMPLETED',2,2,'00:02','debug',1870,'2000-01-01 00:00:00','JOBA','fc0',2,0,'MARENOSTRUM4',30217561,'',1,5,0.0,0.0,'t004_20000101_fc0_2_JOBA.20230919093145.out','t004_20000101_fc0_2_JOBA.20230919093145.err',2,'t004_20000101_fc0_3_JOBA',replace('                 30217561  COMPLETED          2        1 2023-09-19T09:31:27 2023-09-19T09:31:27 2023-09-19T09:31:38          1.87K                                                     \n           30217561.batch  COMPLETED          2        1 2023-09-19T09:31:27 2023-09-19T09:31:27 2023-09-19T09:31:38          1.40K                      862K                      862K \n          30217561.extern  COMPLETED          2        1 2023-09-19T09:31:27 2023-09-19T09:31:27 2023-09-19T09:31:38          1.87K                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(6,1,'t004_20000101_fc0_3_JOBA','2023-09-19-09:31:48','2023-09-19-10:53:25',1695108708,1695108717,1695108722,'COMPLETED',2,2,'00:02','debug',1720,'2000-01-01 00:00:00','JOBA','fc0',3,0,'MARENOSTRUM4',30217562,'',1,5,0.0,0.0,'t004_20000101_fc0_3_JOBA.20230919093206.out','t004_20000101_fc0_3_JOBA.20230919093206.err',2,'',replace('                 30217562  COMPLETED          2        1 2023-09-19T09:31:48 2023-09-19T09:31:53 2023-09-19T09:32:03          1.72K                                                     \n           30217562.batch  COMPLETED          2        1 2023-09-19T09:31:53 2023-09-19T09:31:53 2023-09-19T09:32:03          1.39K                      814K                      814K \n          30217562.extern  COMPLETED          2        1 2023-09-19T09:31:53 2023-09-19T09:31:53 2023-09-19T09:32:03          1.72K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(7,2,'t004_20000101_fc0_1_JOBA','2023-09-19-09:34:37','2023-09-19-10:52:25',1695108877,1695108891,1695108896,'COMPLETED',2,2,'00:02','debug',579,'2000-01-01 00:00:00','JOBA','fc0',1,0,'MARENOSTRUM4',30217598,'',1,6,0.0,0.0,'t004_20000101_fc0_1_JOBA.20230919093454.out','t004_20000101_fc0_1_JOBA.20230919093454.err',2,'t004_20000101_fc0_2_JOBA',replace('                 30217598  COMPLETED          2        1 2023-09-19T09:34:37 2023-09-19T09:34:47 2023-09-19T09:34:56            579                                                     \n           30217598.batch  COMPLETED          2        1 2023-09-19T09:34:47 2023-09-19T09:34:47 2023-09-19T09:34:56            562                     1128K                     1128K \n          30217598.extern  COMPLETED          2        1 2023-09-19T09:34:47 2023-09-19T09:34:47 2023-09-19T09:34:56            579                      871K                      871K \n','\n',char(10)));
INSERT INTO job_data VALUES(8,2,'t004_20000101_fc0_2_JOBA','2023-09-19-09:35:15','2023-09-19-10:53:05',1695108915,1695108920,1695108925,'COMPLETED',2,2,'00:02','debug',787,'2000-01-01 00:00:00','JOBA','fc0',2,0,'MARENOSTRUM4',30217605,'',1,6,0.0,0.0,'t004_20000101_fc0_2_JOBA.20230919093532.out','t004_20000101_fc0_2_JOBA.20230919093532.err',2,'t004_20000101_fc0_3_JOBA',replace('                 30217605  COMPLETED          2        1 2023-09-19T09:35:15 2023-09-19T09:35:17 2023-09-19T09:35:25            787                                                     \n           30217605.batch  COMPLETED          2        1 2023-09-19T09:35:17 2023-09-19T09:35:17 2023-09-19T09:35:25            764                     1039K                     1039K \n          30217605.extern  COMPLETED          2        1 2023-09-19T09:35:17 2023-09-19T09:35:17 2023-09-19T09:35:25            787                      713K                      713K \n','\n',char(10)));
INSERT INTO job_data VALUES(9,3,'t004_20000101_fc0_1_JOBA','2023-09-19-10:52:25','2023-09-26-15:37:16',1695113545,1695113566,1695113571,'COMPLETED',2,2,'00:02','debug',678,'2000-01-01 00:00:00','JOBA','fc0',1,0,'MARENOSTRUM4',30218146,'',1,7,0.0,0.0,'t004_20000101_fc0_1_JOBA.20230919105302.out','t004_20000101_fc0_1_JOBA.20230919105302.err',2,'t004_20000101_fc0_2_JOBA',replace('                 30218146  COMPLETED          2        1 2023-09-19T10:52:25 2023-09-19T10:52:42 2023-09-19T10:52:51            678                                                     \n           30218146.batch  COMPLETED          2        1 2023-09-19T10:52:42 2023-09-19T10:52:42 2023-09-19T10:52:51            657                     1134K                     1134K \n          30218146.extern  COMPLETED          2        1 2023-09-19T10:52:42 2023-09-19T10:52:42 2023-09-19T10:52:51            678                      777K                      777K \n','\n',char(10)));
INSERT INTO job_data VALUES(10,3,'t004_20000101_fc0_2_JOBA','2023-09-19-10:53:05','2023-09-26-15:37:58',1695113585,1695113589,1695113594,'COMPLETED',2,2,'00:02','debug',629,'2000-01-01 00:00:00','JOBA','fc0',2,0,'MARENOSTRUM4',30218152,'',1,7,0.0,0.0,'t004_20000101_fc0_2_JOBA.20230919105323.out','t004_20000101_fc0_2_JOBA.20230919105323.err',2,'t004_20000101_fc0_3_JOBA',replace('                 30218152  COMPLETED          2        1 2023-09-19T10:53:05 2023-09-19T10:53:05 2023-09-19T10:53:14            629                                                     \n           30218152.batch  COMPLETED          2        1 2023-09-19T10:53:05 2023-09-19T10:53:05 2023-09-19T10:53:14            613                     1156K                     1156K \n          30218152.extern  COMPLETED          2        1 2023-09-19T10:53:05 2023-09-19T10:53:05 2023-09-19T10:53:14            629                      766K                      766K \n','\n',char(10)));
INSERT INTO job_data VALUES(11,3,'t004_20000101_fc0_3_JOBA','2023-09-19-10:53:25','2023-09-26-15:39:59',1695113605,1695113613,1695113618,'COMPLETED',2,2,'00:02','debug',630,'2000-01-01 00:00:00','JOBA','fc0',3,0,'MARENOSTRUM4',30218154,'',1,7,0.0,0.0,'t004_20000101_fc0_3_JOBA.20230919105343.out','t004_20000101_fc0_3_JOBA.20230919105343.err',2,'',replace('                 30218154  COMPLETED          2        1 2023-09-19T10:53:25 2023-09-19T10:53:29 2023-09-19T10:53:38            630                                                     \n           30218154.batch  COMPLETED          2        1 2023-09-19T10:53:29 2023-09-19T10:53:29 2023-09-19T10:53:38            615                     1140K                     1140K \n          30218154.extern  COMPLETED          2        1 2023-09-19T10:53:29 2023-09-19T10:53:29 2023-09-19T10:53:38            630                      863K                      863K \n','\n',char(10)));
INSERT INTO job_data VALUES(12,4,'t004_20000101_fc0_1_JOBA','2023-09-26-15:37:16','2023-09-27-11:04:12',1695735436,1695735454,1695735459,'COMPLETED',2,2,'00:02','debug',681,'2000-01-01 00:00:00','JOBA','fc0',1,0,'MARENOSTRUM4',30261186,'',1,8,0.0,0.0,'t004_20000101_fc0_1_JOBA.20230926153735.out','t004_20000101_fc0_1_JOBA.20230926153735.err',2,'t004_20000101_fc0_2_JOBA',replace('                 30261186  COMPLETED          2        1 2023-09-26T15:37:16 2023-09-26T15:37:29 2023-09-26T15:37:41            681                                                     \n           30261186.batch  COMPLETED          2        1 2023-09-26T15:37:29 2023-09-26T15:37:29 2023-09-26T15:37:41            535                     1134K                     1134K \n          30261186.extern  COMPLETED          2        1 2023-09-26T15:37:29 2023-09-26T15:37:29 2023-09-26T15:37:41            681                     1033K                     1033K \n','\n',char(10)));
INSERT INTO job_data VALUES(13,4,'t004_20000101_fc0_2_JOBA','2023-09-26-15:37:58','2023-09-27-11:06:11',1695735478,1695735574,1695735579,'COMPLETED',2,2,'00:02','debug',1640,'2000-01-01 00:00:00','JOBA','fc0',2,0,'MARENOSTRUM4',30261188,'',1,8,0.0,0.0,'t004_20000101_fc0_2_JOBA.20230926153937.out','t004_20000101_fc0_2_JOBA.20230926153937.err',2,'t004_20000101_fc0_3_JOBA',replace('                 30261188  COMPLETED          2        1 2023-09-26T15:37:58 2023-09-26T15:39:30 2023-09-26T15:39:41          1.64K                                                     \n           30261188.batch  COMPLETED          2        1 2023-09-26T15:39:30 2023-09-26T15:39:30 2023-09-26T15:39:41          1.24K                      999K                      999K \n          30261188.extern  COMPLETED          2        1 2023-09-26T15:39:30 2023-09-26T15:39:30 2023-09-26T15:39:41          1.64K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(14,4,'t004_20000101_fc0_3_JOBA','2023-09-26-15:39:59','2023-09-27-11:08:09',1695735599,1695735694,1695735699,'COMPLETED',2,2,'00:02','debug',1800,'2000-01-01 00:00:00','JOBA','fc0',3,0,'MARENOSTRUM4',30261197,'',1,8,0.0,0.0,'t004_20000101_fc0_3_JOBA.20230926154153.out','t004_20000101_fc0_3_JOBA.20230926154153.err',2,'',replace('                 30261197  COMPLETED          2        1 2023-09-26T15:39:59 2023-09-26T15:41:29 2023-09-26T15:41:41          1.80K                                                     \n           30261197.batch  COMPLETED          2        1 2023-09-26T15:41:29 2023-09-26T15:41:29 2023-09-26T15:41:41          1.40K                      973K                      973K \n          30261197.extern  COMPLETED          2        1 2023-09-26T15:41:29 2023-09-26T15:41:29 2023-09-26T15:41:41          1.80K                      700K                      700K \n','\n',char(10)));
INSERT INTO job_data VALUES(15,5,'t004_20000101_fc0_1_JOBA','2023-09-27-11:04:12','2023-09-27-11:07:06',1695805452,1695805555,1695805560,'COMPLETED',2,2,'00:02','debug',1090,'2000-01-01 00:00:00','JOBA','fc0',1,1,'MARENOSTRUM4',30267747,'',1,9,0.0,0.0,'t004_20000101_fc0_1_JOBA.20230927110603.out','t004_20000101_fc0_1_JOBA.20230927110603.err',2,'t004_20000101_fc0_2_JOBA',replace('                 30267747  COMPLETED          2        1 2023-09-27T11:04:12 2023-09-27T11:05:50 2023-09-27T11:06:01          1.09K                                                     \n           30267747.batch  COMPLETED          2        1 2023-09-27T11:05:50 2023-09-27T11:05:50 2023-09-27T11:06:01            835                      971K                      971K \n          30267747.extern  COMPLETED          2        1 2023-09-27T11:05:50 2023-09-27T11:05:50 2023-09-27T11:06:01          1.09K                       27K                       27K \n','\n',char(10)));
INSERT INTO job_data VALUES(16,5,'t004_20000101_fc0_2_JOBA','2023-09-27-11:06:11','2023-09-27-11:09:08',1695805571,1695805665,1695805670,'COMPLETED',2,2,'00:02','debug',1140,'2000-01-01 00:00:00','JOBA','fc0',2,1,'MARENOSTRUM4',30267868,'',1,9,0.0,0.0,'t004_20000101_fc0_2_JOBA.20230927110804.out','t004_20000101_fc0_2_JOBA.20230927110804.err',2,'t004_20000101_fc0_3_JOBA',replace('                 30267868  COMPLETED          2        1 2023-09-27T11:06:11 2023-09-27T11:07:40 2023-09-27T11:07:51          1.14K                                                     \n           30267868.batch  COMPLETED          2        1 2023-09-27T11:07:40 2023-09-27T11:07:40 2023-09-27T11:07:51            872                      921K                      921K \n          30267868.extern  COMPLETED          2        1 2023-09-27T11:07:40 2023-09-27T11:07:40 2023-09-27T11:07:51          1.14K                       22K                       22K \n','\n',char(10)));
INSERT INTO job_data VALUES(17,5,'t004_20000101_fc0_3_JOBA','2023-09-27-11:08:09','2023-09-27-11:10:05',1695805689,1695805772,1695805777,'COMPLETED',2,2,'00:02','debug',0,'2000-01-01 00:00:00','JOBA','fc0',3,1,'MARENOSTRUM4',30267924,'',0,9,0.0,0.0,'t004_20000101_fc0_3_JOBA.20230927110937.out','t004_20000101_fc0_3_JOBA.20230927110937.err',5,'','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',9);
INSERT INTO sqlite_sequence VALUES('job_data',17);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
