PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-06-28-12:26:28','2023-06-28-12:56:46',1687947988,1687949806,'month',1,0,88,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "EXPORT": "%CURRENT_ROOTDIR%", "CHECK": "on_submission", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "local", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.7", "MAXWAITINGJOBS": "3000", "TOTALJOBS": "3000", "SAFETYSLEEPTIME": 10, "RETRIALS": 0, "PRESUBMISSION": false}, "MAIL": {"NOTIFICATIONS": "False", "TO": "daniel.beltran@bsc.es"}, "DEFAULT": {"EXPID": "a01y", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"DATELIST": "20210811 20210812", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "templates/proj.conf", "FILE_JOBS_CONF": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling", "STORAGE": {}}');
INSERT INTO experiment_run VALUES(2,'2023-06-28-12:56:46','2023-06-28-13:20:28',1687949806,1687951228,'month',1,1,45,1,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3000", "TOTALJOBS": "3000", "SAFETYSLEEPTIME": 10, "RETRIALS": "0", "PRESUBMISSION": false}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "EXPORT": "%CURRENT_ROOTDIR%", "CHECK": "on_submission", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "local", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAX_WAITING_JOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}}, "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CALENDAR": "standard"}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": "False", "TO": "daniel.beltran@bsc.es"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling"}');
INSERT INTO experiment_run VALUES(3,'2023-06-28-13:20:28','2023-06-28-13:21:06',1687951228,1687951266,'month',1,0,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}}, "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling"}');
INSERT INTO experiment_run VALUES(4,'2023-06-28-13:21:06','2023-06-28-14:05:36',1687951266,1687953936,'month',1,2,45,4,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}}, "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling"}');
INSERT INTO experiment_run VALUES(5,'2023-06-28-14:05:37','2023-06-28-14:05:47',1687953937,1687953947,'month',1,0,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}}, "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling"}');
INSERT INTO experiment_run VALUES(6,'2023-06-28-14:05:47','2023-06-28-15:34:23',1687953947,1687959263,'month',1,3,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}}, "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling"}');
INSERT INTO experiment_run VALUES(7,'2023-06-28-15:34:23','2023-06-28-16:04:39',1687959263,1687961079,'month',1,6,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}}, "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling"}');
INSERT INTO experiment_run VALUES(8,'2023-06-28-16:04:39','2023-06-28-16:18:26',1687961079,1687961906,'month',1,6,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}}, "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling"}');
INSERT INTO experiment_run VALUES(9,'2023-06-28-16:18:26','2023-06-28-16:49:04',1687961906,1687963744,'month',1,7,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}}, "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling"}');
INSERT INTO experiment_run VALUES(10,'2023-06-28-16:49:04','2023-06-28-17:53:02',1687963744,1687967582,'month',1,25,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}}, "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling"}');
INSERT INTO experiment_run VALUES(11,'2023-06-28-17:53:02','2023-06-28-18:12:54',1687967582,1687968774,'month',1,1,45,1,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "NORD3": {"TYPE": "lsf", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "False", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "1024", "PROCESSORS_PER_NODE": "16"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "PROJECT": "Earth", "USER": "dbeltran", "SCRATCH_DIR": "/esarchive/scratch"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "autosubmit/configuration", "POST": "~/platforms.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(12,'2023-06-28-18:12:54','2023-06-28-21:08:45',1687968774,1687979325,'month',1,26,45,5,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(13,'2023-06-28-21:08:45','2023-06-29-00:19:11',1687979325,1687990751,'month',1,43,45,0,0,0,0,2,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(14,'2023-06-29-00:19:11','2023-06-29-00:19:21',1687990751,1687990761,'month',1,0,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(15,'2023-06-29-00:19:21','2023-06-29-00:20:59',1687990761,1687990859,'month',1,0,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(16,'2023-06-29-00:20:59','2023-06-29-00:21:26',1687990859,1687990886,'month',1,0,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(17,'2023-06-29-00:21:26','2023-06-29-00:21:36',1687990886,1687990896,'month',1,0,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(18,'2023-06-29-00:21:36','2023-06-29-09:52:45',1687990896,1688025165,'month',1,29,45,4,1,1,0,1,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(19,'2023-06-29-09:52:45','2023-06-29-09:54:17',1688025165,1688025257,'month',1,0,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(20,'2023-06-29-09:54:17','2023-06-29-09:59:49',1688025257,1688025589,'month',1,44,45,1,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(21,'2023-06-29-09:59:49','2023-06-29-10:00:30',1688025589,1688025630,'month',1,0,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(22,'2023-06-29-10:00:30','2023-06-29-11:21:34',1688025630,1688030494,'month',1,18,45,3,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(23,'2023-06-29-11:21:34','2023-06-29-11:22:41',1688030494,1688030561,'month',1,0,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(24,'2023-06-29-11:22:41','2023-06-30-10:25:20',1688030561,1688113520,'month',1,30,45,2,3,1,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(25,'2023-06-30-10:25:20','2023-06-30-10:25:20',1688113520,0,'month',1,0,45,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00m", "PROJDIR": "/home/dbeltran/new_autosubmit/a00m/proj/project_files", "DEFAULT": {"EXPID": "a00m", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a00m/proj/auto-performance-profiling/autosubmit/configuration", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a00m_CLEAN','2023-06-28-13:12:55','2023-06-28-13:21:31',1687950775,1687950780,1687950780,'COMPLETED',2,1,'00:30','debug',88,'','CLEAN','',0,0,'MARENOSTRUM4',29250836,'',1,2,0.0,0.0,'a00m_CLEAN.20230628131313.out','a00m_CLEAN.20230628131313.err',2,'a00m_REMOTE_SETUP',replace('                 29250836  COMPLETED          1        1 2023-06-28T13:12:55 2023-06-28T13:12:56 2023-06-28T13:13:00             88                                                     \n           29250836.batch  COMPLETED          1        1 2023-06-28T13:12:56 2023-06-28T13:12:56 2023-06-28T13:13:00             45                      973K                      973K \n          29250836.extern  COMPLETED          1        1 2023-06-28T13:12:56 2023-06-28T13:12:56 2023-06-28T13:13:00             88                      708K                      708K \n','\n',char(10)));
INSERT INTO job_data VALUES(2,0,'a00m_REMOTE_SETUP','2023-06-28-13:13:14','2023-06-28-13:21:50',1687950794,1687950794,1687950866,'FAILED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',34670,'',0,2,0.0,0.0,'a00m_REMOTE_SETUP.20230628131426.out','a00m_REMOTE_SETUP.20230628131426.err',5,'a00m_20210811_StrongScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA,a00m_20210811_WeakScaling_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(3,1,'a00m_CLEAN','2023-06-28-13:21:31','2023-06-28-14:06:17',1687951291,1687951291,1687951291,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',285644,'',0,4,0.0,0.0,'a00m_CLEAN.20230628132145.out','a00m_CLEAN.20230628132145.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(4,1,'a00m_REMOTE_SETUP','2023-06-28-13:21:50','2023-06-28-14:06:47',1687951310,1687951310,1687951576,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',286280,'',0,4,0.0,0.0,'a00m_REMOTE_SETUP.20230628132204.out','a00m_REMOTE_SETUP.20230628132204.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(5,1,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-28-13:26:30','2023-06-28-14:11:21',1687951590,1687951590,1687951624,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',292993,'',0,4,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628132704.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628132704.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(6,1,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-28-13:26:35','2023-06-28-14:11:35',1687951595,1687951595,1687951624,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',293536,'',0,4,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628132704.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628132704.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(7,1,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-28-13:26:41','2023-06-28-14:11:49',1687951601,1687951601,1687951625,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',294068,'',0,4,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628132705.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628132705.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(8,1,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-28-13:27:09','2023-06-28-14:12:43',1687951629,1687951629,1687951644,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',295298,'',0,4,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628132724.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628132724.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(9,2,'a00m_CLEAN','2023-06-28-14:06:17','2023-06-28-15:35:19',1687953977,1687953977,1687953980,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',389802,'',0,6,0.0,0.0,'a00m_CLEAN.20230628140632.out','a00m_CLEAN.20230628140632.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(10,2,'a00m_REMOTE_SETUP','2023-06-28-14:06:47','2023-06-28-15:35:52',1687954007,1687954007,1687954247,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',390796,'',0,6,0.0,0.0,'a00m_REMOTE_SETUP.20230628140706.out','a00m_REMOTE_SETUP.20230628140706.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(11,2,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-28-14:11:21','2023-06-28-14:22:36',1687954281,1687954281,1687954348,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',402922,'',0,6,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628141228.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628141228.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(12,2,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-28-14:11:35','2023-06-28-14:22:53',1687954295,1687954295,1687954348,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',403686,'',0,6,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628141228.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628141228.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(13,2,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-28-14:11:49','2023-06-28-14:23:12',1687954309,1687954309,1687954349,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',404460,'',0,6,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628141229.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628141229.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(14,2,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-28-14:12:43','2023-06-28-14:25:27',1687954363,1687954363,1687954383,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',406571,'',0,6,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628141303.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628141303.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(15,3,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-28-14:22:36','2023-06-28-15:39:28',1687954956,1687954956,1687955060,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',417557,'',0,6,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628142420.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628142420.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(16,3,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-28-14:22:53','2023-06-28-15:39:33',1687954973,1687954973,1687955006,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',418382,'',0,6,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628142421.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628142421.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(17,3,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-28-14:23:12','2023-06-28-15:39:42',1687954992,1687954992,1687955062,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',419534,'',0,6,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628142422.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628142422.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(18,3,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-06-28-14:25:06','2023-06-28-15:40:24',1687955106,1687955106,1687955180,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,0,'MARENOSTRUM0',422835,'',0,6,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628142619.out','a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628142619.err',5,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(19,3,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-28-14:25:27','2023-06-28-15:41:05',1687955127,1687955127,1687955202,'FAILED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',424042,'',0,6,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628142619.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628142619.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(20,3,'a00m_CLEAN','2023-06-28-15:35:19','2023-06-28-16:05:05',1687959319,1687959319,1687959323,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',202779,'',0,7,0.0,0.0,'a00m_CLEAN.20230628153538.out','a00m_CLEAN.20230628153538.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(21,3,'a00m_REMOTE_SETUP','2023-06-28-15:35:52','2023-06-28-16:05:28',1687959352,1687959352,1687959551,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',203697,'',0,7,0.0,0.0,'a00m_REMOTE_SETUP.20230628153611.out','a00m_REMOTE_SETUP.20230628153611.err',5,'a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(22,4,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-28-15:39:28','2023-06-28-16:09:07',1687959568,1687959568,1687959576,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',207159,'',0,7,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628154004.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628154004.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(23,4,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-28-15:39:33','2023-06-28-16:09:12',1687959573,1687959573,1687959581,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',207949,'',0,7,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628154005.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628154005.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(24,4,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-28-15:39:42','2023-06-28-16:09:20',1687959582,1687959582,1687959588,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',208680,'',0,7,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628154005.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628154005.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(25,4,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-28-15:40:11','2023-06-28-16:09:52',1687959611,1687959611,1687959660,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',210113,'',0,7,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628154100.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628154100.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(26,4,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-06-28-15:40:24','2023-06-28-16:09:56',1687959624,1687959624,1687959660,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,0,'MARENOSTRUM0',211631,'',0,7,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628154100.out','a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628154100.err',5,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(27,4,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-28-15:40:37','2023-06-28-16:10:01',1687959637,1687959637,1687959661,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',212039,'',0,7,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628154100.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628154100.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(28,4,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-28-15:41:05','2023-06-28-16:10:29',1687959665,1687959665,1687959681,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',213419,'',0,7,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628154121.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628154121.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(29,4,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-28-15:41:43','2023-06-28-16:10:52',1687959703,1687959703,1687959718,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',215691,'',0,7,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628154158.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628154158.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(30,4,'a00m_CLEAN','2023-06-28-16:05:05','2023-06-28-16:18:54',1687961105,1687961105,1687961108,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',224730,'',0,8,0.0,0.0,'a00m_CLEAN.20230628160523.out','a00m_CLEAN.20230628160523.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(31,4,'a00m_REMOTE_SETUP','2023-06-28-16:05:28','2023-06-28-16:19:16',1687961128,1687961128,1687961329,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',225242,'',0,8,0.0,0.0,'a00m_REMOTE_SETUP.20230628160543.out','a00m_REMOTE_SETUP.20230628160543.err',5,'a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(32,5,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-28-16:09:07','2023-06-28-16:22:34',1687961347,1687961347,1687961354,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',228574,'',0,8,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628160946.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628160946.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(33,5,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-28-16:09:12','2023-06-28-16:22:39',1687961352,1687961352,1687961361,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',229427,'',0,8,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628160946.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628160946.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(34,5,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-28-16:09:20','2023-06-28-16:22:45',1687961360,1687961360,1687961367,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',230165,'',0,8,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628160947.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628160947.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(35,5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-28-16:09:52','2023-06-28-16:23:13',1687961391,1687961391,1687961424,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',231324,'',0,8,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628161023.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628161023.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(36,5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-06-28-16:09:56','2023-06-28-16:23:19',1687961396,1687961396,1687961424,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,0,'MARENOSTRUM0',232330,'',0,8,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628161024.out','a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628161024.err',5,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(37,5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-28-16:10:01','2023-06-28-16:23:24',1687961401,1687961401,1687961424,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',232872,'',0,8,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628161024.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628161024.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(38,5,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-28-16:10:29','2023-06-28-16:23:54',1687961429,1687961429,1687961436,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',234900,'',0,8,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628161046.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628161046.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(39,5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-28-16:10:52','2023-06-28-16:24:20',1687961452,1687961452,1687961466,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',237078,'',0,8,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628161106.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628161106.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(40,5,'a00m_CLEAN','2023-06-28-16:18:54','2023-06-28-16:49:46',1687961934,1687961934,1687961936,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',240728,'',0,9,0.0,0.0,'a00m_CLEAN.20230628161912.out','a00m_CLEAN.20230628161912.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(41,5,'a00m_REMOTE_SETUP','2023-06-28-16:19:16','2023-06-28-16:50:15',1687961956,1687961956,1687962142,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',241240,'',0,9,0.0,0.0,'a00m_REMOTE_SETUP.20230628161931.out','a00m_REMOTE_SETUP.20230628161931.err',5,'a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(42,6,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-28-16:22:34','2023-06-28-16:56:00',1687962154,1687962154,1687962162,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',245689,'',0,9,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628162308.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628162308.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(43,6,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-28-16:22:39','2023-06-28-16:56:05',1687962159,1687962159,1687962168,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',246444,'',0,9,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628162308.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628162308.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(44,6,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-28-16:22:45','2023-06-28-16:56:13',1687962165,1687962165,1687962172,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',247123,'',0,9,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628162309.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628162309.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(45,6,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-28-16:23:13','2023-06-28-16:56:47',1687962193,1687962193,1687962229,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',248538,'',0,9,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628162349.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628162349.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(46,6,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-06-28-16:23:19','2023-06-28-16:56:52',1687962199,1687962199,1687962337,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,0,'MARENOSTRUM0',249808,'',0,9,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628162349.out','a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628162349.err',5,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(47,6,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-28-16:23:24','2023-06-28-16:56:57',1687962204,1687962204,1687962229,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',250769,'',0,9,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628162349.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628162349.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(48,6,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-28-16:23:54','2023-06-28-16:57:44',1687962234,1687962234,1687962241,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',254105,'',0,9,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628162416.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628162416.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(49,6,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-28-16:24:20','2023-06-28-16:59:34',1687962260,1687962260,1687962284,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',258577,'',0,9,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628162444.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628162444.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(50,6,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','2023-06-28-16:25:52','2023-06-28-17:00:21',1687962352,1687962360,1687962402,'FAILED',2,1,'00:30','debug',2070,'2021-08-11 00:00:00','PREPARE_TESTS','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252285,'',1,9,0.0,0.0,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230628162642.out','a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230628162642.err',2,'a00m_20210811_HardwareBenchmarks_STREAM_2,a00m_20210811_HardwareBenchmarks_STREAM_4,a00m_20210811_HardwareBenchmarks_STREAM_16,a00m_20210811_HardwareBenchmarks_OSU_RUN_96,a00m_20210811_HardwareBenchmarks_STREAM_48,a00m_20210811_HardwareBenchmarks_OSU_RUN_48,a00m_20210811_HardwareBenchmarks_OSU_RUN_192,a00m_20210811_HardwareBenchmarks_STREAM_1,a00m_20210811_HardwareBenchmarks_STREAM_32,a00m_20210811_HardwareBenchmarks_STREAM_8',replace('                 29252285     FAILED          1        1 2023-06-28T16:25:52 2023-06-28T16:25:57 2023-06-28T16:26:07          2.07K                                                     \n           29252285.batch     FAILED          1        1 2023-06-28T16:25:57 2023-06-28T16:25:57 2023-06-28T16:26:07          1.65K                      871K                      871K \n          29252285.extern  COMPLETED          1        1 2023-06-28T16:25:57 2023-06-28T16:25:57 2023-06-28T16:26:07          2.07K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(51,6,'a00m_CLEAN','2023-06-28-16:49:46','2023-06-28-17:54:37',1687963786,1687963786,1687963789,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',294793,'',0,10,0.0,0.0,'a00m_CLEAN.20230628165004.out','a00m_CLEAN.20230628165004.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(52,6,'a00m_REMOTE_SETUP','2023-06-28-16:50:15','2023-06-28-17:55:56',1687963815,1687963815,1687964147,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',295589,'',0,10,0.0,0.0,'a00m_REMOTE_SETUP.20230628165031.out','a00m_REMOTE_SETUP.20230628165031.err',5,'a00m_20210811_StrongScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA,a00m_20210811_WeakScaling_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(53,7,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-28-16:56:00','2023-06-28-18:17:04',1687964160,1687964160,1687964168,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',301616,'',0,10,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628165641.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628165641.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(54,7,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-28-16:56:05','2023-06-28-18:17:10',1687964165,1687964165,1687964173,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',302393,'',0,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628165642.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628165642.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(55,7,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-28-16:56:13','2023-06-28-18:17:16',1687964173,1687964173,1687964182,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',303178,'',0,10,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628165642.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628165642.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(56,7,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-28-16:56:47','2023-06-28-18:17:47',1687964207,1687964207,1687966385,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',304346,'',0,10,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628165727.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628165727.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(57,7,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-06-28-16:56:52','2023-06-28-18:17:52',1687964212,1687964212,1687964376,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,0,'MARENOSTRUM0',305679,'',0,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628165727.out','a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628165727.err',5,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(58,7,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-28-16:56:57','2023-06-28-18:17:58',1687964217,1687964217,1687966012,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',306555,'',0,10,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628165727.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628165727.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(59,7,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-28-16:57:44','2023-06-28-18:18:46',1687964264,1687964264,1687964281,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',316598,'',0,10,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628165829.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628165829.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(60,7,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-28-16:59:34','2023-06-28-18:19:39',1687964374,1687964374,1687965365,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',347338,'',0,10,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628170015.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628170015.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(61,7,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','2023-06-28-17:00:21','2023-06-28-18:21:06',1687964421,1687964500,1687964505,'COMPLETED',2,1,'00:30','debug',924,'2021-08-11 00:00:00','PREPARE_TESTS','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252559,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230628170202.out','a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230628170202.err',2,'a00m_20210811_HardwareBenchmarks_STREAM_2,a00m_20210811_HardwareBenchmarks_STREAM_4,a00m_20210811_HardwareBenchmarks_STREAM_16,a00m_20210811_HardwareBenchmarks_OSU_RUN_96,a00m_20210811_HardwareBenchmarks_STREAM_48,a00m_20210811_HardwareBenchmarks_OSU_RUN_48,a00m_20210811_HardwareBenchmarks_OSU_RUN_192,a00m_20210811_HardwareBenchmarks_STREAM_1,a00m_20210811_HardwareBenchmarks_STREAM_32,a00m_20210811_HardwareBenchmarks_STREAM_8',replace('                 29252559  COMPLETED          1        1 2023-06-28T17:00:20 2023-06-28T17:01:37 2023-06-28T17:01:45            924                                                     \n           29252559.batch  COMPLETED          1        1 2023-06-28T17:01:37 2023-06-28T17:01:37 2023-06-28T17:01:45            907                     1026K                     1026K \n          29252559.extern  COMPLETED          1        1 2023-06-28T17:01:37 2023-06-28T17:01:37 2023-06-28T17:01:45            924                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(62,7,'a00m_20210811_HardwareBenchmarks_STREAM_48','2023-06-28-17:02:28','2023-06-28-17:22:47',1687964548,1687964554,1687964601,'FAILED',2,48,'00:30','debug',1000,'2021-08-11 00:00:00','STREAM_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252634,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_48.20230628170321.out','a00m_20210811_HardwareBenchmarks_STREAM_48.20230628170321.err',2,'',replace('                 29252634     FAILED         48        1 2023-06-28T17:02:28 2023-06-28T17:02:31 2023-06-28T17:02:41          1.00K                                                     \n           29252634.batch     FAILED         48        1 2023-06-28T17:02:31 2023-06-28T17:02:31 2023-06-28T17:02:41            967                     1392K                     1392K \n          29252634.extern  COMPLETED         48        1 2023-06-28T17:02:31 2023-06-28T17:02:31 2023-06-28T17:02:41          1.00K                       28K                       28K \n','\n',char(10)));
INSERT INTO job_data VALUES(63,7,'a00m_20210811_HardwareBenchmarks_STREAM_32','2023-06-28-17:02:28','2023-06-28-17:22:47',1687964548,1687964576,1687964736,'FAILED',2,32,'00:30','debug',969,'2021-08-11 00:00:00','STREAM_32','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252635,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_32.20230628170536.out','a00m_20210811_HardwareBenchmarks_STREAM_32.20230628170536.err',2,'',replace('                 29252635     FAILED         32        1 2023-06-28T17:02:28 2023-06-28T17:02:54 2023-06-28T17:03:02            969                                                     \n           29252635.batch     FAILED         32        1 2023-06-28T17:02:54 2023-06-28T17:02:54 2023-06-28T17:03:02            949                     1070K                     1070K \n          29252635.extern  COMPLETED         32        1 2023-06-28T17:02:54 2023-06-28T17:02:54 2023-06-28T17:03:02            969                       27K                       27K \n','\n',char(10)));
INSERT INTO job_data VALUES(64,7,'a00m_20210811_HardwareBenchmarks_STREAM_16','2023-06-28-17:02:28','2023-06-28-17:22:47',1687964548,1687964585,1687964706,'FAILED',2,16,'00:30','debug',915,'2021-08-11 00:00:00','STREAM_16','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252636,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_16.20230628170505.out','a00m_20210811_HardwareBenchmarks_STREAM_16.20230628170505.err',2,'',replace('                 29252636     FAILED         16        1 2023-06-28T17:02:28 2023-06-28T17:03:03 2023-06-28T17:03:11            915                                                     \n           29252636.batch     FAILED         16        1 2023-06-28T17:03:03 2023-06-28T17:03:03 2023-06-28T17:03:11            898                      964K                      964K \n          29252636.extern  COMPLETED         16        1 2023-06-28T17:03:03 2023-06-28T17:03:03 2023-06-28T17:03:11            915                      607K                      607K \n','\n',char(10)));
INSERT INTO job_data VALUES(65,7,'a00m_20210811_HardwareBenchmarks_STREAM_8','2023-06-28-17:03:46','2023-06-28-17:23:24',1687964626,1687964631,1687964674,'FAILED',2,8,'00:30','debug',1290,'2021-08-11 00:00:00','STREAM_8','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252640,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_8.20230628170434.out','a00m_20210811_HardwareBenchmarks_STREAM_8.20230628170434.err',2,'',replace('                 29252640     FAILED          8        1 2023-06-28T17:03:46 2023-06-28T17:03:49 2023-06-28T17:03:59          1.29K                                                     \n           29252640.batch     FAILED          8        1 2023-06-28T17:03:49 2023-06-28T17:03:49 2023-06-28T17:03:59            993                      986K                      986K \n          29252640.extern  COMPLETED          8        1 2023-06-28T17:03:49 2023-06-28T17:03:49 2023-06-28T17:03:59          1.29K                      671K                      671K \n','\n',char(10)));
INSERT INTO job_data VALUES(66,7,'a00m_20210811_HardwareBenchmarks_STREAM_4','2023-06-28-17:06:11','2023-06-28-17:24:02',1687964771,1687964787,1687964900,'FAILED',2,4,'00:30','debug',1120,'2021-08-11 00:00:00','STREAM_4','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252650,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_4.20230628170634.out','a00m_20210811_HardwareBenchmarks_STREAM_4.20230628170634.err',2,'',replace('                 29252650     FAILED          4        1 2023-06-28T17:06:11 2023-06-28T17:06:24 2023-06-28T17:06:34          1.12K                                                     \n           29252650.batch     FAILED          4        1 2023-06-28T17:06:24 2023-06-28T17:06:24 2023-06-28T17:06:34          1.02K                     1000K                     1000K \n          29252650.extern  COMPLETED          4        1 2023-06-28T17:06:24 2023-06-28T17:06:24 2023-06-28T17:06:34          1.12K                       26K                       26K \n','\n',char(10)));
INSERT INTO job_data VALUES(67,7,'a00m_20210811_HardwareBenchmarks_STREAM_2','2023-06-28-17:06:11','2023-06-28-17:24:02',1687964771,1687964844,1687965040,'FAILED',2,2,'00:30','debug',987,'2021-08-11 00:00:00','STREAM_2','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252651,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_2.20230628171039.out','a00m_20210811_HardwareBenchmarks_STREAM_2.20230628171039.err',2,'',replace('                 29252651     FAILED          2        1 2023-06-28T17:06:11 2023-06-28T17:07:22 2023-06-28T17:07:30            987                                                     \n           29252651.batch     FAILED          2        1 2023-06-28T17:07:22 2023-06-28T17:07:22 2023-06-28T17:07:30            965                      977K                      977K \n          29252651.extern  COMPLETED          2        1 2023-06-28T17:07:22 2023-06-28T17:07:22 2023-06-28T17:07:30            987                      625K                      625K \n','\n',char(10)));
INSERT INTO job_data VALUES(68,7,'a00m_20210811_HardwareBenchmarks_STREAM_1','2023-06-28-17:06:11','2023-06-28-17:24:02',1687964771,1687964853,1687965009,'FAILED',2,1,'00:30','debug',982,'2021-08-11 00:00:00','STREAM_1','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252652,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_1.20230628171009.out','a00m_20210811_HardwareBenchmarks_STREAM_1.20230628171009.err',2,'',replace('                 29252652     FAILED          1        1 2023-06-28T17:06:11 2023-06-28T17:07:31 2023-06-28T17:07:39            982                                                     \n           29252652.batch     FAILED          1        1 2023-06-28T17:07:31 2023-06-28T17:07:31 2023-06-28T17:07:39            958                      921K                      921K \n          29252652.extern  COMPLETED          1        1 2023-06-28T17:07:31 2023-06-28T17:07:31 2023-06-28T17:07:39            982                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(69,7,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192','2023-06-28-17:06:59','2023-06-28-17:24:42',1687964819,1687964828,1687964870,'FAILED',2,192,'00:30','debug',4010,'2021-08-11 00:00:00','OSU_RUN_192','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252656,'',4,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230628170749.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230628170749.err',2,'',replace('                 29252656     FAILED        192        4 2023-06-28T17:06:59 2023-06-28T17:07:05 2023-06-28T17:07:16          4.01K                                                     \n           29252656.batch     FAILED         48        1 2023-06-28T17:07:05 2023-06-28T17:07:05 2023-06-28T17:07:16          1.28K                     1400K                     1400K \n          29252656.extern  COMPLETED        192        4 2023-06-28T17:07:05 2023-06-28T17:07:05 2023-06-28T17:07:16          4.01K                      885K                      477K \n','\n',char(10)));
INSERT INTO job_data VALUES(70,7,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96','2023-06-28-17:08:50','2023-06-28-17:24:42',1687964930,1687964936,1687964978,'FAILED',2,96,'00:30','debug',1810,'2021-08-11 00:00:00','OSU_RUN_96','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252661,'',2,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230628170938.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230628170938.err',2,'',replace('                 29252661     FAILED         96        2 2023-06-28T17:08:50 2023-06-28T17:08:53 2023-06-28T17:09:02          1.81K                                                     \n           29252661.batch     FAILED         48        1 2023-06-28T17:08:53 2023-06-28T17:08:53 2023-06-28T17:09:02            932                     1391K                     1391K \n          29252661.extern  COMPLETED         96        2 2023-06-28T17:08:53 2023-06-28T17:08:53 2023-06-28T17:09:02          1.81K                      812K                      470K \n','\n',char(10)));
INSERT INTO job_data VALUES(71,7,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48','2023-06-28-17:11:00','2023-06-28-17:25:29',1687965060,1687965064,1687965109,'FAILED',2,48,'00:30','debug',1220,'2021-08-11 00:00:00','OSU_RUN_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252665,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230628171148.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230628171148.err',2,'',replace('                 29252665     FAILED         48        1 2023-06-28T17:11:00 2023-06-28T17:11:01 2023-06-28T17:11:12          1.22K                                                     \n           29252665.batch     FAILED         48        1 2023-06-28T17:11:01 2023-06-28T17:11:01 2023-06-28T17:11:12          1.20K                     1404K                     1404K \n          29252665.extern  COMPLETED         48        1 2023-06-28T17:11:01 2023-06-28T17:11:01 2023-06-28T17:11:12          1.22K                      755K                      755K \n','\n',char(10)));
INSERT INTO job_data VALUES(72,7,'a00m_20210811_StrongScaling_PREPARE_TESTS','2023-06-28-17:16:30','2023-06-28-18:39:02',1687965390,1687965440,1687965445,'COMPLETED',2,1,'00:30','debug',836,'2021-08-11 00:00:00','PREPARE_TESTS','StrongScaling',0,0,'MARENOSTRUM4',29252701,'',1,10,0.0,0.0,'a00m_20210811_StrongScaling_PREPARE_TESTS.20230628171723.out','a00m_20210811_StrongScaling_PREPARE_TESTS.20230628171723.err',2,'a00m_20210811_StrongScaling_SCALABILITY_48,a00m_20210811_StrongScaling_SCALABILITY_96,a00m_20210811_StrongScaling_SCALABILITY_192',replace('                 29252701  COMPLETED          1        1 2023-06-28T17:16:30 2023-06-28T17:17:18 2023-06-28T17:17:25            836                                                     \n           29252701.batch  COMPLETED          1        1 2023-06-28T17:17:18 2023-06-28T17:17:18 2023-06-28T17:17:25            822                     1013K                     1013K \n          29252701.extern  COMPLETED          1        1 2023-06-28T17:17:18 2023-06-28T17:17:18 2023-06-28T17:17:25            836                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(73,7,'a00m_20210811_StrongScaling_SCALABILITY_192','2023-06-28-17:18:15','2023-06-28-17:26:08',1687965495,1687965502,1687965549,'FAILED',2,192,'00:30','debug',4220,'2021-08-11 00:00:00','SCALABILITY_192','StrongScaling',0,0,'MARENOSTRUM4',29252706,'',4,10,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_192.20230628171909.out','a00m_20210811_StrongScaling_SCALABILITY_192.20230628171909.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29252706     FAILED        192        4 2023-06-28T17:18:15 2023-06-28T17:18:18 2023-06-28T17:18:30          4.22K                                                     \n           29252706.batch     FAILED         48        1 2023-06-28T17:18:18 2023-06-28T17:18:18 2023-06-28T17:18:30          1.29K                     1365K                     1365K \n          29252706.extern  COMPLETED        192        4 2023-06-28T17:18:18 2023-06-28T17:18:18 2023-06-28T17:18:30          4.22K                      861K                   830.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(74,7,'a00m_20210811_StrongScaling_SCALABILITY_96','2023-06-28-17:18:15','2023-06-28-17:26:51',1687965495,1687965522,1687965647,'FAILED',2,96,'00:30','debug',0,'2021-08-11 00:00:00','SCALABILITY_96','StrongScaling',0,0,'MARENOSTRUM4',29252707,'',0,10,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_96.20230628172047.out','a00m_20210811_StrongScaling_SCALABILITY_96.20230628172047.err',5,'a00m_20210811_StrongScaling_FUNCTIONS_DIR','');
INSERT INTO job_data VALUES(75,7,'a00m_20210811_StrongScaling_SCALABILITY_48','2023-06-28-17:18:15','2023-06-28-17:27:26',1687965495,1687965541,1687965616,'FAILED',2,48,'00:30','debug',1230,'2021-08-11 00:00:00','SCALABILITY_48','StrongScaling',0,0,'MARENOSTRUM4',29252708,'',1,10,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_48.20230628172016.out','a00m_20210811_StrongScaling_SCALABILITY_48.20230628172016.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29252708     FAILED         48        1 2023-06-28T17:18:15 2023-06-28T17:18:58 2023-06-28T17:19:10          1.23K                                                     \n           29252708.batch     FAILED         48        1 2023-06-28T17:18:58 2023-06-28T17:18:58 2023-06-28T17:19:10          1.22K                     1393K                     1393K \n          29252708.extern  COMPLETED         48        1 2023-06-28T17:18:58 2023-06-28T17:18:58 2023-06-28T17:19:10          1.23K                      790K                      790K \n','\n',char(10)));
INSERT INTO job_data VALUES(76,8,'a00m_20210811_HardwareBenchmarks_STREAM_48','2023-06-28-17:22:47','2023-06-28-18:21:44',1687965767,1687965773,1687965783,'COMPLETED',2,48,'00:30','debug',1470,'2021-08-11 00:00:00','STREAM_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252771,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_48.20230628172308.out','a00m_20210811_HardwareBenchmarks_STREAM_48.20230628172308.err',2,'',replace('                 29252771  COMPLETED         48        1 2023-06-28T17:22:47 2023-06-28T17:22:50 2023-06-28T17:23:03          1.47K                                                     \n           29252771.batch  COMPLETED         48        1 2023-06-28T17:22:50 2023-06-28T17:22:50 2023-06-28T17:23:03          1.45K                     1391K                     1391K \n          29252771.extern  COMPLETED         48        1 2023-06-28T17:22:50 2023-06-28T17:22:50 2023-06-28T17:23:03          1.47K                      824K                      824K \n','\n',char(10)));
INSERT INTO job_data VALUES(77,8,'a00m_20210811_HardwareBenchmarks_STREAM_32','2023-06-28-17:22:47','2023-06-28-18:21:44',1687965767,1687965790,1687965799,'COMPLETED',2,32,'00:30','debug',1490,'2021-08-11 00:00:00','STREAM_32','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252772,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_32.20230628172343.out','a00m_20210811_HardwareBenchmarks_STREAM_32.20230628172343.err',2,'',replace('                 29252772  COMPLETED         32        1 2023-06-28T17:22:47 2023-06-28T17:23:07 2023-06-28T17:23:19          1.49K                                                     \n           29252772.batch  COMPLETED         32        1 2023-06-28T17:23:07 2023-06-28T17:23:07 2023-06-28T17:23:19          1.48K                     1128K                     1128K \n          29252772.extern  COMPLETED         32        1 2023-06-28T17:23:07 2023-06-28T17:23:07 2023-06-28T17:23:19          1.49K                       28K                       28K \n','\n',char(10)));
INSERT INTO job_data VALUES(78,8,'a00m_20210811_HardwareBenchmarks_STREAM_16','2023-06-28-17:22:47','2023-06-28-18:21:44',1687965767,1687965806,1687965815,'COMPLETED',2,16,'00:30','debug',1680,'2021-08-11 00:00:00','STREAM_16','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252773,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_16.20230628172342.out','a00m_20210811_HardwareBenchmarks_STREAM_16.20230628172342.err',2,'',replace('                 29252773  COMPLETED         16        1 2023-06-28T17:22:47 2023-06-28T17:23:23 2023-06-28T17:23:35          1.68K                                                     \n           29252773.batch  COMPLETED         16        1 2023-06-28T17:23:23 2023-06-28T17:23:23 2023-06-28T17:23:35          1.66K                      935K                      935K \n          29252773.extern  COMPLETED         16        1 2023-06-28T17:23:23 2023-06-28T17:23:23 2023-06-28T17:23:35          1.68K                      660K                      660K \n','\n',char(10)));
INSERT INTO job_data VALUES(79,8,'a00m_20210811_HardwareBenchmarks_STREAM_8','2023-06-28-17:23:24','2023-06-28-18:22:31',1687965804,1687965819,1687965825,'COMPLETED',2,8,'00:30','debug',1070,'2021-08-11 00:00:00','STREAM_8','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252775,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_8.20230628172342.out','a00m_20210811_HardwareBenchmarks_STREAM_8.20230628172342.err',2,'',replace('                 29252775  COMPLETED          8        1 2023-06-28T17:23:24 2023-06-28T17:23:36 2023-06-28T17:23:45          1.07K                                                     \n           29252775.batch  COMPLETED          8        1 2023-06-28T17:23:36 2023-06-28T17:23:36 2023-06-28T17:23:45          1.06K                     1043K                     1043K \n          29252775.extern  COMPLETED          8        1 2023-06-28T17:23:36 2023-06-28T17:23:36 2023-06-28T17:23:45          1.07K                       32K                       32K \n','\n',char(10)));
INSERT INTO job_data VALUES(80,8,'a00m_20210811_HardwareBenchmarks_STREAM_4','2023-06-28-17:24:02','2023-06-28-18:22:31',1687965842,1687965846,1687965852,'COMPLETED',2,4,'00:30','debug',1110,'2021-08-11 00:00:00','STREAM_4','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252779,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_4.20230628172423.out','a00m_20210811_HardwareBenchmarks_STREAM_4.20230628172423.err',2,'',replace('                 29252779  COMPLETED          4        1 2023-06-28T17:24:02 2023-06-28T17:24:02 2023-06-28T17:24:12          1.11K                                                     \n           29252779.batch  COMPLETED          4        1 2023-06-28T17:24:02 2023-06-28T17:24:02 2023-06-28T17:24:12          1.06K                     1023K                     1023K \n          29252779.extern  COMPLETED          4        1 2023-06-28T17:24:02 2023-06-28T17:24:02 2023-06-28T17:24:12          1.11K                       28K                       28K \n','\n',char(10)));
INSERT INTO job_data VALUES(81,8,'a00m_20210811_HardwareBenchmarks_STREAM_2','2023-06-28-17:24:02','2023-06-28-18:22:31',1687965842,1687965858,1687965864,'COMPLETED',2,2,'00:30','debug',1120,'2021-08-11 00:00:00','STREAM_2','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252780,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_2.20230628172423.out','a00m_20210811_HardwareBenchmarks_STREAM_2.20230628172423.err',2,'',replace('                 29252780  COMPLETED          2        1 2023-06-28T17:24:02 2023-06-28T17:24:15 2023-06-28T17:24:25          1.12K                                                     \n           29252780.batch  COMPLETED          2        1 2023-06-28T17:24:15 2023-06-28T17:24:15 2023-06-28T17:24:25          1.06K                     1026K                     1026K \n          29252780.extern  COMPLETED          2        1 2023-06-28T17:24:15 2023-06-28T17:24:15 2023-06-28T17:24:25          1.12K                      700K                      700K \n','\n',char(10)));
INSERT INTO job_data VALUES(82,8,'a00m_20210811_HardwareBenchmarks_STREAM_1','2023-06-28-17:24:02','2023-06-28-18:23:21',1687965842,1687965881,1687965889,'COMPLETED',2,1,'00:30','debug',1410,'2021-08-11 00:00:00','STREAM_1','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252781,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_1.20230628172505.out','a00m_20210811_HardwareBenchmarks_STREAM_1.20230628172505.err',2,'',replace('                 29252781  COMPLETED          1        1 2023-06-28T17:24:02 2023-06-28T17:24:37 2023-06-28T17:24:50          1.41K                                                     \n           29252781.batch  COMPLETED          1        1 2023-06-28T17:24:37 2023-06-28T17:24:37 2023-06-28T17:24:50          1.33K                     1033K                     1033K \n          29252781.extern  COMPLETED          1        1 2023-06-28T17:24:37 2023-06-28T17:24:37 2023-06-28T17:24:50          1.41K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(83,8,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192','2023-06-28-17:24:42','2023-06-28-18:23:21',1687965882,1687965907,1687965956,'COMPLETED',2,192,'00:30','debug',30110,'2021-08-11 00:00:00','OSU_RUN_192','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252784,'',4,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230628172550.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230628172550.err',2,'',replace('                 29252784  COMPLETED        192        4 2023-06-28T17:24:42 2023-06-28T17:25:03 2023-06-28T17:25:56         30.11K                                                     \n           29252784.batch  COMPLETED         48        1 2023-06-28T17:25:03 2023-06-28T17:25:03 2023-06-28T17:25:56         15.19K                     6640K                     6640K \n          29252784.extern  COMPLETED        192        4 2023-06-28T17:25:03 2023-06-28T17:25:03 2023-06-28T17:25:56         30.11K                      879K                      862K \n               29252784.0  COMPLETED         48        1 2023-06-28T17:25:15 2023-06-28T17:25:15 2023-06-28T17:25:23          2.48K                     1344K                     1344K \n               29252784.1  COMPLETED         48        1 2023-06-28T17:25:23 2023-06-28T17:25:23 2023-06-28T17:25:47          8.19K                     1339K                     1339K \n               29252784.2  COMPLETED         48        1 2023-06-28T17:25:47 2023-06-28T17:25:47 2023-06-28T17:25:56          3.11K                     1324K                     1324K \n','\n',char(10)));
INSERT INTO job_data VALUES(84,8,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96','2023-06-28-17:24:42','2023-06-28-18:24:14',1687965882,1687965968,1687966017,'COMPLETED',2,96,'00:30','debug',21650,'2021-08-11 00:00:00','OSU_RUN_96','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252785,'',2,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230628172632.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230628172632.err',2,'',replace('                 29252785  COMPLETED         96        2 2023-06-28T17:24:42 2023-06-28T17:26:04 2023-06-28T17:26:58         21.65K                                                     \n           29252785.batch  COMPLETED         48        1 2023-06-28T17:26:04 2023-06-28T17:26:04 2023-06-28T17:26:58         15.50K                     6658K                     6658K \n          29252785.extern  COMPLETED         96        2 2023-06-28T17:26:04 2023-06-28T17:26:04 2023-06-28T17:26:58         21.65K                      878K                      473K \n               29252785.0  COMPLETED         48        1 2023-06-28T17:26:15 2023-06-28T17:26:15 2023-06-28T17:26:23          2.49K                     1333K                     1333K \n               29252785.1  COMPLETED         48        1 2023-06-28T17:26:23 2023-06-28T17:26:23 2023-06-28T17:26:48          8.53K                     1352K                     1352K \n               29252785.2  COMPLETED         48        1 2023-06-28T17:26:48 2023-06-28T17:26:48 2023-06-28T17:26:58          3.18K                     1320K                     1320K \n','\n',char(10)));
INSERT INTO job_data VALUES(85,8,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48','2023-06-28-17:25:29','2023-06-28-18:24:14',1687965929,1687966499,1687966547,'COMPLETED',2,48,'00:30','debug',14970,'2021-08-11 00:00:00','OSU_RUN_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29252788,'',1,10,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230628173504.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230628173504.err',2,'',replace('                 29252788  COMPLETED         48        1 2023-06-28T17:25:29 2023-06-28T17:34:55 2023-06-28T17:35:47         14.97K                                                     \n           29252788.batch  COMPLETED         48        1 2023-06-28T17:34:55 2023-06-28T17:34:55 2023-06-28T17:35:47         14.96K                     6627K                     6627K \n          29252788.extern  COMPLETED         48        1 2023-06-28T17:34:55 2023-06-28T17:34:55 2023-06-28T17:35:47         14.97K                      804K                      804K \n               29252788.0  COMPLETED         48        1 2023-06-28T17:35:06 2023-06-28T17:35:06 2023-06-28T17:35:14          2.46K                     1343K                     1343K \n               29252788.1  COMPLETED         48        1 2023-06-28T17:35:14 2023-06-28T17:35:14 2023-06-28T17:35:38          8.13K                     1332K                     1332K \n               29252788.2  COMPLETED         48        1 2023-06-28T17:35:39 2023-06-28T17:35:39 2023-06-28T17:35:47          3.06K                     1347K                     1347K \n','\n',char(10)));
INSERT INTO job_data VALUES(86,8,'a00m_20210811_StrongScaling_SCALABILITY_192','2023-06-28-17:26:08','2023-06-28-18:39:33',1687965968,1687966030,1687966185,'COMPLETED',2,192,'00:30','debug',214160,'2021-08-11 00:00:00','SCALABILITY_192','StrongScaling',0,0,'MARENOSTRUM4',29252790,'',4,10,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_192.20230628172713.out','a00m_20210811_StrongScaling_SCALABILITY_192.20230628172713.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29252790  COMPLETED        192        4 2023-06-28T17:26:08 2023-06-28T17:27:07 2023-06-28T17:29:45        214.16K                                                     \n           29252790.batch  COMPLETED         48        1 2023-06-28T17:27:07 2023-06-28T17:27:07 2023-06-28T17:29:45         56.09K                     7065K                     7065K \n          29252790.extern  COMPLETED        192        4 2023-06-28T17:27:07 2023-06-28T17:27:07 2023-06-28T17:29:45        214.16K                      823K                    450304 \n               29252790.0  COMPLETED        192        4 2023-06-28T17:27:28 2023-06-28T17:27:28 2023-06-28T17:29:44        204.04K                  8311088K                  8230227K \n','\n',char(10)));
INSERT INTO job_data VALUES(87,8,'a00m_20210811_StrongScaling_SCALABILITY_96','2023-06-28-17:26:51','2023-06-28-18:39:33',1687966011,1687966193,1687966483,'COMPLETED',2,96,'00:30','debug',223870,'2021-08-11 00:00:00','SCALABILITY_96','StrongScaling',0,0,'MARENOSTRUM4',29252793,'',2,10,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_96.20230628173008.out','a00m_20210811_StrongScaling_SCALABILITY_96.20230628173008.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29252793  COMPLETED         96        2 2023-06-28T17:26:51 2023-06-28T17:29:50 2023-06-28T17:34:45        223.87K                                                     \n           29252793.batch  COMPLETED         48        1 2023-06-28T17:29:50 2023-06-28T17:29:50 2023-06-28T17:34:45        111.31K                     6708K                     6708K \n          29252793.extern  COMPLETED         96        2 2023-06-28T17:29:50 2023-06-28T17:29:50 2023-06-28T17:34:45        223.87K                      835K                      806K \n               29252793.0  COMPLETED         96        2 2023-06-28T17:30:07 2023-06-28T17:30:07 2023-06-28T17:34:42        219.24K                 13792060K                 13621800K \n','\n',char(10)));
INSERT INTO job_data VALUES(88,8,'a00m_20210811_StrongScaling_SCALABILITY_48','2023-06-28-17:27:26','2023-06-28-18:39:33',1687966046,1687966558,1687967119,'COMPLETED',2,48,'00:30','debug',215520,'2021-08-11 00:00:00','SCALABILITY_48','StrongScaling',0,0,'MARENOSTRUM4',29252795,'',1,10,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_48.20230628173614.out','a00m_20210811_StrongScaling_SCALABILITY_48.20230628173614.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29252795  COMPLETED         48        1 2023-06-28T17:27:26 2023-06-28T17:35:54 2023-06-28T17:45:19        215.52K                                                     \n           29252795.batch  COMPLETED         48        1 2023-06-28T17:35:54 2023-06-28T17:35:54 2023-06-28T17:45:19        215.51K                     6.50M                     6.50M \n          29252795.extern  COMPLETED         48        1 2023-06-28T17:35:54 2023-06-28T17:35:54 2023-06-28T17:45:19        215.52K                       68K                       68K \n               29252795.0  COMPLETED         48        1 2023-06-28T17:36:13 2023-06-28T17:36:13 2023-06-28T17:45:18        213.02K                 22631532K                 22631532K \n','\n',char(10)));
INSERT INTO job_data VALUES(89,8,'a00m_20210811_WeakScaling_PREPARE_TESTS','2023-06-28-17:30:20','2023-06-28-18:50:22',1687966220,1687967125,1687967213,'FAILED',2,1,'00:30','debug',1110,'2021-08-11 00:00:00','PREPARE_TESTS','WeakScaling',0,0,'MARENOSTRUM4',29252799,'',1,10,0.0,0.0,'a00m_20210811_WeakScaling_PREPARE_TESTS.20230628174652.out','a00m_20210811_WeakScaling_PREPARE_TESTS.20230628174652.err',2,'a00m_20210811_WeakScaling_SCALABILITY_48,a00m_20210811_WeakScaling_SCALABILITY_192,a00m_20210811_WeakScaling_SCALABILITY_96',replace('                 29252799     FAILED          1        1 2023-06-28T17:30:20 2023-06-28T17:45:23 2023-06-28T17:45:31          1.11K                                                     \n           29252799.batch     FAILED          1        1 2023-06-28T17:45:23 2023-06-28T17:45:23 2023-06-28T17:45:31          1.09K                      976K                      976K \n          29252799.extern  COMPLETED          1        1 2023-06-28T17:45:23 2023-06-28T17:45:23 2023-06-28T17:45:31          1.11K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(90,8,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','2023-06-28-17:35:07','2023-06-28-18:56:05',1687966507,1687967134,1687967182,'FAILED',2,1,'00:30','debug',1060,'2021-08-11 00:00:00','PREPARE_TESTS','CompilationEfficiency',0,0,'MARENOSTRUM4',29252815,'',1,10,0.0,0.0,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230628174622.out','a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230628174622.err',2,'a00m_20210811_CompilationEfficiency_SCALABILITY_96,a00m_20210811_CompilationEfficiency_SCALABILITY_192,a00m_20210811_CompilationEfficiency_SCALABILITY_48',replace('                 29252815     FAILED          1        1 2023-06-28T17:35:07 2023-06-28T17:45:32 2023-06-28T17:45:40          1.06K                                                     \n           29252815.batch     FAILED          1        1 2023-06-28T17:45:32 2023-06-28T17:45:32 2023-06-28T17:45:40          1.04K                      810K                      810K \n          29252815.extern  COMPLETED          1        1 2023-06-28T17:45:32 2023-06-28T17:45:32 2023-06-28T17:45:40          1.06K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(91,8,'a00m_20210811_StrongScaling_FUNCTIONS_DIR','2023-06-28-17:45:27','2023-06-28-18:58:02',1687967127,1687967147,1687967261,'FAILED',2,192,'02:00','debug',145,'2021-08-11 00:00:00','FUNCTIONS_DIR','StrongScaling',0,0,'MARENOSTRUM4',29252912,'',4,10,0.0,0.0,'a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230628174551.out','a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230628174551.err',2,'a00m_20210811_StrongScaling_TRACE_48,a00m_20210811_StrongScaling_TRACE_192,a00m_20210811_StrongScaling_TRACE_96',replace('                 29252912     FAILED        192        4 2023-06-28T17:45:27 2023-06-28T17:45:44 2023-06-28T17:45:48            145                                                     \n           29252912.batch     FAILED         48        1 2023-06-28T17:45:44 2023-06-28T17:45:44 2023-06-28T17:45:48             26                     1362K                     1362K \n          29252912.extern  COMPLETED        192        4 2023-06-28T17:45:44 2023-06-28T17:45:44 2023-06-28T17:45:48            145                      885K                    875776 \n','\n',char(10)));
INSERT INTO job_data VALUES(92,8,'a00m_CLEAN','2023-06-28-17:54:37','2023-06-28-18:13:32',1687967677,1687967710,1687967745,'COMPLETED',2,1,'00:30','debug',6030,'','CLEAN','',0,0,'MARENOSTRUM0',29252989,'',1,11,0.0,0.0,'a00m_CLEAN.20230628175517.out','a00m_CLEAN.20230628175517.err',2,'a00m_REMOTE_SETUP',replace('                 29252989  COMPLETED          1        1 2023-06-28T17:54:37 2023-06-28T17:55:06 2023-06-28T17:55:45          6.03K                                                     \n           29252989.batch  COMPLETED          1        1 2023-06-28T17:55:06 2023-06-28T17:55:06 2023-06-28T17:55:45          6.00K                     1015K                     1015K \n          29252989.extern  COMPLETED          1        1 2023-06-28T17:55:06 2023-06-28T17:55:06 2023-06-28T17:55:45          6.03K                      708K                      708K \n','\n',char(10)));
INSERT INTO job_data VALUES(93,8,'a00m_REMOTE_SETUP','2023-06-28-17:55:56','2023-06-28-18:13:51',1687967756,1687967761,1687967807,'FAILED',2,1,'00:30','debug',1500,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',29253000,'',1,11,0.0,0.0,'a00m_REMOTE_SETUP.20230628175646.out','a00m_REMOTE_SETUP.20230628175646.err',2,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA,a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA',replace('                 29253000     FAILED          1        1 2023-06-28T17:55:56 2023-06-28T17:55:58 2023-06-28T17:56:08          1.50K                                                     \n           29253000.batch     FAILED          1        1 2023-06-28T17:55:58 2023-06-28T17:55:58 2023-06-28T17:56:08          1.16K                      980K                      980K \n          29253000.extern  COMPLETED          1        1 2023-06-28T17:55:58 2023-06-28T17:55:58 2023-06-28T17:56:08          1.50K                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(94,9,'a00m_CLEAN','2023-06-28-18:13:32','2023-06-28-21:09:10',1687968812,1687968812,1687968812,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',148293,'',0,12,0.0,0.0,'a00m_CLEAN.20230628181346.out','a00m_CLEAN.20230628181346.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(95,9,'a00m_REMOTE_SETUP','2023-06-28-18:13:51','2023-06-28-21:10:12',1687968831,1687968831,1687969017,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',148775,'',0,12,0.0,0.0,'a00m_REMOTE_SETUP.20230628181405.out','a00m_REMOTE_SETUP.20230628181405.err',5,'a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(96,9,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-28-18:17:04','2023-06-28-21:11:51',1687969024,1687969024,1687969031,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',151997,'',0,12,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628181741.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628181741.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(97,9,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-28-18:17:10','2023-06-28-21:11:55',1687969029,1687969030,1687969038,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',152828,'',0,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628181741.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628181741.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(98,9,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-28-18:17:16','2023-06-28-21:12:01',1687969036,1687969036,1687969042,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',153432,'',0,12,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628181742.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628181742.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(99,9,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-28-18:17:47','2023-06-28-21:12:30',1687969067,1687969067,1687971349,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',154731,'',0,12,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628181826.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628181826.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(100,9,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-06-28-18:17:52','2023-06-28-21:12:35',1687969072,1687969072,1687969238,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,0,'MARENOSTRUM0',156033,'',0,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628181826.out','a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628181826.err',5,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(101,9,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-28-18:17:58','2023-06-28-21:12:40',1687969078,1687969078,1687970997,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',156916,'',0,12,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628181826.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628181826.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(102,9,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-28-18:18:46','2023-06-28-21:13:21',1687969126,1687969126,1687969140,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',169777,'',0,12,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628181930.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628181930.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(103,9,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-28-18:19:39','2023-06-28-21:14:08',1687969179,1687969179,1687970329,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',189614,'',0,12,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628182020.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628182020.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(104,9,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','2023-06-28-18:21:07','2023-06-28-21:15:35',1687969266,1687969273,1687969279,'COMPLETED',2,1,'00:30','debug',1480,'2021-08-11 00:00:00','PREPARE_TESTS','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253278,'',1,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230628182139.out','a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230628182139.err',2,'a00m_20210811_HardwareBenchmarks_STREAM_16,a00m_20210811_HardwareBenchmarks_OSU_RUN_192,a00m_20210811_HardwareBenchmarks_STREAM_32,a00m_20210811_HardwareBenchmarks_OSU_RUN_48,a00m_20210811_HardwareBenchmarks_STREAM_8,a00m_20210811_HardwareBenchmarks_STREAM_4,a00m_20210811_HardwareBenchmarks_STREAM_48,a00m_20210811_HardwareBenchmarks_OSU_RUN_96,a00m_20210811_HardwareBenchmarks_STREAM_2,a00m_20210811_HardwareBenchmarks_STREAM_1',replace('                 29253278  COMPLETED          1        1 2023-06-28T18:21:06 2023-06-28T18:21:10 2023-06-28T18:21:19          1.48K                                                     \n           29253278.batch  COMPLETED          1        1 2023-06-28T18:21:10 2023-06-28T18:21:10 2023-06-28T18:21:19          1.44K                      979K                      979K \n          29253278.extern  COMPLETED          1        1 2023-06-28T18:21:10 2023-06-28T18:21:10 2023-06-28T18:21:19          1.48K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(105,9,'a00m_20210811_HardwareBenchmarks_STREAM_48','2023-06-28-18:21:44','2023-06-28-21:16:10',1687969304,1687969311,1687969320,'COMPLETED',2,48,'00:30','debug',1410,'2021-08-11 00:00:00','STREAM_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253280,'',1,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_48.20230628182225.out','a00m_20210811_HardwareBenchmarks_STREAM_48.20230628182225.err',2,'',replace('                 29253280  COMPLETED         48        1 2023-06-28T18:21:44 2023-06-28T18:21:47 2023-06-28T18:22:00          1.41K                                                     \n           29253280.batch  COMPLETED         48        1 2023-06-28T18:21:47 2023-06-28T18:21:47 2023-06-28T18:22:00          1.40K                     1368K                     1368K \n          29253280.extern  COMPLETED         48        1 2023-06-28T18:21:47 2023-06-28T18:21:47 2023-06-28T18:22:00          1.41K                      857K                      857K \n','\n',char(10)));
INSERT INTO job_data VALUES(106,9,'a00m_20210811_HardwareBenchmarks_STREAM_32','2023-06-28-18:21:44','2023-06-28-21:16:10',1687969304,1687969329,1687969336,'COMPLETED',2,32,'00:30','debug',1120,'2021-08-11 00:00:00','STREAM_32','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253281,'',1,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_32.20230628182224.out','a00m_20210811_HardwareBenchmarks_STREAM_32.20230628182224.err',2,'',replace('                 29253281  COMPLETED         32        1 2023-06-28T18:21:44 2023-06-28T18:22:04 2023-06-28T18:22:16          1.12K                                                     \n           29253281.batch  COMPLETED         32        1 2023-06-28T18:22:04 2023-06-28T18:22:04 2023-06-28T18:22:16          1.10K                     1135K                     1135K \n          29253281.extern  COMPLETED         32        1 2023-06-28T18:22:04 2023-06-28T18:22:04 2023-06-28T18:22:16          1.12K                       27K                       27K \n','\n',char(10)));
INSERT INTO job_data VALUES(107,9,'a00m_20210811_HardwareBenchmarks_STREAM_16','2023-06-28-18:21:44','2023-06-28-21:16:10',1687969304,1687969339,1687969346,'COMPLETED',2,16,'00:30','debug',1800,'2021-08-11 00:00:00','STREAM_16','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253282,'',1,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_16.20230628182223.out','a00m_20210811_HardwareBenchmarks_STREAM_16.20230628182223.err',2,'',replace('                 29253282  COMPLETED         16        1 2023-06-28T18:21:44 2023-06-28T18:22:16 2023-06-28T18:22:26          1.80K                                                     \n           29253282.batch  COMPLETED         16        1 2023-06-28T18:22:16 2023-06-28T18:22:16 2023-06-28T18:22:26          1.75K                      963K                      963K \n          29253282.extern  COMPLETED         16        1 2023-06-28T18:22:16 2023-06-28T18:22:16 2023-06-28T18:22:26          1.80K                       31K                       31K \n','\n',char(10)));
INSERT INTO job_data VALUES(108,9,'a00m_20210811_HardwareBenchmarks_STREAM_8','2023-06-28-18:22:31','2023-06-28-21:16:50',1687969351,1687969364,1687969371,'COMPLETED',2,8,'00:30','debug',1660,'2021-08-11 00:00:00','STREAM_8','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253291,'',1,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_8.20230628182316.out','a00m_20210811_HardwareBenchmarks_STREAM_8.20230628182316.err',2,'',replace('                 29253291  COMPLETED          8        1 2023-06-28T18:22:31 2023-06-28T18:22:41 2023-06-28T18:22:51          1.66K                                                     \n           29253291.batch  COMPLETED          8        1 2023-06-28T18:22:41 2023-06-28T18:22:41 2023-06-28T18:22:51          1.62K                      993K                      993K \n          29253291.extern  COMPLETED          8        1 2023-06-28T18:22:41 2023-06-28T18:22:41 2023-06-28T18:22:51          1.66K                       27K                       27K \n','\n',char(10)));
INSERT INTO job_data VALUES(109,9,'a00m_20210811_HardwareBenchmarks_STREAM_4','2023-06-28-18:22:31','2023-06-28-21:16:50',1687969351,1687969387,1687969393,'COMPLETED',2,4,'00:30','debug',1680,'2021-08-11 00:00:00','STREAM_4','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253292,'',1,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_4.20230628182315.out','a00m_20210811_HardwareBenchmarks_STREAM_4.20230628182315.err',2,'',replace('                 29253292  COMPLETED          4        1 2023-06-28T18:22:31 2023-06-28T18:23:04 2023-06-28T18:23:13          1.68K                                                     \n           29253292.batch  COMPLETED          4        1 2023-06-28T18:23:04 2023-06-28T18:23:04 2023-06-28T18:23:13          1.64K                      982K                      982K \n          29253292.extern  COMPLETED          4        1 2023-06-28T18:23:04 2023-06-28T18:23:04 2023-06-28T18:23:13          1.68K                       26K                       26K \n','\n',char(10)));
INSERT INTO job_data VALUES(110,9,'a00m_20210811_HardwareBenchmarks_STREAM_2','2023-06-28-18:22:31','2023-06-28-21:17:38',1687969351,1687969397,1687969404,'COMPLETED',2,2,'00:30','debug',1530,'2021-08-11 00:00:00','STREAM_2','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253293,'',1,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_2.20230628182406.out','a00m_20210811_HardwareBenchmarks_STREAM_2.20230628182406.err',2,'',replace('                 29253293  COMPLETED          2        1 2023-06-28T18:22:31 2023-06-28T18:23:14 2023-06-28T18:23:24          1.53K                                                     \n           29253293.batch  COMPLETED          2        1 2023-06-28T18:23:14 2023-06-28T18:23:14 2023-06-28T18:23:24          1.48K                      820K                      820K \n          29253293.extern  COMPLETED          2        1 2023-06-28T18:23:14 2023-06-28T18:23:14 2023-06-28T18:23:24          1.53K                      700K                      700K \n','\n',char(10)));
INSERT INTO job_data VALUES(111,9,'a00m_20210811_HardwareBenchmarks_STREAM_1','2023-06-28-18:23:21','2023-06-28-21:17:38',1687969401,1687969534,1687969540,'COMPLETED',2,1,'00:30','debug',1370,'2021-08-11 00:00:00','STREAM_1','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253337,'',1,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_1.20230628182606.out','a00m_20210811_HardwareBenchmarks_STREAM_1.20230628182606.err',2,'',replace('                 29253337  COMPLETED          1        1 2023-06-28T18:23:21 2023-06-28T18:25:31 2023-06-28T18:25:40          1.37K                                                     \n           29253337.batch  COMPLETED          1        1 2023-06-28T18:25:31 2023-06-28T18:25:31 2023-06-28T18:25:40          1.34K                      982K                      982K \n          29253337.extern  COMPLETED          1        1 2023-06-28T18:25:31 2023-06-28T18:25:31 2023-06-28T18:25:40          1.37K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(112,9,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192','2023-06-28-18:23:21','2023-06-28-21:17:38',1687969401,1687969408,1687969455,'COMPLETED',2,192,'00:30','debug',30340,'2021-08-11 00:00:00','OSU_RUN_192','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253338,'',4,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230628182403.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230628182403.err',2,'',replace('                 29253338  COMPLETED        192        4 2023-06-28T18:23:21 2023-06-28T18:23:24 2023-06-28T18:24:17         30.34K                                                     \n           29253338.batch  COMPLETED         48        1 2023-06-28T18:23:24 2023-06-28T18:23:24 2023-06-28T18:24:17         14.94K                     6664K                     6664K \n          29253338.extern  COMPLETED        192        4 2023-06-28T18:23:24 2023-06-28T18:23:24 2023-06-28T18:24:17         30.34K                      832K                    648960 \n               29253338.0  COMPLETED         48        1 2023-06-28T18:23:34 2023-06-28T18:23:34 2023-06-28T18:23:41          2.45K                     1341K                     1341K \n               29253338.1  COMPLETED         48        1 2023-06-28T18:23:41 2023-06-28T18:23:41 2023-06-28T18:24:07          8.28K                     1326K                     1326K \n               29253338.2  COMPLETED         48        1 2023-06-28T18:24:07 2023-06-28T18:24:07 2023-06-28T18:24:17          3.08K                     1350K                     1350K \n','\n',char(10)));
INSERT INTO job_data VALUES(113,9,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96','2023-06-28-18:24:14','2023-06-28-21:20:23',1687969454,1687969475,1687969525,'COMPLETED',2,96,'00:30','debug',20980,'2021-08-11 00:00:00','OSU_RUN_96','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253340,'',2,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230628182452.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230628182452.err',2,'',replace('                 29253340  COMPLETED         96        2 2023-06-28T18:24:14 2023-06-28T18:24:32 2023-06-28T18:25:25         20.98K                                                     \n           29253340.batch  COMPLETED         48        1 2023-06-28T18:24:32 2023-06-28T18:24:32 2023-06-28T18:25:25         15.89K                     6416K                     6416K \n          29253340.extern  COMPLETED         96        2 2023-06-28T18:24:32 2023-06-28T18:24:32 2023-06-28T18:25:25         20.98K                      777K                   422.50K \n               29253340.0  COMPLETED         48        1 2023-06-28T18:24:44 2023-06-28T18:24:44 2023-06-28T18:24:52          2.57K                     1344K                     1344K \n               29253340.1  COMPLETED         48        1 2023-06-28T18:24:52 2023-06-28T18:24:52 2023-06-28T18:25:16          8.53K                     1337K                     1337K \n               29253340.2  COMPLETED         48        1 2023-06-28T18:25:17 2023-06-28T18:25:17 2023-06-28T18:25:25          3.23K                     1342K                     1342K \n','\n',char(10)));
INSERT INTO job_data VALUES(114,9,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48','2023-06-28-18:24:14','2023-06-28-21:21:05',1687969454,1687969546,1687969596,'COMPLETED',2,48,'00:30','debug',15930,'2021-08-11 00:00:00','OSU_RUN_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29253341,'',1,12,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230628182606.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230628182606.err',2,'',replace('                 29253341  COMPLETED         48        1 2023-06-28T18:24:14 2023-06-28T18:25:42 2023-06-28T18:26:37         15.93K                                                     \n           29253341.batch  COMPLETED         48        1 2023-06-28T18:25:42 2023-06-28T18:25:42 2023-06-28T18:26:37         15.72K                     6417K                     6417K \n          29253341.extern  COMPLETED         48        1 2023-06-28T18:25:42 2023-06-28T18:25:42 2023-06-28T18:26:37         15.93K                       68K                       68K \n               29253341.0  COMPLETED         48        1 2023-06-28T18:25:54 2023-06-28T18:25:54 2023-06-28T18:26:02          2.52K                     1337K                     1337K \n               29253341.1  COMPLETED         48        1 2023-06-28T18:26:02 2023-06-28T18:26:02 2023-06-28T18:26:27          8.38K                     1343K                     1343K \n               29253341.2  COMPLETED         48        1 2023-06-28T18:26:27 2023-06-28T18:26:27 2023-06-28T18:26:37          3.15K                     1335K                     1335K \n','\n',char(10)));
INSERT INTO job_data VALUES(115,9,'a00m_20210811_StrongScaling_PREPARE_TESTS','2023-06-28-18:39:02','2023-06-28-21:30:29',1687970342,1687970347,1687970352,'COMPLETED',2,1,'00:30','debug',1190,'2021-08-11 00:00:00','PREPARE_TESTS','StrongScaling',0,0,'MARENOSTRUM4',29253397,'',1,12,0.0,0.0,'a00m_20210811_StrongScaling_PREPARE_TESTS.20230628183928.out','a00m_20210811_StrongScaling_PREPARE_TESTS.20230628183928.err',2,'a00m_20210811_StrongScaling_SCALABILITY_96,a00m_20210811_StrongScaling_SCALABILITY_192,a00m_20210811_StrongScaling_SCALABILITY_48',replace('                 29253397  COMPLETED          1        1 2023-06-28T18:39:02 2023-06-28T18:39:04 2023-06-28T18:39:12          1.19K                                                     \n           29253397.batch  COMPLETED          1        1 2023-06-28T18:39:04 2023-06-28T18:39:04 2023-06-28T18:39:12          1.16K                     1042K                     1042K \n          29253397.extern  COMPLETED          1        1 2023-06-28T18:39:04 2023-06-28T18:39:04 2023-06-28T18:39:12          1.19K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(116,9,'a00m_20210811_StrongScaling_SCALABILITY_192','2023-06-28-18:39:33','2023-06-28-21:32:02',1687970373,1687970377,1687970531,'COMPLETED',2,192,'00:30','debug',223890,'2021-08-11 00:00:00','SCALABILITY_192','StrongScaling',0,0,'MARENOSTRUM4',29253398,'',4,12,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_192.20230628184009.out','a00m_20210811_StrongScaling_SCALABILITY_192.20230628184009.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29253398  COMPLETED        192        4 2023-06-28T18:39:33 2023-06-28T18:39:33 2023-06-28T18:42:12        223.89K                                                     \n           29253398.batch  COMPLETED         48        1 2023-06-28T18:39:33 2023-06-28T18:39:33 2023-06-28T18:42:12         57.26K                     7091K                     7091K \n          29253398.extern  COMPLETED        192        4 2023-06-28T18:39:33 2023-06-28T18:39:33 2023-06-28T18:42:12        223.89K                      883K                    484096 \n               29253398.0  COMPLETED        192        4 2023-06-28T18:39:53 2023-06-28T18:39:53 2023-06-28T18:42:12        214.57K                  8313740K                  8236928K \n','\n',char(10)));
INSERT INTO job_data VALUES(117,9,'a00m_20210811_StrongScaling_SCALABILITY_96','2023-06-28-18:39:33','2023-06-28-21:32:02',1687970373,1687970558,1687970853,'COMPLETED',2,96,'00:30','debug',226520,'2021-08-11 00:00:00','SCALABILITY_96','StrongScaling',0,0,'MARENOSTRUM4',29253399,'',2,12,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_96.20230628184257.out','a00m_20210811_StrongScaling_SCALABILITY_96.20230628184257.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29253399  COMPLETED         96        2 2023-06-28T18:39:33 2023-06-28T18:42:34 2023-06-28T18:47:33        226.52K                                                     \n           29253399.batch  COMPLETED         48        1 2023-06-28T18:42:34 2023-06-28T18:42:34 2023-06-28T18:47:33        112.17K                     6699K                     6699K \n          29253399.extern  COMPLETED         96        2 2023-06-28T18:42:34 2023-06-28T18:42:34 2023-06-28T18:47:33        226.52K                      867K                   819.50K \n               29253399.0  COMPLETED         96        2 2023-06-28T18:42:57 2023-06-28T18:42:57 2023-06-28T18:47:32        220.92K                 13784332K                 13617750K \n','\n',char(10)));
INSERT INTO job_data VALUES(118,9,'a00m_20210811_StrongScaling_SCALABILITY_48','2023-06-28-18:39:33','2023-06-28-21:32:02',1687970373,1687970861,1687971425,'COMPLETED',2,48,'00:30','debug',216030,'2021-08-11 00:00:00','SCALABILITY_48','StrongScaling',0,0,'MARENOSTRUM4',29253400,'',1,12,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_48.20230628184756.out','a00m_20210811_StrongScaling_SCALABILITY_48.20230628184756.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29253400  COMPLETED         48        1 2023-06-28T18:39:33 2023-06-28T18:47:37 2023-06-28T18:57:07        216.03K                                                     \n           29253400.batch  COMPLETED         48        1 2023-06-28T18:47:37 2023-06-28T18:47:37 2023-06-28T18:57:07        215.79K                     6666K                     6666K \n          29253400.extern  COMPLETED         48        1 2023-06-28T18:47:37 2023-06-28T18:47:37 2023-06-28T18:57:07        216.03K                      869K                      869K \n               29253400.0  COMPLETED         48        1 2023-06-28T18:47:59 2023-06-28T18:47:59 2023-06-28T18:57:04        212.75K                 22624080K                 22624080K \n','\n',char(10)));
INSERT INTO job_data VALUES(119,9,'a00m_20210811_WeakScaling_PREPARE_TESTS','2023-06-28-18:50:22','2023-06-28-19:59:22',1687971022,1687971438,1687971478,'FAILED',2,1,'00:30','debug',1290,'2021-08-11 00:00:00','PREPARE_TESTS','WeakScaling',0,0,'MARENOSTRUM4',29253484,'',1,12,0.0,0.0,'a00m_20210811_WeakScaling_PREPARE_TESTS.20230628185758.out','a00m_20210811_WeakScaling_PREPARE_TESTS.20230628185758.err',2,'a00m_20210811_WeakScaling_SCALABILITY_48,a00m_20210811_WeakScaling_SCALABILITY_96,a00m_20210811_WeakScaling_SCALABILITY_192',replace('                 29253484     FAILED          1        1 2023-06-28T18:50:22 2023-06-28T18:57:14 2023-06-28T18:57:23          1.29K                                                     \n           29253484.batch     FAILED          1        1 2023-06-28T18:57:14 2023-06-28T18:57:14 2023-06-28T18:57:23          1.25K                      978K                      978K \n          29253484.extern  COMPLETED          1        1 2023-06-28T18:57:14 2023-06-28T18:57:14 2023-06-28T18:57:23          1.29K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(120,9,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','2023-06-28-18:56:05','2023-06-28-19:59:22',1687971365,1687971446,1687971562,'FAILED',2,1,'00:30','debug',1250,'2021-08-11 00:00:00','PREPARE_TESTS','CompilationEfficiency',0,0,'MARENOSTRUM4',29253499,'',1,12,0.0,0.0,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230628185728.out','a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230628185728.err',2,'a00m_20210811_CompilationEfficiency_SCALABILITY_192,a00m_20210811_CompilationEfficiency_SCALABILITY_48,a00m_20210811_CompilationEfficiency_SCALABILITY_96',replace('                 29253499     FAILED          1        1 2023-06-28T18:56:05 2023-06-28T18:57:23 2023-06-28T18:57:31          1.25K                                                     \n           29253499.batch     FAILED          1        1 2023-06-28T18:57:23 2023-06-28T18:57:23 2023-06-28T18:57:31          1.21K                      814K                      814K \n          29253499.extern  COMPLETED          1        1 2023-06-28T18:57:23 2023-06-28T18:57:23 2023-06-28T18:57:31          1.25K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(121,9,'a00m_20210811_StrongScaling_FUNCTIONS_DIR','2023-06-28-18:58:02','2023-06-28-19:59:22',1687971482,1687971487,1687971531,'FAILED',2,192,'02:00','debug',178,'2021-08-11 00:00:00','FUNCTIONS_DIR','StrongScaling',0,0,'MARENOSTRUM4',29253511,'',4,12,0.0,0.0,'a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230628185851.out','a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230628185851.err',2,'a00m_20210811_StrongScaling_TRACE_192,a00m_20210811_StrongScaling_TRACE_96,a00m_20210811_StrongScaling_TRACE_48',replace('                 29253511     FAILED        192        4 2023-06-28T18:58:02 2023-06-28T18:58:03 2023-06-28T18:58:07            178                                                     \n           29253511.batch     FAILED         48        1 2023-06-28T18:58:03 2023-06-28T18:58:03 2023-06-28T18:58:07             24                     1393K                     1393K \n          29253511.extern  COMPLETED        192        4 2023-06-28T18:58:03 2023-06-28T18:58:03 2023-06-28T18:58:07            178                      865K                      651K \n','\n',char(10)));
INSERT INTO job_data VALUES(122,10,'a00m_20210811_StrongScaling_FUNCTIONS_DIR','2023-06-28-19:59:22','2023-06-28-21:54:49',1687975162,1687976765,1687976792,'COMPLETED',2,192,'02:00','debug',20090,'2021-08-11 00:00:00','FUNCTIONS_DIR','StrongScaling',0,0,'MARENOSTRUM4',29253847,'',4,12,0.0,0.0,'a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230628202606.out','a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230628202606.err',2,'a00m_20210811_StrongScaling_TRACE_192,a00m_20210811_StrongScaling_TRACE_96,a00m_20210811_StrongScaling_TRACE_48',replace('                 29253847  COMPLETED        192        4 2023-06-28T19:59:22 2023-06-28T20:26:01 2023-06-28T20:26:33         20.09K                                                     \n           29253847.batch  COMPLETED         48        1 2023-06-28T20:26:01 2023-06-28T20:26:01 2023-06-28T20:26:33          5.49K                     1388K                     1388K \n          29253847.extern  COMPLETED        192        4 2023-06-28T20:26:01 2023-06-28T20:26:01 2023-06-28T20:26:33         20.09K                      863K                   437.50K \n               29253847.0  COMPLETED        192        4 2023-06-28T20:26:17 2023-06-28T20:26:17 2023-06-28T20:26:31         12.91K                     1441K                  1402.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(123,10,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','2023-06-28-19:59:22','2023-06-28-21:45:39',1687975162,1687975252,1687975299,'FAILED',2,1,'00:30','debug',1450,'2021-08-11 00:00:00','PREPARE_TESTS','CompilationEfficiency',0,0,'MARENOSTRUM4',29253848,'',1,12,0.0,0.0,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230628200138.out','a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230628200138.err',2,'a00m_20210811_CompilationEfficiency_SCALABILITY_192,a00m_20210811_CompilationEfficiency_SCALABILITY_48,a00m_20210811_CompilationEfficiency_SCALABILITY_96',replace('                 29253848     FAILED          1        1 2023-06-28T19:59:22 2023-06-28T20:00:51 2023-06-28T20:00:58          1.45K                                                     \n           29253848.batch     FAILED          1        1 2023-06-28T20:00:51 2023-06-28T20:00:51 2023-06-28T20:00:58          1.18K                     1022K                     1022K \n          29253848.extern  COMPLETED          1        1 2023-06-28T20:00:51 2023-06-28T20:00:51 2023-06-28T20:00:58          1.45K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(124,10,'a00m_20210811_WeakScaling_PREPARE_TESTS','2023-06-28-19:59:22','2023-06-28-21:39:52',1687975162,1687975373,1687975435,'FAILED',2,1,'00:30','debug',1590,'2021-08-11 00:00:00','PREPARE_TESTS','WeakScaling',0,0,'MARENOSTRUM4',29253849,'',1,12,0.0,0.0,'a00m_20210811_WeakScaling_PREPARE_TESTS.20230628200303.out','a00m_20210811_WeakScaling_PREPARE_TESTS.20230628200303.err',2,'a00m_20210811_WeakScaling_SCALABILITY_48,a00m_20210811_WeakScaling_SCALABILITY_96,a00m_20210811_WeakScaling_SCALABILITY_192',replace('                 29253849     FAILED          1        1 2023-06-28T19:59:22 2023-06-28T20:02:51 2023-06-28T20:03:00          1.59K                                                     \n           29253849.batch     FAILED          1        1 2023-06-28T20:02:51 2023-06-28T20:02:51 2023-06-28T20:03:00          1.55K                     1008K                     1008K \n          29253849.extern  COMPLETED          1        1 2023-06-28T20:02:51 2023-06-28T20:02:51 2023-06-28T20:03:01          1.59K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(125,10,'a00m_20210811_StrongScaling_TRACE_192','2023-06-28-20:26:45','2023-06-28-21:56:31',1687976805,1687976809,1687976890,'FAILED',2,192,'00:30','debug',143,'2021-08-11 00:00:00','TRACE_192','StrongScaling',0,0,'MARENOSTRUM4',29253960,'',4,12,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_192.20230628202810.out','a00m_20210811_StrongScaling_TRACE_192.20230628202810.err',2,'',replace('                 29253960     FAILED        192        4 2023-06-28T20:26:45 2023-06-28T20:26:45 2023-06-28T20:26:49            143                                                     \n           29253960.batch     FAILED         48        1 2023-06-28T20:26:45 2023-06-28T20:26:45 2023-06-28T20:26:49             18                     1374K                     1374K \n          29253960.extern  COMPLETED        192        4 2023-06-28T20:26:45 2023-06-28T20:26:45 2023-06-28T20:26:49            143                      912K                   863.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(126,10,'a00m_20210811_StrongScaling_TRACE_96','2023-06-28-20:26:45','2023-06-28-21:56:31',1687976805,1687976818,1687976859,'FAILED',2,96,'00:30','debug',78,'2021-08-11 00:00:00','TRACE_96','StrongScaling',0,0,'MARENOSTRUM4',29253961,'',2,12,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_96.20230628202739.out','a00m_20210811_StrongScaling_TRACE_96.20230628202739.err',2,'',replace('                 29253961     FAILED         96        2 2023-06-28T20:26:45 2023-06-28T20:26:54 2023-06-28T20:26:58             78                                                     \n           29253961.batch     FAILED         48        1 2023-06-28T20:26:54 2023-06-28T20:26:54 2023-06-28T20:26:58             23                     1369K                     1369K \n          29253961.extern  COMPLETED         96        2 2023-06-28T20:26:54 2023-06-28T20:26:54 2023-06-28T20:26:58             78                      132K                       80K \n','\n',char(10)));
INSERT INTO job_data VALUES(127,10,'a00m_20210811_StrongScaling_TRACE_48','2023-06-28-20:26:45','2023-06-28-21:56:31',1687976805,1687976827,1687976939,'FAILED',2,48,'00:30','debug',44,'2021-08-11 00:00:00','TRACE_48','StrongScaling',0,0,'MARENOSTRUM4',29253962,'',1,12,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_48.20230628202708.out','a00m_20210811_StrongScaling_TRACE_48.20230628202708.err',2,'',replace('                 29253962     FAILED         48        1 2023-06-28T20:26:45 2023-06-28T20:27:02 2023-06-28T20:27:07             44                                                     \n           29253962.batch     FAILED         48        1 2023-06-28T20:27:02 2023-06-28T20:27:02 2023-06-28T20:27:07             23                     1384K                     1384K \n          29253962.extern  COMPLETED         48        1 2023-06-28T20:27:02 2023-06-28T20:27:02 2023-06-28T20:27:07             44                      884K                      884K \n','\n',char(10)));
INSERT INTO job_data VALUES(128,10,'a00m_CLEAN','2023-06-28-21:09:10','2023-06-29-00:21:52',1687979350,1687979350,1687979398,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',20691,'',0,13,0.0,0.0,'a00m_CLEAN.20230628210930.out','a00m_CLEAN.20230628210930.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(129,10,'a00m_REMOTE_SETUP','2023-06-28-21:10:12','2023-06-29-00:22:57',1687979412,1687979412,1687979492,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',21544,'',0,13,0.0,0.0,'a00m_REMOTE_SETUP.20230628211027.out','a00m_REMOTE_SETUP.20230628211027.err',5,'a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(130,10,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-28-21:11:51','2023-06-29-00:24:34',1687979511,1687979511,1687979518,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',24679,'',0,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628211224.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230628211224.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(131,10,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-28-21:11:55','2023-06-29-00:24:39',1687979515,1687979515,1687979523,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',25460,'',0,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628211225.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230628211225.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(132,10,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-28-21:12:01','2023-06-29-00:24:46',1687979521,1687979521,1687979528,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',26154,'',0,13,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628211225.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230628211225.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(133,10,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-28-21:12:30','2023-06-29-00:25:16',1687979550,1687979550,1687981512,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',27334,'',0,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628211305.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230628211305.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(134,10,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-06-28-21:12:36','2023-06-29-00:25:22',1687979555,1687979556,1687979717,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,0,'MARENOSTRUM0',28656,'',0,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628211305.out','a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230628211305.err',5,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(135,10,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-28-21:12:40','2023-06-29-00:25:27',1687979560,1687979560,1687981172,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',29580,'',0,13,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628211305.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230628211305.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(136,10,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-28-21:13:21','2023-06-29-00:26:11',1687979601,1687979601,1687979609,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',39602,'',0,13,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628211403.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230628211403.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(137,10,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-28-21:14:08','2023-06-29-00:27:01',1687979648,1687979648,1687980599,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',56679,'',0,13,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628211450.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230628211450.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(138,10,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','2023-06-28-21:15:35','2023-06-29-00:28:26',1687979735,1687979743,1687979749,'COMPLETED',2,1,'00:30','debug',1120,'2021-08-11 00:00:00','PREPARE_TESTS','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254406,'',1,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230628211606.out','a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230628211606.err',2,'a00m_20210811_HardwareBenchmarks_STREAM_32,a00m_20210811_HardwareBenchmarks_STREAM_16,a00m_20210811_HardwareBenchmarks_OSU_RUN_192,a00m_20210811_HardwareBenchmarks_OSU_RUN_48,a00m_20210811_HardwareBenchmarks_STREAM_8,a00m_20210811_HardwareBenchmarks_STREAM_4,a00m_20210811_HardwareBenchmarks_STREAM_48,a00m_20210811_HardwareBenchmarks_OSU_RUN_96,a00m_20210811_HardwareBenchmarks_STREAM_2,a00m_20210811_HardwareBenchmarks_STREAM_1',replace('                 29254406  COMPLETED          1        1 2023-06-28T21:15:35 2023-06-28T21:15:43 2023-06-28T21:15:50          1.12K                                                     \n           29254406.batch  COMPLETED          1        1 2023-06-28T21:15:43 2023-06-28T21:15:43 2023-06-28T21:15:50            902                     1124K                     1124K \n          29254406.extern  COMPLETED          1        1 2023-06-28T21:15:43 2023-06-28T21:15:43 2023-06-28T21:15:50          1.12K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(139,10,'a00m_20210811_HardwareBenchmarks_STREAM_48','2023-06-28-21:16:10','2023-06-29-00:29:09',1687979770,1687979776,1687979786,'COMPLETED',2,48,'00:30','debug',1550,'2021-08-11 00:00:00','STREAM_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254412,'',1,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_48.20230628211646.out','a00m_20210811_HardwareBenchmarks_STREAM_48.20230628211646.err',2,'',replace('                 29254412  COMPLETED         48        1 2023-06-28T21:16:10 2023-06-28T21:16:13 2023-06-28T21:16:26          1.55K                                                     \n           29254412.batch  COMPLETED         48        1 2023-06-28T21:16:13 2023-06-28T21:16:13 2023-06-28T21:16:26          1.53K                     1388K                     1388K \n          29254412.extern  COMPLETED         48        1 2023-06-28T21:16:13 2023-06-28T21:16:13 2023-06-28T21:16:26          1.55K                       68K                       68K \n','\n',char(10)));
INSERT INTO job_data VALUES(140,10,'a00m_20210811_HardwareBenchmarks_STREAM_32','2023-06-28-21:16:10','2023-06-29-00:29:09',1687979770,1687979793,1687979800,'COMPLETED',2,32,'00:30','debug',1190,'2021-08-11 00:00:00','STREAM_32','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254413,'',1,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_32.20230628211645.out','a00m_20210811_HardwareBenchmarks_STREAM_32.20230628211645.err',2,'',replace('                 29254413  COMPLETED         32        1 2023-06-28T21:16:10 2023-06-28T21:16:30 2023-06-28T21:16:40          1.19K                                                     \n           29254413.batch  COMPLETED         32        1 2023-06-28T21:16:30 2023-06-28T21:16:30 2023-06-28T21:16:40          1.17K                     1134K                     1134K \n          29254413.extern  COMPLETED         32        1 2023-06-28T21:16:30 2023-06-28T21:16:30 2023-06-28T21:16:40          1.19K                       27K                       27K \n','\n',char(10)));
INSERT INTO job_data VALUES(141,10,'a00m_20210811_HardwareBenchmarks_STREAM_16','2023-06-28-21:16:10','2023-06-29-00:29:09',1687979770,1687979809,1687979815,'COMPLETED',2,16,'00:30','debug',1190,'2021-08-11 00:00:00','STREAM_16','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254414,'',1,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_16.20230628211732.out','a00m_20210811_HardwareBenchmarks_STREAM_16.20230628211732.err',2,'',replace('                 29254414  COMPLETED         16        1 2023-06-28T21:16:10 2023-06-28T21:16:46 2023-06-28T21:16:55          1.19K                                                     \n           29254414.batch  COMPLETED         16        1 2023-06-28T21:16:46 2023-06-28T21:16:46 2023-06-28T21:16:55          1.17K                     1011K                     1011K \n          29254414.extern  COMPLETED         16        1 2023-06-28T21:16:46 2023-06-28T21:16:46 2023-06-28T21:16:55          1.19K                      738K                      738K \n','\n',char(10)));
INSERT INTO job_data VALUES(142,10,'a00m_20210811_HardwareBenchmarks_STREAM_8','2023-06-28-21:16:50','2023-06-29-00:30:07',1687979810,1687979819,1687979825,'COMPLETED',2,8,'00:30','debug',1140,'2021-08-11 00:00:00','STREAM_8','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254418,'',1,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_8.20230628211731.out','a00m_20210811_HardwareBenchmarks_STREAM_8.20230628211731.err',2,'',replace('                 29254418  COMPLETED          8        1 2023-06-28T21:16:50 2023-06-28T21:16:56 2023-06-28T21:17:05          1.14K                                                     \n           29254418.batch  COMPLETED          8        1 2023-06-28T21:16:56 2023-06-28T21:16:56 2023-06-28T21:17:05          1.13K                     1039K                     1039K \n          29254418.extern  COMPLETED          8        1 2023-06-28T21:16:56 2023-06-28T21:16:56 2023-06-28T21:17:05          1.14K                       31K                       31K \n','\n',char(10)));
INSERT INTO job_data VALUES(143,10,'a00m_20210811_HardwareBenchmarks_STREAM_4','2023-06-28-21:16:50','2023-06-29-00:30:07',1687979810,1687979830,1687979836,'COMPLETED',2,4,'00:30','debug',1150,'2021-08-11 00:00:00','STREAM_4','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254419,'',1,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_4.20230628211730.out','a00m_20210811_HardwareBenchmarks_STREAM_4.20230628211730.err',2,'',replace('                 29254419  COMPLETED          4        1 2023-06-28T21:16:50 2023-06-28T21:17:07 2023-06-28T21:17:16          1.15K                                                     \n           29254419.batch  COMPLETED          4        1 2023-06-28T21:17:07 2023-06-28T21:17:07 2023-06-28T21:17:16          1.13K                     1035K                     1035K \n          29254419.extern  COMPLETED          4        1 2023-06-28T21:17:07 2023-06-28T21:17:07 2023-06-28T21:17:16          1.15K                       32K                       32K \n','\n',char(10)));
INSERT INTO job_data VALUES(144,10,'a00m_20210811_HardwareBenchmarks_STREAM_2','2023-06-28-21:17:38','2023-06-29-00:31:09',1687979858,1687979971,1687979978,'COMPLETED',2,2,'00:30','debug',1130,'2021-08-11 00:00:00','STREAM_2','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254425,'',1,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_2.20230628212018.out','a00m_20210811_HardwareBenchmarks_STREAM_2.20230628212018.err',2,'',replace('                 29254425  COMPLETED          2        1 2023-06-28T21:17:38 2023-06-28T21:19:26 2023-06-28T21:19:38          1.13K                                                     \n           29254425.batch  COMPLETED          2        1 2023-06-28T21:19:26 2023-06-28T21:19:26 2023-06-28T21:19:38          1.11K                     1035K                     1035K \n          29254425.extern  COMPLETED          2        1 2023-06-28T21:19:26 2023-06-28T21:19:26 2023-06-28T21:19:38          1.13K                      611K                      611K \n','\n',char(10)));
INSERT INTO job_data VALUES(145,10,'a00m_20210811_HardwareBenchmarks_STREAM_1','2023-06-28-21:17:38','2023-06-29-00:31:09',1687979858,1687980091,1687980098,'COMPLETED',2,1,'00:30','debug',1060,'2021-08-11 00:00:00','STREAM_1','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254426,'',1,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_1.20230628212139.out','a00m_20210811_HardwareBenchmarks_STREAM_1.20230628212139.err',2,'',replace('                 29254426  COMPLETED          1        1 2023-06-28T21:17:38 2023-06-28T21:21:26 2023-06-28T21:21:38          1.06K                                                     \n           29254426.batch  COMPLETED          1        1 2023-06-28T21:21:26 2023-06-28T21:21:26 2023-06-28T21:21:38          1.02K                     1014K                     1014K \n          29254426.extern  COMPLETED          1        1 2023-06-28T21:21:26 2023-06-28T21:21:26 2023-06-28T21:21:38          1.06K                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(146,10,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192','2023-06-28-21:17:38','2023-06-29-00:31:09',1687979858,1687980019,1687980069,'COMPLETED',2,192,'00:30','debug',31820,'2021-08-11 00:00:00','OSU_RUN_192','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254427,'',4,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230628212101.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230628212101.err',2,'',replace('                 29254427  COMPLETED        192        4 2023-06-28T21:17:38 2023-06-28T21:20:13 2023-06-28T21:21:09         31.82K                                                     \n           29254427.batch  COMPLETED         48        1 2023-06-28T21:20:13 2023-06-28T21:20:13 2023-06-28T21:21:09         15.22K                     6642K                     6642K \n          29254427.extern  COMPLETED        192        4 2023-06-28T21:20:13 2023-06-28T21:20:13 2023-06-28T21:21:09         31.82K                      833K                   820.50K \n               29254427.0  COMPLETED         48        1 2023-06-28T21:20:26 2023-06-28T21:20:26 2023-06-28T21:20:35          2.49K                     1341K                     1341K \n               29254427.1  COMPLETED         48        1 2023-06-28T21:20:35 2023-06-28T21:20:35 2023-06-28T21:21:00          8.22K                     1359K                     1359K \n               29254427.2  COMPLETED         48        1 2023-06-28T21:21:00 2023-06-28T21:21:00 2023-06-28T21:21:09          3.12K                     1350K                     1350K \n','\n',char(10)));
INSERT INTO job_data VALUES(147,10,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96','2023-06-28-21:20:23','2023-06-29-00:32:03',1687980023,1687980114,1687980161,'COMPLETED',2,96,'00:30','debug',20610,'2021-08-11 00:00:00','OSU_RUN_96','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254447,'',2,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230628212219.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230628212219.err',2,'',replace('                 29254447  COMPLETED         96        2 2023-06-28T21:20:23 2023-06-28T21:21:51 2023-06-28T21:22:41         20.61K                                                     \n           29254447.batch  COMPLETED         48        1 2023-06-28T21:21:51 2023-06-28T21:21:51 2023-06-28T21:22:41         14.84K                     6644K                     6644K \n          29254447.extern  COMPLETED         96        2 2023-06-28T21:21:51 2023-06-28T21:21:51 2023-06-28T21:22:42         20.61K                      856K                      818K \n               29254447.0  COMPLETED         48        1 2023-06-28T21:22:01 2023-06-28T21:22:01 2023-06-28T21:22:08          2.42K                     1339K                     1339K \n               29254447.1  COMPLETED         48        1 2023-06-28T21:22:08 2023-06-28T21:22:08 2023-06-28T21:22:33          8.21K                     1347K                     1347K \n               29254447.2  COMPLETED         48        1 2023-06-28T21:22:33 2023-06-28T21:22:33 2023-06-28T21:22:41          3.15K                     1353K                     1353K \n','\n',char(10)));
INSERT INTO job_data VALUES(148,10,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48','2023-06-28-21:21:05','2023-06-29-00:32:58',1687980065,1687980171,1687980219,'COMPLETED',2,48,'00:30','debug',15170,'2021-08-11 00:00:00','OSU_RUN_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29254453,'',1,13,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230628212254.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230628212254.err',2,'',replace('                 29254453  COMPLETED         48        1 2023-06-28T21:21:05 2023-06-28T21:22:48 2023-06-28T21:23:40         15.17K                                                     \n           29254453.batch  COMPLETED         48        1 2023-06-28T21:22:48 2023-06-28T21:22:48 2023-06-28T21:23:40         15.00K                     6638K                     6638K \n          29254453.extern  COMPLETED         48        1 2023-06-28T21:22:48 2023-06-28T21:22:48 2023-06-28T21:23:40         15.17K                       68K                       68K \n               29254453.0  COMPLETED         48        1 2023-06-28T21:22:56 2023-06-28T21:22:56 2023-06-28T21:23:04          2.45K                     1341K                     1341K \n               29254453.1  COMPLETED         48        1 2023-06-28T21:23:04 2023-06-28T21:23:04 2023-06-28T21:23:30          8.38K                     1340K                     1340K \n               29254453.2  COMPLETED         48        1 2023-06-28T21:23:30 2023-06-28T21:23:30 2023-06-28T21:23:40          3.13K                     1338K                     1338K \n','\n',char(10)));
INSERT INTO job_data VALUES(149,10,'a00m_20210811_StrongScaling_PREPARE_TESTS','2023-06-28-21:30:29','2023-06-29-00:55:28',1687980629,1687980692,1687980697,'COMPLETED',2,1,'00:30','debug',1580,'2021-08-11 00:00:00','PREPARE_TESTS','StrongScaling',0,0,'MARENOSTRUM4',29254522,'',1,13,0.0,0.0,'a00m_20210811_StrongScaling_PREPARE_TESTS.20230628213156.out','a00m_20210811_StrongScaling_PREPARE_TESTS.20230628213156.err',2,'a00m_20210811_StrongScaling_SCALABILITY_96,a00m_20210811_StrongScaling_SCALABILITY_192,a00m_20210811_StrongScaling_SCALABILITY_48',replace('                 29254522  COMPLETED          1        1 2023-06-28T21:30:29 2023-06-28T21:31:30 2023-06-28T21:31:39          1.58K                                                     \n           29254522.batch  COMPLETED          1        1 2023-06-28T21:31:30 2023-06-28T21:31:30 2023-06-28T21:31:39          1.17K                      983K                      983K \n          29254522.extern  COMPLETED          1        1 2023-06-28T21:31:30 2023-06-28T21:31:30 2023-06-28T21:31:39          1.58K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(150,10,'a00m_20210811_StrongScaling_SCALABILITY_192','2023-06-28-21:32:02','2023-06-29-00:56:03',1687980722,1687980728,1687980885,'COMPLETED',2,192,'00:30','debug',225220,'2021-08-11 00:00:00','SCALABILITY_192','StrongScaling',0,0,'MARENOSTRUM4',29254523,'',4,13,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_192.20230628213233.out','a00m_20210811_StrongScaling_SCALABILITY_192.20230628213233.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29254523  COMPLETED        192        4 2023-06-28T21:32:02 2023-06-28T21:32:04 2023-06-28T21:34:45        225.22K                                                     \n           29254523.batch  COMPLETED         48        1 2023-06-28T21:32:04 2023-06-28T21:32:04 2023-06-28T21:34:45         56.76K                     6814K                     6814K \n          29254523.extern  COMPLETED        192        4 2023-06-28T21:32:04 2023-06-28T21:32:04 2023-06-28T21:34:45        225.22K                      855K                    649472 \n               29254523.0  COMPLETED        192        4 2023-06-28T21:32:27 2023-06-28T21:32:27 2023-06-28T21:34:44        214.82K                  8311076K                  8228014K \n','\n',char(10)));
INSERT INTO job_data VALUES(151,10,'a00m_20210811_StrongScaling_SCALABILITY_96','2023-06-28-21:32:02','2023-06-29-00:56:04',1687980722,1687981108,1687981403,'COMPLETED',2,96,'00:30','debug',221250,'2021-08-11 00:00:00','SCALABILITY_96','StrongScaling',0,0,'MARENOSTRUM4',29254524,'',2,13,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_96.20230628213846.out','a00m_20210811_StrongScaling_SCALABILITY_96.20230628213846.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29254524  COMPLETED         96        2 2023-06-28T21:32:02 2023-06-28T21:38:25 2023-06-28T21:43:23        221.25K                                                     \n           29254524.batch  COMPLETED         48        1 2023-06-28T21:38:25 2023-06-28T21:38:25 2023-06-28T21:43:23        112.70K                     6705K                     6705K \n          29254524.extern  COMPLETED         96        2 2023-06-28T21:38:25 2023-06-28T21:38:25 2023-06-28T21:43:23        221.25K                      863K                   465.50K \n               29254524.0  COMPLETED         96        2 2023-06-28T21:38:46 2023-06-28T21:38:46 2023-06-28T21:43:22        216.23K                 13794932K                 13623896K \n','\n',char(10)));
INSERT INTO job_data VALUES(152,10,'a00m_20210811_StrongScaling_SCALABILITY_48','2023-06-28-21:32:02','2023-06-29-00:56:04',1687980722,1687981410,1687981972,'COMPLETED',2,48,'00:30','debug',217470,'2021-08-11 00:00:00','SCALABILITY_48','StrongScaling',0,0,'MARENOSTRUM4',29254525,'',1,13,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_48.20230628214345.out','a00m_20210811_StrongScaling_SCALABILITY_48.20230628214345.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29254525  COMPLETED         48        1 2023-06-28T21:32:02 2023-06-28T21:43:26 2023-06-28T21:52:52        217.47K                                                     \n           29254525.batch  COMPLETED         48        1 2023-06-28T21:43:26 2023-06-28T21:43:26 2023-06-28T21:52:52        217.45K                     6644K                     6644K \n          29254525.extern  COMPLETED         48        1 2023-06-28T21:43:26 2023-06-28T21:43:26 2023-06-28T21:52:52        217.47K                      879K                      879K \n               29254525.0  COMPLETED         48        1 2023-06-28T21:43:47 2023-06-28T21:43:47 2023-06-28T21:52:51        214.51K                 22618180K                 22618180K \n','\n',char(10)));
INSERT INTO job_data VALUES(153,11,'a00m_20210811_WeakScaling_PREPARE_TESTS','2023-06-28-21:39:52','2023-06-29-01:05:02',1687981192,1687981979,1687981987,'COMPLETED',2,1,'00:30','debug',1080,'2021-08-11 00:00:00','PREPARE_TESTS','WeakScaling',0,0,'MARENOSTRUM4',29254532,'',1,13,0.0,0.0,'a00m_20210811_WeakScaling_PREPARE_TESTS.20230628215319.out','a00m_20210811_WeakScaling_PREPARE_TESTS.20230628215319.err',2,'a00m_20210811_WeakScaling_SCALABILITY_48,a00m_20210811_WeakScaling_SCALABILITY_96,a00m_20210811_WeakScaling_SCALABILITY_192',replace('                 29254532  COMPLETED          1        1 2023-06-28T21:39:52 2023-06-28T21:52:56 2023-06-28T21:53:07          1.08K                                                     \n           29254532.batch  COMPLETED          1        1 2023-06-28T21:52:56 2023-06-28T21:52:56 2023-06-28T21:53:07          1.06K                     1145K                     1145K \n          29254532.extern  COMPLETED          1        1 2023-06-28T21:52:56 2023-06-28T21:52:56 2023-06-28T21:53:07          1.08K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(154,11,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','2023-06-28-21:45:39','2023-06-28-22:33:11',1687981539,1687981994,1687982086,'FAILED',2,1,'00:30','debug',1270,'2021-08-11 00:00:00','PREPARE_TESTS','CompilationEfficiency',0,0,'MARENOSTRUM4',29254537,'',1,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230628215318.out','a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230628215318.err',2,'a00m_20210811_CompilationEfficiency_SCALABILITY_192,a00m_20210811_CompilationEfficiency_SCALABILITY_48,a00m_20210811_CompilationEfficiency_SCALABILITY_96',replace('                 29254537     FAILED          1        1 2023-06-28T21:45:39 2023-06-28T21:53:11 2023-06-28T21:53:22          1.27K                                                     \n           29254537.batch     FAILED          1        1 2023-06-28T21:53:11 2023-06-28T21:53:11 2023-06-28T21:53:22          1.25K                     1137K                     1137K \n          29254537.extern  COMPLETED          1        1 2023-06-28T21:53:11 2023-06-28T21:53:11 2023-06-28T21:53:22          1.27K                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(155,11,'a00m_20210811_WeakScaling_SCALABILITY_192','2023-06-28-21:53:23','2023-06-28-22:32:13',1687982003,1687982010,1687982056,'FAILED',2,192,'00:30','debug',4510,'2021-08-11 00:00:00','SCALABILITY_192','WeakScaling',0,0,'MARENOSTRUM4',29254592,'',4,13,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_192.20230628215415.out','a00m_20210811_WeakScaling_SCALABILITY_192.20230628215415.err',2,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29254592     FAILED        192        4 2023-06-28T21:53:23 2023-06-28T21:53:27 2023-06-28T21:53:39          4.51K                                                     \n           29254592.batch     FAILED         48        1 2023-06-28T21:53:27 2023-06-28T21:53:27 2023-06-28T21:53:39          1.37K                     1363K                     1363K \n          29254592.extern  COMPLETED        192        4 2023-06-28T21:53:27 2023-06-28T21:53:27 2023-06-28T21:53:39          4.51K                      879K                    670976 \n','\n',char(10)));
INSERT INTO job_data VALUES(156,11,'a00m_20210811_WeakScaling_SCALABILITY_96','2023-06-28-21:53:23','2023-06-28-22:32:13',1687982003,1687982031,1687982170,'FAILED',2,96,'00:30','debug',2330,'2021-08-11 00:00:00','SCALABILITY_96','WeakScaling',0,0,'MARENOSTRUM4',29254593,'',2,13,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_96.20230628215609.out','a00m_20210811_WeakScaling_SCALABILITY_96.20230628215609.err',2,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29254593     FAILED         96        2 2023-06-28T21:53:23 2023-06-28T21:53:47 2023-06-28T21:53:59          2.33K                                                     \n           29254593.batch     FAILED         48        1 2023-06-28T21:53:47 2023-06-28T21:53:47 2023-06-28T21:53:59          1.10K                     1393K                     1393K \n          29254593.extern  COMPLETED         96        2 2023-06-28T21:53:47 2023-06-28T21:53:47 2023-06-28T21:54:00          2.33K                      850K                      802K \n','\n',char(10)));
INSERT INTO job_data VALUES(157,11,'a00m_20210811_WeakScaling_SCALABILITY_48','2023-06-28-21:53:23','2023-06-28-22:33:11',1687982003,1687982051,1687982138,'FAILED',2,48,'00:30','debug',948,'2021-08-11 00:00:00','SCALABILITY_48','WeakScaling',0,0,'MARENOSTRUM4',29254594,'',1,13,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_48.20230628215538.out','a00m_20210811_WeakScaling_SCALABILITY_48.20230628215538.err',2,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29254594     FAILED         48        1 2023-06-28T21:53:23 2023-06-28T21:54:07 2023-06-28T21:54:17            948                                                     \n           29254594.batch     FAILED         48        1 2023-06-28T21:54:07 2023-06-28T21:54:07 2023-06-28T21:54:17            765                     1392K                     1392K \n          29254594.extern  COMPLETED         48        1 2023-06-28T21:54:07 2023-06-28T21:54:07 2023-06-28T21:54:17            948                      842K                      842K \n','\n',char(10)));
INSERT INTO job_data VALUES(158,11,'a00m_20210811_StrongScaling_FUNCTIONS_DIR','2023-06-28-21:54:49','2023-06-29-01:22:14',1687982089,1687982103,1687982132,'COMPLETED',2,192,'02:00','debug',21050,'2021-08-11 00:00:00','FUNCTIONS_DIR','StrongScaling',0,0,'MARENOSTRUM4',29254598,'',4,13,0.0,0.0,'a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230628215508.out','a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230628215508.err',2,'a00m_20210811_StrongScaling_TRACE_96,a00m_20210811_StrongScaling_TRACE_48,a00m_20210811_StrongScaling_TRACE_192',replace('                 29254598  COMPLETED        192        4 2023-06-28T21:54:49 2023-06-28T21:55:00 2023-06-28T21:55:32         21.05K                                                     \n           29254598.batch  COMPLETED         48        1 2023-06-28T21:55:00 2023-06-28T21:55:00 2023-06-28T21:55:32          5.95K                     1397K                     1397K \n          29254598.extern  COMPLETED        192        4 2023-06-28T21:55:00 2023-06-28T21:55:00 2023-06-28T21:55:32         21.05K                      834K                    436992 \n               29254598.0  COMPLETED        192        4 2023-06-28T21:55:15 2023-06-28T21:55:15 2023-06-28T21:55:30         13.53K                     1440K                   1438976 \n','\n',char(10)));
INSERT INTO job_data VALUES(159,11,'a00m_20210811_StrongScaling_TRACE_192','2023-06-28-21:56:31','2023-06-28-22:30:25',1687982191,1687982195,1687982276,'FAILED',2,192,'00:30','debug',188,'2021-08-11 00:00:00','TRACE_192','StrongScaling',0,0,'MARENOSTRUM4',29254599,'',4,13,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_192.20230628215756.out','a00m_20210811_StrongScaling_TRACE_192.20230628215756.err',2,'',replace('                 29254599     FAILED        192        4 2023-06-28T21:56:31 2023-06-28T21:56:32 2023-06-28T21:56:35            188                                                     \n           29254599.batch     FAILED         48        1 2023-06-28T21:56:32 2023-06-28T21:56:32 2023-06-28T21:56:35             31                     1388K                     1388K \n          29254599.extern  COMPLETED        192        4 2023-06-28T21:56:32 2023-06-28T21:56:32 2023-06-28T21:56:35            188                      890K                      451K \n','\n',char(10)));
INSERT INTO job_data VALUES(160,11,'a00m_20210811_StrongScaling_TRACE_96','2023-06-28-21:56:31','2023-06-28-22:30:25',1687982191,1687982203,1687982245,'FAILED',2,96,'00:30','debug',70,'2021-08-11 00:00:00','TRACE_96','StrongScaling',0,0,'MARENOSTRUM4',29254600,'',2,13,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_96.20230628215725.out','a00m_20210811_StrongScaling_TRACE_96.20230628215725.err',2,'',replace('                 29254600     FAILED         96        2 2023-06-28T21:56:31 2023-06-28T21:56:40 2023-06-28T21:56:43             70                                                     \n           29254600.batch     FAILED         48        1 2023-06-28T21:56:40 2023-06-28T21:56:40 2023-06-28T21:56:43             21                     1391K                     1391K \n          29254600.extern  COMPLETED         96        2 2023-06-28T21:56:40 2023-06-28T21:56:40 2023-06-28T21:56:43             70                      851K                      841K \n','\n',char(10)));
INSERT INTO job_data VALUES(161,11,'a00m_20210811_StrongScaling_TRACE_48','2023-06-28-21:56:32','2023-06-28-22:30:25',1687982191,1687982211,1687982348,'FAILED',2,48,'00:30','debug',38,'2021-08-11 00:00:00','TRACE_48','StrongScaling',0,0,'MARENOSTRUM4',29254601,'',1,13,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_48.20230628215654.out','a00m_20210811_StrongScaling_TRACE_48.20230628215654.err',2,'',replace('                 29254601     FAILED         48        1 2023-06-28T21:56:31 2023-06-28T21:56:48 2023-06-28T21:56:51             38                                                     \n           29254601.batch     FAILED         48        1 2023-06-28T21:56:48 2023-06-28T21:56:48 2023-06-28T21:56:51             21                     1388K                     1388K \n          29254601.extern  COMPLETED         48        1 2023-06-28T21:56:48 2023-06-28T21:56:48 2023-06-28T21:56:51             38                      883K                      883K \n','\n',char(10)));
INSERT INTO job_data VALUES(162,12,'a00m_20210811_StrongScaling_TRACE_192','2023-06-28-22:30:25','2023-06-28-22:37:58',1687984225,1687984253,1687984328,'FAILED',2,192,'00:30','debug',118,'2021-08-11 00:00:00','TRACE_192','StrongScaling',0,0,'MARENOSTRUM4',29254778,'',4,13,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_192.20230628223208.out','a00m_20210811_StrongScaling_TRACE_192.20230628223208.err',2,'',replace('                 29254778     FAILED        192        4 2023-06-28T22:30:25 2023-06-28T22:30:50 2023-06-28T22:30:53            118                                                     \n           29254778.batch     FAILED         48        1 2023-06-28T22:30:50 2023-06-28T22:30:50 2023-06-28T22:30:53             18                     1392K                     1392K \n          29254778.extern  COMPLETED        192        4 2023-06-28T22:30:50 2023-06-28T22:30:50 2023-06-28T22:30:53            118                      867K                   830.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(163,12,'a00m_20210811_StrongScaling_TRACE_96','2023-06-28-22:30:25','2023-06-28-22:37:58',1687984225,1687984261,1687984297,'FAILED',2,96,'00:30','debug',109,'2021-08-11 00:00:00','TRACE_96','StrongScaling',0,0,'MARENOSTRUM4',29254779,'',2,13,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_96.20230628223137.out','a00m_20210811_StrongScaling_TRACE_96.20230628223137.err',2,'',replace('                 29254779     FAILED         96        2 2023-06-28T22:30:25 2023-06-28T22:30:57 2023-06-28T22:31:01            109                                                     \n           29254779.batch     FAILED         48        1 2023-06-28T22:30:57 2023-06-28T22:30:57 2023-06-28T22:31:01             37                     1392K                     1392K \n          29254779.extern  COMPLETED         96        2 2023-06-28T22:30:57 2023-06-28T22:30:57 2023-06-28T22:31:01            109                      840K                      837K \n','\n',char(10)));
INSERT INTO job_data VALUES(164,12,'a00m_20210811_StrongScaling_TRACE_48','2023-06-28-22:30:25','2023-06-28-22:37:58',1687984225,1687984269,1687984387,'FAILED',2,48,'00:30','debug',52,'2021-08-11 00:00:00','TRACE_48','StrongScaling',0,0,'MARENOSTRUM4',29254780,'',1,13,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_48.20230628223307.out','a00m_20210811_StrongScaling_TRACE_48.20230628223307.err',2,'',replace('                 29254780     FAILED         48        1 2023-06-28T22:30:26 2023-06-28T22:31:05 2023-06-28T22:31:09             52                                                     \n           29254780.batch     FAILED         48        1 2023-06-28T22:31:05 2023-06-28T22:31:05 2023-06-28T22:31:09             30                     1392K                     1392K \n          29254780.extern  COMPLETED         48        1 2023-06-28T22:31:05 2023-06-28T22:31:05 2023-06-28T22:31:09             52                      853K                      853K \n','\n',char(10)));
INSERT INTO job_data VALUES(165,12,'a00m_20210811_WeakScaling_SCALABILITY_192','2023-06-28-22:32:13','2023-06-29-01:07:14',1687984333,1687984339,1687984339,'COMPLETED',2,192,'00:30','debug',755,'2021-08-11 00:00:00','SCALABILITY_192','WeakScaling',0,0,'MARENOSTRUM4',29254783,'',4,13,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_192.20230628223236.out','a00m_20210811_WeakScaling_SCALABILITY_192.20230628223236.err',2,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29254783  COMPLETED        192        4 2023-06-28T22:32:13 2023-06-28T22:32:16 2023-06-28T22:32:21            755                                                     \n           29254783.batch  COMPLETED         48        1 2023-06-28T22:32:16 2023-06-28T22:32:16 2023-06-28T22:32:21             24                     1386K                     1386K \n          29254783.extern  COMPLETED        192        4 2023-06-28T22:32:16 2023-06-28T22:32:16 2023-06-28T22:32:21            755                      766K                    226048 \n','\n',char(10)));
INSERT INTO job_data VALUES(166,12,'a00m_20210811_WeakScaling_SCALABILITY_96','2023-06-28-22:32:13','2023-06-29-01:07:14',1687984333,1687984352,1687984352,'COMPLETED',2,96,'00:30','debug',456,'2021-08-11 00:00:00','SCALABILITY_96','WeakScaling',0,0,'MARENOSTRUM4',29254784,'',2,13,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_96.20230628223236.out','a00m_20210811_WeakScaling_SCALABILITY_96.20230628223236.err',2,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29254784  COMPLETED         96        2 2023-06-28T22:32:13 2023-06-28T22:32:28 2023-06-28T22:32:33            456                                                     \n           29254784.batch  COMPLETED         48        1 2023-06-28T22:32:28 2023-06-28T22:32:28 2023-06-28T22:32:33             35                     1381K                     1381K \n          29254784.extern  COMPLETED         96        2 2023-06-28T22:32:28 2023-06-28T22:32:28 2023-06-28T22:32:33            456                      780K                   776.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(167,12,'a00m_20210811_WeakScaling_SCALABILITY_48','2023-06-28-22:33:11','2023-06-29-01:12:08',1687984391,1687984395,1687984395,'COMPLETED',2,48,'00:30','debug',48,'2021-08-11 00:00:00','SCALABILITY_48','WeakScaling',0,0,'MARENOSTRUM4',29254785,'',1,13,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_48.20230628223329.out','a00m_20210811_WeakScaling_SCALABILITY_48.20230628223329.err',2,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29254785  COMPLETED         48        1 2023-06-28T22:33:11 2023-06-28T22:33:12 2023-06-28T22:33:15             48                                                     \n           29254785.batch  COMPLETED         48        1 2023-06-28T22:33:12 2023-06-28T22:33:12 2023-06-28T22:33:15             25                     1407K                     1407K \n          29254785.extern  COMPLETED         48        1 2023-06-28T22:33:12 2023-06-28T22:33:12 2023-06-28T22:33:15             48                       24K                       24K \n','\n',char(10)));
INSERT INTO job_data VALUES(168,12,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','2023-06-28-22:33:11','2023-06-29-08:04:56',1687984391,1687984401,1687984406,'COMPLETED',2,1,'00:30','debug',865,'2021-08-11 00:00:00','PREPARE_TESTS','CompilationEfficiency',0,0,'MARENOSTRUM4',29254786,'',1,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230628223329.out','a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230628223329.err',2,'a00m_20210811_CompilationEfficiency_SCALABILITY_192,a00m_20210811_CompilationEfficiency_SCALABILITY_48,a00m_20210811_CompilationEfficiency_SCALABILITY_96',replace('                 29254786  COMPLETED          1        1 2023-06-28T22:33:11 2023-06-28T22:33:19 2023-06-28T22:33:26            865                                                     \n           29254786.batch  COMPLETED          1        1 2023-06-28T22:33:19 2023-06-28T22:33:19 2023-06-28T22:33:26            850                      907K                      907K \n          29254786.extern  COMPLETED          1        1 2023-06-28T22:33:19 2023-06-28T22:33:19 2023-06-28T22:33:26            865                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(169,12,'a00m_20210811_CompilationEfficiency_SCALABILITY_192','2023-06-28-22:33:35','2023-06-29-09:13:08',1687984415,1687984419,1687984419,'COMPLETED',2,192,'00:30','debug',160,'2021-08-11 00:00:00','SCALABILITY_192','CompilationEfficiency',0,0,'MARENOSTRUM4',29254787,'',4,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_SCALABILITY_192.20230628223359.out','a00m_20210811_CompilationEfficiency_SCALABILITY_192.20230628223359.err',2,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR',replace('                 29254787  COMPLETED        192        4 2023-06-28T22:33:36 2023-06-28T22:33:36 2023-06-28T22:33:39            160                                                     \n           29254787.batch  COMPLETED         48        1 2023-06-28T22:33:36 2023-06-28T22:33:36 2023-06-28T22:33:39             23                     1382K                     1382K \n          29254787.extern  COMPLETED        192        4 2023-06-28T22:33:36 2023-06-28T22:33:36 2023-06-28T22:33:40            160                      833K                    423168 \n','\n',char(10)));
INSERT INTO job_data VALUES(170,12,'a00m_20210811_CompilationEfficiency_SCALABILITY_96','2023-06-28-22:33:35','2023-06-29-09:13:08',1687984415,1687984427,1687984427,'COMPLETED',2,96,'00:30','debug',88,'2021-08-11 00:00:00','SCALABILITY_96','CompilationEfficiency',0,0,'MARENOSTRUM4',29254788,'',2,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_SCALABILITY_96.20230628223359.out','a00m_20210811_CompilationEfficiency_SCALABILITY_96.20230628223359.err',2,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR',replace('                 29254788  COMPLETED         96        2 2023-06-28T22:33:36 2023-06-28T22:33:44 2023-06-28T22:33:47             88                                                     \n           29254788.batch  COMPLETED         48        1 2023-06-28T22:33:44 2023-06-28T22:33:44 2023-06-28T22:33:47             32                     1389K                     1389K \n          29254788.extern  COMPLETED         96        2 2023-06-28T22:33:44 2023-06-28T22:33:44 2023-06-28T22:33:48             88                      854K                      443K \n','\n',char(10)));
INSERT INTO job_data VALUES(171,12,'a00m_20210811_CompilationEfficiency_SCALABILITY_48','2023-06-28-22:33:35','2023-06-29-09:13:08',1687984415,1687984437,1687984437,'COMPLETED',2,48,'00:30','debug',202,'2021-08-11 00:00:00','SCALABILITY_48','CompilationEfficiency',0,0,'MARENOSTRUM4',29254789,'',1,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_SCALABILITY_48.20230628223358.out','a00m_20210811_CompilationEfficiency_SCALABILITY_48.20230628223358.err',2,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR',replace('                 29254789  COMPLETED         48        1 2023-06-28T22:33:36 2023-06-28T22:33:52 2023-06-28T22:33:59            202                                                     \n           29254789.batch  COMPLETED         48        1 2023-06-28T22:33:52 2023-06-28T22:33:52 2023-06-28T22:33:59             21                     1389K                     1389K \n          29254789.extern  COMPLETED         48        1 2023-06-28T22:33:52 2023-06-28T22:33:52 2023-06-28T22:33:59            202                       28K                       28K \n','\n',char(10)));
INSERT INTO job_data VALUES(172,12,'a00m_20210811_WeakScaling_FUNCTIONS_DIR','2023-06-28-22:34:03','2023-06-28-22:51:11',1687984443,1687984450,1687984514,'FAILED',2,192,'02:00','debug',6260,'2021-08-11 00:00:00','FUNCTIONS_DIR','WeakScaling',0,0,'MARENOSTRUM4',29254793,'',4,13,0.0,0.0,'a00m_20210811_WeakScaling_FUNCTIONS_DIR.20230628223421.out','a00m_20210811_WeakScaling_FUNCTIONS_DIR.20230628223421.err',2,'a00m_20210811_WeakScaling_TRACE_48,a00m_20210811_WeakScaling_TRACE_192,a00m_20210811_WeakScaling_TRACE_96',replace('                 29254793     FAILED        192        4 2023-06-28T22:34:04 2023-06-28T22:34:06 2023-06-28T22:34:24          6.26K                                                     \n           29254793.batch     FAILED         48        1 2023-06-28T22:34:06 2023-06-28T22:34:06 2023-06-28T22:34:24          1.92K                     1410K                     1410K \n          29254793.extern  COMPLETED        192        4 2023-06-28T22:34:06 2023-06-28T22:34:06 2023-06-28T22:34:24          6.26K                      916K                   870.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(173,12,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR','2023-06-28-22:34:26','2023-06-28-22:38:23',1687984466,1687984477,1687984562,'FAILED',2,192,'02:00','debug',5270,'2021-08-11 00:00:00','FUNCTIONS_DIR','CompilationEfficiency',0,0,'MARENOSTRUM4',29254795,'',4,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR.20230628223444.out','a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR.20230628223444.err',2,'a00m_20210811_CompilationEfficiency_TRACE_96,a00m_20210811_CompilationEfficiency_TRACE_192,a00m_20210811_CompilationEfficiency_TRACE_48',replace('                 29254795     FAILED        192        4 2023-06-28T22:34:26 2023-06-28T22:34:34 2023-06-28T22:34:49          5.27K                                                     \n           29254795.batch     FAILED         48        1 2023-06-28T22:34:34 2023-06-28T22:34:34 2023-06-28T22:34:49          1.50K                     1387K                     1387K \n          29254795.extern  COMPLETED        192        4 2023-06-28T22:34:34 2023-06-28T22:34:34 2023-06-28T22:34:49          5.27K                      884K                      855K \n','\n',char(10)));
INSERT INTO job_data VALUES(174,13,'a00m_20210811_StrongScaling_TRACE_192','2023-06-28-22:37:58','2023-06-29-08:04:31',1687984678,1687984685,1687985445,'COMPLETED',2,192,'00:30','debug',1150000,'2021-08-11 00:00:00','TRACE_192','StrongScaling',0,0,'MARENOSTRUM4',29254800,'',4,13,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_192.20230628223819.out','a00m_20210811_StrongScaling_TRACE_192.20230628223819.err',2,'',replace('                 29254800  COMPLETED        192        4 2023-06-28T22:37:59 2023-06-28T22:38:01 2023-06-28T22:50:45          1.15M                                                     \n           29254800.batch  COMPLETED         48        1 2023-06-28T22:38:01 2023-06-28T22:38:01 2023-06-28T22:50:45        289.27K                     7054K                     7054K \n          29254800.extern  COMPLETED        192        4 2023-06-28T22:38:01 2023-06-28T22:38:01 2023-06-28T22:50:45          1.15M                      872K                   856.50K \n               29254800.0  COMPLETED        192        4 2023-06-28T22:38:29 2023-06-28T22:38:29 2023-06-28T22:50:45          1.14M                 17817016K                 17730544K \n','\n',char(10)));
INSERT INTO job_data VALUES(175,13,'a00m_20210811_StrongScaling_TRACE_96','2023-06-28-22:37:58','2023-06-29-08:04:31',1687984678,1687985458,1687986178,'WAITING',2,96,'00:30','debug',531690,'2021-08-11 00:00:00','TRACE_96','StrongScaling',0,0,'MARENOSTRUM4',29254801,'',2,13,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_96.20230628225108.out','a00m_20210811_StrongScaling_TRACE_96.20230628225108.err',4,'',replace('                 29254801 CANCELLED+         96        2 2023-06-28T22:37:59 2023-06-28T22:50:55 2023-06-28T23:02:20        531.69K                                                     \n           29254801.batch  CANCELLED         48        1 2023-06-28T22:50:55 2023-06-28T22:50:55 2023-06-28T23:02:20        264.30K                     6782K                     6782K \n          29254801.extern  COMPLETED         96        2 2023-06-28T22:50:55 2023-06-28T22:50:55 2023-06-28T23:02:20        531.69K                      886K                      477K \n               29254801.0     FAILED         96        2 2023-06-28T22:51:20 2023-06-28T22:51:20 2023-06-28T23:02:25        525.99K                 23299156K                 23107994K \n','\n',char(10)));
INSERT INTO job_data VALUES(176,13,'a00m_20210811_StrongScaling_TRACE_48','2023-06-28-22:37:58','2023-06-29-08:04:31',1687984678,1687986419,1687986450,'WAITING',2,48,'00:30','debug',0,'2021-08-11 00:00:00','TRACE_48','StrongScaling',0,0,'MARENOSTRUM4',29254802,'',1,13,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_48.20230628230659.out','a00m_20210811_StrongScaling_TRACE_48.20230628230659.err',4,'',replace('                 29254802 CANCELLED+         48        1 2023-06-28T22:37:59 2023-06-28T23:02:20 2023-06-28T23:02:20              0                                                     \n','\n',char(10)));
INSERT INTO job_data VALUES(177,13,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR','2023-06-28-22:38:23','2023-06-28-23:12:23',1687984703,1687986238,1687986269,'FAILED',2,192,'02:00','debug',0,'2021-08-11 00:00:00','FUNCTIONS_DIR','CompilationEfficiency',0,0,'MARENOSTRUM4',29254805,'',1,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR.20230628230358.out','a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR.20230628230358.err',2,'a00m_20210811_CompilationEfficiency_TRACE_96,a00m_20210811_CompilationEfficiency_TRACE_192,a00m_20210811_CompilationEfficiency_TRACE_48',replace('                 29254805 CANCELLED+        192        1 2023-06-28T22:38:24 2023-06-28T23:02:20 2023-06-28T23:02:20              0                                                     \n','\n',char(10)));
INSERT INTO job_data VALUES(178,13,'a00m_20210811_WeakScaling_FUNCTIONS_DIR','2023-06-28-22:51:11','2023-06-28-23:12:23',1687985471,1687986329,1687986359,'FAILED',2,192,'02:00','debug',0,'2021-08-11 00:00:00','FUNCTIONS_DIR','WeakScaling',0,0,'MARENOSTRUM4',29254878,'',1,13,0.0,0.0,'a00m_20210811_WeakScaling_FUNCTIONS_DIR.20230628230529.out','a00m_20210811_WeakScaling_FUNCTIONS_DIR.20230628230529.err',2,'a00m_20210811_WeakScaling_TRACE_48,a00m_20210811_WeakScaling_TRACE_192,a00m_20210811_WeakScaling_TRACE_96',replace('                 29254878 CANCELLED+        192        1 2023-06-28T22:51:11 2023-06-28T23:02:20 2023-06-28T23:02:20              0                                                     \n','\n',char(10)));
INSERT INTO job_data VALUES(179,14,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR','2023-06-28-23:12:23','2023-06-28-23:31:23',1687986743,1687986774,1687986832,'FAILED',2,192,'02:00','debug',6530,'2021-08-11 00:00:00','FUNCTIONS_DIR','CompilationEfficiency',0,0,'MARENOSTRUM4',29255037,'',4,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR.20230628231304.out','a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR.20230628231304.err',2,'a00m_20210811_CompilationEfficiency_TRACE_96,a00m_20210811_CompilationEfficiency_TRACE_192,a00m_20210811_CompilationEfficiency_TRACE_48',replace('                 29255037     FAILED        192        4 2023-06-28T23:12:23 2023-06-28T23:12:50 2023-06-28T23:13:07          6.53K                                                     \n           29255037.batch     FAILED         48        1 2023-06-28T23:12:50 2023-06-28T23:12:50 2023-06-28T23:13:07          2.14K                     1386K                     1386K \n          29255037.extern  COMPLETED        192        4 2023-06-28T23:12:50 2023-06-28T23:12:50 2023-06-28T23:13:07          6.53K                      878K                   874.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(180,14,'a00m_20210811_WeakScaling_FUNCTIONS_DIR','2023-06-28-23:12:23','2023-06-28-23:31:23',1687986743,1687986802,1687986881,'FAILED',2,192,'02:00','debug',4910,'2021-08-11 00:00:00','FUNCTIONS_DIR','WeakScaling',0,0,'MARENOSTRUM4',29255038,'',4,13,0.0,0.0,'a00m_20210811_WeakScaling_FUNCTIONS_DIR.20230628231352.out','a00m_20210811_WeakScaling_FUNCTIONS_DIR.20230628231352.err',2,'a00m_20210811_WeakScaling_TRACE_48,a00m_20210811_WeakScaling_TRACE_192,a00m_20210811_WeakScaling_TRACE_96',replace('                 29255038     FAILED        192        4 2023-06-28T23:12:23 2023-06-28T23:13:18 2023-06-28T23:13:31          4.91K                                                     \n           29255038.batch     FAILED         48        1 2023-06-28T23:13:18 2023-06-28T23:13:18 2023-06-28T23:13:31          1.54K                     1396K                     1396K \n          29255038.extern  COMPLETED        192        4 2023-06-28T23:13:18 2023-06-28T23:13:18 2023-06-28T23:13:31          4.91K                      859K                    652032 \n','\n',char(10)));
INSERT INTO job_data VALUES(181,15,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR','2023-06-28-23:31:23','2023-06-28-23:34:13',1687987883,1687987964,1687987975,'COMPLETED',2,192,'02:00','debug',5360,'2021-08-11 00:00:00','FUNCTIONS_DIR','CompilationEfficiency',0,1,'MARENOSTRUM4',29255143,'',4,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR.20230628233248.out','a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR.20230628233248.err',2,'a00m_20210811_CompilationEfficiency_TRACE_96,a00m_20210811_CompilationEfficiency_TRACE_192,a00m_20210811_CompilationEfficiency_TRACE_48',replace('                 29255143  COMPLETED        192        4 2023-06-28T23:31:23 2023-06-28T23:32:41 2023-06-28T23:32:56          5.36K                                                     \n           29255143.batch  COMPLETED         48        1 2023-06-28T23:32:41 2023-06-28T23:32:41 2023-06-28T23:32:56          1.80K                     1387K                     1387K \n          29255143.extern  COMPLETED        192        4 2023-06-28T23:32:41 2023-06-28T23:32:41 2023-06-28T23:32:56          5.36K                      867K                    853760 \n','\n',char(10)));
INSERT INTO job_data VALUES(182,15,'a00m_20210811_WeakScaling_FUNCTIONS_DIR','2023-06-28-23:31:23','2023-06-28-23:34:38',1687987883,1687987991,1687988001,'COMPLETED',2,192,'02:00','debug',4550,'2021-08-11 00:00:00','FUNCTIONS_DIR','WeakScaling',0,1,'MARENOSTRUM4',29255144,'',4,13,0.0,0.0,'a00m_20210811_WeakScaling_FUNCTIONS_DIR.20230628233334.out','a00m_20210811_WeakScaling_FUNCTIONS_DIR.20230628233334.err',2,'a00m_20210811_WeakScaling_TRACE_48,a00m_20210811_WeakScaling_TRACE_192,a00m_20210811_WeakScaling_TRACE_96',replace('                 29255144  COMPLETED        192        4 2023-06-28T23:31:23 2023-06-28T23:33:08 2023-06-28T23:33:21          4.55K                                                     \n           29255144.batch  COMPLETED         48        1 2023-06-28T23:33:08 2023-06-28T23:33:08 2023-06-28T23:33:21          1.60K                     1400K                     1400K \n          29255144.extern  COMPLETED        192        4 2023-06-28T23:33:08 2023-06-28T23:33:08 2023-06-28T23:33:21          4.55K                      896K                   655.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(183,15,'a00m_20210811_CompilationEfficiency_TRACE_192','2023-06-28-23:33:14','2023-06-28-23:35:01',1687987994,1687988012,1687988022,'COMPLETED',2,192,'00:30','debug',4750,'2021-08-11 00:00:00','TRACE_192','CompilationEfficiency',0,1,'MARENOSTRUM4',29255146,'',4,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_TRACE_192.20230628233334.out','a00m_20210811_CompilationEfficiency_TRACE_192.20230628233334.err',2,'',replace('                 29255146  COMPLETED        192        4 2023-06-28T23:33:13 2023-06-28T23:33:29 2023-06-28T23:33:42          4.75K                                                     \n           29255146.batch  COMPLETED         48        1 2023-06-28T23:33:29 2023-06-28T23:33:29 2023-06-28T23:33:42          1.57K                     1398K                     1398K \n          29255146.extern  COMPLETED        192        4 2023-06-28T23:33:29 2023-06-28T23:33:29 2023-06-28T23:33:42          4.75K                      885K                   852.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(184,15,'a00m_20210811_CompilationEfficiency_TRACE_96','2023-06-28-23:33:14','2023-06-28-23:35:52',1687987994,1687988049,1687988061,'COMPLETED',2,96,'00:30','debug',3840,'2021-08-11 00:00:00','TRACE_96','CompilationEfficiency',0,1,'MARENOSTRUM4',29255147,'',2,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_TRACE_96.20230628233424.out','a00m_20210811_CompilationEfficiency_TRACE_96.20230628233424.err',2,'',replace('                 29255147  COMPLETED         96        2 2023-06-28T23:33:13 2023-06-28T23:34:04 2023-06-28T23:34:23          3.84K                                                     \n           29255147.batch  COMPLETED         48        1 2023-06-28T23:34:04 2023-06-28T23:34:04 2023-06-28T23:34:23          2.16K                     1397K                     1397K \n          29255147.extern  COMPLETED         96        2 2023-06-28T23:34:04 2023-06-28T23:34:04 2023-06-28T23:34:23          3.84K                      790K                      407K \n','\n',char(10)));
INSERT INTO job_data VALUES(185,15,'a00m_20210811_WeakScaling_TRACE_192','2023-06-28-23:33:38','2023-06-28-23:35:27',1687988018,1687988029,1687988039,'COMPLETED',2,192,'00:30','debug',5050,'2021-08-11 00:00:00','TRACE_192','WeakScaling',0,1,'MARENOSTRUM4',29255148,'',4,13,0.0,0.0,'a00m_20210811_WeakScaling_TRACE_192.20230628233358.out','a00m_20210811_WeakScaling_TRACE_192.20230628233358.err',2,'',replace('                 29255148  COMPLETED        192        4 2023-06-28T23:33:38 2023-06-28T23:33:46 2023-06-28T23:33:59          5.05K                                                     \n           29255148.batch  COMPLETED         48        1 2023-06-28T23:33:46 2023-06-28T23:33:46 2023-06-28T23:33:59          1.71K                     1396K                     1396K \n          29255148.extern  COMPLETED        192        4 2023-06-28T23:33:46 2023-06-28T23:33:46 2023-06-28T23:34:00          5.05K                      877K                      636K \n','\n',char(10)));
INSERT INTO job_data VALUES(186,15,'a00m_20210811_WeakScaling_TRACE_96','2023-06-28-23:33:38','2023-06-28-23:36:12',1687988018,1687988074,1687988086,'COMPLETED',2,96,'00:30','debug',3650,'2021-08-11 00:00:00','TRACE_96','WeakScaling',0,1,'MARENOSTRUM4',29255149,'',2,13,0.0,0.0,'a00m_20210811_WeakScaling_TRACE_96.20230628233449.out','a00m_20210811_WeakScaling_TRACE_96.20230628233449.err',2,'',replace('                 29255149  COMPLETED         96        2 2023-06-28T23:33:38 2023-06-28T23:34:31 2023-06-28T23:34:48          3.65K                                                     \n           29255149.batch  COMPLETED         48        1 2023-06-28T23:34:31 2023-06-28T23:34:31 2023-06-28T23:34:48          2.05K                     1395K                     1395K \n          29255149.extern  COMPLETED         96        2 2023-06-28T23:34:31 2023-06-28T23:34:31 2023-06-28T23:34:48          3.65K                      857K                      847K \n','\n',char(10)));
INSERT INTO job_data VALUES(187,15,'a00m_20210811_CompilationEfficiency_TRACE_48','2023-06-28-23:34:02','2023-06-28-23:36:31',1687988042,1687988099,1687988112,'COMPLETED',2,48,'00:30','debug',1870,'2021-08-11 00:00:00','TRACE_48','CompilationEfficiency',0,1,'MARENOSTRUM4',29255151,'',1,13,0.0,0.0,'a00m_20210811_CompilationEfficiency_TRACE_48.20230628233509.out','a00m_20210811_CompilationEfficiency_TRACE_48.20230628233509.err',2,'',replace('                 29255151  COMPLETED         48        1 2023-06-28T23:34:02 2023-06-28T23:34:56 2023-06-28T23:35:12          1.87K                                                     \n           29255151.batch  COMPLETED         48        1 2023-06-28T23:34:56 2023-06-28T23:34:56 2023-06-28T23:35:12          1.84K                     1389K                     1389K \n          29255151.extern  COMPLETED         48        1 2023-06-28T23:34:56 2023-06-28T23:34:56 2023-06-28T23:35:12          1.87K                       35K                       35K \n','\n',char(10)));
INSERT INTO job_data VALUES(188,15,'a00m_20210811_WeakScaling_TRACE_48','2023-06-28-23:34:28','2023-06-28-23:36:50',1687988068,1687988120,1687988130,'COMPLETED',2,48,'00:30','debug',1460,'2021-08-11 00:00:00','TRACE_48','WeakScaling',0,1,'MARENOSTRUM4',29255153,'',1,13,0.0,0.0,'a00m_20210811_WeakScaling_TRACE_48.20230628233528.out','a00m_20210811_WeakScaling_TRACE_48.20230628233528.err',2,'',replace('                 29255153  COMPLETED         48        1 2023-06-28T23:34:28 2023-06-28T23:35:17 2023-06-28T23:35:30          1.46K                                                     \n           29255153.batch  COMPLETED         48        1 2023-06-28T23:35:17 2023-06-28T23:35:17 2023-06-28T23:35:30          1.44K                     1387K                     1387K \n          29255153.extern  COMPLETED         48        1 2023-06-28T23:35:17 2023-06-28T23:35:17 2023-06-28T23:35:30          1.46K                      835K                      835K \n','\n',char(10)));
INSERT INTO job_data VALUES(189,15,'a00m_CLEAN','2023-06-29-00:21:52','2023-06-29-09:58:07',1687990912,1687990912,1687990961,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',287123,'',0,18,0.0,0.0,'a00m_CLEAN.20230629002211.out','a00m_CLEAN.20230629002211.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(190,15,'a00m_REMOTE_SETUP','2023-06-29-00:22:57','2023-06-29-10:01:13',1687990977,1687990977,1687991061,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',289118,'',0,18,0.0,0.0,'a00m_REMOTE_SETUP.20230629002311.out','a00m_REMOTE_SETUP.20230629002311.err',5,'a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(191,15,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-29-00:24:34','2023-06-29-10:13:57',1687991074,1687991074,1687991082,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',296491,'',0,18,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230629002510.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230629002510.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(192,15,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-29-00:24:39','2023-06-29-10:14:01',1687991079,1687991079,1687991087,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',297583,'',0,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230629002511.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230629002511.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(193,15,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-29-00:24:46','2023-06-29-10:14:07',1687991086,1687991086,1687991093,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',299209,'',0,18,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230629002511.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230629002511.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(194,15,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-29-00:25:16','2023-06-29-10:14:33',1687991116,1687991116,1687993820,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',303586,'',0,18,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629002553.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629002553.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(195,15,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-06-29-00:25:22','2023-06-29-10:14:38',1687991122,1687991122,1687991289,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,0,'MARENOSTRUM0',305291,'',0,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230629002553.out','a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230629002553.err',5,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(196,15,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-29-00:25:27','2023-06-29-09:58:02',1687991127,1687991127,1687993473,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',306298,'',0,18,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629002553.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629002553.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(197,15,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-29-00:26:11','2023-06-29-10:15:11',1687991171,1687991171,1687991180,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',319431,'',0,18,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230629002656.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230629002656.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(198,15,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-29-00:27:01','2023-06-29-10:15:36',1687991221,1687991221,1687992905,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',339184,'',0,18,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629002740.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629002740.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(199,15,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','2023-06-29-00:28:26','2023-06-29-10:17:10',1687991306,1687991313,1687991318,'COMPLETED',2,1,'00:30','debug',1470,'2021-08-11 00:00:00','PREPARE_TESTS','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255443,'',1,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230629002902.out','a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230629002902.err',2,'a00m_20210811_HardwareBenchmarks_STREAM_16,a00m_20210811_HardwareBenchmarks_OSU_RUN_192,a00m_20210811_HardwareBenchmarks_STREAM_32,a00m_20210811_HardwareBenchmarks_OSU_RUN_48,a00m_20210811_HardwareBenchmarks_STREAM_8,a00m_20210811_HardwareBenchmarks_STREAM_4,a00m_20210811_HardwareBenchmarks_STREAM_48,a00m_20210811_HardwareBenchmarks_OSU_RUN_96,a00m_20210811_HardwareBenchmarks_STREAM_2,a00m_20210811_HardwareBenchmarks_STREAM_1',replace('                 29255443  COMPLETED          1        1 2023-06-29T00:28:26 2023-06-29T00:28:30 2023-06-29T00:28:38          1.47K                                                     \n           29255443.batch  COMPLETED          1        1 2023-06-29T00:28:30 2023-06-29T00:28:30 2023-06-29T00:28:38          1.41K                      956K                      956K \n          29255443.extern  COMPLETED          1        1 2023-06-29T00:28:30 2023-06-29T00:28:30 2023-06-29T00:28:38          1.47K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(200,15,'a00m_20210811_HardwareBenchmarks_STREAM_48','2023-06-29-00:29:09','2023-06-29-10:17:32',1687991349,1687991357,1687991366,'COMPLETED',2,48,'00:30','debug',1490,'2021-08-11 00:00:00','STREAM_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255448,'',1,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_48.20230629003003.out','a00m_20210811_HardwareBenchmarks_STREAM_48.20230629003003.err',2,'',replace('                 29255448  COMPLETED         48        1 2023-06-29T00:29:08 2023-06-29T00:29:13 2023-06-29T00:29:26          1.49K                                                     \n           29255448.batch  COMPLETED         48        1 2023-06-29T00:29:13 2023-06-29T00:29:13 2023-06-29T00:29:26          1.46K                     1397K                     1397K \n          29255448.extern  COMPLETED         48        1 2023-06-29T00:29:13 2023-06-29T00:29:13 2023-06-29T00:29:26          1.49K                      849K                      849K \n','\n',char(10)));
INSERT INTO job_data VALUES(201,15,'a00m_20210811_HardwareBenchmarks_STREAM_32','2023-06-29-00:29:09','2023-06-29-10:17:32',1687991349,1687991377,1687991383,'COMPLETED',2,32,'00:30','debug',1060,'2021-08-11 00:00:00','STREAM_32','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255449,'',1,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_32.20230629003002.out','a00m_20210811_HardwareBenchmarks_STREAM_32.20230629003002.err',2,'',replace('                 29255449  COMPLETED         32        1 2023-06-29T00:29:08 2023-06-29T00:29:33 2023-06-29T00:29:43          1.06K                                                     \n           29255449.batch  COMPLETED         32        1 2023-06-29T00:29:33 2023-06-29T00:29:33 2023-06-29T00:29:43          1.04K                     1236K                     1236K \n          29255449.extern  COMPLETED         32        1 2023-06-29T00:29:33 2023-06-29T00:29:33 2023-06-29T00:29:44          1.06K                      880K                      880K \n','\n',char(10)));
INSERT INTO job_data VALUES(202,15,'a00m_20210811_HardwareBenchmarks_STREAM_16','2023-06-29-00:29:09','2023-06-29-10:17:32',1687991349,1687991427,1687991436,'COMPLETED',2,16,'00:30','debug',2260,'2021-08-11 00:00:00','STREAM_16','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255450,'',1,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_16.20230629003102.out','a00m_20210811_HardwareBenchmarks_STREAM_16.20230629003102.err',2,'',replace('                 29255450  COMPLETED         16        1 2023-06-29T00:29:08 2023-06-29T00:30:24 2023-06-29T00:30:36          2.26K                                                     \n           29255450.batch  COMPLETED         16        1 2023-06-29T00:30:24 2023-06-29T00:30:24 2023-06-29T00:30:36          2.22K                     1017K                     1017K \n          29255450.extern  COMPLETED         16        1 2023-06-29T00:30:24 2023-06-29T00:30:24 2023-06-29T00:30:36          2.26K                       26K                       26K \n','\n',char(10)));
INSERT INTO job_data VALUES(203,15,'a00m_20210811_HardwareBenchmarks_STREAM_8','2023-06-29-00:30:07','2023-06-29-10:18:23',1687991407,1687991441,1687991448,'COMPLETED',2,8,'00:30','debug',1690,'2021-08-11 00:00:00','STREAM_8','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255453,'',1,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_8.20230629003101.out','a00m_20210811_HardwareBenchmarks_STREAM_8.20230629003101.err',2,'',replace('                 29255453  COMPLETED          8        1 2023-06-29T00:30:07 2023-06-29T00:30:37 2023-06-29T00:30:49          1.69K                                                     \n           29255453.batch  COMPLETED          8        1 2023-06-29T00:30:37 2023-06-29T00:30:37 2023-06-29T00:30:49          1.64K                      962K                      962K \n          29255453.extern  COMPLETED          8        1 2023-06-29T00:30:37 2023-06-29T00:30:37 2023-06-29T00:30:49          1.69K                       22K                       22K \n','\n',char(10)));
INSERT INTO job_data VALUES(204,15,'a00m_20210811_HardwareBenchmarks_STREAM_4','2023-06-29-00:30:07','2023-06-29-10:18:53',1687991407,1687991457,1687991464,'COMPLETED',2,4,'00:30','debug',1690,'2021-08-11 00:00:00','STREAM_4','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255454,'',1,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_4.20230629003101.out','a00m_20210811_HardwareBenchmarks_STREAM_4.20230629003101.err',2,'',replace('                 29255454  COMPLETED          4        1 2023-06-29T00:30:07 2023-06-29T00:30:53 2023-06-29T00:31:04          1.69K                                                     \n           29255454.batch  COMPLETED          4        1 2023-06-29T00:30:53 2023-06-29T00:30:53 2023-06-29T00:31:04          1.59K                      952K                      952K \n          29255454.extern  COMPLETED          4        1 2023-06-29T00:30:53 2023-06-29T00:30:53 2023-06-29T00:31:04          1.69K                       26K                       26K \n','\n',char(10)));
INSERT INTO job_data VALUES(205,15,'a00m_20210811_HardwareBenchmarks_STREAM_2','2023-06-29-00:31:09','2023-06-29-10:19:20',1687991469,1687991684,1687991693,'COMPLETED',2,2,'00:30','debug',2100,'2021-08-11 00:00:00','STREAM_2','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255456,'',1,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_2.20230629003534.out','a00m_20210811_HardwareBenchmarks_STREAM_2.20230629003534.err',2,'',replace('                 29255456  COMPLETED          2        1 2023-06-29T00:31:09 2023-06-29T00:34:39 2023-06-29T00:34:53          2.10K                                                     \n           29255456.batch  COMPLETED          2        1 2023-06-29T00:34:39 2023-06-29T00:34:39 2023-06-29T00:34:53          2.05K                      942K                      942K \n          29255456.extern  COMPLETED          2        1 2023-06-29T00:34:39 2023-06-29T00:34:39 2023-06-29T00:34:53          2.10K                       27K                       27K \n','\n',char(10)));
INSERT INTO job_data VALUES(206,15,'a00m_20210811_HardwareBenchmarks_STREAM_1','2023-06-29-00:31:09','2023-06-29-10:19:21',1687991469,1687991742,1687991749,'COMPLETED',2,1,'00:30','debug',2210,'2021-08-11 00:00:00','STREAM_1','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255457,'',1,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_1.20230629003622.out','a00m_20210811_HardwareBenchmarks_STREAM_1.20230629003622.err',2,'',replace('                 29255457  COMPLETED          1        1 2023-06-29T00:31:09 2023-06-29T00:35:39 2023-06-29T00:35:49          2.21K                                                     \n           29255457.batch  COMPLETED          1        1 2023-06-29T00:35:39 2023-06-29T00:35:39 2023-06-29T00:35:49          2.14K                      900K                      900K \n          29255457.extern  COMPLETED          1        1 2023-06-29T00:35:39 2023-06-29T00:35:39 2023-06-29T00:35:49          2.21K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(207,15,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192','2023-06-29-00:31:10','2023-06-29-10:19:51',1687991469,1687991478,1687991526,'COMPLETED',2,192,'00:30','debug',34630,'2021-08-11 00:00:00','OSU_RUN_192','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255458,'',4,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230629003159.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230629003159.err',2,'',replace('                 29255458  COMPLETED        192        4 2023-06-29T00:31:09 2023-06-29T00:31:14 2023-06-29T00:32:06         34.63K                                                     \n           29255458.batch  COMPLETED         48        1 2023-06-29T00:31:14 2023-06-29T00:31:14 2023-06-29T00:32:06         18.70K                     6625K                     6625K \n          29255458.extern  COMPLETED        192        4 2023-06-29T00:31:14 2023-06-29T00:31:14 2023-06-29T00:32:06         34.63K                      869K                    670464 \n               29255458.0  COMPLETED         48        1 2023-06-29T00:31:24 2023-06-29T00:31:24 2023-06-29T00:31:32          3.08K                     1342K                     1342K \n               29255458.1  COMPLETED         48        1 2023-06-29T00:31:32 2023-06-29T00:31:32 2023-06-29T00:31:57         10.26K                     1339K                     1339K \n               29255458.2  COMPLETED         48        1 2023-06-29T00:31:57 2023-06-29T00:31:57 2023-06-29T00:32:06          3.89K                     1346K                     1346K \n','\n',char(10)));
INSERT INTO job_data VALUES(208,15,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96','2023-06-29-00:32:03','2023-06-29-10:19:51',1687991523,1687991536,1687991584,'COMPLETED',2,96,'00:30','debug',20820,'2021-08-11 00:00:00','OSU_RUN_96','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255459,'',2,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230629003254.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230629003254.err',2,'',replace('                 29255459  COMPLETED         96        2 2023-06-29T00:32:03 2023-06-29T00:32:12 2023-06-29T00:33:06         20.82K                                                     \n           29255459.batch  COMPLETED         48        1 2023-06-29T00:32:12 2023-06-29T00:32:12 2023-06-29T00:33:06         14.87K                     6655K                     6655K \n          29255459.extern  COMPLETED         96        2 2023-06-29T00:32:12 2023-06-29T00:32:12 2023-06-29T00:33:06         20.82K                      905K                      888K \n               29255459.0  COMPLETED         48        1 2023-06-29T00:32:22 2023-06-29T00:32:22 2023-06-29T00:32:29          2.44K                     1337K                     1337K \n               29255459.1  COMPLETED         48        1 2023-06-29T00:32:29 2023-06-29T00:32:29 2023-06-29T00:32:56          8.20K                     1341K                     1341K \n               29255459.2  COMPLETED         48        1 2023-06-29T00:32:56 2023-06-29T00:32:56 2023-06-29T00:33:06          3.06K                     1352K                     1352K \n','\n',char(10)));
INSERT INTO job_data VALUES(209,15,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48','2023-06-29-00:32:58','2023-06-29-10:20:18',1687991578,1687991599,1687991646,'COMPLETED',2,48,'00:30','debug',14660,'2021-08-11 00:00:00','OSU_RUN_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29255460,'',1,18,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230629003348.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230629003348.err',2,'',replace('                 29255460  COMPLETED         48        1 2023-06-29T00:32:58 2023-06-29T00:33:16 2023-06-29T00:34:06         14.66K                                                     \n           29255460.batch  COMPLETED         48        1 2023-06-29T00:33:16 2023-06-29T00:33:16 2023-06-29T00:34:06         14.64K                     6640K                     6640K \n          29255460.extern  COMPLETED         48        1 2023-06-29T00:33:16 2023-06-29T00:33:16 2023-06-29T00:34:07         14.66K                       68K                       68K \n               29255460.0  COMPLETED         48        1 2023-06-29T00:33:26 2023-06-29T00:33:26 2023-06-29T00:33:33          2.44K                     1340K                     1340K \n               29255460.1  COMPLETED         48        1 2023-06-29T00:33:33 2023-06-29T00:33:33 2023-06-29T00:33:58          8.10K                     1343K                     1343K \n               29255460.2  COMPLETED         48        1 2023-06-29T00:33:58 2023-06-29T00:33:58 2023-06-29T00:34:06          3.06K                     1331K                     1331K \n','\n',char(10)));
INSERT INTO job_data VALUES(210,15,'a00m_20210811_StrongScaling_PREPARE_TESTS','2023-06-29-00:55:28','2023-06-29-12:03:33',1687992928,1687992934,1687992939,'COMPLETED',2,1,'00:30','debug',1210,'2021-08-11 00:00:00','PREPARE_TESTS','StrongScaling',0,0,'MARENOSTRUM4',29255535,'',1,18,0.0,0.0,'a00m_20210811_StrongScaling_PREPARE_TESTS.20230629005558.out','a00m_20210811_StrongScaling_PREPARE_TESTS.20230629005558.err',2,'a00m_20210811_StrongScaling_SCALABILITY_96,a00m_20210811_StrongScaling_SCALABILITY_192,a00m_20210811_StrongScaling_SCALABILITY_48',replace('                 29255535  COMPLETED          1        1 2023-06-29T00:55:28 2023-06-29T00:55:31 2023-06-29T00:55:40          1.21K                                                     \n           29255535.batch  COMPLETED          1        1 2023-06-29T00:55:31 2023-06-29T00:55:31 2023-06-29T00:55:40          1.16K                      976K                      976K \n          29255535.extern  COMPLETED          1        1 2023-06-29T00:55:31 2023-06-29T00:55:31 2023-06-29T00:55:40          1.21K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(211,15,'a00m_20210811_StrongScaling_SCALABILITY_192','2023-06-29-00:56:04','2023-06-29-12:04:39',1687992963,1687992967,1687993123,'COMPLETED',2,192,'00:30','debug',227900,'2021-08-11 00:00:00','SCALABILITY_192','StrongScaling',0,0,'MARENOSTRUM4',29255552,'',4,18,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_192.20230629005635.out','a00m_20210811_StrongScaling_SCALABILITY_192.20230629005635.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29255552  COMPLETED        192        4 2023-06-29T00:56:03 2023-06-29T00:56:04 2023-06-29T00:58:43        227.90K                                                     \n           29255552.batch  COMPLETED         48        1 2023-06-29T00:56:04 2023-06-29T00:56:04 2023-06-29T00:58:43         58.93K                     6844K                     6844K \n          29255552.extern  COMPLETED        192        4 2023-06-29T00:56:04 2023-06-29T00:56:04 2023-06-29T00:58:43        227.90K                      896K                    686336 \n               29255552.0  COMPLETED        192        4 2023-06-29T00:56:25 2023-06-29T00:56:25 2023-06-29T00:58:43        217.82K                  8324452K                  8236108K \n','\n',char(10)));
INSERT INTO job_data VALUES(212,15,'a00m_20210811_StrongScaling_SCALABILITY_96','2023-06-29-00:56:04','2023-06-29-12:04:39',1687992964,1687993140,1687993433,'COMPLETED',2,96,'00:30','debug',229760,'2021-08-11 00:00:00','SCALABILITY_96','StrongScaling',0,0,'MARENOSTRUM4',29255553,'',2,18,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_96.20230629005911.out','a00m_20210811_StrongScaling_SCALABILITY_96.20230629005911.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29255553  COMPLETED         96        2 2023-06-29T00:56:03 2023-06-29T00:58:56 2023-06-29T01:03:53        229.76K                                                     \n           29255553.batch  COMPLETED         48        1 2023-06-29T00:58:56 2023-06-29T00:58:56 2023-06-29T01:03:53        116.02K                     6743K                     6743K \n          29255553.extern  COMPLETED         96        2 2023-06-29T00:58:56 2023-06-29T00:58:56 2023-06-29T01:03:53        229.76K                      843K                   819.50K \n               29255553.0  COMPLETED         96        2 2023-06-29T00:59:16 2023-06-29T00:59:16 2023-06-29T01:03:52        224.54K                 13785908K                 13620290K \n','\n',char(10)));
INSERT INTO job_data VALUES(213,15,'a00m_20210811_StrongScaling_SCALABILITY_48','2023-06-29-00:56:04','2023-06-29-12:04:39',1687992964,1687993910,1687994473,'COMPLETED',2,48,'00:30','debug',214470,'2021-08-11 00:00:00','SCALABILITY_48','StrongScaling',0,0,'MARENOSTRUM4',29255554,'',1,18,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_48.20230629011204.out','a00m_20210811_StrongScaling_SCALABILITY_48.20230629011204.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29255554  COMPLETED         48        1 2023-06-29T00:56:03 2023-06-29T01:11:47 2023-06-29T01:21:15        214.47K                                                     \n           29255554.batch  COMPLETED         48        1 2023-06-29T01:11:47 2023-06-29T01:11:47 2023-06-29T01:21:15        214.23K                     6696K                     6696K \n          29255554.extern  COMPLETED         48        1 2023-06-29T01:11:47 2023-06-29T01:11:47 2023-06-29T01:21:15        214.47K                       72K                       72K \n               29255554.0  COMPLETED         48        1 2023-06-29T01:12:06 2023-06-29T01:12:06 2023-06-29T01:21:12        211.63K                 22614580K                 22614580K \n','\n',char(10)));
INSERT INTO job_data VALUES(214,15,'a00m_20210811_WeakScaling_PREPARE_TESTS','2023-06-29-01:05:02','2023-06-29-12:12:10',1687993502,1687993603,1687993610,'COMPLETED',2,1,'00:30','debug',2060,'2021-08-11 00:00:00','PREPARE_TESTS','WeakScaling',0,0,'MARENOSTRUM4',29255625,'',1,18,0.0,0.0,'a00m_20210811_WeakScaling_PREPARE_TESTS.20230629010709.out','a00m_20210811_WeakScaling_PREPARE_TESTS.20230629010709.err',2,'a00m_20210811_WeakScaling_SCALABILITY_48,a00m_20210811_WeakScaling_SCALABILITY_96,a00m_20210811_WeakScaling_SCALABILITY_192',replace('                 29255625  COMPLETED          1        1 2023-06-29T01:05:02 2023-06-29T01:06:42 2023-06-29T01:06:51          2.06K                                                     \n           29255625.batch  COMPLETED          1        1 2023-06-29T01:06:42 2023-06-29T01:06:42 2023-06-29T01:06:51          1.71K                     1027K                     1027K \n          29255625.extern  COMPLETED          1        1 2023-06-29T01:06:42 2023-06-29T01:06:42 2023-06-29T01:06:52          2.06K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(215,15,'a00m_20210811_WeakScaling_SCALABILITY_192','2023-06-29-01:07:14','2023-06-29-12:22:44',1687993634,1687994511,1688018607,'COMPLETED',2,192,'00:30','debug',2830000,'2021-08-11 00:00:00','SCALABILITY_192','WeakScaling',0,0,'MARENOSTRUM4',29255630,'',4,18,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_192.20230629012210.out','a00m_20210811_WeakScaling_SCALABILITY_192.20230629012210.err',4,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29255630    TIMEOUT        192        4 2023-06-29T01:07:14 2023-06-29T01:21:47 2023-06-29T01:51:52          2.83M                                                     \n           29255630.batch  CANCELLED         48        1 2023-06-29T01:21:47 2023-06-29T01:21:47 2023-06-29T01:51:52        709.98K                     6956K                     6956K \n          29255630.extern  COMPLETED        192        4 2023-06-29T01:21:47 2023-06-29T01:21:47 2023-06-29T01:51:52          2.83M                      867K                    832768 \n               29255630.0     FAILED        192        4 2023-06-29T01:22:07 2023-06-29T01:22:07 2023-06-29T01:51:57          2.83M                 82569160K                 81904698K \n','\n',char(10)));
INSERT INTO job_data VALUES(216,15,'a00m_20210811_WeakScaling_SCALABILITY_96','2023-06-29-01:07:14','2023-06-29-12:22:44',1687993634,1687996330,1688018667,'COMPLETED',2,96,'00:30','debug',12500,'2021-08-11 00:00:00','SCALABILITY_96','WeakScaling',0,0,'MARENOSTRUM4',29255632,'',2,18,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_96.20230629080427.out','a00m_20210811_WeakScaling_SCALABILITY_96.20230629080427.err',4,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29255632     FAILED         96        2 2023-06-29T01:07:14 2023-06-29T01:52:06 2023-06-29T01:52:46         12.50K                                                     \n           29255632.batch     FAILED         48        1 2023-06-29T01:52:06 2023-06-29T01:52:06 2023-06-29T01:52:46          6.44K                     1407K                     1407K \n          29255632.extern  COMPLETED         96        2 2023-06-29T01:52:06 2023-06-29T01:52:06 2023-06-29T01:52:46         12.50K                      821K                   793.50K \n               29255632.0  COMPLETED         96        2 2023-06-29T01:52:27 2023-06-29T01:52:27 2023-06-29T01:52:46          7.34K                     1438K                  1378.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(217,15,'a00m_20210811_WeakScaling_SCALABILITY_48','2023-06-29-01:12:08','2023-06-29-09:55:35',1687993928,1687996373,1688018637,'COMPLETED',2,48,'00:30','debug',5490,'2021-08-11 00:00:00','SCALABILITY_48','WeakScaling',0,1,'MARENOSTRUM4',29255651,'',1,18,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_48.20230629080357.out','a00m_20210811_WeakScaling_SCALABILITY_48.20230629080357.err',4,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29255651 OUT_OF_ME+         48        1 2023-06-29T01:12:08 2023-06-29T01:52:49 2023-06-29T01:53:25          5.49K                                                     \n           29255651.batch OUT_OF_ME+         48        1 2023-06-29T01:52:49 2023-06-29T01:52:49 2023-06-29T01:53:25          5.47K                     6624K                     6624K \n          29255651.extern OUT_OF_ME+         48        1 2023-06-29T01:52:49 2023-06-29T01:52:49 2023-06-29T01:53:25          5.49K                       68K                       68K \n               29255651.0 OUT_OF_ME+         48        1 2023-06-29T01:53:07 2023-06-29T01:53:07 2023-06-29T01:53:25          2.99K                     1347K                     1347K \n','\n',char(10)));
INSERT INTO job_data VALUES(218,15,'a00m_20210811_StrongScaling_FUNCTIONS_DIR','2023-06-29-01:22:14','2023-06-29-12:22:11',1687994534,1687996413,1687996440,'COMPLETED',2,192,'02:00','debug',21040,'2021-08-11 00:00:00','FUNCTIONS_DIR','StrongScaling',0,0,'MARENOSTRUM4',29255680,'',4,18,0.0,0.0,'a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230629080327.out','a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230629080327.err',2,'a00m_20210811_StrongScaling_TRACE_192,a00m_20210811_StrongScaling_TRACE_96,a00m_20210811_StrongScaling_TRACE_48',replace('                 29255680  COMPLETED        192        4 2023-06-29T01:22:14 2023-06-29T01:53:30 2023-06-29T01:54:02         21.04K                                                     \n           29255680.batch  COMPLETED         48        1 2023-06-29T01:53:30 2023-06-29T01:53:30 2023-06-29T01:54:02          5.37K                     1371K                     1371K \n          29255680.extern  COMPLETED        192        4 2023-06-29T01:53:30 2023-06-29T01:53:30 2023-06-29T01:54:02         21.04K                      868K                      830K \n               29255680.0  COMPLETED        192        4 2023-06-29T01:53:45 2023-06-29T01:53:45 2023-06-29T01:54:00         13.11K                     1461K                   1452288 \n','\n',char(10)));
INSERT INTO job_data VALUES(219,15,'a00m_20210811_StrongScaling_TRACE_192','2023-06-29-08:04:31','2023-06-29-12:23:37',1688018671,1688018682,1688019442,'COMPLETED',2,192,'00:30','debug',1150000,'2021-08-11 00:00:00','TRACE_192','StrongScaling',0,0,'MARENOSTRUM4',29257388,'',4,18,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_192.20230629080451.out','a00m_20210811_StrongScaling_TRACE_192.20230629080451.err',2,'',replace('                 29257388  COMPLETED        192        4 2023-06-29T08:04:31 2023-06-29T08:04:38 2023-06-29T08:17:23          1.15M                                                     \n           29257388.batch  COMPLETED         48        1 2023-06-29T08:04:38 2023-06-29T08:04:38 2023-06-29T08:17:23        299.37K                     7096K                     7096K \n          29257388.extern  COMPLETED        192        4 2023-06-29T08:04:38 2023-06-29T08:04:38 2023-06-29T08:17:23          1.15M                      873K                    677632 \n               29257388.0  COMPLETED        192        4 2023-06-29T08:05:06 2023-06-29T08:05:06 2023-06-29T08:17:23          1.14M                 17817456K                 17728525K \n','\n',char(10)));
INSERT INTO job_data VALUES(220,15,'a00m_20210811_StrongScaling_TRACE_96','2023-06-29-08:04:31','2023-06-29-12:54:48',1688018671,1688019458,1688020889,'COMPLETED',2,96,'00:30','debug',1120000,'2021-08-11 00:00:00','TRACE_96','StrongScaling',0,0,'MARENOSTRUM4',29257389,'',2,18,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_96.20230629081743.out','a00m_20210811_StrongScaling_TRACE_96.20230629081743.err',2,'',replace('                 29257389  COMPLETED         96        2 2023-06-29T08:04:31 2023-06-29T08:17:34 2023-06-29T08:41:30          1.12M                                                     \n           29257389.batch  COMPLETED         48        1 2023-06-29T08:17:34 2023-06-29T08:17:34 2023-06-29T08:41:30        556.80K                     6822K                     6822K \n          29257389.extern  COMPLETED         96        2 2023-06-29T08:17:34 2023-06-29T08:17:34 2023-06-29T08:41:30          1.12M                      777K                   422.50K \n               29257389.0  COMPLETED         96        2 2023-06-29T08:18:01 2023-06-29T08:18:01 2023-06-29T08:41:30          1.11M                 23730044K                 23532484K \n','\n',char(10)));
INSERT INTO job_data VALUES(221,15,'a00m_20210811_StrongScaling_TRACE_48','2023-06-29-08:04:31','2023-06-29-12:56:28',1688018671,1688020908,1688022764,'COMPLETED',2,48,'00:30','debug',718250,'2021-08-11 00:00:00','TRACE_48','StrongScaling',0,0,'MARENOSTRUM4',29257390,'',1,18,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_48.20230629084205.out','a00m_20210811_StrongScaling_TRACE_48.20230629084205.err',4,'',replace('                 29257390    TIMEOUT         48        1 2023-06-29T08:04:31 2023-06-29T08:41:44 2023-06-29T09:12:06        718.25K                                                     \n           29257390.batch  CANCELLED         48        1 2023-06-29T08:41:44 2023-06-29T08:41:44 2023-06-29T09:12:06        718.24K                     6761K                     6761K \n          29257390.extern  COMPLETED         48        1 2023-06-29T08:41:44 2023-06-29T08:41:44 2023-06-29T09:12:06        718.25K                      786K                      786K \n               29257390.0     FAILED         48        1 2023-06-29T08:42:11 2023-06-29T08:42:11 2023-06-29T09:12:09        714.49K                 32856116K                 32856116K \n','\n',char(10)));
INSERT INTO job_data VALUES(222,15,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','2023-06-29-08:04:56','2023-06-29-12:19:22',1688018696,1688022736,1688022740,'COMPLETED',2,1,'00:30','debug',1200,'2021-08-11 00:00:00','PREPARE_TESTS','CompilationEfficiency',0,0,'MARENOSTRUM4',29257393,'',1,18,0.0,0.0,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230629091244.out','a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230629091244.err',2,'a00m_20210811_CompilationEfficiency_SCALABILITY_192,a00m_20210811_CompilationEfficiency_SCALABILITY_48,a00m_20210811_CompilationEfficiency_SCALABILITY_96',replace('                 29257393  COMPLETED          1        1 2023-06-29T08:04:56 2023-06-29T09:12:13 2023-06-29T09:12:21          1.20K                                                     \n           29257393.batch  COMPLETED          1        1 2023-06-29T09:12:13 2023-06-29T09:12:13 2023-06-29T09:12:21          1.16K                      961K                      961K \n          29257393.extern  COMPLETED          1        1 2023-06-29T09:12:13 2023-06-29T09:12:13 2023-06-29T09:12:21          1.20K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(223,15,'a00m_20210811_CompilationEfficiency_SCALABILITY_192','2023-06-29-09:13:08','2023-06-29-12:57:34',1688022788,1688022798,1688023712,'COMPLETED',2,192,'00:30','debug',1060000,'2021-08-11 00:00:00','SCALABILITY_192','CompilationEfficiency',0,0,'MARENOSTRUM4',29257561,'',4,18,0.0,0.0,'a00m_20210811_CompilationEfficiency_SCALABILITY_192.20230629091330.out','a00m_20210811_CompilationEfficiency_SCALABILITY_192.20230629091330.err',4,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR',replace('                 29257561     FAILED        192        4 2023-06-29T09:13:07 2023-06-29T09:13:15 2023-06-29T09:27:48          1.06M                                                     \n           29257561.batch     FAILED         48        1 2023-06-29T09:13:15 2023-06-29T09:13:15 2023-06-29T09:27:48        262.22K                     6857K                     6857K \n          29257561.extern  COMPLETED        192        4 2023-06-29T09:13:15 2023-06-29T09:13:15 2023-06-29T09:27:52          1.06M                      910K                      679K \n               29257561.0  COMPLETED        192        4 2023-06-29T09:13:37 2023-06-29T09:13:37 2023-06-29T09:27:30          1.04M                  8254644K                  8149384K \n               29257561.1     FAILED        192        4 2023-06-29T09:27:47 2023-06-29T09:27:47 2023-06-29T09:27:49             56                     1438K                  1405.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(224,15,'a00m_20210811_CompilationEfficiency_SCALABILITY_96','2023-06-29-09:13:08','2023-06-29-13:48:02',1688022788,1688023682,0,'COMPLETED',2,96,'00:30','debug',0,'2021-08-11 00:00:00','SCALABILITY_96','CompilationEfficiency',0,0,'MARENOSTRUM4',29257562,'',0,18,0.0,0.0,'','',4,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR','');
INSERT INTO job_data VALUES(225,15,'a00m_20210811_CompilationEfficiency_SCALABILITY_48','2023-06-29-09:13:08','2023-06-29-13:48:02',1688022788,0,0,'COMPLETED',2,48,'00:30','debug',0,'2021-08-11 00:00:00','SCALABILITY_48','CompilationEfficiency',0,0,'MARENOSTRUM4',29257563,'',0,18,0.0,0.0,'','',4,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR','');
INSERT INTO job_data VALUES(226,16,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-29-09:58:02','2023-06-29-10:14:43',1688025482,1688025482,1688025525,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',385942,'',0,20,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629095830.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629095830.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(227,16,'a00m_CLEAN','2023-06-29-09:58:07','2023-06-29-10:00:54',1688025487,1688025486,1688025504,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',386478,'',0,20,0.0,0.0,'a00m_CLEAN.20230629095830.out','a00m_CLEAN.20230629095830.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(228,17,'a00m_CLEAN','2023-06-29-10:00:54','2023-06-29-11:23:35',1688025654,1688025654,1688025654,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',390839,'',0,22,0.0,0.0,'a00m_CLEAN.20230629100108.out','a00m_CLEAN.20230629100108.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(229,17,'a00m_REMOTE_SETUP','2023-06-29-10:01:13','2023-06-29-11:24:06',1688025673,1688025672,1688026428,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',391875,'',0,22,0.0,0.0,'a00m_REMOTE_SETUP.20230629100127.out','a00m_REMOTE_SETUP.20230629100127.err',5,'a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(230,17,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-29-10:13:57','2023-06-29-11:36:59',1688026437,1688026436,1688026444,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,0,'MARENOSTRUM0',415395,'',0,22,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230629101429.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230629101429.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(231,17,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-29-10:14:01','2023-06-29-11:37:14',1688026441,1688026441,1688026449,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,0,'MARENOSTRUM0',416493,'',0,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230629101429.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230629101429.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(232,17,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-29-10:14:07','2023-06-29-11:37:28',1688026447,1688026446,1688026453,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,0,'MARENOSTRUM0',417206,'',0,22,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230629101429.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230629101429.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(233,17,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-29-10:14:33','2023-06-29-11:02:19',1688026473,1688026473,1688026505,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',418453,'',0,22,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629101505.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629101505.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(234,17,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-06-29-10:14:38','2023-06-29-11:38:34',1688026478,1688026478,1688026612,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,0,'MARENOSTRUM0',419642,'',0,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230629101505.out','a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230629101505.err',5,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(235,17,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-29-10:14:43','2023-06-29-11:02:39',1688026483,1688026482,1688026505,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',420859,'',0,22,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629101505.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629101505.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(236,17,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-29-10:15:11','2023-06-29-11:39:42',1688026511,1688026511,1688026524,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,0,'MARENOSTRUM0',424358,'',0,22,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230629101531.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230629101531.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(237,17,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-29-10:15:36','2023-06-29-11:02:58',1688026536,1688026535,1688026554,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',427858,'',0,22,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629101554.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629101554.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(238,17,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','2023-06-29-10:17:10','2023-06-29-11:42:15',1688026630,1688026639,1688026646,'COMPLETED',2,1,'00:30','debug',1130,'2021-08-11 00:00:00','PREPARE_TESTS','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258005,'',1,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230629101728.out','a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230629101728.err',2,'a00m_20210811_HardwareBenchmarks_STREAM_16,a00m_20210811_HardwareBenchmarks_OSU_RUN_192,a00m_20210811_HardwareBenchmarks_OSU_RUN_48,a00m_20210811_HardwareBenchmarks_STREAM_8,a00m_20210811_HardwareBenchmarks_STREAM_4,a00m_20210811_HardwareBenchmarks_STREAM_48,a00m_20210811_HardwareBenchmarks_STREAM_32,a00m_20210811_HardwareBenchmarks_OSU_RUN_96,a00m_20210811_HardwareBenchmarks_STREAM_2,a00m_20210811_HardwareBenchmarks_STREAM_1',replace('                 29258005  COMPLETED          1        1 2023-06-29T10:17:10 2023-06-29T10:17:16 2023-06-29T10:17:26          1.13K                                                     \n           29258005.batch  COMPLETED          1        1 2023-06-29T10:17:16 2023-06-29T10:17:16 2023-06-29T10:17:26          1.11K                        1M                        1M \n          29258005.extern  COMPLETED          1        1 2023-06-29T10:17:16 2023-06-29T10:17:16 2023-06-29T10:17:26          1.13K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(239,17,'a00m_20210811_HardwareBenchmarks_STREAM_48','2023-06-29-10:17:32','2023-06-29-11:43:04',1688026652,1688026693,1688026703,'COMPLETED',2,48,'00:30','debug',1680,'2021-08-11 00:00:00','STREAM_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258006,'',1,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_48.20230629101818.out','a00m_20210811_HardwareBenchmarks_STREAM_48.20230629101818.err',2,'',replace('                 29258006  COMPLETED         48        1 2023-06-29T10:17:31 2023-06-29T10:18:10 2023-06-29T10:18:25          1.68K                                                     \n           29258006.batch  COMPLETED         48        1 2023-06-29T10:18:10 2023-06-29T10:18:10 2023-06-29T10:18:25          1.48K                     1384K                     1384K \n          29258006.extern  COMPLETED         48        1 2023-06-29T10:18:10 2023-06-29T10:18:10 2023-06-29T10:18:25          1.68K                      780K                      780K \n','\n',char(10)));
INSERT INTO job_data VALUES(240,17,'a00m_20210811_HardwareBenchmarks_STREAM_32','2023-06-29-10:17:32','2023-06-29-11:43:04',1688026652,1688026716,1688026722,'COMPLETED',2,32,'00:30','debug',1310,'2021-08-11 00:00:00','STREAM_32','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258007,'',1,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_32.20230629101848.out','a00m_20210811_HardwareBenchmarks_STREAM_32.20230629101848.err',2,'',replace('                 29258007  COMPLETED         32        1 2023-06-29T10:17:31 2023-06-29T10:18:32 2023-06-29T10:18:43          1.31K                                                     \n           29258007.batch  COMPLETED         32        1 2023-06-29T10:18:32 2023-06-29T10:18:32 2023-06-29T10:18:43          1.23K                     1071K                     1071K \n          29258007.extern  COMPLETED         32        1 2023-06-29T10:18:32 2023-06-29T10:18:32 2023-06-29T10:18:43          1.31K                       30K                       30K \n','\n',char(10)));
INSERT INTO job_data VALUES(241,17,'a00m_20210811_HardwareBenchmarks_STREAM_16','2023-06-29-10:17:32','2023-06-29-11:43:04',1688026652,1688026729,1688026735,'COMPLETED',2,16,'00:30','debug',1010,'2021-08-11 00:00:00','STREAM_16','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258008,'',1,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_16.20230629101917.out','a00m_20210811_HardwareBenchmarks_STREAM_16.20230629101917.err',2,'',replace('                 29258008  COMPLETED         16        1 2023-06-29T10:17:31 2023-06-29T10:18:45 2023-06-29T10:18:55          1.01K                                                     \n           29258008.batch  COMPLETED         16        1 2023-06-29T10:18:45 2023-06-29T10:18:45 2023-06-29T10:18:55            984                     1116K                     1116K \n          29258008.extern  COMPLETED         16        1 2023-06-29T10:18:45 2023-06-29T10:18:45 2023-06-29T10:18:55          1.01K                      837K                      837K \n','\n',char(10)));
INSERT INTO job_data VALUES(242,17,'a00m_20210811_HardwareBenchmarks_STREAM_8','2023-06-29-10:18:23','2023-06-29-11:43:56',1688026703,1688026746,1688026753,'COMPLETED',2,8,'00:30','debug',1100,'2021-08-11 00:00:00','STREAM_8','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258009,'',1,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_8.20230629101917.out','a00m_20210811_HardwareBenchmarks_STREAM_8.20230629101917.err',2,'',replace('                 29258009  COMPLETED          8        1 2023-06-29T10:18:22 2023-06-29T10:19:03 2023-06-29T10:19:13          1.10K                                                     \n           29258009.batch  COMPLETED          8        1 2023-06-29T10:19:03 2023-06-29T10:19:03 2023-06-29T10:19:13          1.08K                     1135K                     1135K \n          29258009.extern  COMPLETED          8        1 2023-06-29T10:19:03 2023-06-29T10:19:03 2023-06-29T10:19:13          1.10K                      863K                      863K \n','\n',char(10)));
INSERT INTO job_data VALUES(243,17,'a00m_20210811_HardwareBenchmarks_STREAM_4','2023-06-29-10:18:53','2023-06-29-11:43:56',1688026733,1688026761,1688026767,'COMPLETED',2,4,'00:30','debug',1020,'2021-08-11 00:00:00','STREAM_4','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258011,'',1,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_4.20230629101945.out','a00m_20210811_HardwareBenchmarks_STREAM_4.20230629101945.err',2,'',replace('                 29258011  COMPLETED          4        1 2023-06-29T10:18:53 2023-06-29T10:19:17 2023-06-29T10:19:27          1.02K                                                     \n           29258011.batch  COMPLETED          4        1 2023-06-29T10:19:17 2023-06-29T10:19:17 2023-06-29T10:19:27          1.00K                     1136K                     1136K \n          29258011.extern  COMPLETED          4        1 2023-06-29T10:19:17 2023-06-29T10:19:17 2023-06-29T10:19:27          1.02K                      873K                      873K \n','\n',char(10)));
INSERT INTO job_data VALUES(244,17,'a00m_20210811_HardwareBenchmarks_STREAM_2','2023-06-29-10:19:21','2023-06-29-11:44:47',1688026760,1688026775,1688026781,'COMPLETED',2,2,'00:30','debug',1020,'2021-08-11 00:00:00','STREAM_2','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258015,'',1,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_2.20230629101945.out','a00m_20210811_HardwareBenchmarks_STREAM_2.20230629101945.err',2,'',replace('                 29258015  COMPLETED          2        1 2023-06-29T10:19:20 2023-06-29T10:19:31 2023-06-29T10:19:41          1.02K                                                     \n           29258015.batch  COMPLETED          2        1 2023-06-29T10:19:31 2023-06-29T10:19:31 2023-06-29T10:19:41          1.01K                     1138K                     1138K \n          29258015.extern  COMPLETED          2        1 2023-06-29T10:19:31 2023-06-29T10:19:31 2023-06-29T10:19:41          1.02K                      890K                      890K \n','\n',char(10)));
INSERT INTO job_data VALUES(245,17,'a00m_20210811_HardwareBenchmarks_STREAM_1','2023-06-29-10:19:21','2023-06-29-11:44:47',1688026761,1688026789,1688026795,'COMPLETED',2,1,'00:30','debug',937,'2021-08-11 00:00:00','STREAM_1','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258016,'',1,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_1.20230629102013.out','a00m_20210811_HardwareBenchmarks_STREAM_1.20230629102013.err',2,'',replace('                 29258016  COMPLETED          1        1 2023-06-29T10:19:20 2023-06-29T10:19:45 2023-06-29T10:19:55            937                                                     \n           29258016.batch  COMPLETED          1        1 2023-06-29T10:19:45 2023-06-29T10:19:45 2023-06-29T10:19:55            924                     1134K                     1134K \n          29258016.extern  COMPLETED          1        1 2023-06-29T10:19:45 2023-06-29T10:19:45 2023-06-29T10:19:55            937                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(246,17,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192','2023-06-29-10:19:51','2023-06-29-11:44:47',1688026791,1688026803,1688026853,'COMPLETED',2,192,'00:30','debug',31190,'2021-08-11 00:00:00','OSU_RUN_192','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258017,'',4,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230629102012.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230629102012.err',2,'',replace('                 29258017  COMPLETED        192        4 2023-06-29T10:19:51 2023-06-29T10:19:59 2023-06-29T10:20:53         31.19K                                                     \n           29258017.batch  COMPLETED         48        1 2023-06-29T10:19:59 2023-06-29T10:19:59 2023-06-29T10:20:53         16.13K                     6636K                     6636K \n          29258017.extern  COMPLETED        192        4 2023-06-29T10:19:59 2023-06-29T10:19:59 2023-06-29T10:20:53         31.19K                      837K                   622.50K \n               29258017.0  COMPLETED         48        1 2023-06-29T10:20:11 2023-06-29T10:20:11 2023-06-29T10:20:20          2.58K                     1325K                     1325K \n               29258017.1  COMPLETED         48        1 2023-06-29T10:20:20 2023-06-29T10:20:20 2023-06-29T10:20:45          8.68K                     1353K                     1353K \n               29258017.2  COMPLETED         48        1 2023-06-29T10:20:45 2023-06-29T10:20:45 2023-06-29T10:20:53          3.24K                     1341K                     1341K \n','\n',char(10)));
INSERT INTO job_data VALUES(247,17,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96','2023-06-29-10:19:51','2023-06-29-11:46:26',1688026791,1688026876,1688026922,'COMPLETED',2,96,'00:30','debug',19610,'2021-08-11 00:00:00','OSU_RUN_96','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258018,'',2,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230629102131.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230629102131.err',2,'',replace('                 29258018  COMPLETED         96        2 2023-06-29T10:19:51 2023-06-29T10:21:13 2023-06-29T10:22:02         19.61K                                                     \n           29258018.batch  COMPLETED         48        1 2023-06-29T10:21:13 2023-06-29T10:21:13 2023-06-29T10:22:02         14.40K                     6627K                     6627K \n          29258018.extern  COMPLETED         96        2 2023-06-29T10:21:13 2023-06-29T10:21:13 2023-06-29T10:22:02         19.61K                      863K                   465.50K \n               29258018.0  COMPLETED         48        1 2023-06-29T10:21:21 2023-06-29T10:21:21 2023-06-29T10:21:29          2.41K                     1332K                     1332K \n               29258018.1  COMPLETED         48        1 2023-06-29T10:21:29 2023-06-29T10:21:29 2023-06-29T10:21:54          8.09K                     1334K                     1334K \n               29258018.2  COMPLETED         48        1 2023-06-29T10:21:54 2023-06-29T10:21:54 2023-06-29T10:22:02          3.00K                     1350K                     1350K \n','\n',char(10)));
INSERT INTO job_data VALUES(248,17,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48','2023-06-29-10:20:18','2023-06-29-11:47:09',1688026818,1688026929,1688026978,'COMPLETED',2,48,'00:30','debug',15510,'2021-08-11 00:00:00','OSU_RUN_48','HardwareBenchmarks',0,0,'MARENOSTRUM4',29258020,'',1,22,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230629102213.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230629102213.err',2,'',replace('                 29258020  COMPLETED         48        1 2023-06-29T10:20:17 2023-06-29T10:22:06 2023-06-29T10:23:00         15.51K                                                     \n           29258020.batch  COMPLETED         48        1 2023-06-29T10:22:06 2023-06-29T10:22:06 2023-06-29T10:23:00         15.35K                     6632K                     6632K \n          29258020.extern  COMPLETED         48        1 2023-06-29T10:22:06 2023-06-29T10:22:06 2023-06-29T10:23:00         15.51K                      861K                      861K \n               29258020.0  COMPLETED         48        1 2023-06-29T10:22:17 2023-06-29T10:22:17 2023-06-29T10:22:25          2.52K                     1346K                     1346K \n               29258020.1  COMPLETED         48        1 2023-06-29T10:22:25 2023-06-29T10:22:25 2023-06-29T10:22:50          8.36K                     1347K                     1347K \n               29258020.2  COMPLETED         48        1 2023-06-29T10:22:50 2023-06-29T10:22:50 2023-06-29T10:23:00          3.16K                     1333K                     1333K \n','\n',char(10)));
INSERT INTO job_data VALUES(249,18,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-29-11:02:19','2023-06-29-11:09:16',1688029339,1688029339,1688029457,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',23949,'',0,22,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629110341.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629110341.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(250,18,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-29-11:02:39','2023-06-29-11:09:29',1688029359,1688029358,1688029457,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',24481,'',0,22,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629110341.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629110341.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(251,18,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-29-11:02:58','2023-06-29-11:09:42',1688029378,1688029377,1688029457,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',25206,'',0,22,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629110341.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629110341.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(252,19,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-29-11:09:16','2023-06-29-11:18:23',1688029756,1688029755,1688029818,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',30567,'',0,22,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629111018.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629111018.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(253,19,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-29-11:09:29','2023-06-29-11:18:36',1688029769,1688029768,1688029845,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',31064,'',0,22,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629111018.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629111018.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(254,19,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-29-11:09:42','2023-06-29-11:18:49',1688029782,1688029781,1688029845,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',31747,'',0,22,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629111018.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629111018.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(255,20,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-29-11:18:23','2023-06-29-11:38:21',1688030303,1688030302,1688030405,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,0,'MARENOSTRUM0',40649,'',0,22,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629111929.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629111929.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(256,20,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-29-11:18:36','2023-06-29-11:38:47',1688030316,1688030316,1688030405,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,0,'MARENOSTRUM0',41147,'',0,22,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629111929.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629111929.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(257,20,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-29-11:18:49','2023-06-29-11:41:27',1688030329,1688030329,1688030406,'FAILED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,0,'MARENOSTRUM0',41880,'',0,22,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629111929.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629111929.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(258,20,'a00m_CLEAN','2023-06-29-11:23:35','2023-06-29-11:23:54',1688030615,1688030615,1688030615,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,1,'MARENOSTRUM0',47988,'',0,24,0.0,0.0,'a00m_CLEAN.20230629112354.out','a00m_CLEAN.20230629112354.err',5,'a00m_REMOTE_SETUP','');
INSERT INTO job_data VALUES(259,20,'a00m_REMOTE_SETUP','2023-06-29-11:24:07','2023-06-29-11:36:45',1688030646,1688030646,1688031392,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,1,'MARENOSTRUM0',48687,'',0,24,0.0,0.0,'a00m_REMOTE_SETUP.20230629112426.out','a00m_REMOTE_SETUP.20230629112426.err',5,'a00m_20210811_WeakScaling_REMOTE_INIDATA,a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA,a00m_20210811_StrongScaling_REMOTE_INIDATA,a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(260,20,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-06-29-11:36:59','2023-06-29-11:38:06',1688031419,1688031419,1688031445,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,1,'MARENOSTRUM0',60716,'',0,24,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230629113806.out','a00m_20210811_CompilationEfficiency_REMOTE_INIDATA.20230629113806.err',5,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(261,20,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-06-29-11:37:14','2023-06-29-11:38:06',1688031433,1688031433,1688031458,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,1,'MARENOSTRUM0',61448,'',0,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230629113806.out','a00m_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230629113806.err',5,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(262,20,'a00m_20210811_WeakScaling_REMOTE_INIDATA','2023-06-29-11:37:28','2023-06-29-11:38:06',1688031448,1688031447,1688031471,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,1,'MARENOSTRUM0',62184,'',0,24,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_INIDATA.20230629113806.out','a00m_20210811_WeakScaling_REMOTE_INIDATA.20230629113806.err',5,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(263,21,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-06-29-11:38:21','2023-06-29-12:19:06',1688031501,1688031501,1688033940,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,1,'MARENOSTRUM0',64067,'',0,24,0.0,0.0,'a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629113927.out','a00m_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230629113927.err',5,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(264,21,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-06-29-11:38:34','2023-06-29-11:42:11',1688031514,1688031513,1688031703,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,1,'MARENOSTRUM0',65241,'',0,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230629113927.out','a00m_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230629113927.err',5,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(265,21,'a00m_20210811_WeakScaling_REMOTE_COMPILATION','2023-06-29-11:38:47','2023-06-29-12:11:54',1688031527,1688031527,1688033502,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,1,'MARENOSTRUM0',65928,'',0,24,0.0,0.0,'a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629113927.out','a00m_20210811_WeakScaling_REMOTE_COMPILATION.20230629113927.err',5,'a00m_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(266,21,'a00m_20210811_StrongScaling_REMOTE_INIDATA','2023-06-29-11:39:42','2023-06-29-11:41:13',1688031582,1688031581,1688031607,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,1,'MARENOSTRUM0',73130,'',0,24,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_INIDATA.20230629114028.out','a00m_20210811_StrongScaling_REMOTE_INIDATA.20230629114028.err',5,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(267,21,'a00m_20210811_StrongScaling_REMOTE_COMPILATION','2023-06-29-11:41:27','2023-06-29-12:03:29',1688031687,1688031687,1688032990,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,1,'MARENOSTRUM0',97979,'',0,24,0.0,0.0,'a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629114211.out','a00m_20210811_StrongScaling_REMOTE_COMPILATION.20230629114211.err',5,'a00m_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(268,21,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS','2023-06-29-11:42:15','2023-06-29-11:44:05',1688031735,1688031737,1688031743,'COMPLETED',2,1,'00:30','debug',1280,'2021-08-11 00:00:00','PREPARE_TESTS','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258638,'',1,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230629114300.out','a00m_20210811_HardwareBenchmarks_PREPARE_TESTS.20230629114300.err',2,'a00m_20210811_HardwareBenchmarks_STREAM_16,a00m_20210811_HardwareBenchmarks_OSU_RUN_192,a00m_20210811_HardwareBenchmarks_OSU_RUN_48,a00m_20210811_HardwareBenchmarks_STREAM_8,a00m_20210811_HardwareBenchmarks_STREAM_4,a00m_20210811_HardwareBenchmarks_STREAM_48,a00m_20210811_HardwareBenchmarks_STREAM_32,a00m_20210811_HardwareBenchmarks_OSU_RUN_96,a00m_20210811_HardwareBenchmarks_STREAM_2,a00m_20210811_HardwareBenchmarks_STREAM_1',replace('                 29258638  COMPLETED          1        1 2023-06-29T11:42:14 2023-06-29T11:42:15 2023-06-29T11:42:23          1.28K                                                     \n           29258638.batch  COMPLETED          1        1 2023-06-29T11:42:15 2023-06-29T11:42:15 2023-06-29T11:42:23          1.25K                      889K                      889K \n          29258638.extern  COMPLETED          1        1 2023-06-29T11:42:15 2023-06-29T11:42:15 2023-06-29T11:42:23          1.28K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(269,21,'a00m_20210811_HardwareBenchmarks_STREAM_48','2023-06-29-11:43:04','2023-06-29-11:44:56',1688031784,1688031789,1688031798,'COMPLETED',2,48,'00:30','debug',1470,'2021-08-11 00:00:00','STREAM_48','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258647,'',1,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_48.20230629114352.out','a00m_20210811_HardwareBenchmarks_STREAM_48.20230629114352.err',2,'',replace('                 29258647  COMPLETED         48        1 2023-06-29T11:43:03 2023-06-29T11:43:06 2023-06-29T11:43:18          1.47K                                                     \n           29258647.batch  COMPLETED         48        1 2023-06-29T11:43:06 2023-06-29T11:43:06 2023-06-29T11:43:18          1.46K                     1399K                     1399K \n          29258647.extern  COMPLETED         48        1 2023-06-29T11:43:06 2023-06-29T11:43:06 2023-06-29T11:43:18          1.47K                      830K                      830K \n','\n',char(10)));
INSERT INTO job_data VALUES(270,21,'a00m_20210811_HardwareBenchmarks_STREAM_32','2023-06-29-11:43:04','2023-06-29-11:44:55',1688031784,1688031817,1688031825,'COMPLETED',2,32,'00:30','debug',1350,'2021-08-11 00:00:00','STREAM_32','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258648,'',1,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_32.20230629114352.out','a00m_20210811_HardwareBenchmarks_STREAM_32.20230629114352.err',2,'',replace('                 29258648  COMPLETED         32        1 2023-06-29T11:43:03 2023-06-29T11:43:33 2023-06-29T11:43:45          1.35K                                                     \n           29258648.batch  COMPLETED         32        1 2023-06-29T11:43:33 2023-06-29T11:43:33 2023-06-29T11:43:45          1.33K                     1246K                     1246K \n          29258648.extern  COMPLETED         32        1 2023-06-29T11:43:33 2023-06-29T11:43:33 2023-06-29T11:43:45          1.35K                      851K                      851K \n','\n',char(10)));
INSERT INTO job_data VALUES(271,21,'a00m_20210811_HardwareBenchmarks_STREAM_16','2023-06-29-11:43:04','2023-06-29-11:45:47',1688031784,1688031833,1688031839,'COMPLETED',2,16,'00:30','debug',954,'2021-08-11 00:00:00','STREAM_16','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258649,'',1,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_16.20230629114443.out','a00m_20210811_HardwareBenchmarks_STREAM_16.20230629114443.err',2,'',replace('                 29258649  COMPLETED         16        1 2023-06-29T11:43:03 2023-06-29T11:43:49 2023-06-29T11:43:59            954                                                     \n           29258649.batch  COMPLETED         16        1 2023-06-29T11:43:49 2023-06-29T11:43:49 2023-06-29T11:43:59            939                     1133K                     1133K \n          29258649.extern  COMPLETED         16        1 2023-06-29T11:43:49 2023-06-29T11:43:49 2023-06-29T11:43:59            954                      892K                      892K \n','\n',char(10)));
INSERT INTO job_data VALUES(272,21,'a00m_20210811_HardwareBenchmarks_STREAM_8','2023-06-29-11:43:56','2023-06-29-11:45:47',1688031836,1688031852,1688031859,'COMPLETED',2,8,'00:30','debug',1720,'2021-08-11 00:00:00','STREAM_8','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258652,'',1,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_8.20230629114443.out','a00m_20210811_HardwareBenchmarks_STREAM_8.20230629114443.err',2,'',replace('                 29258652  COMPLETED          8        1 2023-06-29T11:43:55 2023-06-29T11:44:09 2023-06-29T11:44:19          1.72K                                                     \n           29258652.batch  COMPLETED          8        1 2023-06-29T11:44:09 2023-06-29T11:44:09 2023-06-29T11:44:19          1.68K                      939K                      939K \n          29258652.extern  COMPLETED          8        1 2023-06-29T11:44:09 2023-06-29T11:44:09 2023-06-29T11:44:19          1.72K                       34K                       34K \n','\n',char(10)));
INSERT INTO job_data VALUES(273,21,'a00m_20210811_HardwareBenchmarks_STREAM_4','2023-06-29-11:43:56','2023-06-29-11:45:47',1688031836,1688031865,1688031871,'COMPLETED',2,4,'00:30','debug',1620,'2021-08-11 00:00:00','STREAM_4','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258653,'',1,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_4.20230629114442.out','a00m_20210811_HardwareBenchmarks_STREAM_4.20230629114442.err',2,'',replace('                 29258653  COMPLETED          4        1 2023-06-29T11:43:55 2023-06-29T11:44:22 2023-06-29T11:44:32          1.62K                                                     \n           29258653.batch  COMPLETED          4        1 2023-06-29T11:44:22 2023-06-29T11:44:22 2023-06-29T11:44:32          1.59K                      948K                      948K \n          29258653.extern  COMPLETED          4        1 2023-06-29T11:44:22 2023-06-29T11:44:22 2023-06-29T11:44:32          1.62K                       27K                       27K \n','\n',char(10)));
INSERT INTO job_data VALUES(274,21,'a00m_20210811_HardwareBenchmarks_STREAM_2','2023-06-29-11:44:47','2023-06-29-11:49:17',1688031887,1688032054,1688032061,'COMPLETED',2,2,'00:30','debug',1760,'2021-08-11 00:00:00','STREAM_2','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258659,'',1,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_2.20230629114742.out','a00m_20210811_HardwareBenchmarks_STREAM_2.20230629114742.err',2,'',replace('                 29258659  COMPLETED          2        1 2023-06-29T11:44:46 2023-06-29T11:47:34 2023-06-29T11:47:41          1.76K                                                     \n           29258659.batch  COMPLETED          2        1 2023-06-29T11:47:34 2023-06-29T11:47:34 2023-06-29T11:47:41          1.71K                      985K                      985K \n          29258659.extern  COMPLETED          2        1 2023-06-29T11:47:34 2023-06-29T11:47:34 2023-06-29T11:47:41          1.76K                       26K                       26K \n','\n',char(10)));
INSERT INTO job_data VALUES(275,21,'a00m_20210811_HardwareBenchmarks_STREAM_1','2023-06-29-11:44:47','2023-06-29-11:49:18',1688031887,1688032065,1688032071,'COMPLETED',2,1,'00:30','debug',1660,'2021-08-11 00:00:00','STREAM_1','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258660,'',1,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_STREAM_1.20230629114813.out','a00m_20210811_HardwareBenchmarks_STREAM_1.20230629114813.err',2,'',replace('                 29258660  COMPLETED          1        1 2023-06-29T11:44:46 2023-06-29T11:47:42 2023-06-29T11:47:51          1.66K                                                     \n           29258660.batch  COMPLETED          1        1 2023-06-29T11:47:42 2023-06-29T11:47:42 2023-06-29T11:47:51          1.61K                      818K                      818K \n          29258660.extern  COMPLETED          1        1 2023-06-29T11:47:42 2023-06-29T11:47:42 2023-06-29T11:47:51          1.66K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(276,21,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192','2023-06-29-11:44:47','2023-06-29-11:48:09',1688031887,1688031940,1688031989,'COMPLETED',2,192,'00:30','debug',33650,'2021-08-11 00:00:00','OSU_RUN_192','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258661,'',4,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230629114623.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_192.20230629114623.err',2,'',replace('                 29258661  COMPLETED        192        4 2023-06-29T11:44:46 2023-06-29T11:45:37 2023-06-29T11:46:29         33.65K                                                     \n           29258661.batch  COMPLETED         48        1 2023-06-29T11:45:37 2023-06-29T11:45:37 2023-06-29T11:46:29         15.88K                     6409K                     6409K \n          29258661.extern  COMPLETED        192        4 2023-06-29T11:45:37 2023-06-29T11:45:37 2023-06-29T11:46:29         33.65K                      879K                      672K \n               29258661.0  COMPLETED         48        1 2023-06-29T11:45:48 2023-06-29T11:45:48 2023-06-29T11:45:55          2.57K                     1349K                     1349K \n               29258661.1  COMPLETED         48        1 2023-06-29T11:45:55 2023-06-29T11:45:55 2023-06-29T11:46:20          8.69K                     1340K                     1340K \n               29258661.2  COMPLETED         48        1 2023-06-29T11:46:20 2023-06-29T11:46:20 2023-06-29T11:46:29          3.23K                     1353K                     1353K \n','\n',char(10)));
INSERT INTO job_data VALUES(277,21,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96','2023-06-29-11:46:26','2023-06-29-11:48:46',1688031986,1688031999,1688032047,'COMPLETED',2,96,'00:30','debug',19510,'2021-08-11 00:00:00','OSU_RUN_96','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258672,'',2,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230629114704.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_96.20230629114704.err',2,'',replace('                 29258672  COMPLETED         96        2 2023-06-29T11:46:26 2023-06-29T11:46:34 2023-06-29T11:47:28         19.51K                                                     \n           29258672.batch  COMPLETED         48        1 2023-06-29T11:46:34 2023-06-29T11:46:34 2023-06-29T11:47:28         14.72K                     6664K                     6664K \n          29258672.extern  COMPLETED         96        2 2023-06-29T11:46:34 2023-06-29T11:46:34 2023-06-29T11:47:28         19.51K                      879K                      873K \n               29258672.0  COMPLETED         48        1 2023-06-29T11:46:46 2023-06-29T11:46:46 2023-06-29T11:46:53          2.40K                     1348K                     1348K \n               29258672.1  COMPLETED         48        1 2023-06-29T11:46:53 2023-06-29T11:46:53 2023-06-29T11:47:18          8.16K                     1341K                     1341K \n               29258672.2  COMPLETED         48        1 2023-06-29T11:47:18 2023-06-29T11:47:18 2023-06-29T11:47:28          3.04K                     1338K                     1338K \n','\n',char(10)));
INSERT INTO job_data VALUES(278,21,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48','2023-06-29-11:47:09','2023-06-29-11:50:22',1688032029,1688032077,1688032125,'COMPLETED',2,48,'00:30','debug',15490,'2021-08-11 00:00:00','OSU_RUN_48','HardwareBenchmarks',0,1,'MARENOSTRUM4',29258675,'',1,24,0.0,0.0,'a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230629114813.out','a00m_20210811_HardwareBenchmarks_OSU_RUN_48.20230629114813.err',2,'',replace('                 29258675  COMPLETED         48        1 2023-06-29T11:47:08 2023-06-29T11:47:53 2023-06-29T11:48:47         15.49K                                                     \n           29258675.batch  COMPLETED         48        1 2023-06-29T11:47:53 2023-06-29T11:47:53 2023-06-29T11:48:47         15.32K                     6641K                     6641K \n          29258675.extern  COMPLETED         48        1 2023-06-29T11:47:53 2023-06-29T11:47:53 2023-06-29T11:48:47         15.49K                      865K                      865K \n               29258675.0  COMPLETED         48        1 2023-06-29T11:48:04 2023-06-29T11:48:04 2023-06-29T11:48:12          2.50K                     1343K                     1343K \n               29258675.1  COMPLETED         48        1 2023-06-29T11:48:12 2023-06-29T11:48:12 2023-06-29T11:48:37          8.37K                     1343K                     1343K \n               29258675.2  COMPLETED         48        1 2023-06-29T11:48:37 2023-06-29T11:48:37 2023-06-29T11:48:47          3.10K                     1354K                     1354K \n','\n',char(10)));
INSERT INTO job_data VALUES(279,21,'a00m_20210811_StrongScaling_PREPARE_TESTS','2023-06-29-12:03:33','2023-06-29-12:05:38',1688033013,1688033051,1688033059,'COMPLETED',2,1,'00:30','debug',2150,'2021-08-11 00:00:00','PREPARE_TESTS','StrongScaling',0,1,'MARENOSTRUM4',29258842,'',1,24,0.0,0.0,'a00m_20210811_StrongScaling_PREPARE_TESTS.20230629120434.out','a00m_20210811_StrongScaling_PREPARE_TESTS.20230629120434.err',2,'a00m_20210811_StrongScaling_SCALABILITY_96,a00m_20210811_StrongScaling_SCALABILITY_192,a00m_20210811_StrongScaling_SCALABILITY_48',replace('                 29258842  COMPLETED          1        1 2023-06-29T12:03:32 2023-06-29T12:04:06 2023-06-29T12:04:20          2.15K                                                     \n           29258842.batch  COMPLETED          1        1 2023-06-29T12:04:06 2023-06-29T12:04:06 2023-06-29T12:04:20          1.77K                      911K                      911K \n          29258842.extern  COMPLETED          1        1 2023-06-29T12:04:06 2023-06-29T12:04:06 2023-06-29T12:04:20          2.15K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(280,21,'a00m_20210811_StrongScaling_SCALABILITY_192','2023-06-29-12:04:39','2023-06-29-12:08:47',1688033079,1688033084,1688033244,'COMPLETED',2,192,'00:30','debug',228610,'2021-08-11 00:00:00','SCALABILITY_192','StrongScaling',0,1,'MARENOSTRUM4',29258845,'',4,24,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_192.20230629120509.out','a00m_20210811_StrongScaling_SCALABILITY_192.20230629120509.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29258845  COMPLETED        192        4 2023-06-29T12:04:38 2023-06-29T12:04:40 2023-06-29T12:07:24        228.61K                                                     \n           29258845.batch  COMPLETED         48        1 2023-06-29T12:04:40 2023-06-29T12:04:40 2023-06-29T12:07:24         57.76K                     7124K                     7124K \n          29258845.extern  COMPLETED        192        4 2023-06-29T12:04:40 2023-06-29T12:04:40 2023-06-29T12:07:24        228.61K                      881K                    893696 \n               29258845.0  COMPLETED        192        4 2023-06-29T12:05:06 2023-06-29T12:05:06 2023-06-29T12:07:23        217.53K                  8312684K                  8235810K \n','\n',char(10)));
INSERT INTO job_data VALUES(281,21,'a00m_20210811_StrongScaling_SCALABILITY_96','2023-06-29-12:04:39','2023-06-29-12:13:40',1688033079,1688033253,1688033544,'COMPLETED',2,96,'00:30','debug',222980,'2021-08-11 00:00:00','SCALABILITY_96','StrongScaling',0,1,'MARENOSTRUM4',29258846,'',2,24,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_96.20230629120743.out','a00m_20210811_StrongScaling_SCALABILITY_96.20230629120743.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29258846  COMPLETED         96        2 2023-06-29T12:04:38 2023-06-29T12:07:29 2023-06-29T12:12:24        222.98K                                                     \n           29258846.batch  COMPLETED         48        1 2023-06-29T12:07:29 2023-06-29T12:07:29 2023-06-29T12:12:24        112.67K                     6733K                     6733K \n          29258846.extern  COMPLETED         96        2 2023-06-29T12:07:29 2023-06-29T12:07:29 2023-06-29T12:12:24        222.98K                      883K                      862K \n               29258846.0  COMPLETED         96        2 2023-06-29T12:07:47 2023-06-29T12:07:47 2023-06-29T12:12:23        218.84K                 13799116K                 13622698K \n','\n',char(10)));
INSERT INTO job_data VALUES(282,21,'a00m_20210811_StrongScaling_SCALABILITY_48','2023-06-29-12:04:39','2023-06-29-12:23:12',1688033079,1688033554,1688034116,'COMPLETED',2,48,'00:30','debug',217590,'2021-08-11 00:00:00','SCALABILITY_48','StrongScaling',0,1,'MARENOSTRUM4',29258847,'',1,24,0.0,0.0,'a00m_20210811_StrongScaling_SCALABILITY_48.20230629121237.out','a00m_20210811_StrongScaling_SCALABILITY_48.20230629121237.err',2,'a00m_20210811_StrongScaling_FUNCTIONS_DIR',replace('                 29258847  COMPLETED         48        1 2023-06-29T12:04:38 2023-06-29T12:12:30 2023-06-29T12:21:56        217.59K                                                     \n           29258847.batch  COMPLETED         48        1 2023-06-29T12:12:30 2023-06-29T12:12:30 2023-06-29T12:21:56        217.57K                     6699K                     6699K \n          29258847.extern  COMPLETED         48        1 2023-06-29T12:12:30 2023-06-29T12:12:30 2023-06-29T12:21:56        217.59K                      853K                      853K \n               29258847.0  COMPLETED         48        1 2023-06-29T12:12:48 2023-06-29T12:12:48 2023-06-29T12:21:55        214.97K                 22616960K                 22616960K \n','\n',char(10)));
INSERT INTO job_data VALUES(283,21,'a00m_20210811_WeakScaling_PREPARE_TESTS','2023-06-29-12:12:10','2023-06-29-12:23:44',1688033530,1688034124,1688034131,'COMPLETED',2,1,'00:30','debug',1220,'2021-08-11 00:00:00','PREPARE_TESTS','WeakScaling',0,1,'MARENOSTRUM4',29258995,'',1,24,0.0,0.0,'a00m_20210811_WeakScaling_PREPARE_TESTS.20230629122239.out','a00m_20210811_WeakScaling_PREPARE_TESTS.20230629122239.err',2,'a00m_20210811_WeakScaling_SCALABILITY_48,a00m_20210811_WeakScaling_SCALABILITY_96,a00m_20210811_WeakScaling_SCALABILITY_192',replace('                 29258995  COMPLETED          1        1 2023-06-29T12:12:10 2023-06-29T12:22:04 2023-06-29T12:22:11          1.22K                                                     \n           29258995.batch  COMPLETED          1        1 2023-06-29T12:22:04 2023-06-29T12:22:04 2023-06-29T12:22:11          1.20K                      943K                      943K \n          29258995.extern  COMPLETED          1        1 2023-06-29T12:22:04 2023-06-29T12:22:04 2023-06-29T12:22:11          1.22K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(284,21,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS','2023-06-29-12:19:22','2023-06-29-12:55:49',1688033962,1688036053,1688036058,'COMPLETED',2,1,'00:30','debug',1530,'2021-08-11 00:00:00','PREPARE_TESTS','CompilationEfficiency',0,1,'MARENOSTRUM4',29259087,'',1,24,0.0,0.0,'a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230629125443.out','a00m_20210811_CompilationEfficiency_PREPARE_TESTS.20230629125443.err',2,'a00m_20210811_CompilationEfficiency_SCALABILITY_192,a00m_20210811_CompilationEfficiency_SCALABILITY_48,a00m_20210811_CompilationEfficiency_SCALABILITY_96',replace('                 29259087  COMPLETED          1        1 2023-06-29T12:19:21 2023-06-29T12:54:08 2023-06-29T12:54:20          1.53K                                                     \n           29259087.batch  COMPLETED          1        1 2023-06-29T12:54:08 2023-06-29T12:54:08 2023-06-29T12:54:20          1.06K                      942K                      942K \n          29259087.extern  COMPLETED          1        1 2023-06-29T12:54:08 2023-06-29T12:54:08 2023-06-29T12:54:20          1.53K                     1726K                     1726K \n','\n',char(10)));
INSERT INTO job_data VALUES(285,21,'a00m_20210811_StrongScaling_FUNCTIONS_DIR','2023-06-29-12:22:11','2023-06-29-12:24:36',1688034131,1688034155,1688034183,'COMPLETED',2,192,'02:00','debug',20620,'2021-08-11 00:00:00','FUNCTIONS_DIR','StrongScaling',0,1,'MARENOSTRUM4',29259174,'',4,24,0.0,0.0,'a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230629122239.out','a00m_20210811_StrongScaling_FUNCTIONS_DIR.20230629122239.err',2,'a00m_20210811_StrongScaling_TRACE_192,a00m_20210811_StrongScaling_TRACE_96,a00m_20210811_StrongScaling_TRACE_48',replace('                 29259174  COMPLETED        192        4 2023-06-29T12:22:10 2023-06-29T12:22:31 2023-06-29T12:23:04         20.62K                                                     \n           29259174.batch  COMPLETED         48        1 2023-06-29T12:22:31 2023-06-29T12:22:31 2023-06-29T12:23:04          5.53K                     1393K                     1393K \n          29259174.extern  COMPLETED        192        4 2023-06-29T12:22:31 2023-06-29T12:22:31 2023-06-29T12:23:04         20.62K                      868K                    456448 \n               29259174.0  COMPLETED        192        4 2023-06-29T12:22:49 2023-06-29T12:22:49 2023-06-29T12:23:01         12.13K                     1465K                   1447168 \n','\n',char(10)));
INSERT INTO job_data VALUES(286,21,'a00m_20210811_WeakScaling_SCALABILITY_192','2023-06-29-12:22:44','2023-06-29-12:55:25',1688034164,1688034202,1688036060,'FAILED',2,192,'00:30','debug',2910000,'2021-08-11 00:00:00','SCALABILITY_192','WeakScaling',0,1,'MARENOSTRUM4',29259177,'',4,24,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_192.20230629122332.out','a00m_20210811_WeakScaling_SCALABILITY_192.20230629122332.err',2,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29259177    TIMEOUT        192        4 2023-06-29T12:22:44 2023-06-29T12:23:19 2023-06-29T12:53:33          2.91M                                                     \n           29259177.batch  CANCELLED         48        1 2023-06-29T12:23:19 2023-06-29T12:23:19 2023-06-29T12:53:33        720.12K                     6858K                     6858K \n          29259177.extern  COMPLETED        192        4 2023-06-29T12:23:19 2023-06-29T12:23:19 2023-06-29T12:53:33          2.91M                      869K                      650K \n               29259177.0     FAILED        192        4 2023-06-29T12:23:37 2023-06-29T12:23:37 2023-06-29T12:53:36          2.90M                 82617424K                 81922417K \n','\n',char(10)));
INSERT INTO job_data VALUES(287,21,'a00m_20210811_WeakScaling_SCALABILITY_96','2023-06-29-12:22:44','2023-06-29-12:58:31',1688034164,1688036163,1688036247,'FAILED',2,96,'00:30','debug',11750,'2021-08-11 00:00:00','SCALABILITY_96','WeakScaling',0,1,'MARENOSTRUM4',29259178,'',2,24,0.0,0.0,'a00m_20210811_WeakScaling_SCALABILITY_96.20230629125623.out','a00m_20210811_WeakScaling_SCALABILITY_96.20230629125623.err',2,'a00m_20210811_WeakScaling_FUNCTIONS_DIR',replace('                 29259178     FAILED         96        2 2023-06-29T12:22:44 2023-06-29T12:55:58 2023-06-29T12:56:37         11.75K                                                     \n           29259178.batch     FAILED         48        1 2023-06-29T12:55:58 2023-06-29T12:55:58 2023-06-29T12:56:37          5.88K                     2168K                     2168K \n          29259178.extern  COMPLETED         96        2 2023-06-29T12:55:58 2023-06-29T12:55:58 2023-06-29T12:56:37         11.75K                      883K                   475.50K \n               29259178.0  COMPLETED         96        2 2023-06-29T12:56:20 2023-06-29T12:56:20 2023-06-29T12:56:37          7.00K                     1437K                  1386.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(288,21,'a00m_20210811_StrongScaling_TRACE_192','2023-06-29-12:23:37','2023-06-29-13:49:00',1688034217,1688036208,1688036962,'COMPLETED',2,192,'02:00','debug',1150000,'2021-08-11 00:00:00','TRACE_192','StrongScaling',0,1,'MARENOSTRUM4',29259205,'',4,24,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_192.20230629125727.out','a00m_20210811_StrongScaling_TRACE_192.20230629125727.err',2,'',replace('                 29259205  COMPLETED        192        4 2023-06-29T12:23:36 2023-06-29T12:56:44 2023-06-29T13:09:24          1.15M                                                     \n           29259205.batch  COMPLETED         48        1 2023-06-29T12:56:44 2023-06-29T12:56:44 2023-06-29T13:09:24        286.96K                     7080K                     7080K \n          29259205.extern  COMPLETED        192        4 2023-06-29T12:56:44 2023-06-29T12:56:44 2023-06-29T13:09:24          1.15M                      868K                    470272 \n               29259205.0  COMPLETED        192        4 2023-06-29T12:57:05 2023-06-29T12:57:05 2023-06-29T13:09:24          1.14M                 17821256K                 17726694K \n','\n',char(10)));
INSERT INTO job_data VALUES(289,21,'a00m_20210811_StrongScaling_TRACE_96','2023-06-29-12:54:48','2023-06-29-13:49:01',1688036088,1688036971,1688038397,'COMPLETED',2,96,'02:00','debug',1110000,'2021-08-11 00:00:00','TRACE_96','StrongScaling',0,1,'MARENOSTRUM4',29259597,'',2,24,0.0,0.0,'a00m_20210811_StrongScaling_TRACE_96.20230629134757.out','a00m_20210811_StrongScaling_TRACE_96.20230629134757.err',2,'',replace('                 29259597  COMPLETED         96        2 2023-06-29T12:54:47 2023-06-29T13:09:28 2023-06-29T13:33:17          1.11M                                                     \n           29259597.batch  COMPLETED         48        1 2023-06-29T13:09:28 2023-06-29T13:09:28 2023-06-29T13:33:17        561.74K                     6832K                     6832K \n          29259597.extern  COMPLETED         96        2 2023-06-29T13:09:28 2023-06-29T13:09:28 2023-06-29T13:33:17          1.11M                      827K                   807.50K \n               29259597.0  COMPLETED         96        2 2023-06-29T13:09:50 2023-06-29T13:09:50 2023-06-29T13:33:17          1.11M                 23743876K                 23538838K \n','\n',char(10)));
INSERT INTO job_data VALUES(290,21,'a00m_20210811_StrongScaling_TRACE_48','2023-06-29-12:56:28','2023-06-29-13:47:57',1688036188,1688038406,0,'RUNNING',2,48,'02:00','debug',0,'2021-08-11 00:00:00','TRACE_48','StrongScaling',0,1,'MARENOSTRUM4',29259602,'',0,24,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(291,21,'a00m_20210811_CompilationEfficiency_SCALABILITY_192','2023-06-29-12:57:34','2023-06-29-12:57:34',1688036254,0,0,'SUBMITTED',2,192,'00:30','debug',0,'2021-08-11 00:00:00','SCALABILITY_192','CompilationEfficiency',0,1,'MARENOSTRUM4',29259614,'',0,24,0.0,0.0,'','',0,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR','');
INSERT INTO job_data VALUES(292,21,'a00m_20210811_CompilationEfficiency_SCALABILITY_96','2023-06-29-13:48:02','2023-06-29-13:48:02',1688039282,0,0,'SUBMITTED',2,96,'00:30','debug',0,'2021-08-11 00:00:00','SCALABILITY_96','CompilationEfficiency',0,1,'MARENOSTRUM4',29260302,'',0,24,0.0,0.0,'','',0,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR','');
INSERT INTO job_data VALUES(293,21,'a00m_20210811_CompilationEfficiency_SCALABILITY_48','2023-06-29-13:48:02','2023-06-29-13:48:02',1688039282,0,0,'SUBMITTED',2,48,'00:30','debug',0,'2021-08-11 00:00:00','SCALABILITY_48','CompilationEfficiency',0,1,'MARENOSTRUM4',29260303,'',0,24,0.0,0.0,'','',0,'a00m_20210811_CompilationEfficiency_FUNCTIONS_DIR','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',25);
INSERT INTO sqlite_sequence VALUES('job_data',293);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
