PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-08-31-08:19:24','2023-09-01-12:20:26',1693462764,1693563626,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "LOCAL_SETUP.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "REMOTE_SETUP.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "TRANSFER": {"FILE": "TRANSFER.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}, "URBAN": {"DEPENDENCIES": {"OPA_%OPAREQUEST.1.VARIABLE%%OPAREQUEST.2.STAT%": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_%OPAREQUEST.1.VARIABLE%OPAREQUEST.2.STAT%": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(2,'2023-09-01-12:20:26','2023-09-06-17:55:14',1693563626,1694015714,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "local"}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "testing.sh", "PLATFORM": "marenostrum4", "RUNNING": "once", "PROCESSORS": [1, 5, 10], "TASKS": 1, "THREADS": [2, 4, 8], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "URBAN": {"DEPENDENCIES": {"OPA_%OPAREQUEST.1.VARIABLE%%OPAREQUEST.2.STAT%": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}, "OPA_%OPAREQUEST.1.VARIABLE%OPAREQUEST.2.STAT%": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": null, "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": null, "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(3,'2023-09-06-17:55:14','2023-09-06-18:00:41',1694015714,1694016041,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "PLATFORM": "marenostrum4", "RUNNING": "once", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(4,'2023-09-06-18:00:41','2023-09-06-18:02:34',1694016041,1694016154,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "PLATFORM": "marenostrum4", "RUNNING": "once", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(5,'2023-09-06-18:02:34','2023-09-06-18:03:55',1694016154,1694016235,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "PLATFORM": "marenostrum4", "RUNNING": "once", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(6,'2023-09-06-18:03:55','2023-09-06-18:05:18',1694016235,1694016318,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "PLATFORM": "marenostrum4", "RUNNING": "once", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(7,'2023-09-06-18:05:18','2023-09-06-18:09:43',1694016318,1694016583,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "PLATFORM": "marenostrum4", "RUNNING": "once", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(8,'2023-09-06-18:09:43','2023-09-07-08:01:31',1694016583,1694066491,'month',4,0,1,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "PLATFORM": "marenostrum4", "RUNNING": "once", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(9,'2023-09-07-08:01:31','2023-09-07-15:04:29',1694066491,1694091869,'month',4,0,1,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "PLATFORM": "marenostrum4", "RUNNING": "once", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(10,'2023-09-07-15:04:29','2023-09-07-15:07:00',1694091869,1694092020,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "des28", "USER": "des28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(11,'2023-09-07-15:07:00','2023-09-07-15:07:17',1694092020,1694092037,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "des28", "USER": "des28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(12,'2023-09-07-15:07:17','2023-09-07-15:08:02',1694092037,1694092082,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "des28", "USER": "des28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(13,'2023-09-07-15:08:02','2023-09-07-15:09:34',1694092082,1694092174,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "des28", "USER": "des28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(14,'2023-09-07-15:09:34','2023-09-07-15:11:02',1694092174,1694092262,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "des28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(15,'2023-09-07-15:11:02','2023-09-07-15:14:16',1694092262,1694092456,'month',4,1,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(16,'2023-09-07-15:14:16','2023-09-07-15:19:10',1694092456,1694092750,'month',4,1,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(17,'2023-09-07-15:19:10','2023-09-07-15:35:55',1694092750,1694093755,'month',4,1,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(18,'2023-09-07-15:35:55','2023-09-07-15:36:23',1694093755,1694093783,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4", "QUEUE": "bsc32", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(19,'2023-09-07-15:36:23','2023-09-07-15:36:27',1694093783,1694093787,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4", "QUEUE": "bsc32", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(20,'2023-09-07-15:36:28','2023-09-07-15:42:37',1694093788,1694094157,'month',4,1,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4", "QUEUE": "bsc32", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(21,'2023-09-07-15:42:37','2023-09-13-10:39:40',1694094157,1694594380,'month',4,0,1,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(22,'2023-09-13-10:39:40','2023-09-13-10:39:48',1694594380,1694594388,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "testing.sh", "DEPENDENCIES": {"HETJOB?": {}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(23,'2023-09-13-10:39:48','2023-09-13-10:42:59',1694594388,1694594579,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "testing.sh", "DEPENDENCIES": {"HETJOB?": {}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(24,'2023-09-13-10:42:59','2023-09-13-11:04:54',1694594579,1694595894,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "testing.sh", "DEPENDENCIES": {"HETJOB": {"STATUS": "FAILED"}}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(25,'2023-09-13-11:04:54','2023-09-13-11:05:49',1694595894,1694595949,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(26,'2023-09-13-11:05:49','2023-09-13-11:06:08',1694595949,1694595968,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(27,'2023-09-13-11:06:08','2023-09-13-11:06:17',1694595968,1694595977,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(28,'2023-09-13-11:06:17','2023-09-13-11:12:34',1694595977,1694596354,'month',4,0,1,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "QUEUE": "debug", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(29,'2023-09-13-11:12:34','2023-09-13-11:12:45',1694596354,1694596365,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(30,'2023-09-13-11:12:45','2023-09-13-11:18:40',1694596365,1694596720,'month',4,1,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(31,'2023-09-13-11:18:40','2023-09-14-08:22:39',1694596720,1694672559,'month',4,1,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(32,'2023-09-14-08:22:39','2023-09-14-08:23:08',1694672559,1694672588,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "CUSTOM_DIRECTIVES": "[[''#SBATCH --partition=debug'', ''''], [''#SBATCH --account=project_2000745'', ''--partition=debug'']]", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(33,'2023-09-14-08:23:08','2023-09-18-11:44:14',1694672588,1695030254,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "once", "PLATFORM": "marenostrum4dese", "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "CUSTOM_DIRECTIVES": "[[''#SBATCH --partition=debug'', ''''], [''#SBATCH --account=project_2000745'', ''--partition=debug'']]", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(34,'2023-09-18-11:44:14','2023-09-18-12:52:48',1695030254,1695034368,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "chunk", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "CUSTOM_DIRECTIVES": "[[''#SBATCH --partition=dkdjskldjsalfjskf'', ''#SBATCH --account=project_sahdsajkdhka'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(35,'2023-09-18-12:52:48','2023-09-18-13:51:03',1695034368,1695037863,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "chunk", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "CUSTOM_DIRECTIVES": "[[''#SBATCH --partition=dkdjskldjsalfjskf'', ''#SBATCH --account=project_sahdsajkdhka'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(36,'2023-09-18-13:51:03','2023-09-18-15:59:34',1695037863,1695045574,'month',4,2,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "chunk", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(37,'2023-09-18-15:59:34','2023-09-18-18:33:50',1695045574,1695054830,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "chunk", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(38,'2023-09-18-18:33:50','2023-09-18-18:43:44',1695054830,1695055424,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "chunk", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(39,'2023-09-18-18:43:44','2023-09-18-18:48:45',1695055424,1695055725,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "testing.sh", "RUNNING": "chunk", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "WALLCLOCK": "00:02", "PROCESSORS": [2, 3], "TASKS": 1, "THREADS": [2, 3], "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(40,'2023-09-18-18:48:45','2023-09-18-18:49:46',1695055725,1695055786,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "test", "RUNNING": "chunks", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(41,'2023-09-18-18:49:46','2023-09-18-18:50:05',1695055786,1695055805,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(42,'2023-09-18-18:50:05','2023-09-18-18:50:25',1695055805,1695055825,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(43,'2023-09-18-18:50:25','2023-09-18-18:50:33',1695055825,1695055833,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunks", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(44,'2023-09-18-18:50:33','2023-09-18-18:51:30',1695055833,1695055890,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(45,'2023-09-18-18:51:30','2023-09-18-18:55:06',1695055890,1695056106,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(46,'2023-09-18-18:55:06','2023-09-18-19:03:05',1695056106,1695056585,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(47,'2023-09-18-19:03:05','2023-09-18-19:04:10',1695056585,1695056650,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(48,'2023-09-18-19:04:10','2023-09-18-19:16:25',1695056650,1695057385,'month',4,3,10,0,6,1,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(49,'2023-09-18-19:16:25','2023-09-18-19:17:02',1695057385,1695057422,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(50,'2023-09-18-19:17:02','2023-09-18-19:17:20',1695057422,1695057440,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(51,'2023-09-18-19:17:20','2023-09-18-19:18:18',1695057440,1695057498,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(52,'2023-09-18-19:18:18','2023-09-18-19:25:54',1695057498,1695057954,'month',4,10,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": [0, 0], "NODES": [2, 1], "TASKS": [12, 16], "THREADS": [4, 2], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(53,'2023-09-18-19:25:54','2023-09-18-19:27:36',1695057954,1695058056,'month',4,0,10,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.90", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": [0, 0], "NODES": [2, 1], "TASKS": [12, 16], "THREADS": [4, 2], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(54,'2023-09-18-19:27:36','2023-09-18-19:28:10',1695058056,1695058090,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": [0], "NODES": [2], "TASKS": [12], "THREADS": [4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(55,'2023-09-18-19:28:10','2023-09-18-19:28:15',1695058090,1695058095,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": 0, "NODES": 2, "TASKS": 12, "THREADS": 4, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(56,'2023-09-18-19:28:15','2023-09-18-19:28:57',1695058095,1695058137,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": 0, "NODES": 2, "TASKS": 12, "THREADS": 4, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(57,'2023-09-18-19:28:57','2023-09-18-20:03:40',1695058137,1695060220,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": 0, "NODES": 2, "TASKS": 12, "THREADS": 4, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(58,'2023-09-18-20:03:40','2023-09-18-20:03:45',1695060220,1695060225,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": 0, "NODES": 2, "TASKS": 12, "THREADS": 4, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(59,'2023-09-18-20:03:45','2023-09-18-20:05:17',1695060225,1695060317,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": 0, "NODES": 2, "TASKS": 12, "THREADS": 4, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(60,'2023-09-18-20:05:17','2023-09-18-20:05:57',1695060317,1695060357,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": 0, "NODES": 2, "TASKS": 12, "THREADS": 4, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(61,'2023-09-18-20:05:57','2023-09-18-20:07:17',1695060357,1695060437,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": 0, "NODES": 2, "TASKS": 12, "THREADS": 4, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(62,'2023-09-18-20:07:17','2023-09-18-20:07:23',1695060437,1695060443,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": 0, "NODES": 2, "TASKS": 12, "THREADS": 4, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(63,'2023-09-18-20:07:23','2023-09-18-20:18:29',1695060443,1695061109,'month',4,10,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": 0, "NODES": 2, "TASKS": 12, "THREADS": 4, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(64,'2023-09-18-20:18:29','2023-09-19-13:27:58',1695061109,1695122878,'month',4,1,10,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.91", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "MEMORY": 0, "NODES": 2, "TASKS": 12, "THREADS": 4, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive'']", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(65,'2023-09-19-13:27:58','2023-09-19-13:29:15',1695122878,1695122955,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(66,'2023-09-19-13:29:15','2023-09-19-13:44:22',1695122955,1695123862,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(67,'2023-09-19-13:44:22','2023-09-19-13:44:44',1695123862,1695123884,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(68,'2023-09-19-13:44:44','2023-09-19-13:50:23',1695123884,1695124223,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(69,'2023-09-19-13:50:23','2023-09-19-13:50:45',1695124223,1695124245,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(70,'2023-09-19-13:50:45','2023-09-20-15:52:46',1695124245,1695217966,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(71,'2023-09-20-15:52:46','2023-09-20-15:52:54',1695217966,1695217974,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(72,'2023-09-20-15:52:54','2023-09-20-15:54:43',1695217974,1695218083,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(73,'2023-09-20-15:54:43','2023-09-20-15:54:48',1695218083,1695218088,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": false}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(74,'2023-09-20-15:54:48','2023-09-21-08:30:22',1695218088,1695277822,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": false}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(75,'2023-09-21-08:30:22','2023-09-21-08:30:57',1695277822,1695277857,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": false}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(76,'2023-09-21-08:30:58','2023-09-21-08:31:52',1695277858,1695277912,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": false}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(77,'2023-09-21-08:31:52','2023-09-21-08:32:52',1695277912,1695277972,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(78,'2023-09-21-08:32:53','2023-09-21-08:33:41',1695277973,1695278021,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(79,'2023-09-21-08:33:41','2023-09-21-08:35:41',1695278021,1695278141,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(80,'2023-09-21-08:35:41','2023-09-21-08:55:07',1695278141,1695279307,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(81,'2023-09-21-08:55:07','2023-09-21-08:56:17',1695279307,1695279377,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(82,'2023-09-21-08:56:17','2023-09-21-08:57:37',1695279377,1695279457,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(83,'2023-09-21-08:57:37','2023-09-21-12:14:19',1695279457,1695291259,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "WRAPPERS": {"WRAPPER_HETJOBS": {"JOBS_IN_WRAPPER": "HETJOB", "TYPE": "vertical"}}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(84,'2023-09-21-12:14:19','2023-09-21-12:14:55',1695291259,1695291295,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "levante", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(85,'2023-09-21-12:14:55','2023-09-21-12:15:15',1695291295,1695291315,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "levante", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(86,'2023-09-21-12:15:15','2023-09-21-12:15:55',1695291315,1695291355,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "levante", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(87,'2023-09-21-12:15:55','2023-09-21-12:16:49',1695291355,1695291409,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "levante", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(88,'2023-09-21-12:16:49','2023-09-21-12:17:51',1695291409,1695291471,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "levante", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(89,'2023-09-21-12:17:51','2023-09-21-12:18:25',1695291471,1695291505,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "MARENOSTRUM4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(90,'2023-09-21-12:18:25','2023-09-21-12:18:35',1695291505,1695291515,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "MARENOSTRUM4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(91,'2023-09-21-12:18:35','2023-09-21-12:22:47',1695291515,1695291767,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "MARENOSTRUM4dese", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "MEMORY": [0, 0], "NODES": [3, 1], "TASKS": [32, 32], "THREADS": [4, 4], "CUSTOM_DIRECTIVES": "[[''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic'', ''#SBATCH --exclusive''], [''#SBATCH --export=ALL'', ''#SBATCH --distribution=block:cyclic:fcyclic'', ''#SBATCH --exclusive'']]", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(92,'2023-09-21-12:22:47','2023-09-21-12:23:00',1695291767,1695291780,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "TEST-LOCAL", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(93,'2023-09-21-12:23:00','2023-09-21-12:31:30',1695291780,1695292290,'month',4,2,10,0,0,0,1,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "TEST-LOCAL", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(94,'2023-09-21-12:31:30','2023-09-21-12:37:39',1695292290,1695292659,'month',4,1,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "RUNNING": "once", "WALLCLOCK": "00:30", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(95,'2023-09-21-12:37:39','2023-09-21-14:15:04',1695292659,1695298504,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(96,'2023-09-21-14:15:04','2023-09-21-14:18:22',1695298504,1695298702,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(97,'2023-09-21-14:18:22','2023-09-21-14:19:36',1695298702,1695298776,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(98,'2023-09-21-14:19:36','2023-09-21-14:25:50',1695298776,1695299150,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(99,'2023-09-21-14:25:50','2023-09-21-15:00:51',1695299150,1695301251,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(100,'2023-09-21-15:00:51','2023-09-21-15:02:35',1695301251,1695301355,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(101,'2023-09-21-15:02:35','2023-09-21-15:08:32',1695301355,1695301712,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(102,'2023-09-21-15:08:32','2023-09-21-15:19:06',1695301712,1695302346,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(103,'2023-09-21-15:19:06','2023-09-21-15:23:51',1695302346,1695302631,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(104,'2023-09-21-15:23:51','2023-09-21-15:25:15',1695302631,1695302715,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(105,'2023-09-21-15:25:15','2023-09-21-15:28:06',1695302715,1695302886,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(106,'2023-09-21-15:28:07','2023-09-21-15:29:32',1695302887,1695302972,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(107,'2023-09-21-15:29:32','2023-09-21-15:30:19',1695302972,1695303019,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(108,'2023-09-21-15:30:19','2023-09-21-15:31:11',1695303019,1695303071,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(109,'2023-09-21-15:31:11','2023-09-21-15:32:08',1695303071,1695303128,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(110,'2023-09-21-15:32:08','2023-09-21-15:33:08',1695303128,1695303188,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(111,'2023-09-21-15:33:08','2023-09-21-15:33:41',1695303188,1695303221,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(112,'2023-09-21-15:33:41','2023-09-21-15:34:48',1695303221,1695303288,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(113,'2023-09-21-15:34:48','2023-09-21-15:36:21',1695303288,1695303381,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(114,'2023-09-21-15:36:21','2023-09-21-15:37:41',1695303381,1695303461,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(115,'2023-09-21-15:37:41','2023-09-21-15:39:05',1695303461,1695303545,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(116,'2023-09-21-15:39:05','2023-09-21-15:40:20',1695303545,1695303620,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(117,'2023-09-21-15:40:20','2023-09-21-15:46:42',1695303620,1695304002,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "2FA": true}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(118,'2023-09-21-15:46:42','2023-09-21-15:47:41',1695304002,1695304061,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran", "2FA": "True"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "2FA": "True"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(119,'2023-09-21-15:47:41','2023-09-27-09:09:43',1695304061,1695798583,'month',4,10,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(120,'2023-09-27-09:09:43','2023-09-27-09:09:53',1695798583,1695798593,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(121,'2023-09-27-09:09:53','2023-09-27-09:10:29',1695798593,1695798629,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(122,'2023-09-27-09:10:29','2023-09-27-09:11:02',1695798629,1695798662,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(123,'2023-09-27-09:11:02','2023-09-27-09:11:04',1695798662,1695798664,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(124,'2023-09-27-09:11:04','2023-09-27-09:12:44',1695798664,1695798764,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(125,'2023-09-27-09:12:44','2023-09-27-09:14:00',1695798764,1695798840,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(126,'2023-09-27-09:14:00','2023-09-27-09:14:14',1695798840,1695798854,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(127,'2023-09-27-09:14:14','2023-09-27-09:16:21',1695798854,1695798981,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(128,'2023-09-27-09:16:21','2023-09-27-09:17:19',1695798981,1695799039,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(129,'2023-09-27-09:17:19','2023-09-27-09:21:00',1695799039,1695799260,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(130,'2023-09-27-09:21:00','2023-09-27-09:30:30',1695799260,1695799830,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(131,'2023-09-27-09:30:30','2023-09-27-09:34:55',1695799830,1695800095,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug", "2FA": true}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(132,'2023-09-27-09:34:55','2023-09-27-09:43:35',1695800095,1695800615,'month',4,1,10,0,0,0,1,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(133,'2023-09-27-09:43:35','2023-09-27-09:44:53',1695800615,1695800693,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(134,'2023-09-27-09:44:53','2023-09-27-09:47:05',1695800693,1695800825,'month',4,1,10,0,0,1,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(135,'2023-09-27-09:47:05','2023-09-27-09:47:25',1695800825,1695800845,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(136,'2023-09-27-09:47:25','2023-09-27-09:55:09',1695800845,1695801309,'month',4,3,10,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(137,'2023-09-27-09:55:09','2023-09-27-09:55:29',1695801309,1695801329,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(138,'2023-09-27-09:55:29','2023-09-27-10:05:59',1695801329,1695801959,'month',4,2,10,0,0,0,1,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(139,'2023-09-27-10:05:59','2023-09-27-10:07:53',1695801959,1695802073,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(140,'2023-09-27-10:07:53','2023-09-27-10:09:43',1695802073,1695802183,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(141,'2023-09-27-10:09:43','2023-09-27-10:11:46',1695802183,1695802306,'month',4,0,10,0,0,1,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(142,'2023-09-27-10:11:46','2023-09-27-10:11:48',1695802306,1695802308,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(143,'2023-09-27-10:11:48','2023-09-27-10:17:57',1695802308,1695802677,'month',4,3,10,0,0,1,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(144,'2023-09-27-10:17:57','2023-09-27-10:18:18',1695802677,1695802698,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(145,'2023-09-27-10:18:18','2023-09-27-10:23:30',1695802698,1695803010,'month',4,1,10,0,0,0,1,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(146,'2023-09-27-10:23:30','2023-09-27-10:23:32',1695803010,1695803012,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
INSERT INTO experiment_run VALUES(147,'2023-09-27-10:23:32','2023-09-27-10:40:03',1695803012,0,'month',4,10,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a01a", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "NUMCHUNKS": "10", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"HETJOB": {"FILE": "a", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"HETJOB-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4DESE": {"TYPE": "slurm", "HOST": "des", "PROJECT": "dese28", "USER": "dese28674", "QUEUE": "class_a", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": null, "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": null, "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": null, "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01a", "PROJDIR": "/home/dbeltran/new_autosubmit/a01a/proj/"}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a01a_HETJOB','2023-09-06-17:56:10','2023-09-07-10:09:08',1694015770,1694015966,1694015997,'FAILED',2,5,'00:02','debug',0,'','HETJOB','',0,0,'MARENOSTRUM4',30128987,'',0,3,0.0,0.0,'a01a_HETJOB.20230906175926.out','a01a_HETJOB.20230906175926.err',5,'','');
INSERT INTO job_data VALUES(2,1,'a01a_HETJOB','2023-09-07-10:09:08','2023-09-07-15:11:12',1694074148,0,0,'SUBMITTED',2,5,'00:02','debug',0,'','HETJOB','',0,0,'MARENOSTRUM4',30132566,'',0,9,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(3,2,'a01a_HETJOB','2023-09-07-15:11:12','2023-09-07-15:14:33',1694092272,1694092362,1694092367,'COMPLETED',2,5,'00:02','debug',0,'','HETJOB','',0,0,'MARENOSTRUM4DESE',30133623,'',0,15,0.0,0.0,'a01a_HETJOB.20230907151257.out','a01a_HETJOB.20230907151257.err',5,'','');
INSERT INTO job_data VALUES(4,3,'a01a_HETJOB','2023-09-07-15:14:33','2023-09-07-15:19:24',1694092473,1694092479,1694092484,'COMPLETED',2,1,'00:02','debug',809,'','HETJOB','',0,0,'MARENOSTRUM4DESE',30133646,'',1,16,0.0,0.0,'a01a_HETJOB.20230907151452.out','a01a_HETJOB.20230907151452.err',2,'',replace('                 30133646  COMPLETED          1        1 2023-09-07T15:14:33 2023-09-07T15:14:37 2023-09-07T15:14:44            809                                                     \n           30133646.batch  COMPLETED          1        1 2023-09-07T15:14:37 2023-09-07T15:14:37 2023-09-07T15:14:44            791                     1134K                     1134K \n          30133646.extern  COMPLETED          1        1 2023-09-07T15:14:37 2023-09-07T15:14:37 2023-09-07T15:14:44            809                      700K                      700K \n','\n',char(10)));
INSERT INTO job_data VALUES(5,4,'a01a_HETJOB','2023-09-07-15:19:24','2023-09-07-15:36:03',1694092764,1694092839,1694092844,'COMPLETED',2,1,'00:02','debug',1550,'','HETJOB','',0,0,'MARENOSTRUM4DESE',30133657,'',1,17,0.0,0.0,'a01a_HETJOB.20230907152046.out','a01a_HETJOB.20230907152046.err',2,'',replace('                 30133657  COMPLETED          1        1 2023-09-07T15:19:24 2023-09-07T15:20:37 2023-09-07T15:20:45          1.55K                                                     \n           30133657.batch  COMPLETED          1        1 2023-09-07T15:20:37 2023-09-07T15:20:37 2023-09-07T15:20:45          1.25K                      916K                      916K \n          30133657.extern  COMPLETED          1        1 2023-09-07T15:20:37 2023-09-07T15:20:37 2023-09-07T15:20:45          1.55K                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(6,5,'a01a_HETJOB','2023-09-07-15:36:03','2023-09-07-15:36:32',1694093763,0,0,'SUBMITTED',2,5,'00:02','bsc32',0,'','HETJOB','',0,0,'MARENOSTRUM4',30133707,'',0,18,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(7,6,'a01a_HETJOB','2023-09-07-15:36:32','2023-09-07-15:42:47',1694093792,1694093874,1694093875,'COMPLETED',2,1,'00:02','bsc32',2700,'','HETJOB','',0,0,'MARENOSTRUM4',30133708,'',1,20,0.0,0.0,'a01a_HETJOB.20230907153810.out','a01a_HETJOB.20230907153810.err',2,'',replace('                 30133708  COMPLETED          1        1 2023-09-07T15:36:32 2023-09-07T15:37:50 2023-09-07T15:37:56          2.70K                                                     \n           30133708.batch  COMPLETED          1        1 2023-09-07T15:37:50 2023-09-07T15:37:50 2023-09-07T15:37:56          2.60K                      868K                      868K \n          30133708.extern  COMPLETED          1        1 2023-09-07T15:37:50 2023-09-07T15:37:50 2023-09-07T15:37:56          2.70K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(8,7,'a01a_HETJOB','2023-09-07-15:42:47','2023-09-13-11:06:28',1694094167,0,0,'SUBMITTED',2,5,'00:02','debug',0,'','HETJOB','',0,0,'MARENOSTRUM4DESE',30133736,'',0,21,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(9,8,'a01a_HETJOB','2023-09-13-11:06:28','2023-09-13-11:12:52',1694595988,0,0,'SUBMITTED',2,5,'00:02','debug',0,'','HETJOB','',0,0,'MARENOSTRUM4DESE',30176724,'',0,28,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(10,9,'a01a_HETJOB','2023-09-13-11:12:52','2023-09-13-11:19:02',1694596372,1694596496,1694596501,'COMPLETED',2,10,'00:02','class_a',789,'','HETJOB','',0,0,'MARENOSTRUM4DESE',30176745,'',1,30,0.0,0.0,'a01a_HETJOB.20230913111458.out','a01a_HETJOB.20230913111458.err',2,'',replace('               30176745+0  COMPLETED         10        1 2023-09-13T11:12:52 2023-09-13T11:14:53 2023-09-13T11:15:02            789                                                     \n         30176745+0.batch  COMPLETED         10        1 2023-09-13T11:14:53 2023-09-13T11:14:53 2023-09-13T11:15:02            723                     1151K                     1151K \n        30176745+0.extern  COMPLETED         10        1 2023-09-13T11:14:53 2023-09-13T11:14:53 2023-09-13T11:15:02            789                       28K                       28K \n               30176745+1  COMPLETED         15        1 2023-09-13T11:12:52 2023-09-13T11:14:53 2023-09-13T11:15:02            621                                                     \n        30176745+1.extern  COMPLETED         15        1 2023-09-13T11:14:53 2023-09-13T11:14:53 2023-09-13T11:15:02            621                       32K                       32K \n','\n',char(10)));
INSERT INTO job_data VALUES(11,10,'a01a_HETJOB','2023-09-13-11:19:02','2023-09-21-12:31:36',1694596742,1694596857,1694596862,'COMPLETED',2,10,'00:02','class_a',1470,'','HETJOB','',0,0,'MARENOSTRUM4DESE',30176782,'',1,31,0.0,0.0,'a01a_HETJOB.20230913112102.out','a01a_HETJOB.20230913112102.err',2,'',replace('               30176782+0  COMPLETED         10        1 2023-09-13T11:19:02 2023-09-13T11:20:55 2023-09-13T11:21:02          1.47K                                                     \n         30176782+0.batch  COMPLETED         10        1 2023-09-13T11:20:55 2023-09-13T11:20:55 2023-09-13T11:21:02          1.42K                     1003K                     1003K \n        30176782+0.extern  COMPLETED         10        1 2023-09-13T11:20:55 2023-09-13T11:20:55 2023-09-13T11:21:02          1.47K                      597K                      597K \n               30176782+1  COMPLETED         15        1 2023-09-13T11:19:02 2023-09-13T11:20:55 2023-09-13T11:21:02            387                                                     \n        30176782+1.extern  COMPLETED         15        1 2023-09-13T11:20:55 2023-09-13T11:20:55 2023-09-13T11:21:02            387                       28K                       28K \n','\n',char(10)));
INSERT INTO job_data VALUES(12,10,'a01a_20000101_fc0_1_HETJOB','2023-09-18-13:53:21','2023-09-18-19:08:36',1695037886,1695037966,1695037971,'COMPLETED',16950378714353,5,'00:02','class_a',0,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4DESE',30211072,'',0,36,0.0,0.0,'','',5,'a01a_20000101_fc0_2_HETJOB','');
INSERT INTO job_data VALUES(13,10,'a01a_20000101_fc0_2_HETJOB','2023-09-18-13:53:21','2023-09-18-19:10:31',1695037886,1695037971,1695037976,'COMPLETED',16950378714353,5,'00:02','class_a',0,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4DESE',30211072,'',0,36,0.0,0.0,'','',5,'','');
INSERT INTO job_data VALUES(14,11,'a01a_20000101_fc0_1_HETJOB','2023-09-18-19:08:36','2023-09-18-19:21:24',1695056673,1695056764,1695056884,'COMPLETED',16950566608273,1,'00:30','class_a',0,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4DESE',30214248,'',0,48,0.0,0.0,'','',2,'a01a_20000101_fc0_2_HETJOB','');
INSERT INTO job_data VALUES(15,11,'a01a_20000101_fc0_2_HETJOB','2023-09-18-19:10:31','2023-09-18-19:21:46',1695056673,1695056884,1695057004,'COMPLETED',16950566608273,1,'00:30','class_a',0,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4DESE',30214248,'',0,48,0.0,0.0,'','',2,'a01a_20000101_fc0_3_HETJOB','');
INSERT INTO job_data VALUES(16,11,'a01a_20000101_fc0_3_HETJOB','2023-09-18-19:12:22','2023-09-18-19:22:06',1695056673,1695057004,1695057125,'COMPLETED',16950566608273,1,'00:30','class_a',0,'2000-01-01 00:00:00','HETJOB','fc0',3,0,'MARENOSTRUM4DESE',30214248,'',0,48,0.0,0.0,'','',2,'a01a_20000101_fc0_4_HETJOB',replace('               30214248+0    RUNNING        144        3 2023-09-18T19:04:33 2023-09-18T19:06:00             Unknown                                                                    \n         30214248+0.batch    RUNNING         48        1 2023-09-18T19:06:00 2023-09-18T19:06:00             Unknown              0                                                     \n        30214248+0.extern    RUNNING        144        3 2023-09-18T19:06:00 2023-09-18T19:06:00             Unknown              0                                                     \n               30214248+1    RUNNING         48        1 2023-09-18T19:04:33 2023-09-18T19:06:00             Unknown                                                                    \n        30214248+1.extern    RUNNING         48        1 2023-09-18T19:06:00 2023-09-18T19:06:00             Unknown              0                                                     \n','\n',char(10)));
INSERT INTO job_data VALUES(17,12,'a01a_20000101_fc0_1_HETJOB','2023-09-18-19:21:24','2023-09-18-19:26:08',1695057521,1695057650,1695057660,'COMPLETED',16950575067001,1,'00:05','class_a',2142.3600000000001272,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4DESE',30214306,'',0,52,0.0,0.0,'','',2,'a01a_20000101_fc0_2_HETJOB','');
INSERT INTO job_data VALUES(18,12,'a01a_20000101_fc0_2_HETJOB','2023-09-18-19:21:46','2023-09-18-20:12:43',1695057521,1695057660,1695057671,'COMPLETED',16950575067001,1,'00:05','class_a',2356.599999999999909,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4DESE',30214306,'',0,52,0.0,0.0,'','',2,'a01a_20000101_fc0_3_HETJOB','');
INSERT INTO job_data VALUES(19,12,'a01a_20000101_fc0_3_HETJOB','2023-09-18-19:22:06','2023-09-18-20:13:05',1695057521,1695057671,1695057681,'COMPLETED',16950575067001,1,'00:05','class_a',2142.3600000000001272,'2000-01-01 00:00:00','HETJOB','fc0',3,0,'MARENOSTRUM4DESE',30214306,'',0,52,0.0,0.0,'','',2,'a01a_20000101_fc0_4_HETJOB','');
INSERT INTO job_data VALUES(20,12,'a01a_20000101_fc0_4_HETJOB','2023-09-18-19:22:27','2023-09-18-20:13:26',1695057521,1695057681,1695057691,'COMPLETED',16950575067001,1,'00:05','class_a',2142.3600000000001272,'2000-01-01 00:00:00','HETJOB','fc0',4,0,'MARENOSTRUM4DESE',30214306,'',0,52,0.0,0.0,'','',2,'a01a_20000101_fc0_5_HETJOB','');
INSERT INTO job_data VALUES(21,12,'a01a_20000101_fc0_5_HETJOB','2023-09-18-19:22:49','2023-09-18-20:13:48',1695057521,1695057691,1695057701,'COMPLETED',16950575067001,1,'00:05','class_a',2142.3600000000001272,'2000-01-01 00:00:00','HETJOB','fc0',5,0,'MARENOSTRUM4DESE',30214306,'',0,52,0.0,0.0,'','',2,'a01a_20000101_fc0_6_HETJOB',replace('               30214306+0  COMPLETED         96        2 2023-09-18T19:18:41 2023-09-18T19:20:47 2023-09-18T19:22:31         21.64K                                                     \n         30214306+0.batch  COMPLETED         48        1 2023-09-18T19:20:47 2023-09-18T19:20:47 2023-09-18T19:22:31         10.33K                     5376K                     5376K \n        30214306+0.extern  COMPLETED         96        2 2023-09-18T19:20:47 2023-09-18T19:20:47 2023-09-18T19:22:31         21.64K                      893K                   480.50K \n               30214306+1  COMPLETED         48        1 2023-09-18T19:18:41 2023-09-18T19:20:47 2023-09-18T19:22:31         10.58K                                                     \n        30214306+1.extern  COMPLETED         48        1 2023-09-18T19:20:47 2023-09-18T19:20:47 2023-09-18T19:22:31         10.58K                       72K                       72K \n','\n',char(10)));
INSERT INTO job_data VALUES(22,12,'a01a_20000101_fc0_7_HETJOB','2023-09-18-19:23:08','2023-09-21-15:51:09',1695057521,1695057711,1695057721,'COMPLETED',16950575067001,1,'00:05','class_a',2142.3600000000001272,'2000-01-01 00:00:00','HETJOB','fc0',7,0,'MARENOSTRUM4DESE',30214306,'',0,52,0.0,0.0,'','',5,'a01a_20000101_fc0_8_HETJOB','');
INSERT INTO job_data VALUES(23,12,'a01a_20000101_fc0_6_HETJOB','2023-09-18-19:23:08','2023-09-18-20:13:48',1695057521,1695057701,1695057711,'COMPLETED',16950575067001,1,'00:05','class_a',2142.3600000000001272,'2000-01-01 00:00:00','HETJOB','fc0',6,0,'MARENOSTRUM4DESE',30214306,'',0,52,0.0,0.0,'','',5,'a01a_20000101_fc0_7_HETJOB','');
INSERT INTO job_data VALUES(24,12,'a01a_20000101_fc0_8_HETJOB','2023-09-18-19:23:08','2023-09-18-20:13:49',1695057521,1695057721,1695057731,'COMPLETED',16950575067001,1,'00:05','class_a',2142.3600000000001272,'2000-01-01 00:00:00','HETJOB','fc0',8,0,'MARENOSTRUM4DESE',30214306,'',0,52,0.0,0.0,'','',5,'a01a_20000101_fc0_9_HETJOB','');
INSERT INTO job_data VALUES(25,12,'a01a_20000101_fc0_10_HETJOB','2023-09-18-19:23:08','2023-09-18-20:13:49',1695057521,1695057741,1695057751,'COMPLETED',16950575067001,1,'00:05','class_a',2142.3600000000001272,'2000-01-01 00:00:00','HETJOB','fc0',10,0,'MARENOSTRUM4DESE',30214306,'',0,52,0.0,0.0,'','',5,'','');
INSERT INTO job_data VALUES(26,12,'a01a_20000101_fc0_9_HETJOB','2023-09-18-19:23:09','2023-09-18-20:13:49',1695057521,1695057731,1695057741,'COMPLETED',16950575067001,1,'00:05','class_a',2142.3600000000001272,'2000-01-01 00:00:00','HETJOB','fc0',9,0,'MARENOSTRUM4DESE',30214306,'',0,52,0.0,0.0,'','',5,'a01a_20000101_fc0_10_HETJOB','');
INSERT INTO job_data VALUES(27,13,'a01a_20000101_fc0_1_HETJOB','2023-09-18-19:26:08','2023-09-18-20:12:20',1695057968,0,0,'SUBMITTED',2,1,'00:05','class_a',0,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4DESE',30214331,'',0,53,0.0,0.0,'','',0,'a01a_20000101_fc0_2_HETJOB','');
INSERT INTO job_data VALUES(28,14,'a01a_20000101_fc0_1_HETJOB','2023-09-18-20:12:20','2023-09-18-20:18:41',1695060461,1695060696,1695060706,'COMPLETED',16950604477039,1,'00:05','class_a',2270.5300000000001999,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4DESE',30214429,'',0,63,0.0,0.0,'','',2,'a01a_20000101_fc0_2_HETJOB','');
INSERT INTO job_data VALUES(29,14,'a01a_20000101_fc0_2_HETJOB','2023-09-18-20:12:43','2023-09-18-20:20:11',1695060461,1695060706,1695060716,'COMPLETED',16950604477039,1,'00:05','class_a',2270.5300000000001999,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4DESE',30214429,'',0,63,0.0,0.0,'','',2,'a01a_20000101_fc0_3_HETJOB','');
INSERT INTO job_data VALUES(30,14,'a01a_20000101_fc0_3_HETJOB','2023-09-18-20:13:05','2023-09-21-12:23:25',1695060461,1695060716,1695060727,'COMPLETED',16950604477039,1,'00:05','class_a',2497.7899999999999636,'2000-01-01 00:00:00','HETJOB','fc0',3,0,'MARENOSTRUM4DESE',30214429,'',0,63,0.0,0.0,'','',2,'a01a_20000101_fc0_4_HETJOB','');
INSERT INTO job_data VALUES(31,14,'a01a_20000101_fc0_4_HETJOB','2023-09-18-20:13:26','2023-09-21-15:49:04',1695060461,1695060727,1695060737,'COMPLETED',16950604477039,1,'00:05','class_a',2270.5300000000001999,'2000-01-01 00:00:00','HETJOB','fc0',4,0,'MARENOSTRUM4DESE',30214429,'',0,63,0.0,0.0,'','',2,'a01a_20000101_fc0_5_HETJOB','');
INSERT INTO job_data VALUES(32,14,'a01a_20000101_fc0_5_HETJOB','2023-09-18-20:13:48','2023-09-21-15:49:46',1695060461,1695060737,1695060747,'COMPLETED',16950604477039,1,'00:05','class_a',2270.5300000000001999,'2000-01-01 00:00:00','HETJOB','fc0',5,0,'MARENOSTRUM4DESE',30214429,'',0,63,0.0,0.0,'','',2,'a01a_20000101_fc0_6_HETJOB','');
INSERT INTO job_data VALUES(33,14,'a01a_20000101_fc0_6_HETJOB','2023-09-18-20:13:48','2023-09-21-15:50:07',1695060461,1695060747,1695060757,'COMPLETED',16950604477039,1,'00:05','class_a',2270.5300000000001999,'2000-01-01 00:00:00','HETJOB','fc0',6,0,'MARENOSTRUM4DESE',30214429,'',0,63,0.0,0.0,'','',2,'a01a_20000101_fc0_7_HETJOB','');
INSERT INTO job_data VALUES(34,14,'a01a_20000101_fc0_9_HETJOB','2023-09-18-20:13:49','2023-09-21-15:51:49',1695060461,1695060777,1695060787,'COMPLETED',16950604477039,1,'00:05','class_a',2270.5300000000001999,'2000-01-01 00:00:00','HETJOB','fc0',9,0,'MARENOSTRUM4DESE',30214429,'',0,63,0.0,0.0,'','',2,'a01a_20000101_fc0_10_HETJOB','');
INSERT INTO job_data VALUES(35,14,'a01a_20000101_fc0_10_HETJOB','2023-09-18-20:13:49','2023-09-21-15:52:09',1695060461,1695060787,1695060797,'COMPLETED',16950604477039,1,'00:05','class_a',2270.5300000000001999,'2000-01-01 00:00:00','HETJOB','fc0',10,0,'MARENOSTRUM4DESE',30214429,'',0,63,0.0,0.0,'','',2,'','');
INSERT INTO job_data VALUES(36,14,'a01a_20000101_fc0_8_HETJOB','2023-09-18-20:13:49','2023-09-21-15:51:29',1695060461,1695060767,1695060777,'COMPLETED',16950604477039,1,'00:05','class_a',2270.5300000000001999,'2000-01-01 00:00:00','HETJOB','fc0',8,0,'MARENOSTRUM4DESE',30214429,'',0,63,0.0,0.0,'','',2,'a01a_20000101_fc0_9_HETJOB',replace('                 30214429  COMPLETED         96        2 2023-09-18T20:07:41 2023-09-18T20:11:30 2023-09-18T20:13:18         20.66K                                                     \n           30214429.batch  COMPLETED         48        1 2023-09-18T20:11:30 2023-09-18T20:11:30 2023-09-18T20:13:18          9.80K                     5336K                     5336K \n          30214429.extern  COMPLETED         96        2 2023-09-18T20:11:30 2023-09-18T20:11:30 2023-09-18T20:13:18         20.66K                      899K                      869K \n','\n',char(10)));
INSERT INTO job_data VALUES(37,15,'a01a_20000101_fc0_1_HETJOB','2023-09-18-20:18:41','2023-09-21-12:23:00',1695061121,1695061184,1695061194,'COMPLETED',2,1,'00:05','class_a',0,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4DESE',30214451,'',0,64,0.0,0.0,'a01a_20000101_fc0_1_HETJOB.20230918201948.out','a01a_20000101_fc0_1_HETJOB.20230918201948.err',5,'a01a_20000101_fc0_2_HETJOB','');
INSERT INTO job_data VALUES(38,15,'a01a_20000101_fc0_2_HETJOB','2023-09-18-20:20:11','2023-09-21-12:23:13',1695061211,0,0,'SUBMITTED',2,1,'00:05','class_a',0,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4DESE',30214458,'',0,64,0.0,0.0,'','',0,'a01a_20000101_fc0_3_HETJOB','');
INSERT INTO job_data VALUES(39,16,'a01a_20000101_fc0_1_HETJOB','2023-09-21-12:23:01','2023-09-21-15:47:47',1695291780,1695291780,1695291785,'COMPLETED',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'TEST-LOCAL',44748,'',0,93,0.0,0.0,'a01a_20000101_fc0_1_HETJOB.20230921122313.out','a01a_20000101_fc0_1_HETJOB.20230921122313.err',5,'a01a_20000101_fc0_2_HETJOB','');
INSERT INTO job_data VALUES(40,16,'a01a_20000101_fc0_2_HETJOB','2023-09-21-12:23:13','2023-09-21-15:48:07',1695291793,1695291793,1695291798,'COMPLETED',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'TEST-LOCAL',44774,'',0,93,0.0,0.0,'a01a_20000101_fc0_2_HETJOB.20230921122325.out','a01a_20000101_fc0_2_HETJOB.20230921122325.err',5,'a01a_20000101_fc0_3_HETJOB','');
INSERT INTO job_data VALUES(41,16,'a01a_20000101_fc0_3_HETJOB','2023-09-21-12:23:25','2023-09-21-15:48:44',1695291805,0,0,'SUBMITTED',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',3,0,'TEST-LOCAL',44923,'',0,93,0.0,0.0,'','',0,'a01a_20000101_fc0_4_HETJOB','');
INSERT INTO job_data VALUES(42,16,'a01a_HETJOB','2023-09-21-12:31:36','2023-09-21-12:32:11',1695292296,1695292312,1695292317,'COMPLETED',2,1,'00:30','debug',0,'','HETJOB','',0,1,'MARENOSTRUM4',30237762,'',0,94,0.0,0.0,'a01a_HETJOB.20230921123154.out','a01a_HETJOB.20230921123154.err',5,'','');
INSERT INTO job_data VALUES(43,17,'a01a_20000101_fc0_1_HETJOB','2023-09-21-15:47:47','2023-09-27-09:36:10',1695304067,1695304072,1695304077,'COMPLETED',2,1,'00:30','debug',1940,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4',30238292,'',1,119,0.0,0.0,'a01a_20000101_fc0_1_HETJOB.20230921154804.out','a01a_20000101_fc0_1_HETJOB.20230921154804.err',2,'a01a_20000101_fc0_2_HETJOB',replace('                 30238292  COMPLETED          1        1 2023-09-21T15:47:47 2023-09-21T15:47:49 2023-09-21T15:47:59          1.94K                                                     \n           30238292.batch  COMPLETED          1        1 2023-09-21T15:47:49 2023-09-21T15:47:49 2023-09-21T15:47:59          1.37K                      929K                      929K \n          30238292.extern  COMPLETED          1        1 2023-09-21T15:47:49 2023-09-21T15:47:49 2023-09-21T15:47:59          1.94K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(44,17,'a01a_20000101_fc0_2_HETJOB','2023-09-21-15:48:07','2023-09-27-09:37:55',1695304087,1695304100,1695304105,'COMPLETED',2,1,'00:30','debug',1720,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4',30238293,'',1,119,0.0,0.0,'a01a_20000101_fc0_2_HETJOB.20230921154824.out','a01a_20000101_fc0_2_HETJOB.20230921154824.err',2,'a01a_20000101_fc0_3_HETJOB',replace('                 30238293  COMPLETED          1        1 2023-09-21T15:48:07 2023-09-21T15:48:17 2023-09-21T15:48:27          1.72K                                                     \n           30238293.batch  COMPLETED          1        1 2023-09-21T15:48:17 2023-09-21T15:48:17 2023-09-21T15:48:27          1.36K                      816K                      816K \n          30238293.extern  COMPLETED          1        1 2023-09-21T15:48:17 2023-09-21T15:48:17 2023-09-21T15:48:27          1.72K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(45,17,'a01a_20000101_fc0_3_HETJOB','2023-09-21-15:48:44','2023-09-27-09:50:10',1695304124,1695304130,1695304135,'COMPLETED',2,1,'00:30','debug',1500,'2000-01-01 00:00:00','HETJOB','fc0',3,0,'MARENOSTRUM4',30238295,'',1,119,0.0,0.0,'a01a_20000101_fc0_3_HETJOB.20230921154901.out','a01a_20000101_fc0_3_HETJOB.20230921154901.err',2,'a01a_20000101_fc0_4_HETJOB',replace('                 30238295  COMPLETED          1        1 2023-09-21T15:48:44 2023-09-21T15:48:47 2023-09-21T15:48:56          1.50K                                                     \n           30238295.batch  COMPLETED          1        1 2023-09-21T15:48:47 2023-09-21T15:48:47 2023-09-21T15:48:56          1.45K                      818K                      818K \n          30238295.extern  COMPLETED          1        1 2023-09-21T15:48:47 2023-09-21T15:48:47 2023-09-21T15:48:56          1.50K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(46,17,'a01a_20000101_fc0_4_HETJOB','2023-09-21-15:49:04','2023-09-27-09:51:37',1695304144,1695304162,1695304167,'COMPLETED',2,1,'00:30','debug',1380,'2000-01-01 00:00:00','HETJOB','fc0',4,0,'MARENOSTRUM4',30238298,'',1,119,0.0,0.0,'a01a_20000101_fc0_4_HETJOB.20230921154926.out','a01a_20000101_fc0_4_HETJOB.20230921154926.err',2,'a01a_20000101_fc0_5_HETJOB',replace('                 30238298  COMPLETED          1        1 2023-09-21T15:49:04 2023-09-21T15:49:19 2023-09-21T15:49:27          1.38K                                                     \n           30238298.batch  COMPLETED          1        1 2023-09-21T15:49:19 2023-09-21T15:49:19 2023-09-21T15:49:27          1.33K                      912K                      912K \n          30238298.extern  COMPLETED          1        1 2023-09-21T15:49:19 2023-09-21T15:49:19 2023-09-21T15:49:27          1.38K                      700K                      700K \n','\n',char(10)));
INSERT INTO job_data VALUES(47,17,'a01a_20000101_fc0_5_HETJOB','2023-09-21-15:49:46','2023-09-27-10:29:45',1695304186,1695304190,1695304195,'COMPLETED',2,1,'00:30','debug',1850,'2000-01-01 00:00:00','HETJOB','fc0',5,0,'MARENOSTRUM4',30238300,'',1,119,0.0,0.0,'a01a_20000101_fc0_5_HETJOB.20230921155004.out','a01a_20000101_fc0_5_HETJOB.20230921155004.err',2,'a01a_20000101_fc0_6_HETJOB',replace('                 30238300  COMPLETED          1        1 2023-09-21T15:49:46 2023-09-21T15:49:47 2023-09-21T15:49:57          1.85K                                                     \n           30238300.batch  COMPLETED          1        1 2023-09-21T15:49:47 2023-09-21T15:49:47 2023-09-21T15:49:57          1.34K                      812K                      812K \n          30238300.extern  COMPLETED          1        1 2023-09-21T15:49:47 2023-09-21T15:49:47 2023-09-21T15:49:57          1.85K                      710K                      710K \n','\n',char(10)));
INSERT INTO job_data VALUES(48,17,'a01a_20000101_fc0_6_HETJOB','2023-09-21-15:50:07','2023-09-27-10:31:28',1695304207,1695304258,1695304263,'COMPLETED',2,1,'00:30','debug',1420,'2000-01-01 00:00:00','HETJOB','fc0',6,0,'MARENOSTRUM4',30238303,'',1,119,0.0,0.0,'a01a_20000101_fc0_6_HETJOB.20230921155106.out','a01a_20000101_fc0_6_HETJOB.20230921155106.err',2,'a01a_20000101_fc0_7_HETJOB',replace('                 30238303  COMPLETED          1        1 2023-09-21T15:50:07 2023-09-21T15:50:55 2023-09-21T15:51:03          1.42K                                                     \n           30238303.batch  COMPLETED          1        1 2023-09-21T15:50:55 2023-09-21T15:50:55 2023-09-21T15:51:03          1.37K                      915K                      915K \n          30238303.extern  COMPLETED          1        1 2023-09-21T15:50:55 2023-09-21T15:50:55 2023-09-21T15:51:03          1.42K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(49,17,'a01a_20000101_fc0_7_HETJOB','2023-09-21-15:51:09','2023-09-27-10:33:12',1695304269,1695304272,1695304277,'COMPLETED',2,1,'00:30','debug',1380,'2000-01-01 00:00:00','HETJOB','fc0',7,0,'MARENOSTRUM4',30238306,'',1,119,0.0,0.0,'a01a_20000101_fc0_7_HETJOB.20230921155126.out','a01a_20000101_fc0_7_HETJOB.20230921155126.err',2,'a01a_20000101_fc0_8_HETJOB',replace('                 30238306  COMPLETED          1        1 2023-09-21T15:51:09 2023-09-21T15:51:10 2023-09-21T15:51:17          1.38K                                                     \n           30238306.batch  COMPLETED          1        1 2023-09-21T15:51:10 2023-09-21T15:51:10 2023-09-21T15:51:17          1.34K                      814K                      814K \n          30238306.extern  COMPLETED          1        1 2023-09-21T15:51:10 2023-09-21T15:51:10 2023-09-21T15:51:17          1.38K                      708K                      708K \n','\n',char(10)));
INSERT INTO job_data VALUES(50,17,'a01a_20000101_fc0_8_HETJOB','2023-09-21-15:51:29','2023-09-27-10:35:03',1695304289,1695304292,1695304297,'COMPLETED',2,1,'00:30','debug',1450,'2000-01-01 00:00:00','HETJOB','fc0',8,0,'MARENOSTRUM4',30238310,'',1,119,0.0,0.0,'a01a_20000101_fc0_8_HETJOB.20230921155146.out','a01a_20000101_fc0_8_HETJOB.20230921155146.err',2,'a01a_20000101_fc0_9_HETJOB',replace('                 30238310  COMPLETED          1        1 2023-09-21T15:51:29 2023-09-21T15:51:30 2023-09-21T15:51:37          1.45K                                                     \n           30238310.batch  COMPLETED          1        1 2023-09-21T15:51:30 2023-09-21T15:51:30 2023-09-21T15:51:37          1.40K                      814K                      814K \n          30238310.extern  COMPLETED          1        1 2023-09-21T15:51:30 2023-09-21T15:51:30 2023-09-21T15:51:37          1.45K                      710K                      710K \n','\n',char(10)));
INSERT INTO job_data VALUES(51,17,'a01a_20000101_fc0_9_HETJOB','2023-09-21-15:51:49','2023-09-27-10:36:47',1695304309,1695304317,1695304322,'COMPLETED',2,1,'00:30','debug',1750,'2000-01-01 00:00:00','HETJOB','fc0',9,0,'MARENOSTRUM4',30238311,'',1,119,0.0,0.0,'a01a_20000101_fc0_9_HETJOB.20230921155206.out','a01a_20000101_fc0_9_HETJOB.20230921155206.err',2,'a01a_20000101_fc0_10_HETJOB',replace('                 30238311  COMPLETED          1        1 2023-09-21T15:51:49 2023-09-21T15:51:54 2023-09-21T15:52:04          1.75K                                                     \n           30238311.batch  COMPLETED          1        1 2023-09-21T15:51:54 2023-09-21T15:51:54 2023-09-21T15:52:04          1.29K                      810K                      810K \n          30238311.extern  COMPLETED          1        1 2023-09-21T15:51:54 2023-09-21T15:51:54 2023-09-21T15:52:04          1.75K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(52,17,'a01a_20000101_fc0_10_HETJOB','2023-09-21-15:52:09','2023-09-27-10:38:32',1695304329,1695304340,1695304345,'COMPLETED',2,1,'00:30','debug',1770,'2000-01-01 00:00:00','HETJOB','fc0',10,0,'MARENOSTRUM4',30238320,'',1,119,0.0,0.0,'a01a_20000101_fc0_10_HETJOB.20230921155226.out','a01a_20000101_fc0_10_HETJOB.20230921155226.err',2,'',replace('                 30238320  COMPLETED          1        1 2023-09-21T15:52:09 2023-09-21T15:52:17 2023-09-21T15:52:27          1.77K                                                     \n           30238320.batch  COMPLETED          1        1 2023-09-21T15:52:17 2023-09-21T15:52:17 2023-09-21T15:52:27          1.38K                      905K                      905K \n          30238320.extern  COMPLETED          1        1 2023-09-21T15:52:17 2023-09-21T15:52:17 2023-09-21T15:52:27          1.77K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(53,18,'a01a_20000101_fc0_1_HETJOB','2023-09-27-09:36:10','2023-09-27-09:45:01',1695800170,1695800251,1695800256,'COMPLETED',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4',30266738,'',0,132,0.0,0.0,'a01a_20000101_fc0_1_HETJOB.20230927093733.out','a01a_20000101_fc0_1_HETJOB.20230927093733.err',5,'a01a_20000101_fc0_2_HETJOB','');
INSERT INTO job_data VALUES(54,18,'a01a_20000101_fc0_2_HETJOB','2023-09-27-09:37:55','2023-09-27-09:45:24',1695800275,0,0,'SUBMITTED',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4',30266752,'',0,132,0.0,0.0,'','',0,'a01a_20000101_fc0_3_HETJOB','');
INSERT INTO job_data VALUES(55,19,'a01a_20000101_fc0_1_HETJOB','2023-09-27-09:45:01','2023-09-27-09:47:33',1695800701,1695800712,1695800717,'COMPLETED',2,1,'00:30','debug',1200,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4',30266863,'',1,134,0.0,0.0,'a01a_20000101_fc0_1_HETJOB.20230927094519.out','a01a_20000101_fc0_1_HETJOB.20230927094519.err',2,'a01a_20000101_fc0_2_HETJOB',replace('                 30266863  COMPLETED          1        1 2023-09-27T09:45:01 2023-09-27T09:45:07 2023-09-27T09:45:18          1.20K                                                     \n           30266863.batch  COMPLETED          1        1 2023-09-27T09:45:07 2023-09-27T09:45:07 2023-09-27T09:45:18            901                      917K                      917K \n          30266863.extern  COMPLETED          1        1 2023-09-27T09:45:07 2023-09-27T09:45:07 2023-09-27T09:45:18          1.20K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(56,19,'a01a_20000101_fc0_2_HETJOB','2023-09-27-09:45:24','2023-09-27-09:48:40',1695800724,1695800805,0,'RUNNING',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4',30266865,'',0,134,0.0,0.0,'','',0,'a01a_20000101_fc0_3_HETJOB','');
INSERT INTO job_data VALUES(57,20,'a01a_20000101_fc0_1_HETJOB','2023-09-27-09:47:33','2023-09-27-09:55:37',1695800853,1695800895,1695800900,'COMPLETED',2,1,'00:30','debug',1200,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4',30266883,'',1,136,0.0,0.0,'a01a_20000101_fc0_1_HETJOB.20230927094817.out','a01a_20000101_fc0_1_HETJOB.20230927094817.err',2,'a01a_20000101_fc0_2_HETJOB',replace('                 30266883  COMPLETED          1        1 2023-09-27T09:47:33 2023-09-27T09:48:10 2023-09-27T09:48:21          1.20K                                                     \n           30266883.batch  COMPLETED          1        1 2023-09-27T09:48:10 2023-09-27T09:48:10 2023-09-27T09:48:21            919                      909K                      909K \n          30266883.extern  COMPLETED          1        1 2023-09-27T09:48:10 2023-09-27T09:48:10 2023-09-27T09:48:21          1.20K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(58,20,'a01a_20000101_fc0_2_HETJOB','2023-09-27-09:48:40','2023-09-27-09:56:49',1695800920,1695800988,1695800993,'COMPLETED',2,1,'00:30','debug',1140,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4',30266900,'',1,136,0.0,0.0,'a01a_20000101_fc0_2_HETJOB.20230927095003.out','a01a_20000101_fc0_2_HETJOB.20230927095003.err',2,'a01a_20000101_fc0_3_HETJOB',replace('                 30266900  COMPLETED          1        1 2023-09-27T09:48:40 2023-09-27T09:49:43 2023-09-27T09:49:54          1.14K                                                     \n           30266900.batch  COMPLETED          1        1 2023-09-27T09:49:43 2023-09-27T09:49:43 2023-09-27T09:49:54            900                      950K                      950K \n          30266900.extern  COMPLETED          1        1 2023-09-27T09:49:43 2023-09-27T09:49:43 2023-09-27T09:49:54          1.14K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(59,20,'a01a_20000101_fc0_3_HETJOB','2023-09-27-09:50:10','2023-09-27-09:58:38',1695801010,1695801081,1695801086,'COMPLETED',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',3,0,'MARENOSTRUM4',30266914,'',0,136,0.0,0.0,'a01a_20000101_fc0_3_HETJOB.20230927095131.out','a01a_20000101_fc0_3_HETJOB.20230927095131.err',5,'a01a_20000101_fc0_4_HETJOB','');
INSERT INTO job_data VALUES(60,20,'a01a_20000101_fc0_4_HETJOB','2023-09-27-09:51:37','2023-09-27-10:16:08',1695801097,0,0,'SUBMITTED',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',4,0,'MARENOSTRUM4',30266928,'',0,136,0.0,0.0,'','',0,'a01a_20000101_fc0_5_HETJOB','');
INSERT INTO job_data VALUES(61,21,'a01a_20000101_fc0_1_HETJOB','2023-09-27-09:55:37','2023-09-27-10:09:51',1695801337,1695801351,1695801356,'COMPLETED',2,1,'00:30','debug',1190,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4',30266965,'',1,138,0.0,0.0,'a01a_20000101_fc0_1_HETJOB.20230927095556.out','a01a_20000101_fc0_1_HETJOB.20230927095556.err',2,'a01a_20000101_fc0_2_HETJOB',replace('                 30266965  COMPLETED          1        1 2023-09-27T09:55:37 2023-09-27T09:55:46 2023-09-27T09:55:57          1.19K                                                     \n           30266965.batch  COMPLETED          1        1 2023-09-27T09:55:46 2023-09-27T09:55:46 2023-09-27T09:55:57            945                      900K                      900K \n          30266965.extern  COMPLETED          1        1 2023-09-27T09:55:46 2023-09-27T09:55:46 2023-09-27T09:55:57          1.19K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(62,21,'a01a_20000101_fc0_2_HETJOB','2023-09-27-09:56:49','2023-09-27-10:12:57',1695801409,1695801447,1695801452,'COMPLETED',2,1,'00:30','debug',939,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4',30266969,'',1,138,0.0,0.0,'a01a_20000101_fc0_2_HETJOB.20230927095728.out','a01a_20000101_fc0_2_HETJOB.20230927095728.err',2,'a01a_20000101_fc0_3_HETJOB',replace('                 30266969  COMPLETED          1        1 2023-09-27T09:56:49 2023-09-27T09:57:25 2023-09-27T09:57:32            939                                                     \n           30266969.batch  COMPLETED          1        1 2023-09-27T09:57:25 2023-09-27T09:57:25 2023-09-27T09:57:32            916                      916K                      916K \n          30266969.extern  COMPLETED          1        1 2023-09-27T09:57:25 2023-09-27T09:57:25 2023-09-27T09:57:32            939                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(63,21,'a01a_20000101_fc0_3_HETJOB','2023-09-27-09:58:38','2023-09-27-10:14:39',1695801518,1695801539,1695801544,'COMPLETED',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',3,0,'MARENOSTRUM4',30267003,'',0,138,0.0,0.0,'a01a_20000101_fc0_3_HETJOB.20230927095946.out','a01a_20000101_fc0_3_HETJOB.20230927095946.err',5,'a01a_20000101_fc0_4_HETJOB','');
INSERT INTO job_data VALUES(64,22,'a01a_20000101_fc0_1_HETJOB','2023-09-27-10:09:51','2023-09-27-10:11:55',1695802191,1695802250,0,'RUNNING',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4',30267098,'',0,141,0.0,0.0,'','',0,'a01a_20000101_fc0_2_HETJOB','');
INSERT INTO job_data VALUES(65,23,'a01a_20000101_fc0_1_HETJOB','2023-09-27-10:11:55','2023-09-27-10:18:26',1695802315,1695802348,1695802353,'COMPLETED',2,1,'00:30','debug',1010,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4',30267110,'',1,143,0.0,0.0,'a01a_20000101_fc0_1_HETJOB.20230927101235.out','a01a_20000101_fc0_1_HETJOB.20230927101235.err',2,'a01a_20000101_fc0_2_HETJOB',replace('                 30267110  COMPLETED          1        1 2023-09-27T10:11:55 2023-09-27T10:12:24 2023-09-27T10:12:35          1.01K                                                     \n           30267110.batch  COMPLETED          1        1 2023-09-27T10:12:24 2023-09-27T10:12:24 2023-09-27T10:12:35            787                     1019K                     1019K \n          30267110.extern  COMPLETED          1        1 2023-09-27T10:12:24 2023-09-27T10:12:24 2023-09-27T10:12:35          1.01K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(66,23,'a01a_20000101_fc0_2_HETJOB','2023-09-27-10:12:57','2023-09-27-10:19:47',1695802377,1695802458,1695802463,'COMPLETED',2,1,'00:30','debug',1110,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4',30267118,'',1,143,0.0,0.0,'a01a_20000101_fc0_2_HETJOB.20230927101418.out','a01a_20000101_fc0_2_HETJOB.20230927101418.err',2,'a01a_20000101_fc0_3_HETJOB',replace('                 30267118  COMPLETED          1        1 2023-09-27T10:12:57 2023-09-27T10:14:13 2023-09-27T10:14:24          1.11K                                                     \n           30267118.batch  COMPLETED          1        1 2023-09-27T10:14:13 2023-09-27T10:14:13 2023-09-27T10:14:24            857                     1018K                     1018K \n          30267118.extern  COMPLETED          1        1 2023-09-27T10:14:13 2023-09-27T10:14:13 2023-09-27T10:14:24          1.11K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(67,23,'a01a_20000101_fc0_3_HETJOB','2023-09-27-10:14:39','2023-09-27-10:26:13',1695802479,1695802554,1695802559,'COMPLETED',2,1,'00:30','debug',1190,'2000-01-01 00:00:00','HETJOB','fc0',3,0,'MARENOSTRUM4',30267125,'',1,143,0.0,0.0,'a01a_20000101_fc0_3_HETJOB.20230927101604.out','a01a_20000101_fc0_3_HETJOB.20230927101604.err',2,'a01a_20000101_fc0_4_HETJOB',replace('                 30267125  COMPLETED          1        1 2023-09-27T10:14:39 2023-09-27T10:15:49 2023-09-27T10:16:00          1.19K                                                     \n           30267125.batch  COMPLETED          1        1 2023-09-27T10:15:49 2023-09-27T10:15:49 2023-09-27T10:16:00            876                      972K                      972K \n          30267125.extern  COMPLETED          1        1 2023-09-27T10:15:49 2023-09-27T10:15:49 2023-09-27T10:16:00          1.19K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(68,23,'a01a_20000101_fc0_4_HETJOB','2023-09-27-10:16:08','2023-09-27-10:27:56',1695802568,1695802656,0,'RUNNING',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',4,0,'MARENOSTRUM4',30267141,'',0,143,0.0,0.0,'','',0,'a01a_20000101_fc0_5_HETJOB','');
INSERT INTO job_data VALUES(69,24,'a01a_20000101_fc0_1_HETJOB','2023-09-27-10:18:26','2023-09-27-10:23:39',1695802706,1695802750,1695802755,'COMPLETED',2,1,'00:30','debug',1140,'2000-01-01 00:00:00','HETJOB','fc0',1,0,'MARENOSTRUM4',30267160,'',1,145,0.0,0.0,'a01a_20000101_fc0_1_HETJOB.20230927101910.out','a01a_20000101_fc0_1_HETJOB.20230927101910.err',2,'a01a_20000101_fc0_2_HETJOB',replace('                 30267160  COMPLETED          1        1 2023-09-27T10:18:26 2023-09-27T10:19:05 2023-09-27T10:19:16          1.14K                                                     \n           30267160.batch  COMPLETED          1        1 2023-09-27T10:19:05 2023-09-27T10:19:05 2023-09-27T10:19:16            871                      979K                      979K \n          30267160.extern  COMPLETED          1        1 2023-09-27T10:19:05 2023-09-27T10:19:05 2023-09-27T10:19:16          1.14K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(70,24,'a01a_20000101_fc0_2_HETJOB','2023-09-27-10:19:47','2023-09-27-10:24:22',1695802787,0,0,'SUBMITTED',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',2,0,'MARENOSTRUM4',30267185,'',0,145,0.0,0.0,'','',0,'a01a_20000101_fc0_3_HETJOB','');
INSERT INTO job_data VALUES(71,25,'a01a_20000101_fc0_1_HETJOB','2023-09-27-10:23:39','2023-09-27-10:25:22',1695803019,1695803035,1695803040,'COMPLETED',2,1,'00:30','debug',686,'2000-01-01 00:00:00','HETJOB','fc0',1,1,'MARENOSTRUM4',30267272,'',1,147,0.0,0.0,'a01a_20000101_fc0_1_HETJOB.20230927102359.out','a01a_20000101_fc0_1_HETJOB.20230927102359.err',2,'a01a_20000101_fc0_2_HETJOB',replace('                 30267272  COMPLETED          1        1 2023-09-27T10:23:39 2023-09-27T10:23:51 2023-09-27T10:24:02            686                                                     \n           30267272.batch  COMPLETED          1        1 2023-09-27T10:23:51 2023-09-27T10:23:51 2023-09-27T10:24:02            528                     1129K                     1129K \n          30267272.extern  COMPLETED          1        1 2023-09-27T10:23:51 2023-09-27T10:23:51 2023-09-27T10:24:02            686                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(72,25,'a01a_20000101_fc0_2_HETJOB','2023-09-27-10:24:22','2023-09-27-10:27:11',1695803062,1695803144,1695803149,'COMPLETED',2,1,'00:30','debug',1020,'2000-01-01 00:00:00','HETJOB','fc0',2,1,'MARENOSTRUM4',30267277,'',1,147,0.0,0.0,'a01a_20000101_fc0_2_HETJOB.20230927102548.out','a01a_20000101_fc0_2_HETJOB.20230927102548.err',2,'a01a_20000101_fc0_3_HETJOB',replace('                 30267277  COMPLETED          1        1 2023-09-27T10:24:22 2023-09-27T10:25:39 2023-09-27T10:25:50          1.02K                                                     \n           30267277.batch  COMPLETED          1        1 2023-09-27T10:25:39 2023-09-27T10:25:39 2023-09-27T10:25:50            786                      964K                      964K \n          30267277.extern  COMPLETED          1        1 2023-09-27T10:25:39 2023-09-27T10:25:39 2023-09-27T10:25:50          1.02K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(73,25,'a01a_20000101_fc0_3_HETJOB','2023-09-27-10:26:13','2023-09-27-10:28:56',1695803173,1695803249,1695803254,'COMPLETED',2,1,'00:30','debug',738,'2000-01-01 00:00:00','HETJOB','fc0',3,1,'MARENOSTRUM4',30267291,'',1,147,0.0,0.0,'a01a_20000101_fc0_3_HETJOB.20230927102734.out','a01a_20000101_fc0_3_HETJOB.20230927102734.err',2,'a01a_20000101_fc0_4_HETJOB',replace('                 30267291  COMPLETED          1        1 2023-09-27T10:26:13 2023-09-27T10:27:24 2023-09-27T10:27:35            738                                                     \n           30267291.batch  COMPLETED          1        1 2023-09-27T10:27:24 2023-09-27T10:27:24 2023-09-27T10:27:35            547                     1129K                     1129K \n          30267291.extern  COMPLETED          1        1 2023-09-27T10:27:24 2023-09-27T10:27:24 2023-09-27T10:27:36            738                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(74,25,'a01a_20000101_fc0_4_HETJOB','2023-09-27-10:27:56','2023-09-27-10:30:50',1695803276,1695803360,1695803365,'COMPLETED',2,1,'00:30','debug',1020,'2000-01-01 00:00:00','HETJOB','fc0',4,1,'MARENOSTRUM4',30267297,'',1,147,0.0,0.0,'a01a_20000101_fc0_4_HETJOB.20230927102923.out','a01a_20000101_fc0_4_HETJOB.20230927102923.err',2,'a01a_20000101_fc0_5_HETJOB',replace('                 30267297  COMPLETED          1        1 2023-09-27T10:27:56 2023-09-27T10:29:16 2023-09-27T10:29:27          1.02K                                                     \n           30267297.batch  COMPLETED          1        1 2023-09-27T10:29:16 2023-09-27T10:29:16 2023-09-27T10:29:27            749                      988K                      988K \n          30267297.extern  COMPLETED          1        1 2023-09-27T10:29:16 2023-09-27T10:29:16 2023-09-27T10:29:27          1.02K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(75,25,'a01a_20000101_fc0_5_HETJOB','2023-09-27-10:29:45','2023-09-27-10:32:27',1695803385,1695803465,1695803470,'COMPLETED',2,1,'00:30','debug',780,'2000-01-01 00:00:00','HETJOB','fc0',5,1,'MARENOSTRUM4',30267314,'',1,147,0.0,0.0,'a01a_20000101_fc0_5_HETJOB.20230927103124.out','a01a_20000101_fc0_5_HETJOB.20230927103124.err',2,'a01a_20000101_fc0_6_HETJOB',replace('                 30267314  COMPLETED          1        1 2023-09-27T10:29:45 2023-09-27T10:31:00 2023-09-27T10:31:11            780                                                     \n           30267314.batch  COMPLETED          1        1 2023-09-27T10:31:00 2023-09-27T10:31:00 2023-09-27T10:31:11            595                     1104K                     1104K \n          30267314.extern  COMPLETED          1        1 2023-09-27T10:31:00 2023-09-27T10:31:00 2023-09-27T10:31:11            780                      710K                      710K \n','\n',char(10)));
INSERT INTO job_data VALUES(76,25,'a01a_20000101_fc0_6_HETJOB','2023-09-27-10:31:28','2023-09-27-10:34:12',1695803488,1695803568,1695803573,'COMPLETED',2,1,'00:30','debug',1030,'2000-01-01 00:00:00','HETJOB','fc0',6,1,'MARENOSTRUM4',30267345,'',1,147,0.0,0.0,'a01a_20000101_fc0_6_HETJOB.20230927103250.out','a01a_20000101_fc0_6_HETJOB.20230927103250.err',2,'a01a_20000101_fc0_7_HETJOB',replace('                 30267345  COMPLETED          1        1 2023-09-27T10:31:28 2023-09-27T10:32:43 2023-09-27T10:32:55          1.03K                                                     \n           30267345.batch  COMPLETED          1        1 2023-09-27T10:32:43 2023-09-27T10:32:43 2023-09-27T10:32:55            781                        1M                        1M \n          30267345.extern  COMPLETED          1        1 2023-09-27T10:32:43 2023-09-27T10:32:43 2023-09-27T10:32:55          1.03K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(77,25,'a01a_20000101_fc0_7_HETJOB','2023-09-27-10:33:12','2023-09-27-10:36:01',1695803592,1695803679,1695803684,'COMPLETED',2,1,'00:30','debug',894,'2000-01-01 00:00:00','HETJOB','fc0',7,1,'MARENOSTRUM4',30267368,'',1,147,0.0,0.0,'a01a_20000101_fc0_7_HETJOB.20230927103439.out','a01a_20000101_fc0_7_HETJOB.20230927103439.err',2,'a01a_20000101_fc0_8_HETJOB',replace('                 30267368  COMPLETED          1        1 2023-09-27T10:33:12 2023-09-27T10:34:34 2023-09-27T10:34:45            894                                                     \n           30267368.batch  COMPLETED          1        1 2023-09-27T10:34:34 2023-09-27T10:34:34 2023-09-27T10:34:45            657                     1122K                     1122K \n          30267368.extern  COMPLETED          1        1 2023-09-27T10:34:34 2023-09-27T10:34:34 2023-09-27T10:34:45            894                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(78,25,'a01a_20000101_fc0_8_HETJOB','2023-09-27-10:35:03','2023-09-27-10:37:46',1695803703,1695803780,1695803785,'COMPLETED',2,1,'00:30','debug',672,'2000-01-01 00:00:00','HETJOB','fc0',8,1,'MARENOSTRUM4',30267381,'',1,147,0.0,0.0,'a01a_20000101_fc0_8_HETJOB.20230927103625.out','a01a_20000101_fc0_8_HETJOB.20230927103625.err',2,'a01a_20000101_fc0_9_HETJOB',replace('                 30267381  COMPLETED          1        1 2023-09-27T10:35:03 2023-09-27T10:36:15 2023-09-27T10:36:27            672                                                     \n           30267381.batch  COMPLETED          1        1 2023-09-27T10:36:15 2023-09-27T10:36:15 2023-09-27T10:36:27            499                     1082K                     1082K \n          30267381.extern  COMPLETED          1        1 2023-09-27T10:36:15 2023-09-27T10:36:15 2023-09-27T10:36:27            672                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(79,25,'a01a_20000101_fc0_9_HETJOB','2023-09-27-10:36:47','2023-09-27-10:39:29',1695803807,1695803883,1695803888,'COMPLETED',2,1,'00:30','debug',871,'2000-01-01 00:00:00','HETJOB','fc0',9,1,'MARENOSTRUM4',30267393,'',1,147,0.0,0.0,'a01a_20000101_fc0_9_HETJOB.20230927103808.out','a01a_20000101_fc0_9_HETJOB.20230927103808.err',2,'a01a_20000101_fc0_10_HETJOB',replace('                 30267393  COMPLETED          1        1 2023-09-27T10:36:47 2023-09-27T10:37:58 2023-09-27T10:38:09            871                                                     \n           30267393.batch  COMPLETED          1        1 2023-09-27T10:37:58 2023-09-27T10:37:58 2023-09-27T10:38:09            633                     1149K                     1149K \n          30267393.extern  COMPLETED          1        1 2023-09-27T10:37:58 2023-09-27T10:37:58 2023-09-27T10:38:09            871                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(80,25,'a01a_20000101_fc0_10_HETJOB','2023-09-27-10:38:32','2023-09-27-10:39:53',1695803912,1695803982,1695803987,'COMPLETED',2,1,'00:30','debug',0,'2000-01-01 00:00:00','HETJOB','fc0',10,1,'MARENOSTRUM4',30267411,'',0,147,0.0,0.0,'a01a_20000101_fc0_10_HETJOB.20230927103952.out','a01a_20000101_fc0_10_HETJOB.20230927103952.err',5,'','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',147);
INSERT INTO sqlite_sequence VALUES('job_data',80);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
