PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-09-21-09:39:13','2023-09-21-09:40:11',1695281953,1695282011,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"LOCAL": {"TYPE": "ps", "HOST": "<LOCAL_HOST>", "USER": "<USER>", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "<LOCAL_SCRATCH_DIR>"}, "REMOTE": {"TYPE": "ps", "HOST": "<REMOTE_HOST>", "USER": "<USER>", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "<REMOTE_SCRATCH_DIR>"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(2,'2023-09-21-09:40:11','2023-09-21-09:41:56',1695282011,1695282116,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"LOCAL": {"TYPE": "ps", "HOST": "<LOCAL_HOST>", "USER": "<USER>", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "<LOCAL_SCRATCH_DIR>"}, "REMOTE": {"TYPE": "ps", "HOST": "<REMOTE_HOST>", "USER": "<USER>", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "<REMOTE_SCRATCH_DIR>"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(3,'2023-09-21-09:41:56','2023-09-21-09:46:20',1695282116,1695282380,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"LOCAL": {"TYPE": "ps", "HOST": "<LOCAL_HOST>", "USER": "<USER>", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "<LOCAL_SCRATCH_DIR>"}, "REMOTE": {"TYPE": "ps", "HOST": "<REMOTE_HOST>", "USER": "<USER>", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "<REMOTE_SCRATCH_DIR>"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(4,'2023-09-21-09:46:20','2023-09-21-09:47:59',1695282380,1695282479,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "<REMOTE_HOST>", "USER": "<USER>", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "<REMOTE_SCRATCH_DIR>"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(5,'2023-09-21-09:47:59','2023-09-21-10:04:45',1695282479,1695283485,'year',1,0,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(6,'2023-09-21-10:04:45','2023-09-21-10:04:53',1695283485,1695283493,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(7,'2023-09-21-10:04:53','2023-09-21-10:08:07',1695283493,1695283687,'year',1,0,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(8,'2023-09-21-10:08:07','2023-09-21-10:10:05',1695283687,1695283805,'year',1,0,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(9,'2023-09-21-10:10:05','2023-09-21-10:10:20',1695283805,1695283820,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(10,'2023-09-21-10:10:20','2023-09-21-10:10:21',1695283820,1695283821,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(11,'2023-09-21-10:10:21','2023-09-21-10:10:59',1695283821,1695283859,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(12,'2023-09-21-10:10:59','2023-09-21-10:11:00',1695283859,1695283860,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(13,'2023-09-21-10:11:00','2023-09-21-10:13:22',1695283860,1695284002,'year',1,0,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(14,'2023-09-21-10:13:22','2023-09-21-10:14:17',1695284002,1695284057,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(15,'2023-09-21-10:14:17','2023-09-21-10:14:19',1695284057,1695284059,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(16,'2023-09-21-10:14:19','2023-09-21-10:14:44',1695284059,1695284084,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(17,'2023-09-21-10:14:44','2023-09-21-10:14:46',1695284084,1695284086,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(18,'2023-09-21-10:14:46','2023-09-21-10:15:13',1695284086,1695284113,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(19,'2023-09-21-10:15:13','2023-09-21-10:15:15',1695284113,1695284115,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(20,'2023-09-21-10:15:15','2023-09-21-10:15:51',1695284115,1695284151,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(21,'2023-09-21-10:15:51','2023-09-21-10:15:52',1695284151,1695284152,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(22,'2023-09-21-10:15:52','2023-09-21-10:26:19',1695284152,1695284779,'year',1,1,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "master", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(23,'2023-09-21-10:26:19','2023-09-21-10:27:52',1695284779,1695284872,'year',1,1,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/bsc32/bsc32070"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(24,'2023-09-21-10:27:52','2023-09-21-10:35:55',1695284872,1695285355,'year',1,1,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/bsc32/bsc32070"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(25,'2023-09-21-10:35:55','2023-09-21-10:37:54',1695285355,1695285474,'year',1,1,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/bsc32/bsc32070"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(26,'2023-09-21-10:37:54','2023-09-21-10:43:05',1695285474,1695285785,'year',1,1,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(27,'2023-09-21-10:43:05','2023-09-21-10:48:12',1695285785,1695286092,'year',1,1,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(28,'2023-09-21-10:48:12','2023-09-21-10:49:02',1695286092,1695286142,'year',1,1,8,0,0,0,1,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran", "DISABLE_RECOVERY_THREADS": true}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(29,'2023-09-21-10:49:02','2023-09-21-11:09:14',1695286142,1695287354,'year',1,1,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran", "DISABLE_RECOVERY_THREADS": "True"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(30,'2023-09-21-11:09:14','2023-09-21-12:34:05',1695287354,1695292445,'year',1,7,8,1,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrate"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(31,'2023-09-21-12:34:05','2023-09-21-12:35:18',1695292445,1695292518,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(32,'2023-09-21-12:35:18','2023-09-21-12:37:16',1695292518,1695292636,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(33,'2023-09-21-12:37:16','2023-09-21-14:14:36',1695292636,1695298476,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(34,'2023-09-21-14:14:36','2023-09-21-14:18:20',1695298476,1695298700,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(35,'2023-09-21-14:18:20','2023-09-21-14:19:09',1695298700,1695298749,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(36,'2023-09-21-14:19:09','2023-09-21-14:25:48',1695298749,1695299148,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(37,'2023-09-21-14:25:48','2023-09-21-14:59:38',1695299148,1695301178,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(38,'2023-09-21-14:59:39','2023-09-21-15:02:28',1695301179,1695301348,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(39,'2023-09-21-15:02:28','2023-09-21-15:07:20',1695301348,1695301640,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(40,'2023-09-21-15:07:20','2023-09-21-15:09:45',1695301640,1695301785,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(41,'2023-09-21-15:09:45','2023-09-21-15:16:09',1695301785,1695302169,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(42,'2023-09-21-15:16:09','2023-09-21-15:18:18',1695302169,1695302298,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(43,'2023-09-21-15:18:18','2023-09-21-15:23:47',1695302298,1695302627,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(44,'2023-09-21-15:23:47','2023-09-21-15:25:10',1695302627,1695302710,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(45,'2023-09-21-15:25:10','2023-09-21-15:26:06',1695302710,1695302766,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(46,'2023-09-21-15:26:06','2023-09-21-15:28:01',1695302766,1695302881,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(47,'2023-09-21-15:28:01','2023-09-21-15:29:03',1695302881,1695302943,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(48,'2023-09-21-15:29:03','2023-09-21-15:30:15',1695302943,1695303015,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(49,'2023-09-21-15:30:15','2023-09-21-15:30:44',1695303015,1695303044,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(50,'2023-09-21-15:30:44','2023-09-21-15:32:00',1695303044,1695303120,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(51,'2023-09-21-15:32:00','2023-09-21-15:32:38',1695303120,1695303158,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(52,'2023-09-21-15:32:38','2023-09-21-15:33:36',1695303158,1695303216,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(53,'2023-09-21-15:33:36','2023-09-21-15:34:40',1695303216,1695303280,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(54,'2023-09-21-15:34:40','2023-09-21-15:36:17',1695303280,1695303377,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(55,'2023-09-21-15:36:17','2023-09-21-15:37:17',1695303377,1695303437,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(56,'2023-09-21-15:37:17','2023-09-21-15:38:41',1695303437,1695303521,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(57,'2023-09-21-15:38:41','2023-09-21-15:40:15',1695303521,1695303615,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(58,'2023-09-21-15:40:15','2023-09-21-15:44:30',1695303615,1695303870,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(59,'2023-09-21-15:44:30','2023-09-21-15:46:11',1695303870,1695303971,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(60,'2023-09-21-15:46:11','2023-09-21-15:46:11',1695303971,0,'year',1,0,8,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a01f", "HPCARCH": "remote", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01f/proj/git_project/conf/bootstrap"}, "EXPERIMENT": {"DATELIST": "19910101 19930101", "CALENDAR": "standard", "CHUNKSIZE": 0, "NUMCHUNKS": 0, "CHUNKSIZEUNIT": "year", "MEMBERS": "fc0"}, "JOBS": {"SYNC_TO_REMOTE": {"FILE": "templates/sync_to_remote.sh", "PLATFORM": "local", "RUNNING": "once", "TITLE": "Synchronize local data to remote platform", "DOC": "This task synchronizes the local files with\nthe remote platform. More specifically, it\nwill `scp` the singularity image.\n", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_TO_REMOTE": {}}, "TITLE": "Remote setup", "DOC": "This task will fetch the test domain data\nfor mHM from their Git tag.\n", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "TITLE": "Simulation", "DOC": "This is the main task of the workflow. It\nwill replace the period dates in the test\nmhm.nml creating a new file to be used in\nthe simulation with mHM (--nml).\n", "ADDITIONAL_FILES": []}, "GRAPH": {"FILE": "templates/graph.sh", "PLATFORM": "remote", "RUNNING": "date", "DEPENDENCIES": {"SIM": {}, "SIM-1": {}}, "TITLE": "Plot graph", "DOC": "This is the step in the simulation, where\nwe plot the graphs for mHM.\n", "ADDITIONAL_FILES": []}, "SYNC_FROM_REMOTE": {"FILE": "templates/sync_from_remote.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"GRAPH": {}}, "TITLE": "Synchronize remote data to local platform", "DOC": "This task copies remote data produced by mHM\nto the local platform.\n", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "PLATFORM": "remote", "RUNNING": "once", "DEPENDENCIES": {"SYNC_FROM_REMOTE": {}}, "TITLE": "Clean remote files", "DOC": "The very final step. It will stop and clean\nthe containers used for this simulation. It\nwill also delete the output files of mHM.\n", "ADDITIONAL_FILES": []}}, "MHM": {"BRANCH_NAME": "develop", "DOMAIN": 1, "EVAL_PERIOD_DURATION_YEARS": 2}, "PLATFORMS": {"REMOTE": {"TYPE": "ps", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/home/dbeltran/rocrateZZ"}}, "ROCRATE": {"INPUTS": ["MHM"], "OUTPUTS": ["*/*.gif"], "PATCH": "{\n  \"@graph\": [\n    {\n      \"@id\": \"./\",\n      \"license\": \"Apache-2.0\",\n      \"creator\": {\n        \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n      },\n      \"publisher\": {\n        \"@id\": \"https://ror.org/05sd8tv96\"\n      }\n    },\n    {\n      \"@id\": \"#create-action\",\n      \"@type\": \"CreateAction\",\n      \"name\": \"Run mHM\",\n      \"instrument\": { \"@id\": \"workflow.yml\" },\n      \"agent\": { \"@id\": \"https://orcid.org/0000-0001-8250-4074\" }\n    },\n    {\n      \"@id\": \"ro-crate-metadata.json\",\n      \"author\": [\n        {\n          \"@id\": \"https://orcid.org/0000-0001-8250-4074\"\n        }\n      ]\n    },\n    {\n      \"@id\": \"https://orcid.org/0000-0001-8250-4074\",\n      \"@type\": \"Person\",\n      \"affiliation\": {\n          \"@id\": \"https://ror.org/05sd8tv96\"\n      },\n      \"contactPoint\": {\n          \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\"\n      },\n      \"name\": \"Bruno P. Kinoshita\"\n    },\n    {\n        \"@id\": \"mailto: bruno.depaulakinoshita@bsc.es\",\n        \"@type\": \"ContactPoint\",\n        \"contactType\": \"Author\",\n        \"email\": \"bruno.depaulakinoshita@bsc.es\",\n        \"identifier\": \"bruno.depaulakinoshita@bsc.es\",\n        \"url\": \"https://orcid.org/0000-0001-8250-4074\"\n    },\n    {\n        \"@id\": \"https://ror.org/05sd8tv96\",\n        \"@type\": \"Organization\",\n        \"name\": \"Barcelona Supercomputing Center\"\n    }\n  ]\n}\n"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01f", "PROJDIR": "/home/dbeltran/new_autosubmit/a01f/proj/project_files", "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://github.com/kinow/auto-mhm-test-domains.git", "PROJECT_BRANCH": "fb57531b52b1e2a2dbd6a1c53a64c954fcca4e5d", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a01f_SYNC_TO_REMOTE','2023-09-21-09:48:04','2023-09-21-10:04:59',1695282484,1695282484,1695282556,'FAILED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',21782,'',0,5,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921094916.out','a01f_SYNC_TO_REMOTE.20230921094916.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(2,1,'a01f_SYNC_TO_REMOTE','2023-09-21-10:04:59','2023-09-21-10:08:10',1695283499,1695283499,1695283571,'FAILED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',22768,'',0,7,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921100611.out','a01f_SYNC_TO_REMOTE.20230921100611.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(3,2,'a01f_SYNC_TO_REMOTE','2023-09-21-10:08:10','2023-09-21-10:10:08',1695283690,1695283690,1695283762,'FAILED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',22912,'',0,8,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921100922.out','a01f_SYNC_TO_REMOTE.20230921100922.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(4,3,'a01f_SYNC_TO_REMOTE','2023-09-21-10:10:08','2023-09-21-10:10:22',1695283808,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',23099,'',0,9,0.0,0.0,'','',0,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(5,4,'a01f_SYNC_TO_REMOTE','2023-09-21-10:10:22','2023-09-21-10:11:01',1695283822,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',23157,'',0,11,0.0,0.0,'','',0,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(6,5,'a01f_SYNC_TO_REMOTE','2023-09-21-10:11:01','2023-09-21-10:13:25',1695283861,1695283861,1695283933,'FAILED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',23231,'',0,13,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921101213.out','a01f_SYNC_TO_REMOTE.20230921101213.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(7,6,'a01f_SYNC_TO_REMOTE','2023-09-21-10:13:25','2023-09-21-10:14:20',1695284005,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',23418,'',0,14,0.0,0.0,'','',0,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(8,7,'a01f_SYNC_TO_REMOTE','2023-09-21-10:14:20','2023-09-21-10:14:47',1695284060,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',23530,'',0,16,0.0,0.0,'','',0,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(9,8,'a01f_SYNC_TO_REMOTE','2023-09-21-10:14:47','2023-09-21-10:15:16',1695284087,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',23591,'',0,18,0.0,0.0,'','',0,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(10,9,'a01f_SYNC_TO_REMOTE','2023-09-21-10:15:16','2023-09-21-10:15:53',1695284116,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',23658,'',0,20,0.0,0.0,'','',0,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(11,10,'a01f_SYNC_TO_REMOTE','2023-09-21-10:15:53','2023-09-21-10:26:22',1695284153,1695284153,1695284154,'COMPLETED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',23730,'',0,22,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921101605.out','a01f_SYNC_TO_REMOTE.20230921101605.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(12,10,'a01f_REMOTE_SETUP','2023-09-21-10:16:06','2023-09-21-10:26:35',1695284166,1695284166,1695284178,'FAILED',2,1,'00:00','debug',0,'','REMOTE_SETUP','',0,0,'REMOTE',43300,'',0,22,0.0,0.0,'a01f_REMOTE_SETUP.20230921101618.out','a01f_REMOTE_SETUP.20230921101618.err',5,'a01f_19910101_SIM,a01f_19930101_SIM','');
INSERT INTO job_data VALUES(13,11,'a01f_SYNC_TO_REMOTE','2023-09-21-10:26:22','2023-09-21-10:27:54',1695284782,1695284782,1695284783,'COMPLETED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',24451,'',0,23,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921102634.out','a01f_SYNC_TO_REMOTE.20230921102634.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(14,11,'a01f_REMOTE_SETUP','2023-09-21-10:26:35','2023-09-21-10:28:07',1695284795,1695284795,1695284807,'FAILED',2,1,'00:00','debug',0,'','REMOTE_SETUP','',0,0,'REMOTE',26557,'',0,23,0.0,0.0,'a01f_REMOTE_SETUP.20230921102647.out','a01f_REMOTE_SETUP.20230921102647.err',5,'a01f_19910101_SIM,a01f_19930101_SIM','');
INSERT INTO job_data VALUES(15,12,'a01f_SYNC_TO_REMOTE','2023-09-21-10:27:54','2023-09-21-10:35:57',1695284874,1695284874,1695284875,'COMPLETED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',24613,'',0,24,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921102806.out','a01f_SYNC_TO_REMOTE.20230921102806.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(16,12,'a01f_REMOTE_SETUP','2023-09-21-10:28:07','2023-09-21-10:36:10',1695284887,1695284887,1695284899,'FAILED',2,1,'00:00','debug',0,'','REMOTE_SETUP','',0,0,'REMOTE',34041,'',0,24,0.0,0.0,'a01f_REMOTE_SETUP.20230921102819.out','a01f_REMOTE_SETUP.20230921102819.err',5,'a01f_19910101_SIM,a01f_19930101_SIM','');
INSERT INTO job_data VALUES(17,13,'a01f_SYNC_TO_REMOTE','2023-09-21-10:35:57','2023-09-21-10:37:56',1695285357,1695285357,1695285357,'COMPLETED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',27445,'',0,25,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921103609.out','a01f_SYNC_TO_REMOTE.20230921103609.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(18,13,'a01f_REMOTE_SETUP','2023-09-21-10:36:10','2023-09-21-10:38:08',1695285370,1695285369,1695285382,'FAILED',2,1,'00:00','debug',0,'','REMOTE_SETUP','',0,0,'REMOTE',7166,'',0,25,0.0,0.0,'a01f_REMOTE_SETUP.20230921103622.out','a01f_REMOTE_SETUP.20230921103622.err',5,'a01f_19910101_SIM,a01f_19930101_SIM','');
INSERT INTO job_data VALUES(19,14,'a01f_SYNC_TO_REMOTE','2023-09-21-10:37:56','2023-09-21-10:43:07',1695285476,1695285476,1695285476,'COMPLETED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',27879,'',0,26,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921103808.out','a01f_SYNC_TO_REMOTE.20230921103808.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(20,14,'a01f_REMOTE_SETUP','2023-09-21-10:38:08','2023-09-21-10:43:20',1695285488,1695285488,1695285500,'FAILED',2,1,'00:00','debug',0,'','REMOTE_SETUP','',0,0,'REMOTE',27996,'',0,26,0.0,0.0,'a01f_REMOTE_SETUP.20230921103820.out','a01f_REMOTE_SETUP.20230921103820.err',5,'a01f_19910101_SIM,a01f_19930101_SIM','');
INSERT INTO job_data VALUES(21,15,'a01f_SYNC_TO_REMOTE','2023-09-21-10:43:07','2023-09-21-10:48:14',1695285787,1695285787,1695285788,'COMPLETED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',30394,'',0,27,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921104319.out','a01f_SYNC_TO_REMOTE.20230921104319.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(22,15,'a01f_REMOTE_SETUP','2023-09-21-10:43:20','2023-09-21-10:48:26',1695285800,1695285800,1695285812,'FAILED',2,1,'00:00','debug',0,'','REMOTE_SETUP','',0,0,'REMOTE',30522,'',0,27,0.0,0.0,'a01f_REMOTE_SETUP.20230921104332.out','a01f_REMOTE_SETUP.20230921104332.err',5,'a01f_19910101_SIM,a01f_19930101_SIM','');
INSERT INTO job_data VALUES(23,16,'a01f_SYNC_TO_REMOTE','2023-09-21-10:48:14','2023-09-21-10:49:04',1695286094,1695286094,1695286094,'COMPLETED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',31346,'',0,28,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921104826.out','a01f_SYNC_TO_REMOTE.20230921104826.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(24,16,'a01f_REMOTE_SETUP','2023-09-21-10:48:26','2023-09-21-10:49:16',1695286106,1695286106,0,'FAILED',2,1,'00:00','debug',0,'','REMOTE_SETUP','',0,0,'REMOTE',31463,'',0,28,0.0,0.0,'','',0,'a01f_19910101_SIM,a01f_19930101_SIM','');
INSERT INTO job_data VALUES(25,17,'a01f_SYNC_TO_REMOTE','2023-09-21-10:49:04','2023-09-21-11:09:16',1695286144,1695286144,1695286144,'COMPLETED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,0,'LOCAL',31674,'',0,29,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921104916.out','a01f_SYNC_TO_REMOTE.20230921104916.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(26,17,'a01f_REMOTE_SETUP','2023-09-21-10:49:16','2023-09-21-11:09:28',1695286156,1695286156,1695286168,'FAILED',2,1,'00:00','debug',0,'','REMOTE_SETUP','',0,0,'REMOTE',31783,'',0,29,0.0,0.0,'a01f_REMOTE_SETUP.20230921104928.out','a01f_REMOTE_SETUP.20230921104928.err',5,'a01f_19910101_SIM,a01f_19930101_SIM','');
INSERT INTO job_data VALUES(27,18,'a01f_SYNC_TO_REMOTE','2023-09-21-11:09:16','2023-09-21-11:09:28',1695287356,1695287356,1695287356,'COMPLETED',2,1,'00:00','debug',0,'','SYNC_TO_REMOTE','',0,1,'LOCAL',39024,'',0,30,0.0,0.0,'a01f_SYNC_TO_REMOTE.20230921110928.out','a01f_SYNC_TO_REMOTE.20230921110928.err',5,'a01f_REMOTE_SETUP','');
INSERT INTO job_data VALUES(28,18,'a01f_REMOTE_SETUP','2023-09-21-11:09:28','2023-09-21-11:09:53',1695287368,1695287368,1695287383,'COMPLETED',2,1,'00:00','debug',0,'','REMOTE_SETUP','',0,1,'REMOTE',39105,'',0,30,0.0,0.0,'a01f_REMOTE_SETUP.20230921110940.out','a01f_REMOTE_SETUP.20230921110940.err',5,'a01f_19910101_SIM,a01f_19930101_SIM','');
INSERT INTO job_data VALUES(29,18,'a01f_19910101_SIM','2023-09-21-11:09:53','2023-09-21-11:29:11',1695287393,1695287393,1695288545,'COMPLETED',2,1,'00:00','debug',0,'1991-01-01 00:00:00','SIM','',0,1,'REMOTE',39904,'',0,30,0.0,0.0,'a01f_19910101_SIM.20230921111007.out','a01f_19910101_SIM.20230921111007.err',5,'a01f_19910101_GRAPH','');
INSERT INTO job_data VALUES(30,18,'a01f_19930101_SIM','2023-09-21-11:09:53','2023-09-21-11:29:11',1695287393,1695287393,1695288544,'COMPLETED',2,1,'00:00','debug',0,'1993-01-01 00:00:00','SIM','',0,1,'REMOTE',39953,'',0,30,0.0,0.0,'a01f_19930101_SIM.20230921111007.out','a01f_19930101_SIM.20230921111007.err',5,'a01f_19930101_GRAPH','');
INSERT INTO job_data VALUES(31,18,'a01f_19910101_GRAPH','2023-09-21-11:29:11','2023-09-21-11:29:25',1695288551,1695288551,1695288560,'COMPLETED',2,1,'00:00','debug',0,'1991-01-01 00:00:00','GRAPH','',0,1,'REMOTE',41204,'',0,30,0.0,0.0,'a01f_19910101_GRAPH.20230921112925.out','a01f_19910101_GRAPH.20230921112925.err',5,'a01f_SYNC_FROM_REMOTE','');
INSERT INTO job_data VALUES(32,18,'a01f_19930101_GRAPH','2023-09-21-11:29:11','2023-09-21-11:29:25',1695288551,1695288551,1695288555,'COMPLETED',2,1,'00:00','debug',0,'1993-01-01 00:00:00','GRAPH','',0,1,'REMOTE',41256,'',0,30,0.0,0.0,'a01f_19930101_GRAPH.20230921112925.out','a01f_19930101_GRAPH.20230921112925.err',5,'a01f_SYNC_FROM_REMOTE','');
INSERT INTO job_data VALUES(33,18,'a01f_SYNC_FROM_REMOTE','2023-09-21-11:29:25','2023-09-21-11:29:37',1695288565,1695288565,1695288566,'COMPLETED',2,1,'00:00','debug',0,'','SYNC_FROM_REMOTE','',0,1,'LOCAL',41597,'',0,30,0.0,0.0,'a01f_SYNC_FROM_REMOTE.20230921112937.out','a01f_SYNC_FROM_REMOTE.20230921112937.err',5,'a01f_CLEAN','');
INSERT INTO job_data VALUES(34,18,'a01f_CLEAN','2023-09-21-11:29:37','2023-09-21-11:29:50',1695288577,1695288590,1695288590,'FAILED',2,1,'00:00','debug',0,'','CLEAN','',0,1,'REMOTE',41970,'',0,30,0.0,0.0,'a01f_CLEAN.20230921112950.out','a01f_CLEAN.20230921112950.err',5,'','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',60);
INSERT INTO sqlite_sequence VALUES('job_data',34);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
