PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-08-10-10:39:16','2023-08-10-10:50:34',1691656756,1691657434,'day',1,0,9,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a07q", "HPCARCH": "LUMI", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/bootstrap/"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI-login", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "ADDITIONAL_FILES": ["templates/namelists/fort.4", "templates/namelists/namelist_ref", "templates/namelists/namelist_ice_ref"]}, "SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(2,'2023-08-10-10:50:34','2023-08-10-10:59:30',1691657434,1691657970,'day',1,0,5,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a07q", "HPCARCH": "LUMI", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/bootstrap/"}, "JOBS": {"SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(3,'2023-08-10-10:59:30','2023-08-10-11:05:52',1691657970,1691658352,'day',1,0,5,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a07q", "HPCARCH": "LUMI", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/bootstrap/"}, "JOBS": {"SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(4,'2023-08-10-11:05:52','2023-08-10-11:37:06',1691658352,1691660226,'day',1,0,5,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a07q", "HPCARCH": "LUMI", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/bootstrap/"}, "JOBS": {"SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(5,'2023-08-10-11:37:06','2023-08-10-11:50:05',1691660226,1691661005,'day',1,0,5,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/bootstrap/"}, "JOBS": {"SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "MARENOSTRUM4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(6,'2023-08-10-11:50:05','2023-08-10-11:50:35',1691661005,1691661035,'day',1,0,5,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/bootstrap/"}, "JOBS": {"SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "MARENOSTRUM4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(7,'2023-08-10-11:50:35','2023-08-10-11:51:08',1691661035,1691661068,'day',1,0,5,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/bootstrap/"}, "JOBS": {"SIM": {"FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "MARENOSTRUM4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PARTITION": "debug", "PROCESSORS": 1024, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "NODES": 1, "TASKS": 48, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug", "WALLCLOCK": "00:30", "NODES": 1, "TASKS": 48, "PROCESSORS": 48}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30", "NODES": 3, "TASKS": 16, "THREADS": 8, "PROCESSORS": 48}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "SIMULATION": {"TYPE": "coupled", "CLIMATE_RESTART": "none", "OCEAN_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_2020"}, "EXPERIMENT": {"DATELIST": 2020012000, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git", "BRANCH": "RAPS_de340", "NAME": "ifs-nemo"}, "CONFIGURATION": {"IFS": {"GTYPE": "tco", "RESOL": 79, "LEVELS": 137, "EXPVER": "hz9m", "LABEL": "LWDA", "XPROC": 4, "YPROC": 4, "IO_NODES": 1, "NEMO_SERVER_NUM": 8}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.87", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(8,'2023-08-10-11:51:08','2023-08-10-11:52:06',1691661068,1691661126,'month',4,0,0,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/"}');
INSERT INTO experiment_run VALUES(9,'2023-08-10-11:52:06','2023-08-10-11:52:39',1691661126,1691661159,'month',4,0,0,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "LUMI": {"TYPE": "slurm", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30", "HOST": "bsc"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "JOBS": {"SIM": {"WALLCLOCK": "00:10", "RETRIALS": "2", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/"}');
INSERT INTO experiment_run VALUES(10,'2023-08-10-11:52:39','2023-08-10-11:53:04',1691661159,1691661184,'month',4,0,0,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "LUMI": {"TYPE": "slurm", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30", "HOST": "bsc"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "JOBS": {"SIM": {"WALLCLOCK": "00:10", "RETRIALS": "2", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/"}');
INSERT INTO experiment_run VALUES(11,'2023-08-10-11:53:04','2023-08-10-11:54:01',1691661184,1691661241,'month',4,0,0,0,0,0,0,0,'{"DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "marenostrum4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/"}');
INSERT INTO experiment_run VALUES(12,'2023-08-10-11:54:01','2023-08-10-11:54:13',1691661241,1691661253,'month',4,0,0,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "MARENOSTRUM4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "TEMP_DIR": ""}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "ps", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "PARTITION": "compute", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/"}}');
INSERT INTO experiment_run VALUES(13,'2023-08-10-11:54:13','2023-08-10-11:54:25',1691661253,1691661265,'month',4,0,1,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "MARENOSTRUM4", "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "TEMP_DIR": ""}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "ps", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "PARTITION": "compute", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/"}}');
INSERT INTO experiment_run VALUES(14,'2023-08-10-11:54:25','2023-08-10-11:54:35',1691661265,1691661275,'month',2,0,0,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "MARENOSTRUM4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "TEMP_DIR": ""}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "ps", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "PARTITION": "compute", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/"}}');
INSERT INTO experiment_run VALUES(15,'2023-08-10-11:54:35','2023-08-10-11:58:49',1691661275,1691661529,'month',2,4,4,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "MARENOSTRUM4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "TEMP_DIR": ""}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "ps", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "PARTITION": "compute", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/"}}');
INSERT INTO experiment_run VALUES(16,'2023-08-10-11:58:49','2023-08-10-12:00:02',1691661529,1691661602,'month',2,0,4,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "MARENOSTRUM4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(17,'2023-08-10-12:00:02','2023-08-10-12:01:34',1691661602,1691661694,'month',2,0,4,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "MARENOSTRUM4", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(18,'2023-08-10-12:01:34','2023-08-10-12:14:01',1691661694,1691662441,'month',2,0,4,1,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(19,'2023-08-10-12:14:01','2023-08-10-12:35:34',1691662441,1691663734,'month',2,0,4,1,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(20,'2023-08-10-12:35:34','2023-08-10-12:35:57',1691663734,1691663757,'month',2,0,4,1,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "2", "NUMCHUNKS": "4", "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(21,'2023-08-10-12:35:57','2023-08-10-14:21:20',1691663757,1691670080,'month',2,0,4,0,3,1,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(22,'2023-08-10-14:21:20','2023-08-10-14:21:44',1691670080,1691670104,'month',2,0,4,0,3,1,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "2", "NUMCHUNKS": "4", "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(23,'2023-08-10-14:21:44','2023-08-10-14:22:14',1691670104,1691670134,'month',2,0,4,0,3,1,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "2", "NUMCHUNKS": "4", "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(24,'2023-08-10-14:22:14','2023-08-10-14:33:57',1691670134,1691670837,'month',2,0,4,0,3,1,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(25,'2023-08-10-14:33:57','2023-08-10-14:34:05',1691670837,1691670845,'month',2,0,4,0,3,1,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "2", "NUMCHUNKS": "4", "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(26,'2023-08-10-14:34:05','2023-08-10-14:37:57',1691670845,1691671077,'month',2,0,4,0,3,1,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "2", "NUMCHUNKS": "4", "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(27,'2023-08-10-14:37:57','2023-08-10-14:40:32',1691671077,1691671232,'month',2,0,4,0,0,0,4,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "RETRIALS": "2", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "2", "NUMCHUNKS": "4", "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(28,'2023-08-10-14:40:32','2023-08-10-14:55:29',1691671232,1691672129,'month',2,0,4,0,0,0,4,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "2", "NUMCHUNKS": "4", "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(29,'2023-08-10-14:55:29','2023-08-10-15:11:53',1691672129,1691673113,'month',2,0,4,1,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "2", "NUMCHUNKS": "4", "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(30,'2023-08-10-15:11:53','2023-08-10-15:18:30',1691673113,1691673510,'month',2,0,4,1,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(31,'2023-08-10-15:18:30','2023-08-10-15:18:41',1691673510,1691673521,'month',2,0,4,1,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": "0", "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "2", "NUMCHUNKS": "4", "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(32,'2023-08-10-15:18:41','2023-08-10-15:26:52',1691673521,1691674012,'month',2,0,4,1,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(33,'2023-08-10-15:26:52','2023-08-10-15:59:19',1691674012,1691675959,'month',2,0,4,1,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(34,'2023-08-10-15:59:19','2023-08-10-16:02:54',1691675959,1691676174,'month',2,0,4,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(35,'2023-08-10-16:02:54','2023-08-11-09:32:54',1691676174,1691739174,'month',2,0,4,0,3,1,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(36,'2023-08-11-09:32:54','2023-08-11-09:35:10',1691739174,1691739310,'month',2,0,4,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(37,'2023-08-11-09:35:10','2023-08-11-09:51:10',1691739310,1691740270,'month',2,0,4,1,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(38,'2023-08-11-09:51:10','2023-08-11-10:01:45',1691740270,1691740905,'month',2,0,4,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(39,'2023-08-11-10:01:45','2023-08-11-14:05:45',1691740905,1691755545,'month',2,0,4,1,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(40,'2023-08-11-14:05:45','2023-09-07-08:02:14',1691755545,1694066534,'month',2,0,4,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:10", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.87", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(41,'2023-09-07-08:02:14','2023-09-07-08:03:01',1694066534,1694066581,'month',2,0,4,0,0,0,0,0,'{"JOBS": {"SIM": {"FILE": "conf/templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "48:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(42,'2023-09-07-08:03:01','2023-09-07-08:20:03',1694066581,1694067603,'month',2,0,0,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "JOBS": {"SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(43,'2023-09-07-08:20:03','2023-09-07-08:20:47',1694067603,1694067647,'month',2,0,40,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 2, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 10, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"DN_100U": {"SPLITS": "12", "SPLITS_FROM": "{1"}, "DN_100V": {"SPLITS": "6", "SPLITS_FROM": "2"}, "DN_2T": {"SPLITS": "24", "SPLITS_FROM": "3: {SPLITS_TO: [1:3]*}}"}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(44,'2023-09-07-08:20:47','2023-09-07-08:45:40',1694067647,1694069140,'month',1,0,10,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 10, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"DN_100U": {"SPLITS": "12", "SPLITS_FROM": "{1"}, "DN_100V": {"SPLITS": "6", "SPLITS_FROM": "2"}, "DN_2T": {"SPLITS": "24", "SPLITS_FROM": "3: {SPLITS_TO: [1:3]*}}"}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(45,'2023-09-07-08:45:40','2023-09-07-08:48:39',1694069140,1694069319,'month',1,0,40,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 10, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 10, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100V": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 10, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 10, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"DN_100U": {"SPLITS": "12", "SPLITS_FROM": {"1,2,3": {"SPLITS_TO": "[1:3]*"}}}, "DN_100V": {"SPLITS": "6", "SPLITS_FROM": {"4,5,6": {"SPLITS_TO": "[4:6]*"}}}, "DN_2T": {"SPLITS": "24", "SPLITS_FROM": {"7,8,9": {"SPLITS_TO": "[7:9]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(46,'2023-09-07-08:48:39','2023-09-07-08:49:54',1694069319,1694069394,'month',1,0,28,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 10, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 3, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100V": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 6, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 9, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2,3": {"SPLITS_TO": "[1:3]*"}}}, "DN_100V": {"SPLITS_FROM": {"4,5,6": {"SPLITS_TO": "[4:6]*"}}}, "DN_2T": {"SPLITS_FROM": {"7,8,9": {"SPLITS_TO": "[7:9]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(47,'2023-09-07-08:49:54','2023-09-07-08:51:14',1694069394,1694069474,'month',1,0,28,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 10, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 3, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100V": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 6, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 9, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2,3": {"SPLITS_TO": "[1:3]*"}}}, "DN_100V": {"SPLITS_FROM": {"4,5,6": {"SPLITS_TO": "[4:6]*"}}}, "DN_2T": {"SPLITS_FROM": {"7,8,9": {"SPLITS_TO": "[7:9]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(48,'2023-09-07-08:51:14','2023-09-07-08:51:30',1694069474,1694069490,'month',1,0,28,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 10, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 3, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100V": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 6, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 9, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SPLITS": 10, "DN_100U": {"SPLITS_FROM": {"1,2,3": {"SPLITS_TO": "[1:3]*"}}}, "DN_100V": {"SPLITS_FROM": {"4,5,6": {"SPLITS_TO": "[4:6]*"}}}, "DN_2T": {"SPLITS_FROM": {"7,8,9": {"SPLITS_TO": "[7:9]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(49,'2023-09-07-08:51:30','2023-09-07-08:52:04',1694069490,1694069524,'month',1,0,38,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 10, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 3, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100V": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 6, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 9, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2,3": {"SPLITS_TO": "[1:3]*"}}}, "DN_100V": {"SPLITS_FROM": {"4,5,6": {"SPLITS_TO": "[4:6]*"}}}, "DN_2T": {"SPLITS_FROM": {"7,8,9": {"SPLITS_TO": "[7:9]*"}}}}, "SPLITS": 10, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(50,'2023-09-07-08:52:04','2023-09-07-08:53:54',1694069524,1694069634,'month',1,0,28,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 3, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100V": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 6, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 9, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2,3": {"SPLITS_TO": "[1:3]*"}}}, "DN_100V": {"SPLITS_FROM": {"4,5,6": {"SPLITS_TO": "[4:6]*"}}}, "DN_2T": {"SPLITS_FROM": {"7,8,9": {"SPLITS_TO": "[7:9]*"}}}}, "SPLITS": 10, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(51,'2023-09-07-08:53:54','2023-09-07-08:54:41',1694069634,1694069681,'month',1,0,13,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100V": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 3, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "[1:2]*"}}}, "DN_100V": {"SPLITS_FROM": {"3": {"SPLITS_TO": "3*"}}}, "DN_2T": {"SPLITS_FROM": {"4": {"SPLITS_TO": "4*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(52,'2023-09-07-08:54:41','2023-09-07-08:56:54',1694069681,1694069814,'month',1,0,9,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100V": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 3, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1*"}}}, "DN_100V": {"SPLITS_FROM": {"2": {"SPLITS_TO": "2*"}}}, "DN_2T": {"SPLITS_FROM": {"3": {"SPLITS_TO": "3*"}}}}, "SPLITS": 3, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(53,'2023-09-07-08:56:55','2023-09-07-08:59:19',1694069815,1694069959,'month',1,0,15,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_100V": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 3, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2,3": {"SPLITS_TO": "1*"}}}, "DN_100V": {"SPLITS_FROM": {"4,5,6": {"SPLITS_TO": "2*"}}}, "DN_2T": {"SPLITS_FROM": {"7,8,9": {"SPLITS_TO": "3*"}}}}, "SPLITS": 9, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(54,'2023-09-07-08:59:19','2023-09-07-09:02:40',1694069959,1694070160,'month',1,0,8,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1*"}}}, "DN_2T": {"SPLITS_FROM": {"3,4": {"SPLITS_TO": "2*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(55,'2023-09-07-09:02:40','2023-09-07-09:02:55',1694070160,1694070175,'month',1,0,8,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}}}, "DN_2T": {"SPLITS_FROM": {"3,4": {"SPLITS_TO": "2"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(56,'2023-09-07-09:02:55','2023-09-07-09:05:23',1694070175,1694070323,'month',1,0,8,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1*"}}}, "DN_2T": {"SPLITS_FROM": {"3,4": {"SPLITS_TO": "2*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(57,'2023-09-07-09:05:23','2023-09-07-09:08:25',1694070323,1694070505,'month',1,0,10,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "[1,2]*"}}}, "DN_2T": {"SPLITS_FROM": {"3,4": {"SPLITS_TO": "[1,2,3,4]*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(58,'2023-09-07-09:08:25','2023-09-07-09:08:38',1694070505,1694070518,'month',1,0,2,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_TEST": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_TEST": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DN_TEST": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "[1,2]*"}, "3,4": {"SPLITS_TO": "[3,4]*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(59,'2023-09-07-09:08:38','2023-09-07-09:08:47',1694070518,1694070527,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_TEST": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_TEST": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DN_TEST": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "[1,2]*"}, "3,4": {"SPLITS_TO": "[3,4]*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(60,'2023-09-07-09:08:47','2023-09-07-09:09:16',1694070527,1694070556,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_TEST": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_TEST": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DN_TEST": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "[1,2]*"}, "3,4": {"SPLITS_TO": "[3,4]*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(61,'2023-09-07-09:09:16','2023-09-07-09:10:15',1694070556,1694070615,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DNTEST": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_TEST": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DNTEST": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "[1,2]*"}, "3,4": {"SPLITS_TO": "[3,4]*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(62,'2023-09-07-09:10:15','2023-09-07-09:10:41',1694070615,1694070641,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DNTEST": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_TEST": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DNTEST": {"SPLITS_FROM": {"[1,2]": {"SPLITS_TO": "[1,2]*"}, "[3,4]": {"SPLITS_TO": "[3,4]*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(63,'2023-09-07-09:10:41','2023-09-07-09:11:07',1694070641,1694070667,'month',1,0,8,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DNTEST": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_TEST": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DNTEST": null}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(64,'2023-09-07-09:11:07','2023-09-07-09:17:35',1694070667,1694071055,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DNTEST": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_TEST": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DNTEST": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "[1,2]*"}, "3,4": {"SPLITS_TO": "[3,4]*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(65,'2023-09-07-09:17:35','2023-09-07-09:17:46',1694071055,1694071066,'month',1,0,8,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DNTEST": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_TEST": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DNTEST": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1,2*"}, "3,4": {"SPLITS_TO": "3,4*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(66,'2023-09-07-09:17:46','2023-09-07-09:18:26',1694071066,1694071106,'month',1,0,8,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DNTEST": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_TEST": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DNTEST": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1*,2*"}, "3,4": {"SPLITS_TO": "3*,4*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(67,'2023-09-07-09:18:26','2023-09-07-09:19:00',1694071106,1694071140,'month',1,0,10,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "[1:2]*"}}}, "DN_2T": {"SPLITS_FROM": {"3,4": {"SPLITS_TO": "[1:4]*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(68,'2023-09-07-09:19:00','2023-09-07-09:35:45',1694071140,1694072145,'month',1,0,8,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN_100U": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN_2T": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "DEPENDENCIES": {"DN_100U": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "[1:2]*"}}}, "DN_2T": {"SPLITS_FROM": {"3,4": {"SPLITS_TO": "[1:2]*"}}}}, "SPLITS": 4, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(69,'2023-09-07-09:35:45','2023-09-07-09:36:00',1694072145,1694072160,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "2", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1,2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "4", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:4]": {"SPLITS_TO": "[1,4]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(70,'2023-09-07-09:36:00','2023-09-07-09:37:32',1694072160,1694072252,'month',1,0,10,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 4, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "2", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "4", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:4]": {"SPLITS_TO": "[1:4]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(71,'2023-09-07-09:37:32','2023-09-07-09:42:27',1694072252,1694072547,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:12]": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:24]": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(72,'2023-09-07-09:42:27','2023-09-07-09:43:10',1694072547,1694072590,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:12]": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:24]": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(73,'2023-09-07-09:43:10','2023-09-07-09:44:30',1694072590,1694072670,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:12]": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:24]": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(74,'2023-09-07-09:44:30','2023-09-07-09:44:48',1694072670,1694072688,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"SPLITS_TO": "[1:12]*"}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"SPLITS_TO": "[1:24]*"}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(75,'2023-09-07-09:44:48','2023-09-07-09:47:04',1694072688,1694072824,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(76,'2023-09-07-09:47:04','2023-09-07-09:47:06',1694072824,1694072826,'month',1,0,26,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "12*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "24*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "HOURLY": 12, "BIHOURLY": 24, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(77,'2023-09-07-09:47:06','2023-09-07-09:47:44',1694072826,1694072864,'month',1,0,26,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "12*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "24*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "HOURLY": 12, "BIHOURLY": 24, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(78,'2023-09-07-09:47:44','2023-09-07-09:49:33',1694072864,1694072973,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "HOURLY": "[1:12]*", "BIHOURLY": "[1:24]*", "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(79,'2023-09-07-09:49:33','2023-09-07-09:51:16',1694072973,1694073076,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "HOURLY": "12", "BIHOURLY": "24", "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(80,'2023-09-07-09:51:16','2023-09-07-10:58:14',1694073076,1694077094,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(81,'2023-09-07-10:58:14','2023-09-07-10:59:22',1694077094,1694077162,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(82,'2023-09-07-10:59:22','2023-09-07-10:59:42',1694077162,1694077182,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(83,'2023-09-07-10:59:42','2023-09-07-11:00:11',1694077182,1694077211,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(84,'2023-09-07-11:00:11','2023-09-07-11:00:31',1694077211,1694077231,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(85,'2023-09-07-11:00:31','2023-09-07-11:02:55',1694077231,1694077375,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(86,'2023-09-07-11:02:55','2023-09-07-11:03:32',1694077375,1694077412,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "all*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(87,'2023-09-07-11:03:32','2023-09-07-11:09:23',1694077412,1694077763,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(88,'2023-09-07-11:09:23','2023-09-07-11:10:15',1694077763,1694077815,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(89,'2023-09-07-11:10:15','2023-09-07-11:10:27',1694077815,1694077827,'month',1,0,38,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(90,'2023-09-07-11:10:27','2023-09-07-11:11:51',1694077827,1694077911,'month',1,0,38,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(91,'2023-09-07-11:11:51','2023-09-07-11:17:16',1694077911,1694078236,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(92,'2023-09-07-11:17:16','2023-09-07-11:18:01',1694078236,1694078281,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(93,'2023-09-07-11:18:01','2023-09-07-11:18:25',1694078281,1694078305,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(94,'2023-09-07-11:18:25','2023-09-07-11:19:12',1694078305,1694078352,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(95,'2023-09-07-11:19:12','2023-09-08-10:08:53',1694078352,1694160533,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.88", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[24,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(96,'2023-09-08-10:08:53','2023-09-08-10:10:27',1694160533,1694160627,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[24,12]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(97,'2023-09-08-10:10:27','2023-09-08-10:11:31',1694160627,1694160691,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[24,12]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(98,'2023-09-08-10:11:31','2023-09-08-10:12:10',1694160691,1694160730,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[24,12]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(99,'2023-09-08-10:12:10','2023-09-08-10:14:16',1694160730,1694160856,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[24,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(100,'2023-09-08-10:14:16','2023-09-08-10:15:46',1694160856,1694160946,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "HOURLY": "12", "BIHOURLY": "24", "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(101,'2023-09-08-10:15:46','2023-09-08-10:16:34',1694160946,1694160994,'month',1,0,49,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": null}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(102,'2023-09-08-10:16:34','2023-09-08-10:19:32',1694160994,1694161172,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(103,'2023-09-08-10:19:32','2023-09-08-10:22:02',1694161172,1694161322,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "SIM": {"WALLCLOCK": "48:00", "DEPENDENCIES": {}, "FILE": "", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(104,'2023-09-08-10:22:02','2023-09-08-10:22:39',1694161322,1694161359,'month',1,0,49,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": {"SPLITS_FROM": {"[12:24:2]": {"CHUNKS_TO": "None"}}}}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(105,'2023-09-08-10:22:39','2023-09-08-10:23:29',1694161359,1694161409,'month',1,0,43,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": {"SPLITS_FROM": {"[13:24:2]": {"CHUNKS_TO": "None"}}}}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(106,'2023-09-08-10:23:29','2023-09-08-10:23:53',1694161409,1694161433,'month',1,0,43,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": {"SPLITS_FROM": {"13,15,17,19,21,23": {"CHUNKS_TO": "None"}}}}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(107,'2023-09-08-10:23:53','2023-09-08-10:24:28',1694161433,1694161468,'month',1,0,49,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": null}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(108,'2023-09-08-10:24:28','2023-09-08-10:33:11',1694161468,1694161991,'month',1,0,43,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": {"SPLITS_FROM": {"13,15,17,19,21,23": {"CHUNKS_TO": "None"}}}}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(109,'2023-09-08-10:33:11','2023-09-08-10:36:13',1694161991,1694162173,'month',1,0,61,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": {"SPLITS_FROM": {"13,15,17,19,21,23": {"CHUNKS_TO": "None"}}}}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(110,'2023-09-08-10:36:13','2023-09-08-10:37:01',1694162173,1694162221,'month',1,0,43,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": {"SPLITS_FROM": {"13,15,17,19,21,23": {"CHUNKS_TO": "None"}}}}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(111,'2023-09-08-10:37:01','2023-09-08-10:37:41',1694162221,1694162261,'month',1,0,43,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": {"SPLITS_FROM": {"13,15,17,19,21,23": {"CHUNKS_TO": "None"}}}}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(112,'2023-09-08-10:37:41','2023-09-08-10:40:10',1694162261,1694162410,'month',1,0,43,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": {"SPLITS_FROM": {"[13:23:2]": {"CHUNKS_TO": "None"}}}}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(113,'2023-09-08-10:40:11','2023-09-08-11:36:23',1694162411,1694165783,'month',1,0,43,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "WALLCLOCK": "48:00", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "DEPENDENCIES": {"SIM": {"SPLITS_FROM": {"[13:23:2]": {"CHUNKS_TO": "None"}}}}, "RUNNING": "once", "SPLITS": 24, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(114,'2023-09-08-11:36:23','2023-09-08-11:37:10',1694165783,1694165830,'month',1,0,2,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "WALLCLOCK": "48:00", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(115,'2023-09-08-11:37:10','2023-09-08-11:37:31',1694165830,1694165851,'month',1,0,2,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "WALLCLOCK": "48:00", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(116,'2023-09-08-11:37:31','2023-09-08-11:38:19',1694165851,1694165899,'month',1,0,2,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "WALLCLOCK": "48:00", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(117,'2023-09-08-11:38:19','2023-09-08-11:38:43',1694165899,1694165923,'month',1,0,2,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "WALLCLOCK": "48:00", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(118,'2023-09-08-11:38:43','2023-09-08-11:39:58',1694165923,1694165998,'month',1,0,2,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "WALLCLOCK": "48:00", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(119,'2023-09-08-11:39:58','2023-09-08-11:41:38',1694165998,1694166098,'month',1,2,2,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "WALLCLOCK": "48:00", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(120,'2023-09-08-11:41:38','2023-09-08-11:42:13',1694166098,1694166133,'month',1,2,2,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "WALLCLOCK": "48:00", "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(121,'2023-09-08-11:42:13','2023-09-08-11:43:41',1694166133,1694166221,'month',1,1,4,0,0,0,1,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files", "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}}');
INSERT INTO experiment_run VALUES(122,'2023-09-08-11:43:41','2023-09-08-11:43:45',1694166221,1694166225,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(123,'2023-09-08-11:43:45','2023-09-08-11:43:48',1694166225,1694166228,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(124,'2023-09-08-11:43:48','2023-09-08-11:43:53',1694166228,1694166233,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(125,'2023-09-08-11:43:53','2023-09-08-11:48:55',1694166233,1694166535,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(126,'2023-09-08-11:48:55','2023-09-08-11:49:00',1694166535,1694166540,'month',1,0,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "WALLCLOCK": "00:01", "PROCESSORS": 1, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(127,'2023-09-08-11:49:00','2023-09-08-12:04:18',1694166540,1694167458,'month',1,4,4,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "JOBS": {"SIM": {"FILE": "templates/sim.sh", "RUNNING": "chunk", "DEPENDENCIES": {"SIM-1": {}}, "WALLCLOCK": "00:01", "PROCESSORS": 1, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(128,'2023-09-08-12:04:18','2023-09-08-12:05:57',1694167458,1694167557,'month',1,0,49,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"SIM": {"FILE": "templates/sim.sh", "PLATFORM": "local", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "WRAPPERS": {"WRAPPER": {"TYPE": "vertical", "JOBS_IN_WRAPPER": "SIM", "INNER_RETRIALS": "2", "RETRIALS": "2"}}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(129,'2023-09-08-12:05:57','2023-09-08-12:06:05',1694167557,1694167565,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(130,'2023-09-08-12:06:05','2023-09-08-12:06:15',1694167565,1694167575,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(131,'2023-09-08-12:06:15','2023-09-08-12:06:55',1694167575,1694167615,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(132,'2023-09-08-12:06:55','2023-09-08-12:07:19',1694167615,1694167639,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12:2]"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(133,'2023-09-08-12:07:19','2023-09-08-12:07:38',1694167639,1694167658,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:24]": {"SPLITS_TO": "[1:24]"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(134,'2023-09-08-12:07:38','2023-09-08-12:10:44',1694167658,1694167844,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(135,'2023-09-08-12:10:44','2023-09-08-12:13:41',1694167844,1694168021,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(136,'2023-09-08-12:13:41','2023-09-08-12:21:43',1694168021,1694168503,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["doce", "venticuatro"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(137,'2023-09-08-12:21:43','2023-09-08-12:23:02',1694168503,1694168582,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["doce", "venticuatro"], "OPA_SPLITS": "[24,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(138,'2023-09-08-12:23:02','2023-09-08-12:23:23',1694168582,1694168603,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["doce", "venticuatro"], "OPA_SPLITS": "[24,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(139,'2023-09-08-12:23:23','2023-09-08-12:24:38',1694168603,1694168678,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["doce", "venticuatro"], "OPA_SPLITS": "[24,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(140,'2023-09-08-12:24:38','2023-09-08-12:26:31',1694168678,1694168791,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["doce", "venticuatro"], "OPA_SPLITS": "[24,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(141,'2023-09-08-12:26:31','2023-09-08-12:26:46',1694168791,1694168806,'month',1,0,32,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["doce", "venticuatro"], "OPA_SPLITS": "[24,12]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(142,'2023-09-08-12:26:47','2023-09-08-12:29:31',1694168807,1694168971,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["venticuatro", "doce"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(143,'2023-09-08-12:29:31','2023-09-08-12:29:40',1694168971,1694168980,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["2t", "100v"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_2T": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"[1:12]": {"SPLITS_TO": "[1:24]"}}}}, "ADDITIONAL_FILES": []}, "OPA_100V": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(144,'2023-09-08-12:29:40','2023-09-08-12:29:54',1694168980,1694168994,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["venticuatro", "doce"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(145,'2023-09-08-12:29:54','2023-09-08-12:30:44',1694168994,1694169044,'month',1,0,48,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["doce", "venticuatro"], "OPA_SPLITS": "[12,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*\\2"}}}}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(146,'2023-09-08-12:30:44','2023-09-08-12:31:47',1694169044,1694169107,'month',1,0,54,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["venticuatro", "doce"], "OPA_SPLITS": "[24,12]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(147,'2023-09-08-12:31:47','2023-09-08-12:33:51',1694169107,1694169231,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["venticuatro", "doce"], "OPA_SPLITS": "[24,12]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*\\2"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(148,'2023-09-08-12:33:51','2023-09-08-12:40:35',1694169231,1694169635,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["venticuatro", "doce"], "OPA_SPLITS": "[24,12]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "12", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:12]*\\2"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(149,'2023-09-08-12:40:35','2023-09-08-12:40:57',1694169635,1694169657,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["venticuatro", "doce"], "OPA_SPLITS": "[24,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
INSERT INTO experiment_run VALUES(150,'2023-09-08-12:40:57','2023-09-08-12:40:57',1694169657,0,'month',1,0,60,0,0,0,0,0,'{"PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "QUEUE": "debug", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster1", "PROJECT": "dese28", "QUEUE": "debug", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PARTITION": "debug"}, "LUMI": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_465000454", "EXECUTABLE": "/bin/bash --login", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "PARTITION": "debug", "MAX_WALLCLOCK": "00:30"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "USER": "b382351", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": "", "EXECUTABLE": "/usr/bin/bash -l", "PARTITION": "interactive"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "PROJECT": "bb1153", "PARTITION": "compute", "USER": "b382351", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": false}, "OPA_NAMES": ["venticuatro", "doce"], "OPA_SPLITS": "[24,24]", "JOBS": {"DN": {"FILE": "templates/dn.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": 24, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA_VENTICUATRO": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[1:24]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_DOCE": {"FILE": "templates/opa.sh", "PLATFORM": "local", "RUNNING": "once", "SPLITS": "24", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "[2:24:2]*"}}}}, "ADDITIONAL_FILES": []}}, "RUN": {"SIMULATION": "test-ifs-nemo", "PARAMETER": "default", "MODEL": "ifs-nemo", "APPLICATION": "none", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL_VERSION": "dev-aina", "ENVIRONMENT": "cray6"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "git_project"}, "DEFAULT": {"EXPID": "a010", "HPCARCH": "MARENOSTRUM4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a010/proj/git_project/conf/", "POST": "~/platforms.yml"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a010", "PROJDIR": "/home/dbeltran/new_autosubmit/a010/proj/project_files"}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a010_20000101_fc0_1_SIM','2023-08-10-11:56:28','2023-08-10-12:03:28',1691661359,1691661362,1691661367,'COMPLETED',16916612756924,1,'00:10','debug',862.5,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',29895353,'',0,15,0.0,0.0,'','',5,'a010_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(2,0,'a010_20000101_fc0_2_SIM','2023-08-10-11:56:44','2023-09-08-11:40:16',1691661359,1691661367,1691661372,'COMPLETED',16916612756924,1,'00:10','debug',0,'2000-01-01 00:00:00','SIM','fc0',2,0,'MARENOSTRUM4',29895353,'',0,15,0.0,0.0,'','',5,'a010_20000101_fc0_3_SIM','');
INSERT INTO job_data VALUES(3,0,'a010_20000101_fc0_4_SIM','2023-08-10-11:56:44','2023-09-08-11:52:28',1691661359,1691661377,1691661382,'COMPLETED',16916612756924,1,'00:10','debug',0,'2000-01-01 00:00:00','SIM','fc0',4,0,'MARENOSTRUM4',29895353,'',0,15,0.0,0.0,'','',5,'','');
INSERT INTO job_data VALUES(4,0,'a010_20000101_fc0_3_SIM','2023-08-10-11:56:45','2023-09-08-11:52:28',1691661359,1691661372,1691661377,'COMPLETED',16916612756924,1,'00:10','debug',0,'2000-01-01 00:00:00','SIM','fc0',3,0,'MARENOSTRUM4',29895353,'',0,15,0.0,0.0,'','',5,'a010_20000101_fc0_4_SIM','');
INSERT INTO job_data VALUES(5,1,'a010_20000101_fc0_1_SIM','2023-08-10-12:03:28','2023-08-10-12:22:11',1691661717,0,0,'READY',16916616957252,1,'00:10','debug',0,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',0,'',0,18,0.0,0.0,'','',0,'a010_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(6,2,'a010_20000101_fc0_1_SIM','2023-08-10-12:22:11','2023-08-10-15:28:10',1691662889,0,0,'READY',16916624447664,1,'00:10','debug',0,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',0,'',0,19,0.0,0.0,'','',0,'a010_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(7,3,'a010_20000101_fc0_1_SIM','2023-08-10-15:28:10','2023-08-11-09:37:00',1691674033,1691674040,1691674050,'FAILED',16916740135415,1,'00:10','debug',4640,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',29896867,'',1,33,0.0,0.0,'','',2,'a010_20000101_fc0_2_SIM',replace('                 29896867     FAILED          1        1 2023-08-10T15:27:11 2023-08-10T15:27:17 2023-08-10T15:27:50          4.64K                                                     \n           29896867.batch     FAILED          1        1 2023-08-10T15:27:17 2023-08-10T15:27:17 2023-08-10T15:27:50          4.61K                     5324K                     5324K \n          29896867.extern  COMPLETED          1        1 2023-08-10T15:27:17 2023-08-10T15:27:17 2023-08-10T15:27:50          4.64K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(8,4,'a010_20000101_fc0_1_SIM','2023-08-10-15:28:10','2023-08-11-09:37:00',1691674050,1691674050,1691674060,'FAILED',16916740135415,1,'00:10','debug',4640,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',29896867,'',1,33,0.0,0.0,'','',2,'a010_20000101_fc0_2_SIM',replace('                 29896867     FAILED          1        1 2023-08-10T15:27:11 2023-08-10T15:27:17 2023-08-10T15:27:50          4.64K                                                     \n           29896867.batch     FAILED          1        1 2023-08-10T15:27:17 2023-08-10T15:27:17 2023-08-10T15:27:50          4.61K                     5324K                     5324K \n          29896867.extern  COMPLETED          1        1 2023-08-10T15:27:17 2023-08-10T15:27:17 2023-08-10T15:27:50          4.64K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(9,5,'a010_20000101_fc0_1_SIM','2023-08-10-15:28:11','2023-08-11-09:37:00',1691674060,1691674060,1691674070,'FAILED',16916740135415,1,'00:10','debug',4640,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',29896867,'',1,33,0.0,0.0,'','',2,'a010_20000101_fc0_2_SIM',replace('                 29896867     FAILED          1        1 2023-08-10T15:27:11 2023-08-10T15:27:17 2023-08-10T15:27:50          4.64K                                                     \n           29896867.batch     FAILED          1        1 2023-08-10T15:27:17 2023-08-10T15:27:17 2023-08-10T15:27:50          4.61K                     5324K                     5324K \n          29896867.extern  COMPLETED          1        1 2023-08-10T15:27:17 2023-08-10T15:27:17 2023-08-10T15:27:50          4.64K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(10,6,'a010_20000101_fc0_1_SIM','2023-08-11-09:37:00','2023-08-11-10:04:00',1691739362,1691739367,1691739377,'FAILED',16917393103844,1,'00:10','debug',7160,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',29901069,'',1,37,0.0,0.0,'','',2,'a010_20000101_fc0_2_SIM',replace('                 29901069     FAILED          1        1 2023-08-11T09:36:02 2023-08-11T09:36:04 2023-08-11T09:36:37          7.16K                                                     \n           29901069.batch     FAILED          1        1 2023-08-11T09:36:04 2023-08-11T09:36:04 2023-08-11T09:36:37          7.12K                     5328K                     5328K \n          29901069.extern  COMPLETED          1        1 2023-08-11T09:36:04 2023-08-11T09:36:04 2023-08-11T09:36:37          7.16K                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(11,7,'a010_20000101_fc0_1_SIM','2023-08-11-09:37:01','2023-08-11-10:04:00',1691739377,1691739377,1691739387,'FAILED',16917393103844,1,'00:10','debug',7160,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',29901069,'',1,37,0.0,0.0,'','',2,'a010_20000101_fc0_2_SIM',replace('                 29901069     FAILED          1        1 2023-08-11T09:36:02 2023-08-11T09:36:04 2023-08-11T09:36:37          7.16K                                                     \n           29901069.batch     FAILED          1        1 2023-08-11T09:36:04 2023-08-11T09:36:04 2023-08-11T09:36:37          7.12K                     5328K                     5328K \n          29901069.extern  COMPLETED          1        1 2023-08-11T09:36:04 2023-08-11T09:36:04 2023-08-11T09:36:37          7.16K                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(12,8,'a010_20000101_fc0_1_SIM','2023-08-11-09:37:01','2023-08-11-10:04:00',1691739387,1691739387,1691739397,'FAILED',16917393103844,1,'00:10','debug',7160,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',29901069,'',1,37,0.0,0.0,'','',2,'a010_20000101_fc0_2_SIM',replace('                 29901069     FAILED          1        1 2023-08-11T09:36:02 2023-08-11T09:36:04 2023-08-11T09:36:37          7.16K                                                     \n           29901069.batch     FAILED          1        1 2023-08-11T09:36:04 2023-08-11T09:36:04 2023-08-11T09:36:37          7.12K                     5328K                     5328K \n          29901069.extern  COMPLETED          1        1 2023-08-11T09:36:04 2023-08-11T09:36:04 2023-08-11T09:36:37          7.16K                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(13,9,'a010_20000101_fc0_1_SIM','2023-08-11-10:04:00','2023-09-08-11:40:04',1691740930,1691740998,1691741008,'FAILED',16917409067560,1,'00:10','debug',4580,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',29901188,'',1,39,0.0,0.0,'','',2,'a010_20000101_fc0_2_SIM',replace('                 29901188     FAILED          1        1 2023-08-11T10:02:10 2023-08-11T10:03:11 2023-08-11T10:03:48          4.58K                                                     \n           29901188.batch     FAILED          1        1 2023-08-11T10:03:11 2023-08-11T10:03:11 2023-08-11T10:03:48          4.56K                     5324K                     5324K \n          29901188.extern  COMPLETED          1        1 2023-08-11T10:03:11 2023-08-11T10:03:11 2023-08-11T10:03:48          4.58K                       68K                       68K \n','\n',char(10)));
INSERT INTO job_data VALUES(14,10,'a010_20000101_fc0_1_SIM','2023-08-11-10:04:00','2023-09-08-11:40:04',1691741008,1691741008,1691741018,'FAILED',16917409067560,1,'00:10','debug',4580,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',29901188,'',1,39,0.0,0.0,'','',2,'a010_20000101_fc0_2_SIM',replace('                 29901188     FAILED          1        1 2023-08-11T10:02:10 2023-08-11T10:03:11 2023-08-11T10:03:48          4.58K                                                     \n           29901188.batch     FAILED          1        1 2023-08-11T10:03:11 2023-08-11T10:03:11 2023-08-11T10:03:48          4.56K                     5324K                     5324K \n          29901188.extern  COMPLETED          1        1 2023-08-11T10:03:11 2023-08-11T10:03:11 2023-08-11T10:03:48          4.58K                       68K                       68K \n','\n',char(10)));
INSERT INTO job_data VALUES(15,11,'a010_20000101_fc0_1_SIM','2023-08-11-10:04:01','2023-09-08-11:40:04',1691741018,1691741018,1691741028,'FAILED',16917409067560,1,'00:10','debug',4580,'2000-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',29901188,'',1,39,0.0,0.0,'','',2,'a010_20000101_fc0_2_SIM',replace('                 29901188     FAILED          1        1 2023-08-11T10:02:10 2023-08-11T10:03:11 2023-08-11T10:03:48          4.58K                                                     \n           29901188.batch     FAILED          1        1 2023-08-11T10:03:11 2023-08-11T10:03:11 2023-08-11T10:03:48          4.56K                     5324K                     5324K \n          29901188.extern  COMPLETED          1        1 2023-08-11T10:03:11 2023-08-11T10:03:11 2023-08-11T10:03:48          4.58K                       68K                       68K \n','\n',char(10)));
INSERT INTO job_data VALUES(16,12,'a010_20000101_fc0_1_SIM','2023-09-08-11:40:04','2023-09-08-11:41:42',1694166004,1694166004,1694166009,'COMPLETED',2,1,'48:00','debug',0,'2000-01-01 00:00:00','SIM','fc0',1,0,'LOCAL',14778,'',0,119,0.0,0.0,'a010_20000101_fc0_1_SIM.20230908114016.out','a010_20000101_fc0_1_SIM.20230908114016.err',5,'a010_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(17,12,'a010_20000101_fc0_2_SIM','2023-09-08-11:40:16','2023-09-08-11:41:54',1694166016,1694166016,1694166021,'COMPLETED',2,1,'48:00','debug',0,'2000-01-01 00:00:00','SIM','fc0',2,0,'LOCAL',14821,'',0,119,0.0,0.0,'a010_20000101_fc0_2_SIM.20230908114028.out','a010_20000101_fc0_2_SIM.20230908114028.err',5,'','');
INSERT INTO job_data VALUES(18,13,'a010_20000101_fc0_1_SIM','2023-09-08-11:41:42','2023-09-08-11:42:17',1694166102,1694166102,1694166107,'COMPLETED',2,1,'48:00','debug',0,'2000-01-01 00:00:00','SIM','fc0',1,0,'LOCAL',14959,'',0,120,0.0,0.0,'a010_20000101_fc0_1_SIM.20230908114154.out','a010_20000101_fc0_1_SIM.20230908114154.err',5,'a010_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(19,13,'a010_20000101_fc0_2_SIM','2023-09-08-11:41:54','2023-09-08-11:42:29',1694166114,1694166114,1694166119,'COMPLETED',2,1,'48:00','debug',0,'2000-01-01 00:00:00','SIM','fc0',2,0,'LOCAL',14993,'',0,120,0.0,0.0,'a010_20000101_fc0_2_SIM.20230908114206.out','a010_20000101_fc0_2_SIM.20230908114206.err',5,'','');
INSERT INTO job_data VALUES(20,14,'a010_20000101_fc0_1_SIM','2023-09-08-11:42:17','2023-09-08-11:43:46',1694166137,1694166137,1694166142,'COMPLETED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','SIM','fc0',1,0,'LOCAL',15106,'',0,121,0.0,0.0,'a010_20000101_fc0_1_SIM.20230908114229.out','a010_20000101_fc0_1_SIM.20230908114229.err',5,'a010_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(21,14,'a010_20000101_fc0_2_SIM','2023-09-08-11:42:29','2023-09-08-11:52:28',1694166149,0,0,'SUBMITTED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','SIM','fc0',2,0,'LOCAL',15141,'',0,121,0.0,0.0,'','',0,'a010_20000101_fc0_3_SIM','');
INSERT INTO job_data VALUES(22,15,'a010_20000101_fc0_1_SIM','2023-09-08-11:43:46','2023-09-08-11:52:11',1694166226,0,0,'SUBMITTED',2,1,'00:00','debug',0,'2000-01-01 00:00:00','SIM','fc0',1,0,'LOCAL',15270,'',0,123,0.0,0.0,'','',0,'a010_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(23,16,'a010_20000101_fc0_1_SIM','2023-09-08-11:52:11','2023-09-08-11:52:11',1694166552,1694166667,1694166672,'COMPLETED',16941665429861,1,'00:01','debug',0,'2000-01-01 00:00:00','SIM','fc0',1,1,'MARENOSTRUM4',30139387,'',0,127,0.0,0.0,'a010_20000101_fc0_1_SIM.20230908114229.out','a010_20000101_fc0_1_SIM.20230908114229.err',5,'a010_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(24,16,'a010_20000101_fc0_2_SIM','2023-09-08-11:52:28','2023-09-08-11:52:28',1694166552,1694166672,1694166678,'COMPLETED',16941665429861,1,'00:01','debug',0,'2000-01-01 00:00:00','SIM','fc0',2,1,'MARENOSTRUM4',30139387,'',0,127,0.0,0.0,'a010_20000101_fc0_2_SIM.20230908114206.out','a010_20000101_fc0_2_SIM.20230908114206.err',5,'a010_20000101_fc0_3_SIM','');
INSERT INTO job_data VALUES(25,16,'a010_20000101_fc0_3_SIM','2023-09-08-11:52:28','2023-09-08-11:52:28',1694166552,1694166678,1694166683,'COMPLETED',16941665429861,1,'00:01','debug',0,'2000-01-01 00:00:00','SIM','fc0',3,1,'MARENOSTRUM4',30139387,'',0,127,0.0,0.0,'','',5,'a010_20000101_fc0_4_SIM','');
INSERT INTO job_data VALUES(26,16,'a010_20000101_fc0_4_SIM','2023-09-08-11:52:28','2023-09-08-11:52:28',1694166552,1694166683,1694166688,'COMPLETED',16941665429861,1,'00:01','debug',0,'2000-01-01 00:00:00','SIM','fc0',4,1,'MARENOSTRUM4',30139387,'',0,127,0.0,0.0,'','',5,'','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',150);
INSERT INTO sqlite_sequence VALUES('job_data',26);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
