PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-10-19-15:57:56','2023-10-19-15:59:06',1697723876,1697723946,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.98"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(2,'2023-10-19-15:59:07','2023-10-19-16:01:58',1697723947,1697724118,'month',1,0,86,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.88"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(3,'2023-10-19-16:01:58','2023-10-19-16:03:01',1697724118,1697724181,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.98"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(4,'2023-10-19-16:03:01','2023-10-19-16:03:36',1697724181,1697724216,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.97"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(5,'2023-10-19-16:03:36','2023-10-19-16:04:14',1697724216,1697724254,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.97"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_''O0_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O0''", "PROCESSORS": "48"}, "TRACE_''O0_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O0''", "PROCESSORS": "96"}, "TRACE_''O1_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O1''", "PROCESSORS": "48"}, "TRACE_''O1_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O1''", "PROCESSORS": "96"}, "TRACE_''O3_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O3''", "PROCESSORS": "48"}, "TRACE_''O3_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O3''", "PROCESSORS": "96"}, "TRACE_''XHOST_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''xHost''", "PROCESSORS": "48"}, "TRACE_''XHOST_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''xHost''", "PROCESSORS": "96"}, "SCALABILITY_''O0_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O0''", "PROCESSORS": "48"}, "SCALABILITY_''O0_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O0''", "PROCESSORS": "96"}, "SCALABILITY_''O1_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O1''", "PROCESSORS": "48"}, "SCALABILITY_''O1_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O1''", "PROCESSORS": "96"}, "SCALABILITY_''O3_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O3''", "PROCESSORS": "48"}, "SCALABILITY_''O3_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O3''", "PROCESSORS": "96"}, "SCALABILITY_''XHOST_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''xHost''", "PROCESSORS": "48"}, "SCALABILITY_''XHOST_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''xHost''", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_''BENCH_48''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "48"}, "TRACE_''BENCH_189''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "189"}, "TRACE_''BENCH_96''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "96"}, "SCALABILITY_''BENCH_48''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "48"}, "SCALABILITY_''BENCH_189''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "189"}, "SCALABILITY_''BENCH_96''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "96"}, "TRACE_''ORCA025_740''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''Orca025''", "PROCESSORS": "740"}, "TRACE_''ORCA025_576''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''Orca025''", "PROCESSORS": "576"}, "TRACE_''ORCA1_189''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''Orca1''", "PROCESSORS": "189"}, "TRACE_''ORCA1_48''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''Orca1''", "PROCESSORS": "48"}, "SCALABILITY_''ORCA025_740''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''Orca025''", "PROCESSORS": "740"}, "SCALABILITY_''ORCA025_576''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''Orca025''", "PROCESSORS": "576"}, "SCALABILITY_''ORCA1_189''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''Orca1''", "PROCESSORS": "189"}, "SCALABILITY_''ORCA1_48''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''Orca1''", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_''O0_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O0''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''O0_96''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O0''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_''O1_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O1''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''O1_96''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O1''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_''O3_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O3''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''O3_96''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O3''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_''XHOST_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''xHost''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''XHOST_96''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''xHost''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_''O0_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O0''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''O0_96''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O0''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_''O1_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O1''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''O1_96''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O1''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_''O3_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O3''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''O3_96''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O3''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_''XHOST_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''xHost''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''XHOST_96''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''xHost''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''BENCH_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''BENCH''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''BENCH_189''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''BENCH''", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_''BENCH_96''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''BENCH''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_''BENCH_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''BENCH''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''BENCH_189''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''BENCH''", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_''BENCH_96''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''BENCH''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_''ORCA025_740''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''Orca025''", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_''ORCA025_576''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''Orca025''", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_''ORCA1_189''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''Orca1''", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_''ORCA1_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''Orca1''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''ORCA025_740''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''Orca025''", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_''ORCA025_576''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''Orca025''", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_''ORCA1_189''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''Orca1''", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_''ORCA1_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''Orca1''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(6,'2023-10-19-16:04:14','2023-10-19-16:04:38',1697724254,1697724278,'month',1,0,86,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.88"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_''O0_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O0''", "PROCESSORS": "48"}, "TRACE_''O0_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O0''", "PROCESSORS": "96"}, "TRACE_''O1_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O1''", "PROCESSORS": "48"}, "TRACE_''O1_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O1''", "PROCESSORS": "96"}, "TRACE_''O3_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O3''", "PROCESSORS": "48"}, "TRACE_''O3_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''O3''", "PROCESSORS": "96"}, "TRACE_''XHOST_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''xHost''", "PROCESSORS": "48"}, "TRACE_''XHOST_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''xHost''", "PROCESSORS": "96"}, "SCALABILITY_''O0_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O0''", "PROCESSORS": "48"}, "SCALABILITY_''O0_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O0''", "PROCESSORS": "96"}, "SCALABILITY_''O1_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O1''", "PROCESSORS": "48"}, "SCALABILITY_''O1_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O1''", "PROCESSORS": "96"}, "SCALABILITY_''O3_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O3''", "PROCESSORS": "48"}, "SCALABILITY_''O3_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''O3''", "PROCESSORS": "96"}, "SCALABILITY_''XHOST_48''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''xHost''", "PROCESSORS": "48"}, "SCALABILITY_''XHOST_96''": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''xHost''", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_''BENCH_48''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "48"}, "TRACE_''BENCH_189''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "189"}, "TRACE_''BENCH_96''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "96"}, "SCALABILITY_''BENCH_48''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "48"}, "SCALABILITY_''BENCH_189''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "189"}, "SCALABILITY_''BENCH_96''": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''BENCH''", "PROCESSORS": "96"}, "TRACE_''ORCA025_740''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''Orca025''", "PROCESSORS": "740"}, "TRACE_''ORCA025_576''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''Orca025''", "PROCESSORS": "576"}, "TRACE_''ORCA1_189''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''Orca1''", "PROCESSORS": "189"}, "TRACE_''ORCA1_48''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "''Orca1''", "PROCESSORS": "48"}, "SCALABILITY_''ORCA025_740''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''Orca025''", "PROCESSORS": "740"}, "SCALABILITY_''ORCA025_576''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''Orca025''", "PROCESSORS": "576"}, "SCALABILITY_''ORCA1_189''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''Orca1''", "PROCESSORS": "189"}, "SCALABILITY_''ORCA1_48''": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "''Orca1''", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_''O0_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O0''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''O0_96''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O0''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_''O1_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O1''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''O1_96''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O1''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_''O3_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O3''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''O3_96''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''O3''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_''XHOST_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''xHost''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''XHOST_96''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''xHost''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_''O0_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O0''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''O0_96''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O0''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_''O1_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O1''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''O1_96''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O1''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_''O3_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O3''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''O3_96''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''O3''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_''XHOST_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''xHost''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''XHOST_96''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''xHost''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''BENCH_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''BENCH''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_''BENCH_189''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''BENCH''", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_''BENCH_96''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''BENCH''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_''BENCH_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''BENCH''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''BENCH_189''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''BENCH''", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_''BENCH_96''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''BENCH''", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_''ORCA025_740''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''Orca025''", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_''ORCA025_576''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''Orca025''", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_''ORCA1_189''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''Orca1''", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_''ORCA1_48''": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "''Orca1''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_''ORCA025_740''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''Orca025''", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_''ORCA025_576''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''Orca025''", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_''ORCA1_189''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''Orca1''", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_''ORCA1_48''": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "''Orca1''", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(7,'2023-10-19-16:04:38','2023-10-19-16:05:00',1697724278,1697724300,'month',1,0,86,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.88"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(8,'2023-10-19-16:05:00','2023-10-19-16:07:10',1697724300,1697724430,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.98"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(9,'2023-10-19-16:07:10','2023-10-20-09:54:35',1697724430,1697788475,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.98"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(10,'2023-10-20-09:54:35','2023-10-20-11:38:54',1697788475,1697794734,'month',1,0,86,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.88"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(11,'2023-10-20-11:38:54','2023-10-20-12:12:47',1697794734,1697796767,'month',1,0,86,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.88"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(12,'2023-10-20-12:12:47','2023-10-20-12:13:03',1697796767,1697796783,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.92"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(13,'2023-10-20-12:13:03','2023-10-20-12:13:20',1697796783,1697796800,'month',1,0,86,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.89"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(14,'2023-10-20-12:13:20','2023-10-20-12:15:11',1697796800,1697796911,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.90"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(15,'2023-10-20-12:15:11','2023-10-20-12:16:58',1697796911,1697797018,'month',1,0,86,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.89"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(16,'2023-10-20-12:16:58','2023-10-20-14:09:47',1697797018,1697803787,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.89"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(17,'2023-10-20-14:09:47','2023-10-20-14:14:54',1697803787,1697804094,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.98"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(18,'2023-10-20-14:14:54','2023-10-20-14:19:28',1697804094,1697804368,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.98"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(19,'2023-10-20-14:19:28','2023-10-20-14:38:35',1697804368,1697805515,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.98"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(20,'2023-10-20-14:38:35','2023-10-20-14:38:35',1697805515,0,'month',1,0,181,0,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "4.2.1", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "PLATFORM": "hpc2020", "TRACE_N_FUNCTIONS": "80", "USER_FUNCTIONS_PROC": 384}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/%COMMON.PLATFORM%/environment.env"}, "REPORT": {"CONFIG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/latex/report.cfg", "NAME": "report", "FOLDER": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "STREAM_NAMES": [1, 2, 4, 8, 16, 32, 48], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48], "OSU_NAMES": [48, 96, 192], "OSU_PROCESSORS": [48, 96, 192]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "TEST_NAMES": ["BENCH", "BENCH", "BENCH"], "NAMES": ["bench_48", "bench_189", "bench_96"], "PROCESSORS": [48, 189, 96]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "TEST_NAMES": ["Orca025", "Orca025", "Orca1", "Orca1"], "NAMES": ["orca025_740", "orca025_576", "orca1_189", "orca1_48"], "PROCESSORS": [740, 576, 189, 48]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "TEST_NAMES": ["O0", "O0", "O1", "O1", "O3", "O3", "xHost", "xHost"], "NAMES": ["O0_48", "O0_96", "O1_48", "O1_96", "O3_48", "O3_96", "xHost_48", "xHost_96"], "PROCESSORS": [48, 96, 48, 96, 48, 96, 48, 96]}, "CONFIG": {"MAXWAITINGJOBS": "4", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.98"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}, "HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "PROJECT": "spesiccf", "USER": "TOFILL", "QUEUE": "nf", "EC_QUEUE": "hpc", "SCRATCH_DIR": "/ec/res4/scratch/c3rs", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "[ ''#SBATCH --hint=nomultithread'' ]"}}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PROCESSORS": 64, "TASKS": 64, "QUEUE": "np", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "384", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "DIMEMAS_TRACES": {"FILE": "autosubmit/templates/dimemas_traces.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "DIMEMAS_IMAGES": {"FILE": "autosubmit/templates/dimemas_images.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARADIM": {"FILE": "autosubmit/templates/paradim.sh", "DEPENDENCIES": {"DIMEMAS_TRACES": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "TASKS": 48, "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARADIM": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"PARAVER": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "DIMEMAS_IMAGES": {"MEMBERS_TO": "StrongScaling,WeakScaling,CompilationEfficiency"}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_TO": "HardwareBenchmarks"}, "MODELFACTORS": {"MEMBERS_TO": "StrongScaling"}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "TRACE_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "TRACE_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "TRACE_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "TRACE_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "TRACE_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "TRACE_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "TRACE_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "SCALABILITY_O0_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "48"}, "SCALABILITY_O0_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O0", "PROCESSORS": "96"}, "SCALABILITY_O1_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "48"}, "SCALABILITY_O1_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O1", "PROCESSORS": "96"}, "SCALABILITY_O3_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "48"}, "SCALABILITY_O3_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "O3", "PROCESSORS": "96"}, "SCALABILITY_XHOST_48": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "48"}, "SCALABILITY_XHOST_96": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "xHost", "PROCESSORS": "96"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "TRACE_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "TRACE_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "SCALABILITY_BENCH_48": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "48"}, "SCALABILITY_BENCH_189": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "189"}, "SCALABILITY_BENCH_96": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "BENCH", "PROCESSORS": "96"}, "TRACE_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "TRACE_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "TRACE_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "TRACE_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}, "SCALABILITY_ORCA025_740": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "740"}, "SCALABILITY_ORCA025_576": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca025", "PROCESSORS": "576"}, "SCALABILITY_ORCA1_189": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "189"}, "SCALABILITY_ORCA1_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "TEST_NAME": "Orca1", "PROCESSORS": "48"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O0_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O1_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_O3_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_XHOST_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O0_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O0_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O0", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O1_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O1", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_O3_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_O3_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "O3", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_XHOST_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_XHOST_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "xHost", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "01:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_BENCH_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_BENCH_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_BENCH_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_BENCH_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "BENCH", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_740": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA025_576": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_189": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "SCALABILITY_ORCA1_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_740": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "740", "ADDITIONAL_FILES": []}, "TRACE_ORCA025_576": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca025", "PROCESSORS": "576", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_189": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "189", "ADDITIONAL_FILES": []}, "TRACE_ORCA1_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "TEST_NAME": "Orca1", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01u", "PROJDIR": "/home/dbeltran/new_autosubmit/a01u/proj/project_files", "DEFAULT": {"EXPID": "a6ja", "HPCARCH": "hpc2020", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/platforms/hpc2020/,/home/dbeltran/new_autosubmit/a01u/proj/auto-performance-profiling/autosubmit/configuration/members/", "POST": "~/platforms_credentials.yml"}}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',20);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
