PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-04-28-16:09:04','2023-04-28-16:09:50',1682690944,1682690990,'day',1,0,19,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "DEFAULT": {"EXPID": "a006", "HPCARCH": "LEVANTE", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/jobs.yml,/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/platforms.yml,/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/ifs-fesom.yml", "POST": "/home/sbeyer/platforms_sbeyer.yml"}}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/sbeyer/wf_ifs-fesom-levante"}, "RUN": {"SIMULATION": "test-ifs-fesom", "CONFIGURATION": "test", "PARAMETER": "default", "MODEL": "ifs-fesom", "APPLICATION": "none"}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard", "MODEL": "ifs-fesom"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "LEVANTE-login", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "PLATFORM": "LEVANTE-login", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:15", "PLATFORM": "LEVANTE", "EXECUTABLE": "/usr/bin/bash -l", "THREADS": 2, "PROCESSORS": 64, "CUSTOM_DIRECTIVES": "[''#SBATCH -N 1'', ''#SBATCH --ntasks-per-node=64'', ''#SBATCH --export=ALL'']", "ADDITIONAL_FILES": []}, "GSV": {"FILE": "templates/gsv.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "templates/application.sh", "DEPENDENCIES": {"GSV": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "TEMP_DIR": ""}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_462000048", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_462000048", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_462000048"}, "LEVANTE-LOGIN": {"TYPE": "ps", "HOST": "levante", "PROJECT": "ab0995", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante", "PROJECT": "ab0995", "PARTITION": "compute", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "ab0995"}}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/ifs-source.git", "BRANCH": "nextGEMS_CY47R3_RAPS20", "MODEL": "ifs-fesom", "INPROOT": "/work/ab0995/a270219/IFS_FESOM/ifs-inputs2"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(2,'2023-04-28-16:09:50','2023-04-28-16:10:28',1682690990,1682691028,'day',1,0,19,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "DEFAULT": {"EXPID": "a006", "HPCARCH": "LEVANTE", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/jobs.yml,/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/platforms.yml,/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/ifs-fesom.yml", "POST": "/home/sbeyer/platforms_sbeyer.yml"}}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/sbeyer/wf_ifs-fesom-levante"}, "RUN": {"SIMULATION": "test-ifs-fesom", "CONFIGURATION": "test", "PARAMETER": "default", "MODEL": "ifs-fesom", "APPLICATION": "none"}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard", "MODEL": "ifs-fesom"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "LEVANTE-login", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "PLATFORM": "LEVANTE-login", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:15", "PLATFORM": "LEVANTE", "EXECUTABLE": "/usr/bin/bash -l", "THREADS": 2, "PROCESSORS": 64, "CUSTOM_DIRECTIVES": "[''#SBATCH -N 1'', ''#SBATCH --ntasks-per-node=64'', ''#SBATCH --export=ALL'']", "ADDITIONAL_FILES": []}, "GSV": {"FILE": "templates/gsv.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "templates/application.sh", "DEPENDENCIES": {"GSV": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "TEMP_DIR": ""}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_462000048", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_462000048", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_462000048"}, "LEVANTE-LOGIN": {"TYPE": "ps", "HOST": "levante", "PROJECT": "ab0995", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante", "PROJECT": "ab0995", "PARTITION": "compute", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "ab0995"}}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/ifs-source.git", "BRANCH": "nextGEMS_CY47R3_RAPS20", "MODEL": "ifs-fesom", "INPROOT": "/work/ab0995/a270219/IFS_FESOM/ifs-inputs2"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(3,'2023-04-28-16:10:28','2023-04-28-16:20:36',1682691028,1682691636,'day',1,0,19,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "DEFAULT": {"EXPID": "a006", "HPCARCH": "LEVANTE", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/jobs.yml,/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/platforms.yml,/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/ifs-fesom.yml", "POST": "/home/sbeyer/platforms_sbeyer.yml"}}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/sbeyer/wf_ifs-fesom-levante"}, "RUN": {"SIMULATION": "test-ifs-fesom", "CONFIGURATION": "test", "PARAMETER": "default", "MODEL": "ifs-fesom", "APPLICATION": "none"}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard", "MODEL": "ifs-fesom"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "LEVANTE-login", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "PLATFORM": "LEVANTE-login", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:15", "PLATFORM": "LEVANTE", "EXECUTABLE": "/usr/bin/bash -l", "THREADS": 2, "PROCESSORS": 64, "CUSTOM_DIRECTIVES": "[''#SBATCH -N 1'', ''#SBATCH --ntasks-per-node=64'', ''#SBATCH --export=ALL'']", "ADDITIONAL_FILES": []}, "GSV": {"FILE": "templates/gsv.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "templates/application.sh", "DEPENDENCIES": {"GSV": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "TEMP_DIR": ""}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_462000048", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_462000048", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_462000048"}, "LEVANTE-LOGIN": {"TYPE": "ps", "HOST": "levante", "PROJECT": "ab0995", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante", "PROJECT": "ab0995", "PARTITION": "compute", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "ab0995"}}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/ifs-source.git", "BRANCH": "nextGEMS_CY47R3_RAPS20", "MODEL": "ifs-fesom", "INPROOT": "/work/ab0995/a270219/IFS_FESOM/ifs-inputs2"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(4,'2023-04-28-16:20:36','2023-04-28-16:23:46',1682691636,1682691826,'day',1,0,19,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "DEFAULT": {"EXPID": "a006", "HPCARCH": "LEVANTE", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/jobs.yml,/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/platforms.yml,/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/ifs-fesom.yml", "POST": "/home/sbeyer/platforms_sbeyer.yml"}}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/sbeyer/wf_ifs-fesom-levante"}, "RUN": {"SIMULATION": "test-ifs-fesom", "CONFIGURATION": "test", "PARAMETER": "default", "MODEL": "ifs-fesom", "APPLICATION": "none"}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard", "MODEL": "ifs-fesom"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "LEVANTE-login", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "PLATFORM": "LEVANTE-login", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:15", "PLATFORM": "LEVANTE", "EXECUTABLE": "/usr/bin/bash -l", "THREADS": 2, "PROCESSORS": 64, "CUSTOM_DIRECTIVES": "[''#SBATCH -N 1'', ''#SBATCH --ntasks-per-node=64'', ''#SBATCH --export=ALL'']", "ADDITIONAL_FILES": []}, "GSV": {"FILE": "templates/gsv.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "templates/application.sh", "DEPENDENCIES": {"GSV": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "TEMP_DIR": ""}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_462000048", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_462000048", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_462000048"}, "LEVANTE-LOGIN": {"TYPE": "ps", "HOST": "levante", "PROJECT": "ab0995", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante", "PROJECT": "ab0995", "PARTITION": "compute", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "ab0995"}}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/ifs-source.git", "BRANCH": "nextGEMS_CY47R3_RAPS20", "MODEL": "ifs-fesom", "INPROOT": "/work/ab0995/a270219/IFS_FESOM/ifs-inputs2"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(5,'2023-04-28-16:23:46','2023-06-12-10:14:15',1682691826,1686557655,'day',1,0,19,0,0,0,0,0,'{"PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "DEFAULT": {"EXPID": "a006", "HPCARCH": "LEVANTE", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/jobs.yml,/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/platforms.yml,/home/dbeltran/new_autosubmit/a005/proj/git_project/conf/ifs-fesom.yml", "POST": "/home/sbeyer/platforms_sbeyer.yml"}}, "PROJECT": {"PROJECT_TYPE": "local", "PROJECT_DESTINATION": "local_project"}, "LOCAL": {"PROJECT_PATH": "/home/sbeyer/wf_ifs-fesom-levante"}, "RUN": {"SIMULATION": "test-ifs-fesom", "CONFIGURATION": "test", "PARAMETER": "default", "MODEL": "ifs-fesom", "APPLICATION": "none"}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 5, "CALENDAR": "standard", "MODEL": "ifs-fesom"}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "LEVANTE-login", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "PLATFORM": "LEVANTE-login", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:15", "PLATFORM": "LEVANTE", "EXECUTABLE": "/usr/bin/bash -l", "THREADS": 2, "PROCESSORS": 64, "CUSTOM_DIRECTIVES": "[''#SBATCH -N 1'', ''#SBATCH --ntasks-per-node=64'', ''#SBATCH --export=ALL'']", "ADDITIONAL_FILES": []}, "GSV": {"FILE": "templates/gsv.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "templates/application.sh", "DEPENDENCIES": {"GSV": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55", "TEMP_DIR": ""}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_462000048", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_462000048", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "project_462000048"}, "LEVANTE-LOGIN": {"TYPE": "ps", "HOST": "levante", "PROJECT": "ab0995", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante", "PROJECT": "ab0995", "PARTITION": "compute", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/work", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 128, "BUDGET": "ab0995"}}, "MODEL": {"SOURCE": "https://git.ecmwf.int/scm/~naih/ifs-source.git", "BRANCH": "nextGEMS_CY47R3_RAPS20", "MODEL": "ifs-fesom", "INPROOT": "/work/ab0995/a270219/IFS_FESOM/ifs-inputs2"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(6,'2023-06-12-10:14:15','2023-06-12-10:15:42',1686557655,1686557742,'day',1,0,15,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": ["templates/dn.yml", "lib/runscript/run_dn.py"]}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": ["templates/opa.yml", "lib/runscript/run_opa.py"]}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-icon", "PARAMETER": "default", "MODEL": "icon", "APP": "urban", "GRID": "r2b4", "MODEL_VERSION": null, "ENVIRONMENT": "openmpi"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CALENDAR": "standard"}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(7,'2023-06-12-10:15:42','2023-06-12-10:16:28',1686557742,1686557788,'day',1,0,15,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": ["templates/dn.yml", "lib/runscript/run_dn.py"]}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": ["templates/opa.yml", "lib/runscript/run_opa.py"]}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-icon", "PARAMETER": "default", "MODEL": "icon", "APP": "urban", "GRID": "r2b4", "MODEL_VERSION": null, "ENVIRONMENT": "openmpi"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CALENDAR": "standard"}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(8,'2023-06-12-10:16:28','2023-06-12-10:17:32',1686557788,1686557852,'day',1,0,15,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": ["templates/dn.yml", "lib/runscript/run_dn.py"]}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": ["templates/opa.yml", "lib/runscript/run_opa.py"]}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-icon", "PARAMETER": "default", "MODEL": "icon", "APP": "urban", "GRID": "r2b4", "MODEL_VERSION": null, "ENVIRONMENT": "openmpi"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CALENDAR": "standard"}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(9,'2023-06-12-10:17:32','2023-06-12-10:18:47',1686557852,1686557927,'day',1,0,15,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": ["templates/dn.yml", "lib/runscript/run_dn.py"]}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": ["templates/opa.yml", "lib/runscript/run_opa.py"]}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-icon", "PARAMETER": "default", "MODEL": "icon", "APP": "urban", "GRID": "r2b4", "MODEL_VERSION": null, "ENVIRONMENT": "openmpi"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CALENDAR": "standard"}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(10,'2023-06-12-10:18:47','2023-06-12-10:19:36',1686557927,1686557976,'day',1,0,15,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": ["templates/dn.yml", "lib/runscript/run_dn.py"]}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": ["templates/opa.yml", "lib/runscript/run_opa.py"]}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-icon", "PARAMETER": "default", "MODEL": "icon", "APP": "urban", "GRID": "r2b4", "MODEL_VERSION": null, "ENVIRONMENT": "openmpi"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CALENDAR": "standard"}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(11,'2023-06-12-10:19:36','2023-06-12-10:20:19',1686557976,1686558019,'day',1,0,15,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": ["templates/dn.yml", "lib/runscript/run_dn.py"]}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": ["templates/opa.yml", "lib/runscript/run_opa.py"]}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-icon", "PARAMETER": "default", "MODEL": "icon", "APP": "urban", "GRID": "r2b4", "MODEL_VERSION": null, "ENVIRONMENT": "openmpi"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CALENDAR": "standard"}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(12,'2023-06-12-10:20:19','2023-06-12-10:24:52',1686558019,1686558292,'day',1,0,15,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": ["templates/dn.yml", "lib/runscript/run_dn.py"]}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": ["templates/opa.yml", "lib/runscript/run_opa.py"]}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "RUN": {"SIMULATION": "test-icon", "PARAMETER": "default", "MODEL": "icon", "APP": "urban", "GRID": "r2b4", "MODEL_VERSION": null, "ENVIRONMENT": "openmpi"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/project_files", "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "EXPERIMENT": {"DATELIST": 20200120, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 4, "CALENDAR": "standard"}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(13,'2023-06-12-10:24:52','2023-06-12-10:26:02',1686558292,1686558362,'day',1,0,15,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(14,'2023-06-12-10:26:02','2023-06-12-10:26:34',1686558362,1686558394,'day',1,0,19,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 2}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(15,'2023-06-12-10:26:34','2023-06-12-10:28:29',1686558394,1686558509,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(16,'2023-06-12-10:28:29','2023-06-12-10:30:13',1686558509,1686558613,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "2,3": {"SPLITS_TO": "2"}}}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(17,'2023-06-12-10:30:13','2023-06-12-10:40:13',1686558613,1686559213,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(18,'2023-06-12-10:40:13','2023-06-12-10:40:32',1686559213,1686559232,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "VERTICAL"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(19,'2023-06-12-10:40:32','2023-06-12-10:42:13',1686559232,1686559333,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "VERTICAL"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(20,'2023-06-12-10:42:13','2023-06-12-10:42:36',1686559333,1686559356,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "VERTICAL"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(21,'2023-06-12-10:42:36','2023-06-12-10:44:51',1686559356,1686559491,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "VERTICAL"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(22,'2023-06-12-10:44:51','2023-06-12-10:46:13',1686559491,1686559573,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "VERTICAL"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(23,'2023-06-12-10:46:13','2023-06-12-10:49:54',1686559573,1686559794,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "VERTICAL"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(24,'2023-06-12-10:49:54','2023-06-12-10:53:52',1686559794,1686560032,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "VERTICAL"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(25,'2023-06-12-10:53:52','2023-06-12-13:44:25',1686560032,1686570265,'day',1,0,31,0,0,0,0,0,'{"JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": [], "DEPENDENCIES": {}}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "Lumi-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi-login", "ADDITIONAL_FILES": [], "SPLITS": 2}, "OPA": {"FILE": "templates/opa.sh", "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": [], "SPLITS": 4}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "Lumi", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "WALLCLOCK": "00:55", "NODES": 4, "TASKS": 48, "PROCESSORS": 192, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 1, "BUDGET": "project_465000454"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_REF": "R02B04", "ATM_NPROMA": 32, "OCE_NPROMA": 8, "RUNSCRIPT": "run_DUMMY.py"}}, "GSVREQUEST": {"LEVTYPE": "sfc", "DATE": "20050401/to/20050405", "TIME": "0000/to/2300/by/0100", "STEP": "0", "PARAM": "2t", "GRID": "0.1/0.1", "METHOD": "nn"}, "OPAREQUEST": {"STAT": "min", "STAT_FREQ": "daily", "OUTPUT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t", "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "VERTICAL"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/home/dbeltran/new_autosubmit/a005/proj/workflow/conf,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/simulation/test-icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/parameter/default.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/icon.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/model/icon/r2b4.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/urban.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/gsvrequest.yml,/home/dbeltran/new_autosubmit/a005/proj/workflow/conf/applications/urban/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(26,'2023-06-12-13:44:25','2023-06-12-13:45:20',1686570265,1686570320,'day',1,0,31,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(27,'2023-06-12-13:45:20','2023-06-12-13:49:32',1686570320,1686570572,'day',1,0,31,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(28,'2023-06-12-13:49:32','2023-06-12-13:50:12',1686570572,1686570612,'day',1,0,31,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(29,'2023-06-12-13:50:12','2023-06-12-13:52:16',1686570612,1686570736,'day',1,0,31,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(30,'2023-06-12-13:52:16','2023-06-12-13:54:24',1686570736,1686570864,'day',1,0,31,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(31,'2023-06-12-13:54:24','2023-06-12-15:05:46',1686570864,1686575146,'day',1,0,31,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(32,'2023-06-12-15:05:46','2023-06-12-15:06:31',1686575146,1686575191,'day',1,0,59,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical-horizontal", "NODES": 4}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(33,'2023-06-12-15:06:31','2023-06-12-15:08:52',1686575191,1686575332,'day',1,0,59,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical-horizontal", "NODES": 4}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(34,'2023-06-12-15:08:52','2023-06-12-15:08:59',1686575332,1686575339,'day',1,0,59,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical-horizontal", "NODES": 4}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(35,'2023-06-12-15:08:59','2023-06-12-15:10:52',1686575339,1686575452,'day',1,0,59,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical-horizontal", "NODES": 4}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(36,'2023-06-12-15:10:52','2023-06-12-15:11:00',1686575452,1686575460,'day',1,0,59,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical-horizontal", "NODES": 4}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(37,'2023-06-12-15:11:00','2023-06-12-15:11:09',1686575460,1686575469,'day',1,0,59,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical", "NODES": 4}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(38,'2023-06-12-15:11:09','2023-06-12-15:11:22',1686575469,1686575482,'day',1,0,59,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "horizontal", "NODES": 4}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(39,'2023-06-12-15:11:22','2023-06-12-15:11:38',1686575482,1686575498,'day',1,0,59,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "horizontal-vertical", "NODES": 4}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(40,'2023-06-12-15:11:38','2023-06-12-15:11:49',1686575498,1686575509,'day',1,0,59,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "horizontal-vertical", "NODES": 4, "TASKS": 20}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(41,'2023-06-12-15:11:49','2023-06-12-15:18:19',1686575509,1686575899,'day',1,0,59,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical", "NODES": 4, "TASKS": 20}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(42,'2023-06-12-15:18:19','2023-06-12-15:30:00',1686575899,1686576600,'day',1,2,59,1,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical", "NODES": 4, "TASKS": 20}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a041", "HPCARCH": "Lumi"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(43,'2023-06-12-15:30:00','2023-06-12-16:25:24',1686576600,1686579924,'day',1,25,59,0,19,0,1,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical", "NODES": 4, "TASKS": 20}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a005", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "None"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(44,'2023-06-12-16:25:24','2023-06-13-09:48:51',1686579924,1686642531,'day',1,8,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical", "NODES": 4, "TASKS": 20}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a005", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "RUNNING": "chunk", "WALLCLOCK": "00:05", "NODES": 2, "TASKS": 30, "THREADS": 40}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "NODES": 4, "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "None"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(45,'2023-06-13-09:48:51','2023-06-13-09:49:03',1686642531,1686642543,'day',1,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a005", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": 1}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": ""}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "None"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(46,'2023-06-13-09:49:03','2023-06-13-09:49:03',1686642543,0,'day',1,0,56,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "APP", "TYPE": "vertical"}}, "CONFIGURATION": {"DUMMY": {"ATM_GID": "0043", "ATM_NPROMA": 32, "ATM_REF": "R02B04", "OCE_GID": "0036", "OCE_NPROMA": 8, "OCE_REF": "R02B04", "RUNSCRIPT": "run_DUMMY.py"}}, "DEFAULT": {"EXPID": "a005", "HPCARCH": "marenostrum4"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0 fc1", "NUMCHUNKS": 4, "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-integrate-urban", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": "20050401/to/20050405", "GRID": "0.1/0.1", "LEVTYPE": "sfc", "METHOD": "nn", "PARAM": "2t", "STEP": "0", "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}, "APP-1": {}}, "FILE": "templates/application.sh", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": 1}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "RUNNING": "chunk", "SPLITS": 2, "WALLCLOCK": "00:05"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}, "3,4": {"SPLITS_TO": "2"}}}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": 4, "WALLCLOCK": "00:05"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/scratch/project_465000454/tmp/", "SAVE": true, "STAT": "min", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>", "MAX_PROCESSORS": 720}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM0": {"HOST": "marenostrum0", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TYPE": "slurm", "USER": "bsc32070"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "bsc", "MAX_PROCESSORS": "2400", "MAX_WALLCLOCK": "48:00", "PROCESSORS": 192, "PROCESSORS_PER_NODE": "48", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "SERIAL_QUEUE": "debug", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "WALLCLOCK": "00:55"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "MARENOSTRUM_ARCHIVE": {"ADD_PROJECT_TO_HOST": "False", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "False", "TYPE": "ps", "USER": "bsc32070"}, "TRANSFER_NODE": {"ADD_PROJECT_TO_HOST": "false", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "ps", "USER": "bsc32070"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a005/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "None"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a005", "RUN": {"APP": "urban", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a005_LOCAL_SETUP','2023-06-12-15:24:11','2023-06-12-15:30:17',1686576251,1686576251,1686576256,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',60659,'',0,42,0.0,0.0,'a005_LOCAL_SETUP.20230612152423.out','a005_LOCAL_SETUP.20230612152423.err',5,'a005_SYNCHRONIZE','');
INSERT INTO job_data VALUES(2,0,'a005_SYNCHRONIZE','2023-06-12-15:24:23','2023-06-12-15:30:30',1686576263,1686576263,1686576268,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',60693,'',0,42,0.0,0.0,'a005_SYNCHRONIZE.20230612152435.out','a005_SYNCHRONIZE.20230612152435.err',5,'a005_REMOTE_SETUP','');
INSERT INTO job_data VALUES(3,0,'a005_REMOTE_SETUP','2023-06-12-15:24:40','2023-06-12-15:30:46',1686576280,1686576493,1686576523,'FAILED',2,192,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4',28955302,'',0,42,0.0,0.0,'a005_REMOTE_SETUP.20230612152813.out','a005_REMOTE_SETUP.20230612152813.err',5,'a005_20200120_fc1_1_1_DN,a005_20200120_fc0_2_2_DN,a005_20200120_fc1_4_1_DN,a005_20200120_fc1_1_2_DN,a005_20200120_fc0_3_1_DN,a005_20200120_fc1_4_2_DN,a005_20200120_fc1_2_1_DN,a005_20200120_fc0_3_2_DN,a005_20200120_fc0_1_1_DN,a005_20200120_fc1_2_2_DN,a005_20200120_fc0_4_1_DN,a005_20200120_fc0_1_2_DN,a005_20200120_fc1_3_1_DN,a005_20200120_fc0_4_2_DN,a005_20200120_fc0_2_1_DN,a005_20200120_fc1_3_2_DN','');
INSERT INTO job_data VALUES(4,1,'a005_LOCAL_SETUP','2023-06-12-15:30:17','2023-06-12-15:30:29',1686576617,1686576617,1686576622,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,1,'LOCAL',61057,'',0,43,0.0,0.0,'a005_LOCAL_SETUP.20230612153029.out','a005_LOCAL_SETUP.20230612153029.err',5,'a005_SYNCHRONIZE','');
INSERT INTO job_data VALUES(5,1,'a005_SYNCHRONIZE','2023-06-12-15:30:30','2023-06-12-15:30:42',1686576630,1686576630,1686576635,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,1,'LOCAL',61095,'',0,43,0.0,0.0,'a005_SYNCHRONIZE.20230612153042.out','a005_SYNCHRONIZE.20230612153042.err',5,'a005_REMOTE_SETUP','');
INSERT INTO job_data VALUES(6,1,'a005_REMOTE_SETUP','2023-06-12-15:30:46','2023-06-12-15:33:04',1686576646,1686576713,1686576718,'COMPLETED',2,192,'00:05','debug',2930,'','REMOTE_SETUP','',0,1,'MARENOSTRUM4',28955576,'',4,43,0.0,0.0,'a005_REMOTE_SETUP.20230612153202.out','a005_REMOTE_SETUP.20230612153202.err',2,'a005_20200120_fc1_1_1_DN,a005_20200120_fc0_2_2_DN,a005_20200120_fc1_4_1_DN,a005_20200120_fc1_1_2_DN,a005_20200120_fc0_3_1_DN,a005_20200120_fc1_4_2_DN,a005_20200120_fc1_2_1_DN,a005_20200120_fc0_3_2_DN,a005_20200120_fc0_1_1_DN,a005_20200120_fc1_2_2_DN,a005_20200120_fc0_4_1_DN,a005_20200120_fc0_1_2_DN,a005_20200120_fc1_3_1_DN,a005_20200120_fc0_4_2_DN,a005_20200120_fc0_2_1_DN,a005_20200120_fc1_3_2_DN',replace('                 28955576  COMPLETED        192        4 2023-06-12T15:30:46 2023-06-12T15:31:47 2023-06-12T15:31:59          2.93K                                                     \n           28955576.batch  COMPLETED         48        1 2023-06-12T15:31:47 2023-06-12T15:31:47 2023-06-12T15:31:59            547                     1380K                     1380K \n          28955576.extern  COMPLETED        192        4 2023-06-12T15:31:47 2023-06-12T15:31:47 2023-06-12T15:31:59          2.93K                      869K                   654.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(7,1,'a005_20200120_fc0_1_1_DN','2023-06-12-15:32:09','2023-06-12-15:34:31',1686576729,1686576784,1686576789,'COMPLETED',2,192,'00:05','debug',2800,'2020-01-20 00:00:00','DN','fc0',1,1,'MARENOSTRUM4',28955695,'',4,43,0.0,0.0,'a005_20200120_fc0_1_1_DN.20230612153309.out','a005_20200120_fc0_1_1_DN.20230612153309.err',2,'a005_20200120_fc0_1_1_OPA,a005_20200120_fc0_1_2_OPA',replace('                 28955695  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:32:59 2023-06-12T15:33:11          2.80K                                                     \n           28955695.batch  COMPLETED         48        1 2023-06-12T15:32:59 2023-06-12T15:32:59 2023-06-12T15:33:11            555                     1380K                     1380K \n          28955695.extern  COMPLETED        192        4 2023-06-12T15:32:59 2023-06-12T15:32:59 2023-06-12T15:33:11          2.80K                      873K                    860416 \n','\n',char(10)));
INSERT INTO job_data VALUES(8,1,'a005_20200120_fc0_1_2_DN','2023-06-12-15:32:09','2023-06-12-15:35:32',1686576729,1686576859,1686576864,'COMPLETED',2,192,'00:05','debug',2700,'2020-01-20 00:00:00','DN','fc0',1,1,'MARENOSTRUM4',28955696,'',4,43,0.0,0.0,'a005_20200120_fc0_1_2_DN.20230612153430.out','a005_20200120_fc0_1_2_DN.20230612153430.err',2,'a005_20200120_fc0_1_4_OPA,a005_20200120_fc0_1_3_OPA',replace('                 28955696  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:34:13 2023-06-12T15:34:25          2.70K                                                     \n           28955696.batch  COMPLETED         48        1 2023-06-12T15:34:13 2023-06-12T15:34:13 2023-06-12T15:34:25            501                     1391K                     1391K \n          28955696.extern  COMPLETED        192        4 2023-06-12T15:34:13 2023-06-12T15:34:13 2023-06-12T15:34:25          2.70K                      889K                    669440 \n','\n',char(10)));
INSERT INTO job_data VALUES(9,1,'a005_20200120_fc0_2_1_DN','2023-06-12-15:32:09','2023-06-12-15:37:12',1686576729,1686576943,1686576948,'COMPLETED',2,192,'00:05','debug',2990,'2020-01-20 00:00:00','DN','fc0',2,1,'MARENOSTRUM4',28955697,'',4,43,0.0,0.0,'a005_20200120_fc0_2_1_DN.20230612153550.out','a005_20200120_fc0_2_1_DN.20230612153550.err',2,'a005_20200120_fc0_2_2_OPA,a005_20200120_fc0_2_1_OPA',replace('                 28955697  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:35:37 2023-06-12T15:35:49          2.99K                                                     \n           28955697.batch  COMPLETED         48        1 2023-06-12T15:35:37 2023-06-12T15:35:37 2023-06-12T15:35:49            636                     1365K                     1365K \n          28955697.extern  COMPLETED        192        4 2023-06-12T15:35:37 2023-06-12T15:35:37 2023-06-12T15:35:49          2.99K                      868K                    660224 \n','\n',char(10)));
INSERT INTO job_data VALUES(10,1,'a005_20200120_fc0_2_2_DN','2023-06-12-15:32:09','2023-06-12-15:38:13',1686576729,1686577018,1686577023,'COMPLETED',2,192,'00:05','debug',3090,'2020-01-20 00:00:00','DN','fc0',2,1,'MARENOSTRUM4',28955698,'',4,43,0.0,0.0,'a005_20200120_fc0_2_2_DN.20230612153710.out','a005_20200120_fc0_2_2_DN.20230612153710.err',2,'a005_20200120_fc0_2_4_OPA,a005_20200120_fc0_2_3_OPA',replace('                 28955698  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:36:52 2023-06-12T15:37:04          3.09K                                                     \n           28955698.batch  COMPLETED         48        1 2023-06-12T15:36:52 2023-06-12T15:36:52 2023-06-12T15:37:04            540                     1410K                     1410K \n          28955698.extern  COMPLETED        192        4 2023-06-12T15:36:52 2023-06-12T15:36:52 2023-06-12T15:37:04          3.09K                      885K                   437.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(11,1,'a005_20200120_fc0_3_1_DN','2023-06-12-15:32:09','2023-06-12-15:39:39',1686576729,1686577095,1686577100,'COMPLETED',2,192,'00:05','debug',2960,'2020-01-20 00:00:00','DN','fc0',3,1,'MARENOSTRUM4',28955699,'',4,43,0.0,0.0,'a005_20200120_fc0_3_1_DN.20230612153817.out','a005_20200120_fc0_3_1_DN.20230612153817.err',2,'a005_20200120_fc0_3_2_OPA,a005_20200120_fc0_3_1_OPA',replace('                 28955699  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:38:09 2023-06-12T15:38:21          2.96K                                                     \n           28955699.batch  COMPLETED         48        1 2023-06-12T15:38:09 2023-06-12T15:38:09 2023-06-12T15:38:21            540                     1414K                     1414K \n          28955699.extern  COMPLETED        192        4 2023-06-12T15:38:09 2023-06-12T15:38:09 2023-06-12T15:38:21          2.96K                      841K                      812K \n','\n',char(10)));
INSERT INTO job_data VALUES(12,1,'a005_20200120_fc0_3_2_DN','2023-06-12-15:32:09','2023-06-12-15:40:41',1686576729,1686577168,1686577173,'COMPLETED',2,192,'00:05','debug',2880,'2020-01-20 00:00:00','DN','fc0',3,1,'MARENOSTRUM4',28955700,'',4,43,0.0,0.0,'a005_20200120_fc0_3_2_DN.20230612153938.out','a005_20200120_fc0_3_2_DN.20230612153938.err',2,'a005_20200120_fc0_3_4_OPA,a005_20200120_fc0_3_3_OPA',replace('                 28955700  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:39:22 2023-06-12T15:39:34          2.88K                                                     \n           28955700.batch  COMPLETED         48        1 2023-06-12T15:39:22 2023-06-12T15:39:22 2023-06-12T15:39:34            580                     1361K                     1361K \n          28955700.extern  COMPLETED        192        4 2023-06-12T15:39:22 2023-06-12T15:39:22 2023-06-12T15:39:34          2.88K                      862K                   828.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(13,1,'a005_20200120_fc0_4_1_DN','2023-06-12-15:32:09','2023-06-12-15:42:08',1686576729,1686577242,1686577247,'COMPLETED',2,192,'00:05','debug',2680,'2020-01-20 00:00:00','DN','fc0',4,1,'MARENOSTRUM4',28955701,'',4,43,0.0,0.0,'a005_20200120_fc0_4_1_DN.20230612154046.out','a005_20200120_fc0_4_1_DN.20230612154046.err',2,'a005_20200120_fc0_4_2_OPA,a005_20200120_fc0_4_1_OPA',replace('                 28955701  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:40:36 2023-06-12T15:40:48          2.68K                                                     \n           28955701.batch  COMPLETED         48        1 2023-06-12T15:40:36 2023-06-12T15:40:36 2023-06-12T15:40:48            587                     1401K                     1401K \n          28955701.extern  COMPLETED        192        4 2023-06-12T15:40:36 2023-06-12T15:40:36 2023-06-12T15:40:48          2.68K                      862K                      440K \n','\n',char(10)));
INSERT INTO job_data VALUES(14,1,'a005_20200120_fc0_4_2_DN','2023-06-12-15:32:09','2023-06-12-15:43:09',1686576729,1686577314,1686577319,'COMPLETED',2,192,'00:05','debug',2340,'2020-01-20 00:00:00','DN','fc0',4,1,'MARENOSTRUM4',28955702,'',4,43,0.0,0.0,'a005_20200120_fc0_4_2_DN.20230612154206.out','a005_20200120_fc0_4_2_DN.20230612154206.err',2,'a005_20200120_fc0_4_4_OPA,a005_20200120_fc0_4_3_OPA',replace('                 28955702  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:41:48 2023-06-12T15:41:59          2.34K                                                     \n           28955702.batch  COMPLETED         48        1 2023-06-12T15:41:48 2023-06-12T15:41:48 2023-06-12T15:41:59            568                     1369K                     1369K \n          28955702.extern  COMPLETED        192        4 2023-06-12T15:41:48 2023-06-12T15:41:48 2023-06-12T15:41:59          2.34K                      855K                    635648 \n','\n',char(10)));
INSERT INTO job_data VALUES(15,1,'a005_20200120_fc1_1_1_DN','2023-06-12-15:32:09','2023-06-12-15:46:38',1686576729,1686577496,1686577528,'COMPLETED',2,192,'00:05','debug',26150,'2020-01-20 00:00:00','DN','fc1',1,1,'MARENOSTRUM4',28955703,'',4,43,0.0,0.0,'a005_20200120_fc1_1_1_DN.20230612154456.out','a005_20200120_fc1_1_1_DN.20230612154456.err',2,'a005_20200120_fc1_1_2_OPA,a005_20200120_fc1_1_1_OPA',replace('                 28955703  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:44:14 2023-06-12T15:45:28         26.15K                                                     \n           28955703.batch  COMPLETED         48        1 2023-06-12T15:44:14 2023-06-12T15:44:14 2023-06-12T15:45:28          6.21K                     1944K                     1944K \n          28955703.extern  COMPLETED        192        4 2023-06-12T15:44:14 2023-06-12T15:44:14 2023-06-12T15:45:28         26.15K                      877K                      665K \n','\n',char(10)));
INSERT INTO job_data VALUES(16,1,'a005_20200120_fc1_1_2_DN','2023-06-12-15:32:09','2023-06-12-15:51:53',1686576729,1686577839,1686577844,'COMPLETED',2,192,'00:05','debug',3020,'2020-01-20 00:00:00','DN','fc1',1,1,'MARENOSTRUM4',28955704,'',4,43,0.0,0.0,'a005_20200120_fc1_1_2_DN.20230612155051.out','a005_20200120_fc1_1_2_DN.20230612155051.err',2,'a005_20200120_fc1_1_4_OPA,a005_20200120_fc1_1_3_OPA',replace('                 28955704  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:50:33 2023-06-12T15:50:45          3.02K                                                     \n           28955704.batch  COMPLETED         48        1 2023-06-12T15:50:33 2023-06-12T15:50:33 2023-06-12T15:50:45            611                     1404K                     1404K \n          28955704.extern  COMPLETED        192        4 2023-06-12T15:50:33 2023-06-12T15:50:33 2023-06-12T15:50:45          3.02K                      892K                      658K \n','\n',char(10)));
INSERT INTO job_data VALUES(17,1,'a005_20200120_fc1_2_1_DN','2023-06-12-15:32:09','2023-06-12-15:53:21',1686576729,1686577915,1686577920,'COMPLETED',2,192,'00:05','debug',3880,'2020-01-20 00:00:00','DN','fc1',2,1,'MARENOSTRUM4',28955705,'',4,43,0.0,0.0,'a005_20200120_fc1_2_1_DN.20230612155159.out','a005_20200120_fc1_2_1_DN.20230612155159.err',2,'a005_20200120_fc1_2_2_OPA,a005_20200120_fc1_2_1_OPA',replace('                 28955705  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:51:49 2023-06-12T15:52:01          3.88K                                                     \n           28955705.batch  COMPLETED         48        1 2023-06-12T15:51:49 2023-06-12T15:51:49 2023-06-12T15:52:01            769                     1411K                     1411K \n          28955705.extern  COMPLETED        192        4 2023-06-12T15:51:49 2023-06-12T15:51:49 2023-06-12T15:52:01          3.88K                      867K                    649984 \n','\n',char(10)));
INSERT INTO job_data VALUES(18,1,'a005_20200120_fc1_2_2_DN','2023-06-12-15:32:09','2023-06-12-15:54:24',1686576729,1686577989,1686577994,'COMPLETED',2,192,'00:05','debug',3070,'2020-01-20 00:00:00','DN','fc1',2,1,'MARENOSTRUM4',28955706,'',4,43,0.0,0.0,'a005_20200120_fc1_2_2_DN.20230612155322.out','a005_20200120_fc1_2_2_DN.20230612155322.err',2,'a005_20200120_fc1_2_3_OPA,a005_20200120_fc1_2_4_OPA',replace('                 28955706  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:53:03 2023-06-12T15:53:15          3.07K                                                     \n           28955706.batch  COMPLETED         48        1 2023-06-12T15:53:03 2023-06-12T15:53:03 2023-06-12T15:53:15            547                     1389K                     1389K \n          28955706.extern  COMPLETED        192        4 2023-06-12T15:53:03 2023-06-12T15:53:03 2023-06-12T15:53:15          3.07K                      855K                   235.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(19,1,'a005_20200120_fc1_3_1_DN','2023-06-12-15:32:09','2023-06-12-15:55:52',1686576729,1686578065,1686578070,'COMPLETED',2,192,'00:05','debug',2730,'2020-01-20 00:00:00','DN','fc1',3,1,'MARENOSTRUM4',28955707,'',4,43,0.0,0.0,'a005_20200120_fc1_3_1_DN.20230612155430.out','a005_20200120_fc1_3_1_DN.20230612155430.err',2,'a005_20200120_fc1_3_2_OPA,a005_20200120_fc1_3_1_OPA',replace('                 28955707  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:54:20 2023-06-12T15:54:32          2.73K                                                     \n           28955707.batch  COMPLETED         48        1 2023-06-12T15:54:20 2023-06-12T15:54:20 2023-06-12T15:54:32            454                     1388K                     1388K \n          28955707.extern  COMPLETED        192        4 2023-06-12T15:54:20 2023-06-12T15:54:20 2023-06-12T15:54:32          2.73K                      781K                   399.50K \n','\n',char(10)));
INSERT INTO job_data VALUES(20,1,'a005_20200120_fc1_3_2_DN','2023-06-12-15:32:09','2023-06-12-15:56:52',1686576729,1686578140,1686578145,'COMPLETED',2,192,'00:05','debug',2860,'2020-01-20 00:00:00','DN','fc1',3,1,'MARENOSTRUM4',28955708,'',4,43,0.0,0.0,'a005_20200120_fc1_3_2_DN.20230612155550.out','a005_20200120_fc1_3_2_DN.20230612155550.err',2,'a005_20200120_fc1_3_4_OPA,a005_20200120_fc1_3_3_OPA',replace('                 28955708  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:55:35 2023-06-12T15:55:47          2.86K                                                     \n           28955708.batch  COMPLETED         48        1 2023-06-12T15:55:35 2023-06-12T15:55:35 2023-06-12T15:55:47            531                     1389K                     1389K \n          28955708.extern  COMPLETED        192        4 2023-06-12T15:55:35 2023-06-12T15:55:35 2023-06-12T15:55:47          2.86K                      891K                    674560 \n','\n',char(10)));
INSERT INTO job_data VALUES(21,1,'a005_20200120_fc1_4_1_DN','2023-06-12-15:32:09','2023-06-12-15:58:16',1686576729,1686578217,1686578222,'COMPLETED',2,192,'00:05','debug',2850,'2020-01-20 00:00:00','DN','fc1',4,1,'MARENOSTRUM4',28955709,'',4,43,0.0,0.0,'a005_20200120_fc1_4_1_DN.20230612155713.out','a005_20200120_fc1_4_1_DN.20230612155713.err',2,'a005_20200120_fc1_4_2_OPA,a005_20200120_fc1_4_1_OPA',replace('                 28955709  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:56:51 2023-06-12T15:57:03          2.85K                                                     \n           28955709.batch  COMPLETED         48        1 2023-06-12T15:56:51 2023-06-12T15:56:51 2023-06-12T15:57:03            489                     1388K                     1388K \n          28955709.extern  COMPLETED        192        4 2023-06-12T15:56:51 2023-06-12T15:56:51 2023-06-12T15:57:03          2.85K                      867K                      644K \n','\n',char(10)));
INSERT INTO job_data VALUES(22,1,'a005_20200120_fc1_4_2_DN','2023-06-12-15:32:10','2023-06-12-15:59:39',1686576730,1686578293,1686578298,'COMPLETED',2,192,'00:05','debug',3100,'2020-01-20 00:00:00','DN','fc1',4,1,'MARENOSTRUM4',28955710,'',4,43,0.0,0.0,'a005_20200120_fc1_4_2_DN.20230612155817.out','a005_20200120_fc1_4_2_DN.20230612155817.err',2,'a005_20200120_fc1_4_4_OPA,a005_20200120_fc1_4_3_OPA',replace('                 28955710  COMPLETED        192        4 2023-06-12T15:32:09 2023-06-12T15:58:07 2023-06-12T15:58:19          3.10K                                                     \n           28955710.batch  COMPLETED         48        1 2023-06-12T15:58:07 2023-06-12T15:58:07 2023-06-12T15:58:19            628                     1389K                     1389K \n          28955710.extern  COMPLETED        192        4 2023-06-12T15:58:07 2023-06-12T15:58:07 2023-06-12T15:58:19          3.10K                      899K                      660K \n','\n',char(10)));
INSERT INTO job_data VALUES(23,1,'a005_20200120_fc0_1_1_OPA','2023-06-12-15:33:31','2023-06-12-16:00:41',1686576811,1686578369,1686578374,'COMPLETED',2,192,'00:05','debug',2850,'2020-01-20 00:00:00','OPA','fc0',1,1,'MARENOSTRUM4',28955844,'',4,43,0.0,0.0,'a005_20200120_fc0_1_1_OPA.20230612155939.out','a005_20200120_fc0_1_1_OPA.20230612155939.err',2,'a005_20200120_fc0_1_APP',replace('                 28955844  COMPLETED        192        4 2023-06-12T15:33:31 2023-06-12T15:59:24 2023-06-12T15:59:36          2.85K                                                     \n           28955844.batch  COMPLETED         48        1 2023-06-12T15:59:24 2023-06-12T15:59:24 2023-06-12T15:59:36            503                     1391K                     1391K \n          28955844.extern  COMPLETED        192        4 2023-06-12T15:59:24 2023-06-12T15:59:24 2023-06-12T15:59:36          2.85K                      871K                    669952 \n','\n',char(10)));
INSERT INTO job_data VALUES(24,1,'a005_20200120_fc0_1_2_OPA','2023-06-12-15:33:31','2023-06-12-16:15:31',1686576811,1686579254,1686579259,'COMPLETED',2,192,'00:05','debug',2730,'2020-01-20 00:00:00','OPA','fc0',1,1,'MARENOSTRUM4',28955846,'',4,43,0.0,0.0,'a005_20200120_fc0_1_2_OPA.20230612161429.out','a005_20200120_fc0_1_2_OPA.20230612161429.err',2,'a005_20200120_fc0_1_APP',replace('                 28955846  COMPLETED        192        4 2023-06-12T15:33:31 2023-06-12T16:14:09 2023-06-12T16:14:21          2.73K                                                     \n           28955846.batch  COMPLETED         48        1 2023-06-12T16:14:09 2023-06-12T16:14:09 2023-06-12T16:14:21            600                     1398K                     1398K \n          28955846.extern  COMPLETED        192        4 2023-06-12T16:14:09 2023-06-12T16:14:09 2023-06-12T16:14:21          2.73K                      868K                      843K \n','\n',char(10)));
INSERT INTO job_data VALUES(25,1,'a005_20200120_fc0_1_3_OPA','2023-06-12-15:34:33','2023-06-12-16:16:54',1686576873,1686579335,1686579340,'COMPLETED',2,192,'00:05','debug',2800,'2020-01-20 00:00:00','OPA','fc0',1,1,'MARENOSTRUM4',28955925,'',4,43,0.0,0.0,'a005_20200120_fc0_1_3_OPA.20230612161552.out','a005_20200120_fc0_1_3_OPA.20230612161552.err',2,'a005_20200120_fc0_1_APP',replace('                 28955925  COMPLETED        192        4 2023-06-12T15:34:33 2023-06-12T16:15:29 2023-06-12T16:15:41          2.80K                                                     \n           28955925.batch  COMPLETED         48        1 2023-06-12T16:15:29 2023-06-12T16:15:29 2023-06-12T16:15:41            549                     1382K                     1382K \n          28955925.extern  COMPLETED        192        4 2023-06-12T16:15:29 2023-06-12T16:15:29 2023-06-12T16:15:41          2.80K                      901K                    875776 \n','\n',char(10)));
INSERT INTO job_data VALUES(26,1,'a005_20200120_fc0_1_4_OPA','2023-06-12-15:34:33','2023-06-12-16:18:17',1686576873,1686579418,1686579423,'COMPLETED',2,192,'00:05','debug',2850,'2020-01-20 00:00:00','OPA','fc0',1,1,'MARENOSTRUM4',28955926,'',4,43,0.0,0.0,'a005_20200120_fc0_1_4_OPA.20230612161714.out','a005_20200120_fc0_1_4_OPA.20230612161714.err',2,'a005_20200120_fc0_1_APP',replace('                 28955926  COMPLETED        192        4 2023-06-12T15:34:33 2023-06-12T16:16:52 2023-06-12T16:17:04          2.85K                                                     \n           28955926.batch  COMPLETED         48        1 2023-06-12T16:16:52 2023-06-12T16:16:52 2023-06-12T16:17:04            521                     1370K                     1370K \n          28955926.extern  COMPLETED        192        4 2023-06-12T16:16:52 2023-06-12T16:16:52 2023-06-12T16:17:04          2.85K                      886K                      664K \n','\n',char(10)));
INSERT INTO job_data VALUES(27,1,'a005_20200120_fc0_2_1_OPA','2023-06-12-15:36:12','2023-06-12-16:19:43',1686576972,1686579496,1686579501,'COMPLETED',2,192,'00:05','debug',2830,'2020-01-20 00:00:00','OPA','fc0',2,1,'MARENOSTRUM4',28955939,'',4,43,0.0,0.0,'a005_20200120_fc0_2_1_OPA.20230612161821.out','a005_20200120_fc0_2_1_OPA.20230612161821.err',2,'a005_20200120_fc0_2_APP',replace('                 28955939  COMPLETED        192        4 2023-06-12T15:36:12 2023-06-12T16:18:10 2023-06-12T16:18:22          2.83K                                                     \n           28955939.batch  COMPLETED         48        1 2023-06-12T16:18:10 2023-06-12T16:18:10 2023-06-12T16:18:22            568                     1366K                     1366K \n          28955939.extern  COMPLETED        192        4 2023-06-12T16:18:10 2023-06-12T16:18:10 2023-06-12T16:18:23          2.83K                      882K                    858880 \n','\n',char(10)));
INSERT INTO job_data VALUES(28,1,'a005_20200120_fc0_2_2_OPA','2023-06-12-15:36:12','2023-06-12-16:20:04',1686576972,1686579574,1686579579,'COMPLETED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',2,1,'MARENOSTRUM4',28955940,'',0,43,0.0,0.0,'a005_20200120_fc0_2_2_OPA.20230612161944.out','a005_20200120_fc0_2_2_OPA.20230612161944.err',5,'a005_20200120_fc0_2_APP','');
INSERT INTO job_data VALUES(29,1,'a005_20200120_fc0_2_3_OPA','2023-06-12-15:37:14','2023-06-12-15:37:14',1686577034,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',2,1,'MARENOSTRUM4',28955953,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc0_2_APP','');
INSERT INTO job_data VALUES(30,1,'a005_20200120_fc0_2_4_OPA','2023-06-12-15:37:14','2023-06-12-15:37:14',1686577034,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',2,1,'MARENOSTRUM4',28955954,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc0_2_APP','');
INSERT INTO job_data VALUES(31,1,'a005_20200120_fc0_3_1_OPA','2023-06-12-15:38:40','2023-06-12-15:38:40',1686577120,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',3,1,'MARENOSTRUM4',28955962,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc0_3_APP','');
INSERT INTO job_data VALUES(32,1,'a005_20200120_fc0_3_2_OPA','2023-06-12-15:39:42','2023-06-12-15:39:42',1686577182,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',3,1,'MARENOSTRUM4',28955971,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc0_3_APP','');
INSERT INTO job_data VALUES(33,1,'a005_20200120_fc0_3_3_OPA','2023-06-12-15:41:08','2023-06-12-15:41:08',1686577268,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',3,1,'MARENOSTRUM4',28955977,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc0_3_APP','');
INSERT INTO job_data VALUES(34,1,'a005_20200120_fc0_3_4_OPA','2023-06-12-15:42:09','2023-06-12-15:42:09',1686577329,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',3,1,'MARENOSTRUM4',28955982,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc0_3_APP','');
INSERT INTO job_data VALUES(35,1,'a005_20200120_fc0_4_1_OPA','2023-06-12-15:45:39','2023-06-12-15:45:39',1686577539,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',4,1,'MARENOSTRUM4',28956062,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc0_4_APP','');
INSERT INTO job_data VALUES(36,1,'a005_20200120_fc0_4_2_OPA','2023-06-12-15:50:54','2023-06-12-15:50:54',1686577854,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',4,1,'MARENOSTRUM4',28956319,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc0_4_APP','');
INSERT INTO job_data VALUES(37,1,'a005_20200120_fc0_4_3_OPA','2023-06-12-15:52:22','2023-06-12-15:52:22',1686577942,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',4,1,'MARENOSTRUM4',28956383,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc0_4_APP','');
INSERT INTO job_data VALUES(38,1,'a005_20200120_fc0_4_4_OPA','2023-06-12-15:53:25','2023-06-12-15:53:25',1686578005,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc0',4,1,'MARENOSTRUM4',28956411,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc0_4_APP','');
INSERT INTO job_data VALUES(39,1,'a005_20200120_fc1_1_1_OPA','2023-06-12-15:54:52','2023-06-12-15:54:52',1686578092,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc1',1,1,'MARENOSTRUM4',28956417,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc1_1_APP','');
INSERT INTO job_data VALUES(40,1,'a005_20200120_fc1_1_2_OPA','2023-06-12-15:55:53','2023-06-12-15:55:53',1686578153,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc1',1,1,'MARENOSTRUM4',28956423,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc1_1_APP','');
INSERT INTO job_data VALUES(41,1,'a005_20200120_fc1_1_3_OPA','2023-06-12-15:57:16','2023-06-12-15:57:16',1686578236,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc1',1,1,'MARENOSTRUM4',28956432,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc1_1_APP','');
INSERT INTO job_data VALUES(42,1,'a005_20200120_fc1_1_4_OPA','2023-06-12-15:58:40','2023-06-12-15:58:40',1686578320,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc1',1,1,'MARENOSTRUM4',28956439,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc1_1_APP','');
INSERT INTO job_data VALUES(43,1,'a005_20200120_fc1_2_1_OPA','2023-06-12-15:59:42','2023-06-12-15:59:42',1686578382,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc1',2,1,'MARENOSTRUM4',28956446,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc1_2_APP','');
INSERT INTO job_data VALUES(44,1,'a005_20200120_fc1_2_2_OPA','2023-06-12-16:14:32','2023-06-12-16:14:32',1686579272,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc1',2,1,'MARENOSTRUM4',28957052,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc1_2_APP','');
INSERT INTO job_data VALUES(45,1,'a005_20200120_fc1_2_3_OPA','2023-06-12-16:15:55','2023-06-12-16:15:55',1686579355,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc1',2,1,'MARENOSTRUM4',28957062,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc1_2_APP','');
INSERT INTO job_data VALUES(46,1,'a005_20200120_fc1_2_4_OPA','2023-06-12-16:17:17','2023-06-12-16:17:17',1686579437,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc1',2,1,'MARENOSTRUM4',28957071,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc1_2_APP','');
INSERT INTO job_data VALUES(47,1,'a005_20200120_fc1_3_1_OPA','2023-06-12-16:18:43','2023-06-12-16:18:43',1686579523,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc1',3,1,'MARENOSTRUM4',28957083,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc1_3_APP','');
INSERT INTO job_data VALUES(48,1,'a005_20200120_fc1_3_2_OPA','2023-06-12-16:20:06','2023-06-12-16:20:06',1686579606,0,0,'SUBMITTED',2,192,'00:05','debug',0,'2020-01-20 00:00:00','OPA','fc1',3,1,'MARENOSTRUM4',28957089,'',0,43,0.0,0.0,'','',0,'a005_20200120_fc1_3_APP','');
INSERT INTO job_data VALUES(49,1,'a005_20200120_fc0_1_APP','2023-06-13-08:55:27','2023-06-13-08:56:31',1686580712,1686581302,1686581307,'COMPLETED',16865799243650,192,'00:05','debug',5181.0600000000004003,'2020-01-20 00:00:00','APP','fc0',1,1,'MARENOSTRUM4',28957269,'',0,44,0.0,0.0,'','',2,'a005_20200120_fc0_2_APP','');
INSERT INTO job_data VALUES(50,1,'a005_20200120_fc0_3_APP','2023-06-13-08:55:28','2023-06-13-08:56:31',1686580712,1686581312,1686581318,'COMPLETED',16865799243650,192,'00:05','debug',6216.8299999999999273,'2020-01-20 00:00:00','APP','fc0',3,1,'MARENOSTRUM4',28957269,'',0,44,0.0,0.0,'','',2,'a005_20200120_fc0_4_APP','');
INSERT INTO job_data VALUES(51,1,'a005_20200120_fc0_2_APP','2023-06-13-08:55:28','2023-06-13-08:56:31',1686580712,1686581307,1686581312,'COMPLETED',16865799243650,192,'00:05','debug',5181.0600000000004003,'2020-01-20 00:00:00','APP','fc0',2,1,'MARENOSTRUM4',28957269,'',0,44,0.0,0.0,'','',2,'a005_20200120_fc0_3_APP','');
INSERT INTO job_data VALUES(52,1,'a005_20200120_fc0_4_APP','2023-06-13-08:55:28','2023-06-13-08:56:31',1686580712,1686581318,1686581323,'COMPLETED',16865799243650,192,'00:05','debug',5181.0600000000004003,'2020-01-20 00:00:00','APP','fc0',4,1,'MARENOSTRUM4',28957269,'',0,44,0.0,0.0,'','',2,'',replace('                 28957269  COMPLETED        480       10 2023-06-12T16:38:32 2023-06-12T16:48:17 2023-06-12T16:48:43         21.76K                                                     \n           28957269.batch  COMPLETED         48        1 2023-06-12T16:48:17 2023-06-12T16:48:17 2023-06-12T16:48:43          2.46K                     1365K                     1365K \n          28957269.extern  COMPLETED        480       10 2023-06-12T16:48:17 2023-06-12T16:48:17 2023-06-12T16:48:43         21.76K                      885K                    764518 \n','\n',char(10)));
INSERT INTO job_data VALUES(53,1,'a005_20200120_fc1_1_APP','2023-06-13-08:55:34','2023-06-13-08:55:34',1686580712,1686581380,1686581385,'COMPLETED',16865799247987,192,'00:05','debug',0,'2020-01-20 00:00:00','APP','fc1',1,1,'MARENOSTRUM4',28957270,'',0,44,0.0,0.0,'','',5,'a005_20200120_fc1_2_APP','');
INSERT INTO job_data VALUES(54,1,'a005_20200120_fc1_3_APP','2023-06-13-08:55:35','2023-06-13-08:55:35',1686580712,1686581390,1686581395,'COMPLETED',16865799247987,192,'00:05','debug',0,'2020-01-20 00:00:00','APP','fc1',3,1,'MARENOSTRUM4',28957270,'',0,44,0.0,0.0,'','',5,'a005_20200120_fc1_4_APP','');
INSERT INTO job_data VALUES(55,1,'a005_20200120_fc1_2_APP','2023-06-13-08:55:35','2023-06-13-08:55:35',1686580712,1686581385,1686581390,'COMPLETED',16865799247987,192,'00:05','debug',0,'2020-01-20 00:00:00','APP','fc1',2,1,'MARENOSTRUM4',28957270,'',0,44,0.0,0.0,'','',5,'a005_20200120_fc1_3_APP','');
INSERT INTO job_data VALUES(56,1,'a005_20200120_fc1_4_APP','2023-06-13-08:55:35','2023-06-13-08:55:35',1686580712,1686581395,1686581401,'COMPLETED',16865799247987,192,'00:05','debug',0,'2020-01-20 00:00:00','APP','fc1',4,1,'MARENOSTRUM4',28957270,'',0,44,0.0,0.0,'','',5,'','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',46);
INSERT INTO sqlite_sequence VALUES('job_data',56);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
