PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-05-10-13:15:54','2023-05-10-13:50:01',1683717354,1683719401,'month',4,0,22,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY[1]": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY[4]": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(2,'2023-05-10-13:50:01','2023-05-10-15:37:05',1683719401,1683725825,'month',4,0,22,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY[1]": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY[4]": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(3,'2023-05-10-15:37:05','2023-05-10-15:45:32',1683725825,1683726332,'month',4,0,22,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY[1]": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY[4]": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(4,'2023-05-10-15:45:32','2023-05-10-15:46:25',1683726332,1683726385,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"SPLITS_TO": "1"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(5,'2023-05-10-15:46:26','2023-05-10-15:47:20',1683726386,1683726440,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"SPLITS_TO": "1"}, "1": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(6,'2023-05-10-15:47:20','2023-05-10-17:01:37',1683726440,1683730897,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(7,'2023-05-10-17:01:37','2023-05-10-17:08:23',1683730897,1683731303,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(8,'2023-05-10-17:08:23','2023-05-10-17:09:03',1683731303,1683731343,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(9,'2023-05-10-17:09:03','2023-05-10-17:59:58',1683731343,1683734398,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"SPLITS_TO": "1"}, "1": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(10,'2023-05-10-17:59:58','2023-05-10-18:02:50',1683734398,1683734570,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"SPLITS_TO": "1"}, "1": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(11,'2023-05-10-18:02:50','2023-05-10-18:04:52',1683734570,1683734692,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"SPLITS_TO": "1"}, "1": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(12,'2023-05-10-18:04:52','2023-05-10-18:13:22',1683734692,1683735202,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"SPLITS_TO": "1"}, "1": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(13,'2023-05-10-18:13:22','2023-05-11-08:34:41',1683735202,1683786881,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "1"}, "1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(14,'2023-05-11-08:34:41','2023-05-11-08:35:45',1683786881,1683786945,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "1"}, "1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(15,'2023-05-11-08:35:45','2023-05-11-08:39:53',1683786945,1683787193,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "1"}, "1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(16,'2023-05-11-08:39:53','2023-05-11-08:40:31',1683787193,1683787231,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(17,'2023-05-11-08:40:31','2023-05-11-08:41:16',1683787231,1683787276,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(18,'2023-05-11-08:41:16','2023-05-11-08:44:33',1683787276,1683787473,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(19,'2023-05-11-08:44:33','2023-05-11-08:45:04',1683787473,1683787504,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(20,'2023-05-11-08:45:04','2023-05-11-08:45:56',1683787504,1683787556,'month',4,0,9,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(21,'2023-05-11-08:45:56','2023-05-11-08:46:31',1683787556,1683787591,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(22,'2023-05-11-08:46:31','2023-05-11-08:48:02',1683787591,1683787682,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(23,'2023-05-11-08:48:02','2023-05-11-08:49:17',1683787682,1683787757,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(24,'2023-05-11-08:49:17','2023-05-11-08:50:26',1683787757,1683787826,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(25,'2023-05-11-08:50:26','2023-05-11-08:51:29',1683787826,1683787889,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {"SPLITS_FROM": {"1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "all"}, "2": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "2"}, "3": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "3"}, "4": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "4"}}}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(26,'2023-05-11-08:51:29','2023-05-11-08:52:05',1683787889,1683787925,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": null}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(27,'2023-05-11-08:52:05','2023-05-11-08:52:30',1683787925,1683787950,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": null}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "1"}, "1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(28,'2023-05-11-08:52:30','2023-05-11-08:53:02',1683787950,1683787982,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "1"}, "1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(29,'2023-05-11-08:53:02','2023-05-11-08:54:53',1683787982,1683788093,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(30,'2023-05-11-08:54:53','2023-05-11-08:55:24',1683788093,1683788124,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(31,'2023-05-11-08:55:24','2023-05-11-08:56:18',1683788124,1683788178,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(32,'2023-05-11-08:56:18','2023-05-11-08:57:37',1683788178,1683788257,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"2": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "1"}, "1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(33,'2023-05-11-08:57:37','2023-05-11-08:58:19',1683788257,1683788299,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(34,'2023-05-11-08:58:19','2023-05-11-09:01:26',1683788299,1683788486,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "2,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(35,'2023-05-11-09:01:26','2023-05-11-09:02:22',1683788486,1683788542,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,3"}, "2": {"SPLITS_TO": "2,4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(36,'2023-05-11-09:02:22','2023-05-11-09:08:59',1683788542,1683788939,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,3"}, "2": {"SPLITS_TO": "2,4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(37,'2023-05-11-09:08:59','2023-05-11-09:09:30',1683788939,1683788970,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA_1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(38,'2023-05-11-09:09:30','2023-05-11-09:10:01',1683788970,1683789001,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_1": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA_2": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(39,'2023-05-11-09:10:01','2023-05-11-09:10:29',1683789001,1683789029,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(40,'2023-05-11-09:10:29','2023-05-11-09:11:11',1683789029,1683789071,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "0,1"}, "2": {"SPLITS_TO": "2,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(41,'2023-05-11-09:11:11','2023-05-11-09:11:19',1683789071,1683789079,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(42,'2023-05-11-09:11:19','2023-05-11-09:23:44',1683789079,1683789824,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(43,'2023-05-11-09:23:44','2023-05-11-09:25:27',1683789824,1683789927,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(44,'2023-05-11-09:25:27','2023-05-11-09:26:15',1683789927,1683789975,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(45,'2023-05-11-09:26:15','2023-05-11-09:33:32',1683789975,1683790412,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(46,'2023-05-11-09:33:32','2023-05-11-09:36:05',1683790412,1683790565,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"Differential": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(47,'2023-05-11-09:36:05','2023-05-11-09:42:00',1683790565,1683790920,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(48,'2023-05-11-09:42:00','2023-05-11-09:42:55',1683790920,1683790975,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(49,'2023-05-11-09:42:55','2023-05-11-09:43:27',1683790975,1683791007,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(50,'2023-05-11-09:43:27','2023-05-11-14:19:00',1683791007,1683807540,'month',4,0,17,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "SPLITS": "8", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(51,'2023-05-11-14:19:00','2023-05-11-14:23:10',1683807540,1683807790,'month',4,0,17,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "SPLITS": "8", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(52,'2023-05-11-14:23:10','2023-05-11-14:27:38',1683807790,1683808058,'month',4,0,17,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "SPLITS": "8", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(53,'2023-05-11-14:27:38','2023-05-11-14:30:30',1683808058,1683808230,'month',4,0,17,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "SPLITS": "8", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(54,'2023-05-11-14:30:30','2023-05-11-14:32:01',1683808230,1683808321,'month',4,0,17,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "SPLITS": "8", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(55,'2023-05-11-14:32:01','2023-05-15-10:56:40',1683808321,1684141000,'month',4,0,17,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "SPLITS": "8", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(56,'2023-05-15-10:56:40','2023-05-15-11:00:17',1684141000,1684141217,'month',4,0,17,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "SPLITS": "8", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(57,'2023-05-15-11:00:17','2023-05-15-11:06:00',1684141217,1684141560,'month',4,0,17,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "SPLITS": "8", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "AQUA_DIAGNOSTIC": {"FILE": "LOCALPOST.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(58,'2023-05-15-11:06:00','2023-05-15-11:06:24',1684141560,1684141584,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3"}, "2": {"SPLITS_TO": "4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(59,'2023-05-15-11:06:24','2023-05-15-11:06:51',1684141584,1684141611,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "4"}, "2": {"SPLITS_TO": "3"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(60,'2023-05-15-11:06:51','2023-05-15-11:07:08',1684141611,1684141628,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "3,4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(61,'2023-05-15-11:07:08','2023-05-15-11:09:53',1684141628,1684141793,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "3,4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(62,'2023-05-15-11:09:53','2023-05-15-11:11:54',1684141793,1684141914,'month',4,0,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "3,4"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(63,'2023-05-15-11:11:54','2023-05-15-11:12:26',1684141914,1684141946,'month',4,0,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "3,4"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(64,'2023-05-15-11:12:26','2023-05-15-11:13:20',1684141946,1684142000,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "3,4"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(65,'2023-05-15-11:13:20','2023-05-15-11:26:45',1684142000,1684142805,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2,3,4"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(66,'2023-05-15-11:26:45','2023-05-15-12:48:00',1684142805,1684147680,'month',4,0,24,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2,3,4"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(67,'2023-05-15-12:48:00','2023-05-15-12:48:17',1684147680,1684147697,'month',4,0,24,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2,3,4"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(68,'2023-05-15-12:48:17','2023-05-15-13:09:07',1684147697,1684148947,'month',4,0,48,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2,3,4"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(69,'2023-05-15-13:09:07','2023-05-15-13:09:29',1684148947,1684148969,'month',4,0,48,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null, "DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "1", "SPLITS_TO": "1,2"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2,3,4"}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(70,'2023-05-15-13:09:29','2023-05-15-13:09:58',1684148969,1684148998,'month',4,0,48,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null, "DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "2", "SPLITS_TO": "1,2"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2,3,4"}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(71,'2023-05-15-13:09:58','2023-05-15-13:10:43',1684148998,1684149043,'month',4,0,48,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null, "DATES_FROM": {"0": {"MEMBERS_FROM": {"0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "2", "SPLITS_TO": "1,2"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2,3,4"}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(72,'2023-05-15-13:10:43','2023-05-15-13:16:07',1684149043,1684149367,'month',4,0,48,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null, "DATES_FROM": {"0": {"MEMBERS_FROM": {"0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "2", "SPLITS_TO": "1,2"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2,3,4"}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(73,'2023-05-15-13:16:07','2023-05-15-13:16:42',1684149367,1684149402,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null, "DATES_FROM": {"0": {"MEMBERS_FROM": {"0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "2", "SPLITS_TO": "1,2"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2,3,4"}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(74,'2023-05-15-13:16:42','2023-05-15-13:17:39',1684149402,1684149459,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"0": {"MEMBERS_FROM": {"0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "2", "SPLITS_TO": "1,2"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2,3,4"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(75,'2023-05-15-13:17:39','2023-05-15-13:19:46',1684149459,1684149586,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"0": {"MEMBERS_FROM": {"0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "2", "SPLITS_TO": "1,2"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "3,4"}}}, "2": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "none"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(76,'2023-05-15-13:19:46','2023-05-15-13:22:09',1684149586,1684149729,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"0": {"MEMBERS_FROM": {"0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "2", "SPLITS_TO": "1,2"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "3,4"}}}}}}}, "1": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "none"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(77,'2023-05-15-13:22:09','2023-05-15-13:22:58',1684149729,1684149778,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"0": {"MEMBERS_FROM": {"0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "2", "SPLITS_TO": "1,2"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "3,4"}}}}}}}, "1": {"SPLITS_FROM": {"ALL": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(78,'2023-05-15-13:22:58','2023-05-15-14:00:45',1684149778,1684152045,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"1": {"SPLITS_FROM": {"ALL": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(79,'2023-05-15-14:00:45','2023-05-15-14:01:35',1684152045,1684152095,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000102": {"SPLITS_FROM": {"ALL": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(80,'2023-05-15-14:01:35','2023-05-15-14:02:08',1684152095,1684152128,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "2", "SPLITS_TO": "1,2"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "3,4"}}}}}}}, "20000102": {"SPLITS_FROM": {"ALL": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(81,'2023-05-15-14:02:08','2023-05-15-14:03:51',1684152128,1684152231,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "3,4"}}}}}}}, "20000102": {"SPLITS_FROM": {"ALL": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(82,'2023-05-15-14:03:51','2023-05-15-14:04:54',1684152231,1684152294,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}}, "FC1": {"CHUNKS_FROM": {"2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}, "2": {"SPLITS_TO": "2"}}}}}}}}, "20000102": {"SPLITS_FROM": {"ALL": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(83,'2023-05-15-14:04:54','2023-05-15-14:05:48',1684152294,1684152348,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "1,2"}}}}, "FC1": {"CHUNKS_FROM": {"2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3,4"}, "2": {"SPLITS_TO": "3,4"}}}}}}}}, "20000102": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(84,'2023-05-15-14:05:48','2023-05-15-14:06:49',1684152348,1684152409,'month',4,0,20,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC0": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1,2"}, "2": {"SPLITS_TO": "1,2"}}}}, "FC1": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3,4"}, "2": {"SPLITS_TO": "3,4"}}}}}}}}, "20000102": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(85,'2023-05-15-14:06:49','2023-05-15-14:43:20',1684152409,1684154600,'month',4,0,18,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC0": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}}, "FC1": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}, "2": {"SPLITS_TO": "2"}}}}}}}}, "20000102": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(86,'2023-05-15-14:43:20','2023-05-15-14:51:53',1684154600,1684155113,'month',4,0,18,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC0": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}}, "FC1": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}, "2": {"SPLITS_TO": "2"}}}}}}}}, "20000102": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(87,'2023-05-15-14:51:53','2023-05-15-14:52:41',1684155113,1684155161,'month',4,0,18,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}, "2": {"SPLITS_TO": "2"}}}}}}}, "20000102": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(88,'2023-05-15-14:52:41','2023-05-15-15:01:22',1684155161,1684155682,'month',4,0,18,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC1": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}, "2": {"SPLITS_TO": "2"}}}}}, "FC0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}, "2": {"SPLITS_TO": "2"}}}}}}}, "20000102": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(89,'2023-05-15-15:01:22','2023-05-15-15:31:45',1684155682,1684157505,'month',4,0,18,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC1": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}, "2": {"SPLITS_TO": "2"}}}}}, "FC0": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}, "2": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}, "2": {"SPLITS_TO": "2"}}}}}}}, "20000102": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "none"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(90,'2023-05-15-15:31:45','2023-05-15-15:32:27',1684157505,1684157547,'month',4,0,18,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(91,'2023-05-15-15:32:27','2023-05-15-15:32:57',1684157547,1684157577,'month',4,0,18,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(92,'2023-05-15-15:32:57','2023-05-15-15:33:54',1684157577,1684157634,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(93,'2023-05-15-15:33:54','2023-05-15-15:34:35',1684157634,1684157675,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "1"}, "2": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "2"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(94,'2023-05-15-15:34:35','2023-05-15-15:34:42',1684157675,1684157682,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "dates", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "1"}, "2": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "2"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(95,'2023-05-15-15:34:42','2023-05-15-15:35:48',1684157682,1684157748,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "1"}, "2": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "2"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(96,'2023-05-15-15:35:48','2023-05-15-15:36:37',1684157748,1684157797,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "1"}, "2": {"DATES_TO": "all", "MEMBERS_TO": "all", "CHUNKS_TO": "all", "SPLITS_TO": "2"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(97,'2023-05-15-15:36:37','2023-05-15-15:37:09',1684157797,1684157829,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "1"}, "2": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "2"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(98,'2023-05-15-15:37:09','2023-05-15-15:37:31',1684157829,1684157851,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "1"}, "2": {"DATES_TO": "none", "MEMBERS_TO": "none", "CHUNKS_TO": "none", "SPLITS_TO": "1"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(99,'2023-05-15-15:37:31','2023-05-15-15:37:44',1684157851,1684157864,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(100,'2023-05-15-15:37:44','2023-05-15-15:38:32',1684157864,1684157912,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "1"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(101,'2023-05-15-15:38:32','2023-05-15-15:39:14',1684157912,1684157954,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1,2": {"SPLITS_TO": "1"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(102,'2023-05-15-15:39:14','2023-05-15-15:43:30',1684157954,1684158210,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DIFFERENTIAL": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "1", "SPLITS_TO": "1"}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(103,'2023-05-15-15:43:30','2023-05-15-15:45:38',1684158210,1684158338,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}, "2": {"SPLITS_TO": "1"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(104,'2023-05-15-15:45:38','2023-05-15-15:47:44',1684158338,1684158464,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(105,'2023-05-15-15:47:44','2023-05-15-15:48:54',1684158464,1684158534,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"CHUNKS_FROM": {"1": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "1", "SPLITS_TO": "1"}, "2": {"CHUNKS_TO": "1", "SPLITS_TO": "2"}}}, "2": {"SPLITS_FROM": {"1": {"CHUNKS_TO": "2", "SPLITS_TO": "1"}, "2": {"CHUNKS_TO": "2", "SPLITS_TO": "2"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(106,'2023-05-15-15:48:54','2023-05-16-10:00:28',1684158534,1684224028,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(107,'2023-05-16-10:00:28','2023-05-16-10:01:49',1684224028,1684224109,'month',4,0,201,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(108,'2023-05-16-10:01:49','2023-05-16-10:02:12',1684224109,1684224132,'month',4,0,201,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(109,'2023-05-16-10:02:12','2023-05-16-10:02:46',1684224132,1684224166,'month',4,0,201,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(110,'2023-05-16-10:02:46','2023-05-16-12:27:46',1684224166,1684232866,'month',4,0,101,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(111,'2023-05-16-12:27:46','2023-05-16-12:32:32',1684232866,1684233152,'month',4,0,101,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(112,'2023-05-16-12:32:32','2023-05-17-11:06:02',1684233152,1684314362,'month',4,0,101,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(113,'2023-05-17-11:06:02','2023-05-17-11:07:01',1684314362,1684314421,'month',4,0,101,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(114,'2023-05-17-11:07:01','2023-05-17-12:25:06',1684314421,1684319106,'month',4,5,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "5", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(115,'2023-05-17-12:25:06','2023-05-17-13:20:05',1684319106,1684322405,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "5", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(116,'2023-05-17-13:20:05','2023-05-17-13:35:10',1684322405,1684323310,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(117,'2023-05-17-13:35:10','2023-05-17-13:36:00',1684323310,1684323360,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(118,'2023-05-17-13:36:00','2023-05-17-13:36:26',1684323360,1684323386,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(119,'2023-05-17-13:36:26','2023-05-17-13:36:45',1684323386,1684323405,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(120,'2023-05-17-13:36:45','2023-05-17-13:37:18',1684323405,1684323438,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(121,'2023-05-17-13:37:18','2023-05-17-13:47:07',1684323438,1684324027,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(122,'2023-05-17-13:47:07','2023-05-17-13:50:17',1684324027,1684324217,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(123,'2023-05-17-13:50:17','2023-05-17-13:51:36',1684324217,1684324296,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(124,'2023-05-17-13:51:36','2023-05-17-13:52:41',1684324296,1684324361,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(125,'2023-05-17-13:52:41','2023-05-17-13:53:19',1684324361,1684324399,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(126,'2023-05-17-13:53:19','2023-05-17-13:57:21',1684324399,1684324641,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(127,'2023-05-17-13:57:21','2023-05-17-14:00:37',1684324641,1684324837,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(128,'2023-05-17-14:00:37','2023-05-17-14:01:32',1684324837,1684324892,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(129,'2023-05-17-14:01:32','2023-05-17-15:06:06',1684324892,1684328766,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(130,'2023-05-17-15:06:06','2023-05-17-15:06:24',1684328766,1684328784,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(131,'2023-05-17-15:06:24','2023-05-17-15:06:43',1684328784,1684328803,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(132,'2023-05-17-15:06:43','2023-05-17-15:07:02',1684328803,1684328822,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(133,'2023-05-17-15:07:02','2023-05-17-15:08:13',1684328822,1684328893,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(134,'2023-05-17-15:08:13','2023-05-17-15:10:06',1684328893,1684329006,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(135,'2023-05-17-15:10:06','2023-05-17-15:40:49',1684329006,1684330849,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(136,'2023-05-17-15:40:49','2023-05-17-15:41:05',1684330849,1684330865,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(137,'2023-05-17-15:41:05','2023-05-17-15:42:34',1684330865,1684330954,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(138,'2023-05-17-15:42:34','2023-05-17-15:43:04',1684330954,1684330984,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(139,'2023-05-17-15:43:05','2023-05-17-15:43:31',1684330985,1684331011,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(140,'2023-05-17-15:43:31','2023-05-17-15:45:46',1684331011,1684331146,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(141,'2023-05-17-15:45:46','2023-05-17-15:45:57',1684331146,1684331157,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(142,'2023-05-17-15:45:57','2023-05-17-15:47:33',1684331157,1684331253,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(143,'2023-05-17-15:47:33','2023-05-17-15:49:31',1684331253,1684331371,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(144,'2023-05-17-15:49:31','2023-05-17-15:55:31',1684331371,1684331731,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(145,'2023-05-17-15:55:31','2023-05-17-15:56:46',1684331731,1684331806,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(146,'2023-05-17-15:56:47','2023-05-17-15:58:33',1684331807,1684331913,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(147,'2023-05-17-15:58:33','2023-05-17-15:59:59',1684331913,1684331999,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(148,'2023-05-17-15:59:59','2023-05-17-16:00:10',1684331999,1684332010,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(149,'2023-05-17-16:00:11','2023-05-17-16:00:58',1684332011,1684332058,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(150,'2023-05-17-16:00:58','2023-05-17-16:09:22',1684332058,1684332562,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(151,'2023-05-17-16:09:22','2023-05-17-16:11:52',1684332562,1684332712,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(152,'2023-05-17-16:11:52','2023-05-17-16:13:45',1684332712,1684332825,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(153,'2023-05-17-16:13:45','2023-05-17-16:14:08',1684332825,1684332848,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(154,'2023-05-17-16:14:08','2023-05-17-16:17:03',1684332848,1684333023,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(155,'2023-05-17-16:17:03','2023-05-17-16:18:30',1684333023,1684333110,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(156,'2023-05-17-16:18:30','2023-05-17-16:18:37',1684333110,1684333117,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(157,'2023-05-17-16:18:37','2023-05-17-16:19:16',1684333117,1684333156,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(158,'2023-05-17-16:19:16','2023-05-17-16:26:33',1684333156,1684333593,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(159,'2023-05-17-16:26:33','2023-05-17-16:28:14',1684333593,1684333694,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(160,'2023-05-17-16:28:14','2023-05-17-16:28:22',1684333694,1684333702,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(161,'2023-05-17-16:28:22','2023-05-17-16:29:49',1684333702,1684333789,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(162,'2023-05-17-16:29:49','2023-05-18-08:30:36',1684333789,1684391436,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(163,'2023-05-18-08:30:36','2023-05-18-08:56:56',1684391436,1684393016,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(164,'2023-05-18-08:56:56','2023-05-18-09:00:05',1684393016,1684393205,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(165,'2023-05-18-09:00:05','2023-05-18-09:00:23',1684393205,1684393223,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(166,'2023-05-18-09:00:23','2023-05-18-09:02:58',1684393223,1684393378,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(167,'2023-05-18-09:02:58','2023-05-18-09:03:39',1684393378,1684393419,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(168,'2023-05-18-09:03:39','2023-05-18-09:05:13',1684393419,1684393513,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(169,'2023-05-18-09:05:13','2023-05-18-09:05:21',1684393513,1684393521,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(170,'2023-05-18-09:05:21','2023-05-18-09:05:48',1684393521,1684393548,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(171,'2023-05-18-09:05:48','2023-05-18-09:06:09',1684393548,1684393569,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(172,'2023-05-18-09:06:09','2023-05-18-09:07:23',1684393569,1684393643,'month',4,3,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(173,'2023-05-18-09:07:23','2023-05-18-09:08:16',1684393643,1684393696,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(174,'2023-05-18-09:08:16','2023-05-18-09:10:11',1684393696,1684393811,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(175,'2023-05-18-09:10:11','2023-05-18-09:10:27',1684393811,1684393827,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(176,'2023-05-18-09:10:27','2023-05-18-09:11:14',1684393827,1684393874,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(177,'2023-05-18-09:11:14','2023-05-18-09:12:24',1684393874,1684393944,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(178,'2023-05-18-09:12:24','2023-05-18-09:13:08',1684393944,1684393988,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(179,'2023-05-18-09:13:08','2023-05-18-09:13:51',1684393988,1684394031,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(180,'2023-05-18-09:13:51','2023-05-18-09:15:44',1684394031,1684394144,'month',4,3,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(181,'2023-05-18-09:15:44','2023-05-18-09:17:11',1684394144,1684394231,'month',4,10,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(182,'2023-05-18-09:17:11','2023-05-18-09:17:50',1684394231,1684394270,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(183,'2023-05-18-09:17:50','2023-05-19-12:57:54',1684394270,1684493874,'month',4,10,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(184,'2023-05-19-12:57:54','2023-05-19-12:58:03',1684493874,1684493883,'month',4,0,1001,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "1000", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(185,'2023-05-19-12:58:03','2023-05-19-13:15:51',1684493883,1684494951,'month',4,0,1001,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "1000", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(186,'2023-05-19-13:15:51','2023-05-19-13:16:10',1684494951,1684494970,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": "Differential", "RUNNING": "member"}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(187,'2023-05-19-13:16:10','2023-05-19-13:16:16',1684494970,1684494976,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(188,'2023-05-19-13:16:16','2023-05-19-13:17:14',1684494976,1684495034,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(189,'2023-05-19-13:17:14','2023-05-19-13:18:25',1684495034,1684495105,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(190,'2023-05-19-13:18:25','2023-05-19-13:18:46',1684495105,1684495126,'month',4,0,13,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(191,'2023-05-19-13:18:46','2023-05-19-13:32:51',1684495126,1684495971,'month',4,0,13,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(192,'2023-05-19-13:32:51','2023-05-19-14:09:44',1684495971,1684498184,'month',4,0,13,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(193,'2023-05-19-14:09:44','2023-05-19-14:10:13',1684498184,1684498213,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(194,'2023-05-19-14:10:13','2023-05-19-15:45:53',1684498213,1684503953,'month',4,0,10002,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10000", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(195,'2023-05-19-15:45:53','2023-05-19-15:58:53',1684503953,1684504733,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(196,'2023-05-19-15:58:53','2023-05-19-16:03:13',1684504733,1684504993,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(197,'2023-05-19-16:03:13','2023-05-19-16:10:31',1684504993,1684505431,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(198,'2023-05-19-16:10:31','2023-05-19-16:12:14',1684505431,1684505534,'month',4,0,102,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(199,'2023-05-19-16:12:14','2023-05-19-16:12:45',1684505534,1684505565,'month',4,0,102,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(200,'2023-05-19-16:12:45','2023-05-19-16:16:55',1684505565,1684505815,'month',4,0,102,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(201,'2023-05-19-16:16:55','2023-05-19-16:17:08',1684505815,1684505828,'month',4,0,102,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(202,'2023-05-19-16:17:08','2023-05-19-16:25:11',1684505828,1684506311,'month',4,0,102,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(203,'2023-05-19-16:25:11','2023-05-19-16:25:51',1684506311,1684506351,'month',4,0,103,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(204,'2023-05-19-16:25:51','2023-05-19-16:27:05',1684506351,1684506425,'month',4,0,1003,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "1000", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(205,'2023-05-19-16:27:05','2023-05-22-12:49:59',1684506425,1684752599,'month',4,0,10003,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "10000", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(206,'2023-05-22-12:49:59','2023-05-22-15:11:57',1684752599,1684761117,'month',4,0,103,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(207,'2023-05-22-15:11:57','2023-05-23-10:36:46',1684761117,1684831006,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100000000000", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "APPLICATION": {"FILE": "TRANSFER.sh", "DEPENDENCIES": {"DIFFERENTIAL": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(208,'2023-05-23-10:36:46','2023-05-23-10:36:56',1684831006,1684831016,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "SPLITS": "2", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(209,'2023-05-23-10:36:56','2023-05-23-10:37:11',1684831016,1684831031,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "SPLITS": "2", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(210,'2023-05-23-10:37:11','2023-05-23-10:38:43',1684831031,1684831123,'month',4,0,102,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "SPLITS": "2", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(211,'2023-05-23-10:38:43','2023-05-23-10:38:53',1684831123,1684831133,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(212,'2023-05-23-10:38:53','2023-05-23-10:39:03',1684831133,1684831143,'month',4,0,100,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(213,'2023-05-23-10:39:03','2023-05-23-10:40:18',1684831143,1684831218,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(214,'2023-05-23-10:40:18','2023-05-23-10:46:03',1684831218,1684831563,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(215,'2023-05-23-10:46:03','2023-05-23-10:46:29',1684831563,1684831589,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(216,'2023-05-23-10:46:29','2023-05-23-10:47:45',1684831589,1684831665,'month',4,0,100,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(217,'2023-05-23-10:47:45','2023-05-23-10:52:06',1684831665,1684831926,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(218,'2023-05-23-10:52:06','2023-05-23-10:52:30',1684831926,1684831950,'month',4,0,100,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(219,'2023-05-23-10:52:30','2023-05-23-10:53:19',1684831950,1684831999,'month',4,0,100,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(220,'2023-05-23-10:53:19','2023-05-23-11:33:26',1684831999,1684834406,'month',4,0,100,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(221,'2023-05-23-11:33:26','2023-05-23-11:41:01',1684834406,1684834861,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {}, "SPLITS": "1000000", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(222,'2023-05-23-11:41:01','2023-05-23-12:13:32',1684834861,1684836812,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(223,'2023-05-23-12:13:32','2023-05-23-12:21:08',1684836812,1684837268,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(224,'2023-05-23-12:21:08','2023-05-23-12:21:51',1684837268,1684837311,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(225,'2023-05-23-12:21:51','2023-05-23-12:22:21',1684837311,1684837341,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "SPLITS": "2", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(226,'2023-05-23-12:22:21','2023-05-23-12:22:37',1684837341,1684837357,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "SPLITS": "2", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(227,'2023-05-23-12:22:37','2023-05-23-16:24:51',1684837357,1684851891,'month',4,0,1002,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "SPLITS": "2", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "1000", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(228,'2023-05-23-16:24:51','2023-05-23-16:25:26',1684851891,1684851926,'month',4,0,1003,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "RUNNING": "chunk", "SPLITS": "2", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "1000", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(229,'2023-05-23-16:25:26','2023-05-23-16:25:54',1684851926,1684851954,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {}, "RUNNING": "chunk", "SPLITS": "2", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(230,'2023-05-23-16:25:54','2023-05-23-16:27:49',1684851954,1684852069,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "RUNNING": "chunk", "SPLITS": "2", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(231,'2023-05-23-16:27:49','2023-05-23-16:28:09',1684852069,1684852089,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(232,'2023-05-23-16:28:09','2023-05-23-16:29:50',1684852089,1684852190,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(233,'2023-05-23-16:29:50','2023-05-23-16:29:55',1684852190,1684852195,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(234,'2023-05-23-16:29:55','2023-05-23-16:46:36',1684852195,1684853196,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(235,'2023-05-23-16:46:36','2023-05-23-16:57:16',1684853196,1684853836,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(236,'2023-05-23-16:57:16','2023-05-23-16:59:12',1684853836,1684853952,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(237,'2023-05-23-16:59:12','2023-05-23-16:59:31',1684853952,1684853971,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(238,'2023-05-23-16:59:31','2023-05-23-17:01:47',1684853971,1684854107,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(239,'2023-05-23-17:01:47','2023-05-24-08:47:24',1684854107,1684910844,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(240,'2023-05-24-08:47:24','2023-05-24-08:48:12',1684910844,1684910892,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(241,'2023-05-24-08:48:12','2023-05-24-08:48:57',1684910892,1684910937,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(242,'2023-05-24-08:48:57','2023-05-24-08:49:16',1684910937,1684910956,'month',4,0,18,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(243,'2023-05-24-08:49:16','2023-05-24-08:49:28',1684910956,1684910968,'month',4,0,46,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(244,'2023-05-24-08:49:28','2023-05-24-08:52:28',1684910968,1684911148,'month',4,0,40,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(245,'2023-05-24-08:52:28','2023-05-24-09:02:17',1684911148,1684911737,'month',4,0,40,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(246,'2023-05-24-09:02:17','2023-05-24-09:05:08',1684911737,1684911908,'month',4,0,40,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(247,'2023-05-24-09:05:08','2023-05-24-09:15:15',1684911908,1684912515,'month',4,0,40,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(248,'2023-05-24-09:15:15','2023-05-24-09:15:44',1684912515,1684912544,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(249,'2023-05-24-09:15:44','2023-05-24-09:15:53',1684912544,1684912553,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(250,'2023-05-24-09:15:53','2023-05-24-09:28:45',1684912553,1684913325,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(251,'2023-05-24-09:28:45','2023-05-24-09:30:39',1684913325,1684913439,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(252,'2023-05-24-09:30:39','2023-05-24-09:31:27',1684913439,1684913487,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(253,'2023-05-24-09:31:27','2023-05-24-09:33:58',1684913487,1684913638,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(254,'2023-05-24-09:33:59','2023-05-24-09:39:08',1684913639,1684913948,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(255,'2023-05-24-09:39:08','2023-05-24-09:39:17',1684913948,1684913957,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(256,'2023-05-24-09:39:17','2023-05-24-09:39:43',1684913957,1684913983,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(257,'2023-05-24-09:39:43','2023-05-24-09:51:59',1684913983,1684914719,'month',4,0,3,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(258,'2023-05-24-09:51:59','2023-05-24-10:30:38',1684914719,1684917038,'month',4,0,3,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(259,'2023-05-24-10:30:38','2023-05-24-10:35:19',1684917038,1684917319,'month',4,0,3,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(260,'2023-05-24-10:35:19','2023-05-24-10:37:25',1684917319,1684917445,'month',4,0,3,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(261,'2023-05-24-10:37:25','2023-05-24-10:40:24',1684917445,1684917624,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(262,'2023-05-24-10:40:24','2023-05-24-10:41:42',1684917624,1684917702,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(263,'2023-05-24-10:41:42','2023-05-24-11:41:47',1684917702,1684921307,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(264,'2023-05-24-11:41:47','2023-05-24-11:41:58',1684921307,1684921318,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(265,'2023-05-24-11:41:58','2023-05-24-12:01:26',1684921318,1684922486,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(266,'2023-05-24-12:01:26','2023-05-24-12:02:34',1684922486,1684922554,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(267,'2023-05-24-12:02:34','2023-05-24-12:42:50',1684922554,1684924970,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(268,'2023-05-24-12:42:50','2023-05-24-12:44:02',1684924970,1684925042,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(269,'2023-05-24-12:44:02','2023-05-24-12:44:20',1684925042,1684925060,'month',4,0,22,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(270,'2023-05-24-12:44:20','2023-05-24-12:45:01',1684925060,1684925101,'month',4,0,23,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(271,'2023-05-24-12:45:01','2023-05-24-12:45:50',1684925101,1684925150,'month',4,0,23,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "VERTICAL"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(272,'2023-05-24-12:45:50','2023-05-24-12:51:17',1684925150,1684925477,'month',4,0,23,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "debug", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(273,'2023-05-24-12:51:17','2023-05-24-12:58:58',1684925477,1684925938,'month',4,0,23,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(274,'2023-05-24-12:58:58','2023-05-24-13:28:06',1684925938,1684927686,'month',4,0,23,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(275,'2023-05-24-13:28:06','2023-05-24-13:30:40',1684927686,1684927840,'month',4,0,23,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(276,'2023-05-24-13:30:40','2023-05-24-13:31:39',1684927840,1684927899,'month',4,0,23,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(277,'2023-05-24-13:31:39','2023-05-24-13:34:34',1684927899,1684928074,'month',4,0,23,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(278,'2023-05-24-13:34:34','2023-05-24-15:28:59',1684928074,1684934939,'month',4,10,23,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "10", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(279,'2023-05-24-15:28:59','2023-05-24-15:29:41',1684934939,1684934981,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "1", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(280,'2023-05-24-15:29:41','2023-05-24-15:52:13',1684934981,1684936333,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "1", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(281,'2023-05-24-15:52:13','2023-05-24-15:57:17',1684936333,1684936637,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "1", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(282,'2023-05-24-15:57:17','2023-05-24-15:57:26',1684936637,1684936646,'month',4,0,203,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "100", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(283,'2023-05-24-15:57:26','2023-05-24-15:58:38',1684936646,1684936718,'month',4,0,1803,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "900", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(284,'2023-05-24-15:58:38','2023-05-24-17:14:03',1684936718,1684941243,'month',4,0,18003,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9000", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(285,'2023-05-24-17:14:03','2023-05-24-17:32:03',1684941243,1684942323,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(286,'2023-05-24-17:32:03','2023-05-24-17:41:48',1684942323,1684942908,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(287,'2023-05-24-17:41:48','2023-05-24-17:57:22',1684942908,1684943842,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(288,'2023-05-24-17:57:22','2023-05-24-18:12:12',1684943842,1684944732,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(289,'2023-05-24-18:12:12','2023-05-24-18:41:32',1684944732,1684946492,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(290,'2023-05-24-18:41:32','2023-05-24-18:43:09',1684946492,1684946589,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(291,'2023-05-24-18:43:09','2023-05-25-08:24:53',1684946589,1684995893,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(292,'2023-05-25-08:24:53','2023-05-25-08:43:09',1684995893,1684996989,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(293,'2023-05-25-08:43:09','2023-05-25-08:45:32',1684996989,1684997132,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(294,'2023-05-25-08:45:32','2023-05-25-08:49:56',1684997132,1684997396,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(295,'2023-05-25-08:49:56','2023-05-25-08:56:19',1684997396,1684997779,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(296,'2023-05-25-08:56:19','2023-05-25-08:58:05',1684997779,1684997885,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(297,'2023-05-25-08:58:05','2023-05-25-15:08:21',1684997885,1685020101,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PROCESSORS": "2", "THREADS": "1", "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "POST.sh", "RUNNING": "date", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DIFFERENTIAL": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {}, "SIM": {}}, "SPLITS": "9", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(298,'2023-05-25-15:08:21','2023-05-25-15:08:49',1685020101,1685020129,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "member", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(299,'2023-05-25-15:08:49','2023-05-25-15:09:20',1685020129,1685020160,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "member", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(300,'2023-05-25-15:09:20','2023-05-25-15:09:55',1685020160,1685020195,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(301,'2023-05-25-15:09:55','2023-05-25-15:10:51',1685020195,1685020251,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(302,'2023-05-25-15:10:51','2023-05-25-15:11:01',1685020251,1685020261,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(303,'2023-05-25-15:11:01','2023-05-25-15:19:27',1685020261,1685020767,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}, "2": {"SPLITS_TO": "4,3"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(304,'2023-05-25-15:19:27','2023-05-25-15:25:03',1685020767,1685021103,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}}}}, "SPLITS_FROM": {"2": {"SPLITS_TO": "4,3"}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(305,'2023-05-25-15:25:03','2023-05-25-15:35:37',1685021103,1685021737,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}}}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "4,3"}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(306,'2023-05-25-15:35:37','2023-05-26-10:06:31',1685021737,1685088391,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}}}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "4,3"}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(307,'2023-05-26-10:06:31','2023-05-26-12:29:51',1685088391,1685096991,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}}}}}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "4,3"}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(308,'2023-05-26-12:29:51','2023-05-26-12:33:23',1685096991,1685097203,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}}}, "1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3,4"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(309,'2023-05-26-12:33:23','2023-05-26-12:37:00',1685097203,1685097420,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2,1"}}}, "1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "3,4"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(310,'2023-05-26-12:37:00','2023-05-26-12:37:31',1685097420,1685097451,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}}}, "1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(311,'2023-05-26-12:37:31','2023-05-26-12:37:54',1685097451,1685097474,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}}}, "1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "2"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(312,'2023-05-26-12:37:54','2023-05-26-12:38:15',1685097474,1685097495,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}}}, "1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(313,'2023-05-26-12:38:15','2023-05-26-12:38:50',1685097495,1685097530,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}}}, "1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(314,'2023-05-26-12:38:50','2023-05-26-12:39:27',1685097530,1685097567,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}}}, "1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(315,'2023-05-26-12:39:27','2023-05-26-12:39:39',1685097567,1685097579,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}}}, "1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "none"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(316,'2023-05-26-12:39:39','2023-05-26-12:45:42',1685097579,1685097942,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "none"}}}, "1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "none"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(317,'2023-05-26-12:45:42','2023-05-26-14:28:52',1685097942,1685104132,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "none"}}}, "1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "none"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(318,'2023-05-26-14:28:52','2023-05-26-15:25:33',1685104132,1685107533,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM?": {"1": {"SPLITS_TO": "1?"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(319,'2023-05-26-15:25:33','2023-05-26-15:25:50',1685107533,1685107550,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM?": {"1": {"SPLITS_TO": "1?"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(320,'2023-05-26-15:25:50','2023-05-26-15:27:24',1685107550,1685107644,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM?": {"1": {"SPLITS_TO": "1?"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(321,'2023-05-26-15:27:24','2023-05-26-15:52:24',1685107644,1685109144,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM?": {"1": {"SPLITS_TO": "1?"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(322,'2023-05-26-15:52:24','2023-05-26-15:53:06',1685109144,1685109186,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1?": {"SPLITS_TO": "1"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(323,'2023-05-26-15:53:06','2023-05-26-15:53:23',1685109186,1685109203,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1?": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(324,'2023-05-26-15:53:23','2023-05-26-16:37:11',1685109203,1685111831,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1?": {"SPLITS_TO": "1?"}, "2": {"SPLITS_TO": "2?"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(325,'2023-05-26-16:37:11','2023-05-31-14:21:25',1685111831,1685535685,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1?": {"SPLITS_TO": "1?"}, "2": {"SPLITS_TO": "2?"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(326,'2023-05-31-14:21:25','2023-05-31-15:28:32',1685535685,1685539712,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(327,'2023-05-31-15:28:32','2023-05-31-15:31:08',1685539712,1685539868,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"ALL": {"MEMBERS_FROM": {"ALL": {"CHUNKS_FROM": {"ALL": {"SPLITS_FROM": {"1?": {"SPLITS_TO": "1?"}, "2": {"SPLITS_TO": "2?"}}}}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(328,'2023-05-31-15:31:08','2023-05-31-15:31:37',1685539868,1685539897,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20020201": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20020201", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}, "SPLITS_FROM": {"ALL": null, "SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(329,'2023-05-31-15:31:37','2023-05-31-15:31:43',1685539897,1685539903,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20020201": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20020201", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(330,'2023-05-31-15:31:43','2023-05-31-15:31:53',1685539903,1685539913,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20020201": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20020201", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(331,'2023-05-31-15:31:53','2023-05-31-15:34:46',1685539913,1685540086,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20020201": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20020201", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(332,'2023-05-31-15:34:46','2023-05-31-15:35:01',1685540086,1685540101,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000101", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(333,'2023-05-31-15:35:01','2023-05-31-15:37:03',1685540101,1685540223,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000101", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(334,'2023-05-31-15:37:03','2023-05-31-15:38:38',1685540223,1685540318,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000101", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(335,'2023-05-31-15:38:38','2023-05-31-15:38:50',1685540318,1685540330,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000101", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(336,'2023-05-31-15:38:50','2023-05-31-16:35:12',1685540330,1685543712,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000101", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(337,'2023-05-31-16:35:12','2023-05-31-16:44:14',1685543712,1685544254,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000101", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(338,'2023-05-31-16:44:14','2023-05-31-16:44:36',1685544254,1685544276,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(339,'2023-05-31-16:44:36','2023-05-31-16:46:10',1685544276,1685544370,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(340,'2023-05-31-16:46:10','2023-05-31-16:46:51',1685544370,1685544411,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(341,'2023-05-31-16:46:51','2023-05-31-16:47:26',1685544411,1685544446,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(342,'2023-05-31-16:47:26','2023-05-31-16:53:20',1685544446,1685544800,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(343,'2023-05-31-16:53:20','2023-05-31-16:53:53',1685544800,1685544833,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(344,'2023-05-31-16:53:53','2023-05-31-16:54:03',1685544833,1685544843,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(345,'2023-05-31-16:54:03','2023-05-31-16:55:01',1685544843,1685544901,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(346,'2023-05-31-16:55:01','2023-05-31-16:55:19',1685544901,1685544919,'month',4,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(347,'2023-05-31-16:55:19','2023-05-31-16:55:39',1685544919,1685544939,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000102", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(348,'2023-05-31-16:55:39','2023-05-31-16:55:47',1685544939,1685544947,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000102", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(349,'2023-05-31-16:55:47','2023-05-31-16:56:04',1685544947,1685544964,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000102", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(350,'2023-05-31-16:56:04','2023-05-31-16:56:31',1685544964,1685544991,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000102", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1,2"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(351,'2023-05-31-16:56:31','2023-05-31-17:49:06',1685544991,1685548146,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "OPA": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"DATA_NOTIFY": {"DATES_FROM": {"20000101": {"MEMBERS_FROM": {"FC2": {"DATES_TO": "20000102", "MEMBERS_TO": "fc2", "CHUNKS_TO": "ALL"}}, "SPLITS_FROM": {"ALL": {"SPLITS_TO": "1,2"}}}}}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(352,'2023-05-31-17:49:06','2023-06-01-14:31:00',1685548146,1685622660,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(353,'2023-06-01-14:31:00','2023-06-01-14:38:24',1685622660,1685623104,'month',4,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(354,'2023-06-01-14:38:24','2023-06-01-14:42:48',1685623104,1685623368,'month',4,0,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(355,'2023-06-01-14:42:48','2023-06-01-14:55:14',1685623368,1685624114,'month',4,0,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(356,'2023-06-01-14:55:14','2023-06-01-14:55:32',1685624114,1685624132,'month',4,0,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "4", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(357,'2023-06-01-14:55:32','2023-06-01-14:55:58',1685624132,1685624158,'month',4,0,13,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(358,'2023-06-01-14:55:58','2023-06-01-15:43:58',1685624158,1685627038,'month',4,0,13,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(359,'2023-06-01-15:43:58','2023-06-01-15:53:08',1685627038,1685627588,'month',4,0,13,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(360,'2023-06-01-15:53:08','2023-06-02-10:05:29',1685627588,1685693129,'month',4,0,13,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(361,'2023-06-02-10:05:29','2023-06-02-10:32:13',1685693129,1685694733,'month',4,0,13,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(362,'2023-06-02-10:32:13','2023-06-02-12:11:26',1685694733,1685700686,'month',4,0,13,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(363,'2023-06-02-12:11:26','2023-06-02-12:19:38',1685700686,1685701178,'month',4,0,19,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM3": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(364,'2023-06-02-12:19:38','2023-06-02-12:20:29',1685701178,1685701229,'month',4,0,19,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM3": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(365,'2023-06-02-12:20:29','2023-06-02-12:24:14',1685701229,1685701454,'month',4,0,19,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM3": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"LUMI": {"TYPE": "slurm", "HOST": "lumi.csc.fi", "PROJECT": "project_462000048", "USER": "castrillo", "SCRATCH_DIR": "/scratch", "QUEUE": "normal"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "QUEUE": "bsc_es", "NODES": 2, "TASKS": 16, "THREADS": 8, "PROCESSORS": 32, "INROOT": "%HPCARCH%/marenostrum4", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM3": {"TYPE": "lsf", "HOST": "mn", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "true", "USER": "bsc32704", "SCRATCH_DIR": "/gpfs/scratch", "TEST_SUITE": "True", "PROCESSORS_PER_NODE": "16", "QUEUE": "bsc_es"}, "MOORE": {"TYPE": "slurm", "HOST": "moore", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": "false", "USER": "", "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "ADD_PROJECT_TO_HOST": "false", "USER": "bsc32070", "QUEUE": "serial", "SCRATCH_DIR": "/gpfs/scratch"}, "ECMWF-CCA": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": "false", "USER": "c3a", "SCRATCH_DIR": "/scratch/ms", "TEST_SUITE": "True", "QUEUE": "np", "PROCESSORS_PER_NODE": "36"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(366,'2023-06-02-12:24:14','2023-06-02-12:27:16',1685701454,1685701636,'month',4,0,19,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM3": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "PARTITION": "standard"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(367,'2023-06-02-12:27:16','2023-06-02-14:04:05',1685701636,1685707445,'month',4,19,19,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM3": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1 fc2", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(368,'2023-06-02-14:04:05','2023-06-02-14:04:19',1685707445,1685707459,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "5", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM3": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(369,'2023-06-02-14:04:19','2023-06-06-10:13:13',1685707459,1686039193,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "5", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM3": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(370,'2023-06-06-10:13:13','2023-06-06-10:16:02',1686039193,1686039362,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "5", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM3": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(371,'2023-06-06-10:16:02','2023-06-06-10:16:41',1686039362,1686039401,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "5", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM3": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(372,'2023-06-06-10:16:41','2023-06-08-09:21:05',1686039401,1686208865,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "5", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM3": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM&SIM2", "TYPE": "vertical"}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(373,'2023-06-08-09:21:05','2023-06-08-09:29:17',1686208865,1686209357,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(374,'2023-06-08-09:29:17','2023-06-08-09:42:23',1686209357,1686210143,'month',4,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(375,'2023-06-08-09:42:23','2023-06-08-09:48:33',1686210143,1686210513,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(376,'2023-06-08-09:48:33','2023-06-08-09:49:22',1686210513,1686210562,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(377,'2023-06-08-09:49:22','2023-06-08-09:51:10',1686210562,1686210670,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(378,'2023-06-08-09:51:10','2023-06-08-09:51:25',1686210670,1686210685,'month',4,0,999,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "999", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(379,'2023-06-08-09:51:25','2023-06-08-14:16:21',1686210685,1686226581,'month',4,0,99999,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "99999", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(380,'2023-06-08-14:16:21','2023-06-08-14:20:22',1686226581,1686226822,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(381,'2023-06-08-14:20:22','2023-06-08-14:25:58',1686226822,1686227158,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(382,'2023-06-08-14:25:58','2023-06-14-13:03:09',1686227158,1686740589,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "5", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(383,'2023-06-14-13:03:09','2023-06-14-13:32:20',1686740589,1686742340,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(384,'2023-06-14-13:32:20','2023-06-14-13:51:56',1686742340,1686743516,'month',4,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(385,'2023-06-14-13:51:56','2023-06-14-13:52:41',1686743516,1686743561,'month',4,0,2,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(386,'2023-06-14-13:52:41','2023-06-14-13:52:55',1686743561,1686743575,'month',4,0,31,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 30, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(387,'2023-06-14-13:52:55','2023-06-14-13:53:07',1686743575,1686743587,'month',4,0,21,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 20, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(388,'2023-06-14-13:53:07','2023-06-14-13:53:32',1686743587,1686743612,'month',4,0,41,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 20, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(389,'2023-06-14-13:53:32','2023-06-14-13:54:20',1686743612,1686743660,'month',4,0,81,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {}, "DATA_NOTIFY": {}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 20, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(390,'2023-06-14-13:54:20','2023-06-14-13:54:48',1686743660,1686743688,'month',4,0,81,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 20, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(391,'2023-06-14-13:54:48','2023-06-14-13:55:05',1686743688,1686743705,'month',4,0,41,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(392,'2023-06-14-13:55:05','2023-06-14-13:55:19',1686743705,1686743719,'month',4,0,81,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(393,'2023-06-14-13:55:19','2023-06-19-09:26:40',1686743719,1687159600,'month',4,0,801,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 100, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(394,'2023-06-19-09:26:40','2023-06-19-09:27:11',1687159600,1687159631,'month',4,0,41,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "1", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 5, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(395,'2023-06-19-09:27:11','2023-06-19-09:28:08',1687159631,1687159688,'month',4,0,41,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 5, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(396,'2023-06-19-09:28:08','2023-06-19-09:29:45',1687159688,1687159785,'month',4,0,41,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 5, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(397,'2023-06-19-09:29:45','2023-06-19-09:36:23',1687159785,1687160183,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(398,'2023-06-19-09:36:23','2023-06-19-09:38:04',1687160183,1687160284,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(399,'2023-06-19-09:38:04','2023-06-19-09:38:51',1687160284,1687160331,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(400,'2023-06-19-09:38:51','2023-06-19-09:39:09',1687160331,1687160349,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(401,'2023-06-19-09:39:09','2023-06-19-09:48:15',1687160349,1687160895,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(402,'2023-06-19-09:48:15','2023-06-19-09:50:56',1687160895,1687161056,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(403,'2023-06-19-09:50:56','2023-06-19-09:51:25',1687161056,1687161085,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}, "DATA_NOTIFY": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(404,'2023-06-19-09:51:25','2023-06-19-09:51:48',1687161085,1687161108,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(405,'2023-06-19-09:51:48','2023-06-19-09:52:27',1687161108,1687161147,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(406,'2023-06-19-09:52:27','2023-06-19-09:52:30',1687161147,1687161150,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(407,'2023-06-19-09:52:30','2023-06-19-10:23:33',1687161150,1687163013,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(408,'2023-06-19-10:23:33','2023-06-19-10:44:48',1687163013,1687164288,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(409,'2023-06-19-10:44:48','2023-06-19-11:02:29',1687164288,1687165349,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(410,'2023-06-19-11:02:29','2023-06-19-11:03:11',1687165349,1687165391,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(411,'2023-06-19-11:03:11','2023-06-19-11:05:03',1687165391,1687165503,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}, "SIM2-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(412,'2023-06-19-11:05:03','2023-06-19-11:05:38',1687165503,1687165538,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(413,'2023-06-19-11:05:38','2023-06-19-11:09:56',1687165538,1687165796,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(414,'2023-06-19-11:09:56','2023-06-19-11:10:07',1687165796,1687165807,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(415,'2023-06-19-11:10:07','2023-06-19-11:10:26',1687165807,1687165826,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(416,'2023-06-19-11:10:26','2023-06-19-11:12:20',1687165826,1687165940,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(417,'2023-06-19-11:12:20','2023-06-19-11:12:35',1687165940,1687165955,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(418,'2023-06-19-11:12:35','2023-06-19-11:13:32',1687165955,1687166012,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(419,'2023-06-19-11:13:32','2023-06-19-11:14:01',1687166012,1687166041,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(420,'2023-06-19-11:14:01','2023-06-19-11:16:07',1687166041,1687166167,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(421,'2023-06-19-11:16:07','2023-06-19-11:33:00',1687166167,1687167180,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"INI": {"FILE": "INI.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "NOT": {"FILE": "NOT.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(422,'2023-06-19-11:33:00','2023-06-19-11:34:30',1687167180,1687167270,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"INI": {"FILE": "INI.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "NOT": {"FILE": "NOT.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(423,'2023-06-19-11:34:30','2023-06-19-11:37:01',1687167270,1687167421,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"INI": {"FILE": "INI.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "NOT": {"FILE": "NOT.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(424,'2023-06-19-11:37:01','2023-06-19-11:38:28',1687167421,1687167508,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"INI": {"FILE": "INI.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "NOT": {"FILE": "NOT.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(425,'2023-06-19-11:38:28','2023-06-19-11:42:43',1687167508,1687167763,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"INI": {"FILE": "INI.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "NOT": {"FILE": "NOT.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(426,'2023-06-19-11:42:43','2023-06-19-11:46:03',1687167763,1687167963,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"INI": {"FILE": "INI.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "NOT": {"FILE": "NOT.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(427,'2023-06-19-11:46:03','2023-06-20-14:39:19',1687167963,1687264759,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"INI": {"FILE": "INI.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "NOT": {"FILE": "NOT.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(428,'2023-06-20-14:39:19','2023-06-20-15:00:51',1687264759,1687266051,'month',4,0,11,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"INI": {"FILE": "INI.sh", "RUNNING": "chunk", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "NOT": {"FILE": "NOT.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "DATA_NOTIFY": {"FILE": "DATA_NOTIFY.sh", "DEPENDENCIES": {"NOT": {}, "INI": {}}, "SPLITS": "2", "RUNNING": "once", "WALLCLOCK": "00:05", "DELETE_WHEN_EDGELESS": false, "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}, "DATA_NOTIFY": null}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "SIM2": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(429,'2023-06-20-15:00:51','2023-06-20-15:01:27',1687266051,1687266087,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(430,'2023-06-20-15:01:27','2023-06-20-15:02:20',1687266087,1687266140,'month',4,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(431,'2023-06-20-15:02:20','2023-06-20-15:13:41',1687266140,1687266821,'month',4,0,8000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(432,'2023-06-20-15:13:41','2023-06-20-15:17:13',1687266821,1687267033,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 5000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(433,'2023-06-20-15:17:13','2023-06-20-15:18:09',1687267033,1687267089,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 5000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(434,'2023-06-20-15:18:09','2023-06-20-15:19:15',1687267089,1687267155,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 5000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(435,'2023-06-20-15:19:15','2023-06-20-15:38:38',1687267155,1687268318,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 5000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(436,'2023-06-20-15:38:38','2023-06-20-15:52:00',1687268318,1687269120,'month',4,0,1600,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 200, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(437,'2023-06-20-15:52:00','2023-06-20-15:52:05',1687269120,1687269125,'month',4,0,1600,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 200, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(438,'2023-06-20-15:52:05','2023-06-20-15:53:36',1687269125,1687269216,'month',4,0,1600,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 200, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(439,'2023-06-20-15:53:36','2023-06-20-15:53:45',1687269216,1687269225,'month',4,0,1600,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 200, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(440,'2023-06-20-15:53:45','2023-06-20-15:53:53',1687269225,1687269233,'month',4,0,1600,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 200, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(441,'2023-06-20-15:53:53','2023-06-20-15:54:11',1687269233,1687269251,'month',4,0,1600,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 200, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(442,'2023-06-20-15:54:11','2023-06-20-15:56:03',1687269251,1687269363,'month',4,0,1600,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 200, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(443,'2023-06-20-15:56:03','2023-06-20-16:13:39',1687269363,1687270419,'month',4,0,1600,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 200, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(444,'2023-06-20-16:13:39','2023-06-20-16:18:48',1687270419,1687270728,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 5000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(445,'2023-06-20-16:18:48','2023-06-20-16:25:36',1687270728,1687271136,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 5000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(446,'2023-06-20-16:25:36','2023-06-21-13:31:30',1687271136,1687347090,'month',4,0,80000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(447,'2023-06-21-13:31:30','2023-06-21-13:31:42',1687347090,1687347102,'month',4,0,80,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(448,'2023-06-21-13:31:42','2023-06-21-13:38:18',1687347102,1687347498,'month',4,0,80,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(449,'2023-06-21-13:38:18','2023-06-21-13:40:20',1687347498,1687347620,'month',4,0,80,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(450,'2023-06-21-13:40:20','2023-06-21-14:05:08',1687347620,1687349108,'month',4,0,80,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(451,'2023-06-21-14:05:08','2023-06-21-14:12:14',1687349108,1687349534,'month',4,0,80,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(452,'2023-06-21-14:12:14','2023-06-21-15:05:45',1687349534,1687352745,'month',4,0,80,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(453,'2023-06-21-15:05:45','2023-06-21-15:27:09',1687352745,1687354029,'month',4,0,80,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(454,'2023-06-21-15:27:09','2023-06-21-15:30:07',1687354029,1687354207,'month',4,0,80,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(455,'2023-06-21-15:30:07','2023-06-21-15:30:26',1687354207,1687354226,'month',4,0,800,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 100, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(456,'2023-06-21-15:30:26','2023-06-21-15:30:49',1687354226,1687354249,'month',4,0,8000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(457,'2023-06-21-15:30:49','2023-06-21-16:33:52',1687354249,1687358032,'month',4,0,80000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(458,'2023-06-21-16:33:52','2023-06-21-16:37:24',1687358032,1687358244,'month',4,0,80000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(459,'2023-06-21-16:37:24','2023-06-21-16:38:16',1687358244,1687358296,'month',4,0,80000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 10000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(460,'2023-06-21-16:38:16','2023-06-21-16:39:01',1687358296,1687358341,'month',4,0,96000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 12000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(461,'2023-06-21-16:39:01','2023-06-21-16:47:17',1687358341,1687358837,'month',4,0,100000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 12500, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(462,'2023-06-21-16:47:17','2023-06-21-16:59:45',1687358837,1687359585,'month',4,0,100800,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 12600, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(463,'2023-06-21-16:59:45','2023-06-21-17:30:34',1687359585,1687361434,'month',4,0,104000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 13000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(464,'2023-06-21-17:30:34','2023-06-21-18:13:18',1687361434,1687363998,'month',4,0,104000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 13000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(465,'2023-06-21-18:13:18','2023-06-22-08:53:11',1687363998,1687416791,'month',4,0,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(466,'2023-06-22-08:53:11','2023-06-22-08:54:41',1687416791,1687416881,'month',4,0,96000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 12000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(467,'2023-06-22-08:54:41','2023-08-01-11:07:26',1687416881,1690880846,'month',4,0,100000,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "EXPID": "a00e", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": {"SPLITS_FROM": {"1": {"SPLITS_TO": "1"}, "2": {"SPLITS_TO": "2"}}}}, "SPLITS": "2", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101 20000102", "MEMBERS": "fc0 fc1", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 12500, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(468,'2023-08-01-11:07:26','2023-08-01-11:42:50',1690880846,1690882970,'month',4,0,4000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(469,'2023-08-01-11:42:50','2023-08-01-11:50:41',1690882970,1690883441,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 40000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(470,'2023-08-01-11:50:41','2023-08-01-11:59:25',1690883441,1690883965,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 40000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(471,'2023-08-01-11:59:25','2023-08-01-12:24:52',1690883965,1690885492,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 40000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(472,'2023-08-01-12:24:52','2023-08-01-12:28:11',1690885492,1690885691,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 40000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(473,'2023-08-01-12:28:11','2023-08-01-12:41:58',1690885691,1690886518,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 40000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(474,'2023-08-01-12:41:58','2023-08-01-13:30:47',1690886518,1690889447,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 40000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(475,'2023-08-01-13:30:47','2023-08-01-13:31:22',1690889447,1690889482,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 40000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(476,'2023-08-01-13:31:22','2023-08-01-13:50:22',1690889482,1690890622,'month',4,0,40000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 40000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(477,'2023-08-01-13:50:22','2023-08-01-13:51:01',1690890622,1690890661,'month',4,0,4000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(478,'2023-08-01-13:51:01','2023-08-01-13:51:39',1690890661,1690890699,'month',4,0,4000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(479,'2023-08-01-13:51:39','2023-08-01-14:05:56',1690890699,1690891556,'month',4,0,4000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(480,'2023-08-01-14:05:56','2023-08-01-14:10:03',1690891556,1690891803,'month',4,0,4000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(481,'2023-08-01-14:10:03','2023-08-02-09:30:50',1690891803,1690961450,'month',4,0,4000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(482,'2023-08-02-09:30:50','2023-08-03-09:43:51',1690961450,1691048631,'month',4,0,4000,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.1.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"SIM-1": null}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(483,'2023-08-03-09:43:51','2023-08-03-09:44:42',1691048631,1691048682,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "FROM_STEP": 1}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(484,'2023-08-03-09:44:42','2023-08-03-09:46:17',1691048682,1691048777,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(485,'2023-08-03-09:46:17','2023-08-03-09:46:31',1691048777,1691048791,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(486,'2023-08-03-09:46:31','2023-08-03-09:49:01',1691048791,1691048941,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(487,'2023-08-03-09:49:01','2023-08-03-09:49:26',1691048941,1691048966,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(488,'2023-08-03-09:49:26','2023-08-03-09:50:23',1691048966,1691049023,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(489,'2023-08-03-09:50:23','2023-08-03-09:53:48',1691049023,1691049228,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(490,'2023-08-03-09:53:48','2023-08-03-09:53:57',1691049228,1691049237,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(491,'2023-08-03-09:53:57','2023-08-03-09:54:31',1691049237,1691049271,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(492,'2023-08-03-09:54:31','2023-08-03-09:58:58',1691049271,1691049538,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(493,'2023-08-03-09:58:58','2023-08-03-10:00:32',1691049538,1691049632,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(494,'2023-08-03-10:00:32','2023-08-03-10:00:58',1691049632,1691049658,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(495,'2023-08-03-10:00:58','2023-08-03-10:01:27',1691049658,1691049687,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(496,'2023-08-03-10:01:27','2023-08-03-10:01:51',1691049687,1691049711,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(497,'2023-08-03-10:01:51','2023-08-03-10:02:22',1691049711,1691049742,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(498,'2023-08-03-10:02:22','2023-08-03-10:08:12',1691049742,1691050092,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(499,'2023-08-03-10:08:12','2023-08-07-10:39:40',1691050092,1691397580,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(500,'2023-08-07-10:39:40','2023-08-07-10:39:51',1691397580,1691397591,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(501,'2023-08-07-10:39:51','2023-08-07-10:40:17',1691397591,1691397617,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(502,'2023-08-07-10:40:17','2023-08-07-11:56:53',1691397617,1691402213,'month',4,0,5,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 4000, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"A": {"FILE": "a", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "B": {"FILE": "b", "RUNNING": "once", "SPLITS": 2, "DEPENDENCIES": {"A": {}}, "ADDITIONAL_FILES": []}, "C": {"FILE": "c", "RUNNING": "once", "SPLITS": 1, "DEPENDENCIES": {"B": {}}, "ADDITIONAL_FILES": []}, "RECOVER_B_2": {"FILE": "fix_b", "RUNNING": "once", "DEPENDENCIES": {"B": {"STATUS": "FAILED", "SPLITS_TO": "2"}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(503,'2023-08-07-11:56:53','2023-08-07-11:57:28',1691402213,1691402248,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "sim", "PLATFORM": "local", "RUNNING": "CHUNK", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {"SIM": null}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_TO": "[1:2]*"}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(504,'2023-08-07-11:57:28','2023-08-07-11:58:13',1691402248,1691402293,'month',4,0,7,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "sim", "PLATFORM": "local", "RUNNING": "CHUNK", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {"SIM": null}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_TO": "[1:2]*"}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(505,'2023-08-07-11:58:13','2023-08-07-12:46:17',1691402293,1691405177,'month',4,0,9,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "sim", "PLATFORM": "local", "RUNNING": "CHUNK", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {"SIM": null}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
INSERT INTO experiment_run VALUES(506,'2023-08-07-12:46:17','2023-08-07-12:46:17',1691405177,0,'month',4,0,9,0,0,0,0,0,'{"CONFIG": {"EXPID": "a00e", "AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "6", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "DEFAULT": {"EXPID": "a00e", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "", "POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 1, "CHUNKINI": "", "CALENDAR": "standard", "RUN_ONLY_MEMBERS": ""}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": "true"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "JOBS": {"SIM": {"FILE": "sim", "PLATFORM": "local", "RUNNING": "CHUNK", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "dn", "PLATFORM": "local", "RUNNING": "CHUNK", "SPLITS": 2, "DEPENDENCIES": {"SIM": null}, "ADDITIONAL_FILES": []}, "URBAN": {"FILE": "urban", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"OPA_2TMAX": {"SPLITS_FROM": {"[1:2]": {"SPLITS_TO": "[1:2]*"}}}}, "ADDITIONAL_FILES": []}, "OPA_2TMAX": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {}}, "ADDITIONAL_FILES": []}, "OPA_2TMIN": {"FILE": "opa", "PLATFORM": "local", "RUNNING": "chunk", "SPLITS": 2, "DEPENDENCIES": {"DN": {}}, "ADDITIONAL_FILES": []}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00e", "PROJDIR": "/home/dbeltran/new_autosubmit/a00e/proj/", "PLATFORMS": {"LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a00e_DATA_NOTIFY','2023-06-02-12:27:26','2023-06-02-12:29:43',1685701646,1685701713,1685701718,'COMPLETED',2,1,'00:05','debug',2240,'','DATA_NOTIFY','',0,1,'MARENOSTRUM4',28787731,'',1,367,0.0,0.0,'a00e_DATA_NOTIFY.20230602122841.out','a00e_DATA_NOTIFY.20230602122841.err',2,'a00e_20000101_fc0_1_SIM2,a00e_20000101_fc0_1_SIM,a00e_20000101_fc1_1_SIM,a00e_20000101_fc2_1_SIM,a00e_20000101_fc1_1_SIM2,a00e_20000101_fc2_1_SIM2',replace('                 28787731  COMPLETED          1        1 2023-06-02T12:27:26 2023-06-02T12:28:29 2023-06-02T12:28:39          2.24K                                                     \n           28787731.batch  COMPLETED          1        1 2023-06-02T12:28:29 2023-06-02T12:28:29 2023-06-02T12:28:39          1.65K                      885K                      885K \n          28787731.extern  COMPLETED          1        1 2023-06-02T12:28:29 2023-06-02T12:28:29 2023-06-02T12:28:40          2.24K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(2,0,'a00e_20000101_fc0_1_SIM2','2023-06-02-12:30:49','2023-06-02-12:32:25',1685701732,1685701814,1685701819,'COMPLETED',16857017213555,1,'00:05','debug',1879.8099999999999453,'2000-01-01 00:00:00','SIM2','fc0',1,1,'MARENOSTRUM4',28787750,'',0,367,0.0,0.0,'','',2,'a00e_20000101_fc0_2_SIM2,a00e_20000101_fc0_1_SIM3','');
INSERT INTO job_data VALUES(3,0,'a00e_20000101_fc0_1_SIM','2023-06-02-12:30:52','2023-06-02-12:32:25',1685701732,1685701819,1685701824,'COMPLETED',16857017213555,1,'00:05','debug',1879.8099999999999453,'2000-01-01 00:00:00','SIM','fc0',1,1,'MARENOSTRUM4',28787750,'',0,367,0.0,0.0,'','',2,'a00e_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(4,0,'a00e_20000101_fc0_2_SIM2','2023-06-02-12:31:22','2023-06-02-12:32:25',1685701732,1685701829,1685701834,'COMPLETED',2,1,'00:05','debug',5640,'2000-01-01 00:00:00','SIM2','fc0',2,1,'MARENOSTRUM4',28787750,'',1,367,0.0,0.0,'','',2,'a00e_20000101_fc0_2_SIM3',replace('                 28787750  COMPLETED          1        1 2023-06-02T12:28:52 2023-06-02T12:30:09 2023-06-02T12:30:35          5.64K                                                     \n           28787750.batch  COMPLETED          1        1 2023-06-02T12:30:09 2023-06-02T12:30:09 2023-06-02T12:30:35          5.31K                      905K                      905K \n          28787750.extern  COMPLETED          1        1 2023-06-02T12:30:09 2023-06-02T12:30:09 2023-06-02T12:30:35          5.64K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(5,0,'a00e_20000101_fc0_2_SIM','2023-06-02-12:31:22','2023-06-02-12:32:25',1685701732,1685701824,1685701829,'COMPLETED',16857017213555,1,'00:05','debug',1879.8099999999999453,'2000-01-01 00:00:00','SIM','fc0',2,1,'MARENOSTRUM4',28787750,'',0,367,0.0,0.0,'','',2,'',replace('                 28787750  COMPLETED          1        1 2023-06-02T12:28:52 2023-06-02T12:30:09 2023-06-02T12:30:35          5.64K                                                     \n           28787750.batch  COMPLETED          1        1 2023-06-02T12:30:09 2023-06-02T12:30:09 2023-06-02T12:30:35          5.31K                      905K                      905K \n          28787750.extern  COMPLETED          1        1 2023-06-02T12:30:09 2023-06-02T12:30:09 2023-06-02T12:30:35          5.64K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(6,0,'a00e_20000101_fc0_1_SIM3','2023-06-02-12:31:27','2023-06-02-12:37:04',1685701887,1685702134,1685702139,'COMPLETED',2,1,'00:05','debug',870,'2000-01-01 00:00:00','SIM3','fc0',1,1,'MARENOSTRUM4',28787778,'',1,367,0.0,0.0,'a00e_20000101_fc0_1_SIM3.20230602123539.out','a00e_20000101_fc0_1_SIM3.20230602123539.err',2,'',replace('                 28787778  COMPLETED          1        1 2023-06-02T12:31:27 2023-06-02T12:35:30 2023-06-02T12:35:41            870                                                     \n           28787778.batch  COMPLETED          1        1 2023-06-02T12:35:30 2023-06-02T12:35:30 2023-06-02T12:35:41            668                     1131K                     1131K \n          28787778.extern  COMPLETED          1        1 2023-06-02T12:35:30 2023-06-02T12:35:30 2023-06-02T12:35:41            870                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(7,0,'a00e_20000101_fc1_1_SIM2','2023-06-02-12:33:00','2023-06-02-12:34:03',1685701732,1685701936,1685701941,'COMPLETED',16857017215652,1,'00:05','debug',667.50000000000000001,'2000-01-01 00:00:00','SIM2','fc1',1,1,'MARENOSTRUM4',28787751,'',0,367,0.0,0.0,'','',2,'a00e_20000101_fc1_2_SIM2,a00e_20000101_fc1_1_SIM3','');
INSERT INTO job_data VALUES(8,0,'a00e_20000101_fc1_2_SIM','2023-06-02-12:33:00','2023-06-02-12:34:03',1685701732,1685701946,1685701951,'COMPLETED',16857017215652,1,'00:05','debug',667.50000000000000001,'2000-01-01 00:00:00','SIM','fc1',2,1,'MARENOSTRUM4',28787751,'',0,367,0.0,0.0,'','',2,'','');
INSERT INTO job_data VALUES(9,0,'a00e_20000101_fc1_1_SIM','2023-06-02-12:33:00','2023-06-02-12:34:03',1685701732,1685701941,1685701946,'COMPLETED',16857017215652,1,'00:05','debug',667.50000000000000001,'2000-01-01 00:00:00','SIM','fc1',1,1,'MARENOSTRUM4',28787751,'',0,367,0.0,0.0,'','',2,'a00e_20000101_fc1_2_SIM','');
INSERT INTO job_data VALUES(10,0,'a00e_20000101_fc1_2_SIM2','2023-06-02-12:33:01','2023-06-02-12:34:03',1685701732,1685701951,1685701956,'COMPLETED',16857017215652,1,'00:05','debug',667.50000000000000001,'2000-01-01 00:00:00','SIM2','fc1',2,1,'MARENOSTRUM4',28787751,'',0,367,0.0,0.0,'','',2,'a00e_20000101_fc1_2_SIM3',replace('                 28787751  COMPLETED          1        1 2023-06-02T12:28:52 2023-06-02T12:32:12 2023-06-02T12:32:38          2.67K                                                     \n           28787751.batch  COMPLETED          1        1 2023-06-02T12:32:12 2023-06-02T12:32:12 2023-06-02T12:32:38          2.51K                     1111K                     1111K \n          28787751.extern  COMPLETED          1        1 2023-06-02T12:32:12 2023-06-02T12:32:12 2023-06-02T12:32:38          2.67K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(11,0,'a00e_20000101_fc0_2_SIM3','2023-06-02-12:33:08','2023-06-02-12:38:23',1685701988,1685702228,1685702233,'COMPLETED',2,1,'00:05','debug',820,'2000-01-01 00:00:00','SIM3','fc0',2,1,'MARENOSTRUM4',28787797,'',1,367,0.0,0.0,'a00e_20000101_fc0_2_SIM3.20230602123721.out','a00e_20000101_fc0_2_SIM3.20230602123721.err',2,'',replace('                 28787797  COMPLETED          1        1 2023-06-02T12:33:08 2023-06-02T12:37:04 2023-06-02T12:37:15            820                                                     \n           28787797.batch  COMPLETED          1        1 2023-06-02T12:37:04 2023-06-02T12:37:04 2023-06-02T12:37:15            612                     1134K                     1134K \n          28787797.extern  COMPLETED          1        1 2023-06-02T12:37:04 2023-06-02T12:37:04 2023-06-02T12:37:15            820                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(12,0,'a00e_20000101_fc2_1_SIM2','2023-06-02-12:34:30','2023-06-02-12:36:00',1685701732,1685702034,1685702039,'COMPLETED',16857017217368,1,'00:05','debug',1430,'2000-01-01 00:00:00','SIM2','fc2',1,1,'MARENOSTRUM4',28787752,'',0,367,0.0,0.0,'','',2,'a00e_20000101_fc2_2_SIM2,a00e_20000101_fc2_1_SIM3','');
INSERT INTO job_data VALUES(13,0,'a00e_20000101_fc2_1_SIM','2023-06-02-12:34:32','2023-06-02-12:36:00',1685701732,1685702039,1685702044,'COMPLETED',16857017217368,1,'00:05','debug',1430,'2000-01-01 00:00:00','SIM','fc2',1,1,'MARENOSTRUM4',28787752,'',0,367,0.0,0.0,'','',2,'a00e_20000101_fc2_2_SIM','');
INSERT INTO job_data VALUES(14,0,'a00e_20000101_fc2_2_SIM','2023-06-02-12:34:57','2023-06-02-12:36:00',1685701732,1685702044,1685702049,'COMPLETED',16857017217368,1,'00:05','debug',1430,'2000-01-01 00:00:00','SIM','fc2',2,1,'MARENOSTRUM4',28787752,'',0,367,0.0,0.0,'','',2,'','');
INSERT INTO job_data VALUES(15,0,'a00e_20000101_fc2_2_SIM2','2023-06-02-12:34:58','2023-06-02-12:36:00',1685701732,1685702049,1685702054,'COMPLETED',16857017217368,1,'00:05','debug',1430,'2000-01-01 00:00:00','SIM2','fc2',2,1,'MARENOSTRUM4',28787752,'',0,367,0.0,0.0,'','',2,'a00e_20000101_fc2_2_SIM3',replace('                 28787752  COMPLETED          1        1 2023-06-02T12:28:52 2023-06-02T12:33:50 2023-06-02T12:34:16          5.72K                                                     \n           28787752.batch  COMPLETED          1        1 2023-06-02T12:33:50 2023-06-02T12:33:50 2023-06-02T12:34:16          5.21K                      912K                      912K \n          28787752.extern  COMPLETED          1        1 2023-06-02T12:33:50 2023-06-02T12:33:50 2023-06-02T12:34:17          5.72K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(16,0,'a00e_20000101_fc1_1_SIM3','2023-06-02-12:34:59','2023-06-02-12:40:26',1685702099,1685702335,1685702340,'COMPLETED',2,1,'00:05','debug',1600,'2000-01-01 00:00:00','SIM3','fc1',1,1,'MARENOSTRUM4',28787813,'',1,367,0.0,0.0,'a00e_20000101_fc1_1_SIM3.20230602123901.out','a00e_20000101_fc1_1_SIM3.20230602123901.err',2,'',replace('                 28787813  COMPLETED          1        1 2023-06-02T12:34:59 2023-06-02T12:38:51 2023-06-02T12:39:01          1.60K                                                     \n           28787813.batch  COMPLETED          1        1 2023-06-02T12:38:51 2023-06-02T12:38:51 2023-06-02T12:39:01          1.23K                      915K                      915K \n          28787813.extern  COMPLETED          1        1 2023-06-02T12:38:51 2023-06-02T12:38:51 2023-06-02T12:39:01          1.60K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(17,0,'a00e_20000101_fc1_2_SIM3','2023-06-02-12:35:41','2023-06-02-12:41:44',1685702141,1685702427,1685702432,'COMPLETED',2,1,'00:05','debug',1740,'2000-01-01 00:00:00','SIM3','fc1',2,1,'MARENOSTRUM4',28787819,'',1,367,0.0,0.0,'a00e_20000101_fc1_2_SIM3.20230602124042.out','a00e_20000101_fc1_2_SIM3.20230602124042.err',2,'',replace('                 28787819  COMPLETED          1        1 2023-06-02T12:35:41 2023-06-02T12:40:24 2023-06-02T12:40:34          1.74K                                                     \n           28787819.batch  COMPLETED          1        1 2023-06-02T12:40:24 2023-06-02T12:40:24 2023-06-02T12:40:34          1.31K                      937K                      937K \n          28787819.extern  COMPLETED          1        1 2023-06-02T12:40:24 2023-06-02T12:40:24 2023-06-02T12:40:34          1.74K                      708K                      708K \n','\n',char(10)));
INSERT INTO job_data VALUES(18,0,'a00e_20000101_fc2_1_SIM3','2023-06-02-12:37:25','2023-06-02-12:43:22',1685702245,1685702528,1685702533,'COMPLETED',2,1,'00:05','debug',1620,'2000-01-01 00:00:00','SIM3','fc2',1,1,'MARENOSTRUM4',28787842,'',1,367,0.0,0.0,'a00e_20000101_fc2_1_SIM3.20230602124220.out','a00e_20000101_fc2_1_SIM3.20230602124220.err',2,'',replace('                 28787842  COMPLETED          1        1 2023-06-02T12:37:25 2023-06-02T12:42:04 2023-06-02T12:42:14          1.62K                                                     \n           28787842.batch  COMPLETED          1        1 2023-06-02T12:42:04 2023-06-02T12:42:04 2023-06-02T12:42:14          1.26K                      922K                      922K \n          28787842.extern  COMPLETED          1        1 2023-06-02T12:42:04 2023-06-02T12:42:04 2023-06-02T12:42:15          1.62K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(19,0,'a00e_20000101_fc2_2_SIM3','2023-06-02-12:39:04','2023-06-02-12:44:57',1685702344,1685702627,1685702632,'COMPLETED',2,1,'00:05','debug',1760,'2000-01-01 00:00:00','SIM3','fc2',2,1,'MARENOSTRUM4',28787859,'',1,367,0.0,0.0,'a00e_20000101_fc2_2_SIM3.20230602124354.out','a00e_20000101_fc2_2_SIM3.20230602124354.err',2,'',replace('                 28787859  COMPLETED          1        1 2023-06-02T12:39:04 2023-06-02T12:43:43 2023-06-02T12:43:53          1.76K                                                     \n           28787859.batch  COMPLETED          1        1 2023-06-02T12:43:43 2023-06-02T12:43:43 2023-06-02T12:43:53          1.40K                      915K                      915K \n          28787859.extern  COMPLETED          1        1 2023-06-02T12:43:43 2023-06-02T12:43:43 2023-06-02T12:43:53          1.76K                      706K                      706K \n','\n',char(10)));
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',506);
INSERT INTO sqlite_sequence VALUES('job_data',19);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
