PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-10-06-13:03:46','2023-10-06-13:05:43',1696590226,1696590343,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(2,'2023-10-06-13:05:43','2023-10-06-13:11:55',1696590343,1696590715,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(3,'2023-10-06-13:11:55','2023-10-06-13:13:46',1696590715,1696590826,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(4,'2023-10-06-13:13:46','2023-10-06-13:16:46',1696590826,1696591006,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn4-cluster", "PROJECT": "dese28", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "00:55"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(5,'2023-10-06-13:16:46','2023-10-06-13:21:31',1696591006,1696591291,'day',1,3,703,0,1,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(6,'2023-10-06-13:21:31','2023-10-06-13:22:46',1696591291,1696591366,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(7,'2023-10-06-13:22:46','2023-10-06-13:27:03',1696591366,1696591623,'day',1,3,703,0,0,0,1,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(8,'2023-10-06-13:27:03','2023-10-06-13:45:23',1696591623,1696592723,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(9,'2023-10-06-13:45:23','2023-10-06-13:46:41',1696592723,1696592801,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(10,'2023-10-06-13:46:41','2023-10-06-14:12:42',1696592801,1696594362,'day',1,14,703,0,4,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(11,'2023-10-06-14:12:42','2023-10-06-14:13:52',1696594362,1696594432,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(12,'2023-10-06-14:13:52','2023-10-06-14:23:21',1696594432,1696595001,'day',1,4,703,0,0,0,6,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(13,'2023-10-06-14:23:21','2023-10-06-14:24:23',1696595001,1696595063,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(14,'2023-10-06-14:24:23','2023-10-06-14:29:16',1696595063,1696595356,'day',1,2,703,0,1,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(15,'2023-10-06-14:29:16','2023-10-06-14:30:32',1696595356,1696595432,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(16,'2023-10-06-14:30:32','2023-10-06-14:30:50',1696595432,1696595450,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(17,'2023-10-06-14:30:50','2023-10-06-14:30:53',1696595450,1696595453,'day',1,0,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(18,'2023-10-06-14:30:53','2023-10-06-14:39:01',1696595453,1696595941,'day',1,2,10,0,1,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(19,'2023-10-06-14:39:01','2023-10-06-14:39:38',1696595941,1696595978,'day',1,0,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(20,'2023-10-06-14:39:39','2023-10-06-14:42:56',1696595979,1696596176,'day',1,3,10,0,0,0,1,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(21,'2023-10-06-14:42:56','2023-10-06-14:45:03',1696596176,1696596303,'day',1,3,10,0,0,0,1,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(22,'2023-10-06-14:45:03','2023-10-06-14:50:53',1696596303,1696596653,'day',1,4,10,0,5,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(23,'2023-10-06-14:50:53','2023-10-06-14:51:03',1696596653,1696596663,'day',1,4,10,0,5,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(24,'2023-10-06-14:51:03','2023-10-06-14:51:12',1696596663,1696596672,'day',1,0,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(25,'2023-10-06-14:51:12','2023-10-06-14:52:34',1696596672,1696596754,'day',1,2,10,0,0,0,1,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(26,'2023-10-06-14:52:34','2023-10-06-15:07:33',1696596754,1696597653,'day',1,3,10,0,0,0,1,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(27,'2023-10-06-15:07:33','2023-10-06-15:26:50',1696597653,1696598810,'day',1,10,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(28,'2023-10-06-15:26:50','2023-10-09-08:41:03',1696598810,1696833663,'day',1,10,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(29,'2023-10-09-08:41:03','2023-10-09-09:17:10',1696833663,1696835830,'day',1,5,10,0,4,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(30,'2023-10-09-09:17:10','2023-10-09-09:22:46',1696835830,1696836166,'day',1,10,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(31,'2023-10-09-09:22:46','2023-10-09-09:46:01',1696836166,1696837561,'day',1,10,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(32,'2023-10-09-09:46:01','2023-10-09-09:53:26',1696837561,1696838006,'day',1,5,10,0,4,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(33,'2023-10-09-09:53:26','2023-10-09-10:24:11',1696838006,1696839851,'day',1,10,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(34,'2023-10-09-10:24:11','2023-10-09-10:41:19',1696839851,1696840879,'day',1,10,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.96", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(35,'2023-10-09-10:41:19','2023-10-09-10:58:48',1696840879,1696841928,'day',1,0,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(36,'2023-10-09-10:58:49','2023-10-09-11:08:01',1696841929,1696842481,'day',1,5,10,0,4,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.97", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(37,'2023-10-09-11:08:01','2023-10-09-11:19:49',1696842481,1696843189,'day',1,10,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.97", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(38,'2023-10-09-11:19:49','2023-10-09-12:43:45',1696843189,1696848225,'day',1,10,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.97", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(39,'2023-10-09-12:43:45','2023-10-10-11:11:58',1696848225,1696929118,'day',1,10,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.97", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(40,'2023-10-10-11:11:58','2023-10-10-11:15:55',1696929118,1696929355,'day',1,0,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(41,'2023-10-10-11:15:55','2023-10-10-11:19:37',1696929355,1696929577,'day',1,0,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(42,'2023-10-10-11:19:37','2023-10-10-11:38:01',1696929577,1696930681,'day',1,0,10,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 1, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.97", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(43,'2023-10-10-11:38:02','2023-10-10-11:40:15',1696930682,1696930815,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.97", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(44,'2023-10-10-11:40:15','2023-10-10-11:40:32',1696930815,1696930832,'day',1,0,703,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 100, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.97", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(45,'2023-10-10-11:40:32','2023-10-10-11:44:56',1696930832,1696931096,'day',1,0,17,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.97", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(46,'2023-10-10-11:44:56','2023-10-10-11:45:16',1696931096,1696931116,'day',1,0,24,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.97", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(47,'2023-10-10-11:45:16','2023-10-10-11:50:02',1696931116,1696931402,'day',1,0,24,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}, "OPA": {"DEPENDENCIES": {"DN": {}, "OPA-1": {}}, "FILE": "templates/opa.sh", "RUNNING": "chunk", "SPLITS": "5", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": []}, "APP": {"FILE": "templates/application.sh", "DEPENDENCIES": {"OPA": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4", "QUEUE": "debug", "ADDITIONAL_FILES": ["templates/mhm.nml.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(48,'2023-10-10-11:50:02','2023-10-10-11:50:20',1696931402,1696931420,'day',1,0,6,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(49,'2023-10-10-11:50:20','2023-10-10-11:50:58',1696931420,1696931458,'day',1,0,6,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.97", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(50,'2023-10-10-11:50:58','2023-10-10-11:52:24',1696931458,1696931544,'day',1,0,6,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(51,'2023-10-10-11:52:24','2023-10-10-15:31:04',1696931544,1696944664,'day',1,0,6,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "PLATFORM": "LOCAL", "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(52,'2023-10-10-15:31:04','2023-10-10-15:49:54',1696944664,1696945794,'day',1,0,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(53,'2023-10-10-15:49:54','2023-10-10-15:50:03',1696945794,1696945803,'day',1,0,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(54,'2023-10-10-15:50:03','2023-10-10-16:10:04',1696945803,1696947004,'day',1,0,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(55,'2023-10-10-16:10:04','2023-10-10-16:11:32',1696947004,1696947092,'day',1,0,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(56,'2023-10-10-16:11:32','2023-10-10-16:13:03',1696947092,1696947183,'day',1,0,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(57,'2023-10-10-16:13:03','2023-10-11-11:41:01',1696947183,1697017261,'day',1,0,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(58,'2023-10-11-11:41:01','2023-10-11-11:42:26',1697017261,1697017346,'day',1,0,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "RUNNING": "once", "PLATFORM": "marenostrum4-login", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "marenostrum4-login", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(59,'2023-10-11-11:42:26','2023-10-11-11:43:15',1697017346,1697017395,'day',1,0,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "PLATFORM": "local", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(60,'2023-10-11-11:43:15','2023-10-11-11:49:55',1697017395,1697017795,'day',1,4,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "PLATFORM": "local", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(61,'2023-10-11-11:49:55','2023-10-11-11:54:02',1697017795,1697018042,'day',1,4,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "PLATFORM": "local", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(62,'2023-10-11-11:54:02','2023-10-11-14:08:22',1697018042,1697026102,'day',1,1,4,0,0,0,1,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "PLATFORM": "local", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(63,'2023-10-11-14:08:22','2023-10-11-18:05:21',1697026102,1697040321,'day',1,3,4,0,0,0,1,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "PLATFORM": "local", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(64,'2023-10-11-18:05:21','2023-10-11-19:56:48',1697040321,1697047008,'day',1,2,4,0,0,0,1,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "PLATFORM": "local", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(65,'2023-10-11-19:56:48','2023-10-13-08:58:40',1697047008,1697180320,'day',1,0,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "PLATFORM": "local", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(66,'2023-10-13-08:58:40','2023-10-13-13:32:10',1697180320,1697196730,'day',1,4,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "PLATFORM": "local", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(67,'2023-10-13-13:32:10','2023-10-16-13:24:54',1697196730,1697455494,'day',1,0,0,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "PLATFORM": "local", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.1.0b", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
INSERT INTO experiment_run VALUES(68,'2023-10-16-13:24:54','2023-10-16-13:24:54',1697455494,0,'day',1,0,4,0,0,0,0,0,'{"EXPERIMENT": {"DATELIST": 20200128, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "day", "CHUNKSIZE": 1, "NUMCHUNKS": 3, "CALENDAR": "standard"}, "GSVREQUEST": {"DOMAIN": "g", "CLASS": "rd", "TYPE": "fc", "EXPVER": "hz9n", "STREAM": "lwda", "ANOFFSET": 9, "LEVTYPE": "sfc", "DATE": "%CHUNK_START_DATE%/to/%CHUNK_SECOND_TO_LAST_DATE%", "TIME": "0000/to/2300/by/0100", "STEP": ["0"], "PARAM": null, "GRID": "1/1", "METHOD": "nn", "AREA": "75.0/-25.0/35.0/45.0"}, "APP": {"OTHER": "empty"}, "OPAREQUEST": {"NSTATS": "5", "1": {"VARIABLE": "10u", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "2": {"VARIABLE": "10v", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "3": {"VARIABLE": "2d", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "4": {"VARIABLE": "tp", "STAT": "sum", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}, "5": {"VARIABLE": "2t", "STAT": "raw", "STAT_FREQ": "daily_noon", "OUTPUT_FREQ": "daily", "PERCENTILE_LIST": "None", "THRESH_EXCEED": "None", "TIME_STEP": 60, "SAVE": true, "CHECKPOINT": true, "CHECKPOINT_FILEPATH": "/scratch/project_465000454/tmp/a01r/", "OUT_FILEPATH": "/scratch/project_465000454/tmp/a01r/"}}, "JOBS": {"REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "PLATFORM": "local", "RUNNING": "once", "WALLCLOCK": "00:05", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "DN": {"FILE": "templates/dn.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "DN-1": {}}, "RUNNING": "chunk", "PLATFORM": "local", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": ["conf/applications/wildfires_fwi/request.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "JUWELS-LOGIN": {"TYPE": "ps", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "JUWELS": {"TYPE": "slurm", "HOST": "juwels-cluster", "PROJECT": "hhb19", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "PARTITION": "devel", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 24}, "LUMI-LOGIN": {"TYPE": "ps", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "TEMP_DIR": ""}, "LUMI": {"TYPE": "slurm", "HOST": "lumi-cluster", "PROJECT": "project_465000454", "USER": "<to-be-overloaded-in-user-conf>", "QUEUE": "", "SCRATCH_DIR": "/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROCESSORS_PER_NODE": 20, "BUDGET": "project_465000454", "PARTITION": "standard", "RESERVATION": "ClimateDT_CW"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "RUN": {"APP": "wildfires_fwi"}, "CONFIG": {"AUTOSUBMIT_VERSION": "4.0.98", "TOTALJOBS": 20, "MAXWAITINGJOBS": 20}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01r", "PROJDIR": "/home/dbeltran/new_autosubmit/a01r/proj/project_files", "DEFAULT": {"EXPID": "a01r", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/applications/wildfires_fwi/request.yml,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf,/home/dbeltran/new_autosubmit/a01r/proj/workflow/conf/simulation/%RUN.SIMULATION%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/parameter/%RUN.PARAMETER%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.MODEL%.yml,/home/dbeltran/new_autosubmit/a01r/proj/project_files/conf/model/%RUN.MODEL%/%RUN.GRID%.yml", "POST": "~/platforms.yml"}}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "workflow"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_BRANCH": "app-subworkflow", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "STORAGE": {}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a01r_LOCAL_SETUP','2023-10-06-13:18:04','2023-10-06-13:22:53',1696591084,1696591084,1696591089,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',35652,'',0,5,0.0,0.0,'a01r_LOCAL_SETUP.20231006131816.out','a01r_LOCAL_SETUP.20231006131816.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(2,0,'a01r_SYNCHRONIZE','2023-10-06-13:18:16','2023-10-06-13:23:06',1696591096,1696591096,1696591101,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',35686,'',0,5,0.0,0.0,'a01r_SYNCHRONIZE.20231006131828.out','a01r_SYNCHRONIZE.20231006131828.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(3,0,'a01r_REMOTE_SETUP','2023-10-06-13:18:35','2023-10-06-13:23:21',1696591115,1696591211,1696591216,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30339610,'',0,5,0.0,0.0,'a01r_REMOTE_SETUP.20231006132013.out','a01r_REMOTE_SETUP.20231006132013.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(4,0,'a01r_20200128_fc0_1_DN','2023-10-06-13:20:35','2023-10-06-13:24:25',1696591235,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30339614,'',0,5,0.0,0.0,'','',0,'a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_3_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_2_DN,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_1_OPA','');
INSERT INTO job_data VALUES(5,1,'a01r_LOCAL_SETUP','2023-10-06-13:22:53','2023-10-06-13:46:48',1696591373,1696591373,1696591378,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',36096,'',0,7,0.0,0.0,'a01r_LOCAL_SETUP.20231006132305.out','a01r_LOCAL_SETUP.20231006132305.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(6,1,'a01r_SYNCHRONIZE','2023-10-06-13:23:06','2023-10-06-13:47:00',1696591386,1696591386,1696591391,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',36140,'',0,7,0.0,0.0,'a01r_SYNCHRONIZE.20231006132318.out','a01r_SYNCHRONIZE.20231006132318.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(7,1,'a01r_REMOTE_SETUP','2023-10-06-13:23:21','2023-10-06-13:47:17',1696591401,1696591451,1696591456,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30339622,'',0,7,0.0,0.0,'a01r_REMOTE_SETUP.20231006132420.out','a01r_REMOTE_SETUP.20231006132420.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(8,1,'a01r_20200128_fc0_1_DN','2023-10-06-13:24:25','2023-10-06-13:48:42',1696591465,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30339627,'',0,7,0.0,0.0,'','',0,'a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_3_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_2_DN,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_1_OPA','');
INSERT INTO job_data VALUES(9,2,'a01r_LOCAL_SETUP','2023-10-06-13:46:48','2023-10-06-14:13:59',1696592808,1696592808,1696592813,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',39434,'',0,10,0.0,0.0,'a01r_LOCAL_SETUP.20231006134700.out','a01r_LOCAL_SETUP.20231006134700.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(10,2,'a01r_SYNCHRONIZE','2023-10-06-13:47:00','2023-10-06-14:14:12',1696592820,1696592820,1696592825,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',39470,'',0,10,0.0,0.0,'a01r_SYNCHRONIZE.20231006134712.out','a01r_SYNCHRONIZE.20231006134712.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(11,2,'a01r_REMOTE_SETUP','2023-10-06-13:47:17','2023-10-06-14:14:27',1696592837,1696592905,1696592910,'COMPLETED',2,1,'00:05','debug',1060,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30339800,'',1,10,0.0,0.0,'a01r_REMOTE_SETUP.20231006134837.out','a01r_REMOTE_SETUP.20231006134837.err',2,'a01r_20200128_fc0_1_DN',replace('                 30339800  COMPLETED          1        1 2023-10-06T13:47:17 2023-10-06T13:48:21 2023-10-06T13:48:32          1.06K                                                     \n           30339800.batch  COMPLETED          1        1 2023-10-06T13:48:21 2023-10-06T13:48:21 2023-10-06T13:48:32            817                     1028K                     1028K \n          30339800.extern  COMPLETED          1        1 2023-10-06T13:48:21 2023-10-06T13:48:21 2023-10-06T13:48:32          1.06K                      708K                      708K \n','\n',char(10)));
INSERT INTO job_data VALUES(12,2,'a01r_20200128_fc0_1_DN','2023-10-06-13:48:42','2023-10-06-14:20:51',1696592922,1696593028,1696593033,'COMPLETED',2,1,'00:05','debug',769,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30339803,'',1,10,0.0,0.0,'a01r_20200128_fc0_1_DN.20231006135031.out','a01r_20200128_fc0_1_DN.20231006135031.err',2,'a01r_20200128_fc0_2_DN,a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_3_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_1_OPA',replace('                 30339803  COMPLETED          1        1 2023-10-06T13:48:42 2023-10-06T13:50:24 2023-10-06T13:50:35            769                                                     \n           30339803.batch  COMPLETED          1        1 2023-10-06T13:50:24 2023-10-06T13:50:24 2023-10-06T13:50:35            577                     1102K                     1102K \n          30339803.extern  COMPLETED          1        1 2023-10-06T13:50:24 2023-10-06T13:50:24 2023-10-06T13:50:35            769                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(13,2,'a01r_20200128_fc0_2_DN','2023-10-06-13:50:54','2023-10-06-14:22:55',1696593054,1696593148,1696593153,'COMPLETED',2,1,'00:05','debug',646,'2020-01-28 00:00:00','DN','fc0',2,0,'MARENOSTRUM4-LOGIN',30339814,'',1,10,0.0,0.0,'a01r_20200128_fc0_2_DN.20231006135252.out','a01r_20200128_fc0_2_DN.20231006135252.err',2,'a01r_20200128_fc0_2_1_OPA,a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_3_DN,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA',replace('                 30339814  COMPLETED          1        1 2023-10-06T13:50:54 2023-10-06T13:52:24 2023-10-06T13:52:35            646                                                     \n           30339814.batch  COMPLETED          1        1 2023-10-06T13:52:24 2023-10-06T13:52:24 2023-10-06T13:52:35            504                     1004K                     1004K \n          30339814.extern  COMPLETED          1        1 2023-10-06T13:52:24 2023-10-06T13:52:24 2023-10-06T13:52:35            646                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(14,2,'a01r_20200128_fc0_1_1_OPA','2023-10-06-13:51:01','2023-10-06-14:23:03',1696593061,1696593268,1696593273,'COMPLETED',2,1,'00:05','debug',1710,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30339816,'',1,10,0.0,0.0,'a01r_20200128_fc0_1_1_OPA.20231006135443.out','a01r_20200128_fc0_1_1_OPA.20231006135443.err',2,'a01r_20200128_fc0_2_1_OPA,a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_1_APP,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA',replace('                 30339816  COMPLETED          1        1 2023-10-06T13:51:01 2023-10-06T13:54:24 2023-10-06T13:54:35          1.71K                                                     \n           30339816.batch  COMPLETED          1        1 2023-10-06T13:54:24 2023-10-06T13:54:24 2023-10-06T13:54:35          1.32K                      984K                      984K \n          30339816.extern  COMPLETED          1        1 2023-10-06T13:54:24 2023-10-06T13:54:24 2023-10-06T13:54:35          1.71K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(15,2,'a01r_20200128_fc0_1_2_OPA','2023-10-06-13:51:01','2023-10-06-14:23:03',1696593061,1696593388,1696593393,'COMPLETED',2,1,'00:05','debug',1800,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30339817,'',1,10,0.0,0.0,'a01r_20200128_fc0_1_2_OPA.20231006135655.out','a01r_20200128_fc0_1_2_OPA.20231006135655.err',2,'a01r_20200128_fc0_2_1_OPA,a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_1_APP,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA',replace('                 30339817  COMPLETED          1        1 2023-10-06T13:51:01 2023-10-06T13:56:24 2023-10-06T13:56:35          1.80K                                                     \n           30339817.batch  COMPLETED          1        1 2023-10-06T13:56:24 2023-10-06T13:56:24 2023-10-06T13:56:35          1.39K                      929K                      929K \n          30339817.extern  COMPLETED          1        1 2023-10-06T13:56:24 2023-10-06T13:56:24 2023-10-06T13:56:35          1.80K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(16,2,'a01r_20200128_fc0_1_3_OPA','2023-10-06-13:51:01','2023-10-06-14:23:03',1696593061,1696593508,1696593513,'COMPLETED',2,1,'00:05','debug',1790,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30339818,'',1,10,0.0,0.0,'a01r_20200128_fc0_1_3_OPA.20231006135835.out','a01r_20200128_fc0_1_3_OPA.20231006135835.err',2,'a01r_20200128_fc0_2_1_OPA,a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_1_APP,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA',replace('                 30339818  COMPLETED          1        1 2023-10-06T13:51:01 2023-10-06T13:58:24 2023-10-06T13:58:35          1.79K                                                     \n           30339818.batch  COMPLETED          1        1 2023-10-06T13:58:24 2023-10-06T13:58:24 2023-10-06T13:58:35          1.38K                      949K                      949K \n          30339818.extern  COMPLETED          1        1 2023-10-06T13:58:24 2023-10-06T13:58:24 2023-10-06T13:58:35          1.79K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(17,2,'a01r_20200128_fc0_1_4_OPA','2023-10-06-13:51:01','2023-10-06-14:23:03',1696593061,1696593629,1696593634,'COMPLETED',2,1,'00:05','debug',657,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30339819,'',1,10,0.0,0.0,'a01r_20200128_fc0_1_4_OPA.20231006140044.out','a01r_20200128_fc0_1_4_OPA.20231006140044.err',2,'a01r_20200128_fc0_2_1_OPA,a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_1_APP,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA',replace('                 30339819  COMPLETED          1        1 2023-10-06T13:51:01 2023-10-06T14:00:25 2023-10-06T14:00:35            657                                                     \n           30339819.batch  COMPLETED          1        1 2023-10-06T14:00:25 2023-10-06T14:00:25 2023-10-06T14:00:35            512                     1030K                     1030K \n          30339819.extern  COMPLETED          1        1 2023-10-06T14:00:25 2023-10-06T14:00:25 2023-10-06T14:00:35            657                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(18,2,'a01r_20200128_fc0_1_5_OPA','2023-10-06-13:51:01','2023-10-06-14:23:03',1696593061,1696593748,1696593753,'COMPLETED',2,1,'00:05','debug',1010,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30339820,'',1,10,0.0,0.0,'a01r_20200128_fc0_1_5_OPA.20231006140247.out','a01r_20200128_fc0_1_5_OPA.20231006140247.err',2,'a01r_20200128_fc0_2_1_OPA,a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_1_APP,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA',replace('                 30339820  COMPLETED          1        1 2023-10-06T13:51:01 2023-10-06T14:02:24 2023-10-06T14:02:35          1.01K                                                     \n           30339820.batch  COMPLETED          1        1 2023-10-06T14:02:24 2023-10-06T14:02:24 2023-10-06T14:02:35            779                      987K                      987K \n          30339820.extern  COMPLETED          1        1 2023-10-06T14:02:24 2023-10-06T14:02:24 2023-10-06T14:02:35          1.01K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(19,2,'a01r_20200128_fc0_3_DN','2023-10-06-13:53:10','2023-10-10-16:18:50',1696593190,1696593865,1696593870,'COMPLETED',2,1,'00:05','debug',2000,'2020-01-28 00:00:00','DN','fc0',3,0,'MARENOSTRUM4-LOGIN',30339828,'',1,10,0.0,0.0,'a01r_20200128_fc0_3_DN.20231006140449.out','a01r_20200128_fc0_3_DN.20231006140449.err',2,'a01r_20200128_fc0_3_1_OPA,a01r_20200128_fc0_3_2_OPA,a01r_20200128_fc0_3_3_OPA,a01r_20200128_fc0_3_4_OPA,a01r_20200128_fc0_3_5_OPA,a01r_20200128_fc0_4_DN',replace('                 30339828  COMPLETED          1        1 2023-10-06T13:53:10 2023-10-06T14:04:24 2023-10-06T14:04:32          2.00K                                                     \n           30339828.batch  COMPLETED          1        1 2023-10-06T14:04:24 2023-10-06T14:04:24 2023-10-06T14:04:32          1.36K                      977K                      977K \n          30339828.extern  COMPLETED          1        1 2023-10-06T14:04:24 2023-10-06T14:04:24 2023-10-06T14:04:32          2.00K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(20,2,'a01r_20200128_fc0_1_APP','2023-10-06-14:02:57','2023-10-06-15:16:55',1696593777,1696593988,1696593993,'COMPLETED',2,1,'00:05','debug',1770,'2020-01-28 00:00:00','APP','fc0',1,0,'MARENOSTRUM4',30339903,'',1,10,0.0,0.0,'a01r_20200128_fc0_1_APP.20231006140642.out','a01r_20200128_fc0_1_APP.20231006140642.err',2,'',replace('                 30339903  COMPLETED          1        1 2023-10-06T14:02:57 2023-10-06T14:06:24 2023-10-06T14:06:35          1.77K                                                     \n           30339903.batch  COMPLETED          1        1 2023-10-06T14:06:24 2023-10-06T14:06:24 2023-10-06T14:06:35          1.36K                      963K                      963K \n          30339903.extern  COMPLETED          1        1 2023-10-06T14:06:24 2023-10-06T14:06:24 2023-10-06T14:06:35          1.77K                      710K                      710K \n','\n',char(10)));
INSERT INTO job_data VALUES(21,2,'a01r_20200128_fc0_2_1_OPA','2023-10-06-14:02:57','2023-10-06-14:09:56',1696593777,1696594108,1696594113,'COMPLETED',2,1,'00:05','debug',1770,'2020-01-28 00:00:00','OPA','fc0',2,1,'MARENOSTRUM4',30339904,'',1,10,0.0,0.0,'a01r_20200128_fc0_2_1_OPA.20231006140853.out','a01r_20200128_fc0_2_1_OPA.20231006140853.err',2,'a01r_20200128_fc0_3_1_OPA,a01r_20200128_fc0_3_2_OPA,a01r_20200128_fc0_3_3_OPA,a01r_20200128_fc0_2_APP,a01r_20200128_fc0_3_4_OPA,a01r_20200128_fc0_3_5_OPA',replace('                 30339904  COMPLETED          1        1 2023-10-06T14:02:57 2023-10-06T14:08:24 2023-10-06T14:08:35          1.77K                                                     \n           30339904.batch  COMPLETED          1        1 2023-10-06T14:08:24 2023-10-06T14:08:24 2023-10-06T14:08:35          1.37K                      961K                      961K \n          30339904.extern  COMPLETED          1        1 2023-10-06T14:08:24 2023-10-06T14:08:24 2023-10-06T14:08:35          1.77K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(22,2,'a01r_20200128_fc0_2_2_OPA','2023-10-06-14:02:57','2023-10-06-14:11:59',1696593777,1696594228,1696594233,'COMPLETED',2,1,'00:05','debug',1060,'2020-01-28 00:00:00','OPA','fc0',2,1,'MARENOSTRUM4',30339905,'',1,10,0.0,0.0,'a01r_20200128_fc0_2_2_OPA.20231006141056.out','a01r_20200128_fc0_2_2_OPA.20231006141056.err',2,'a01r_20200128_fc0_3_1_OPA,a01r_20200128_fc0_3_2_OPA,a01r_20200128_fc0_3_3_OPA,a01r_20200128_fc0_2_APP,a01r_20200128_fc0_3_4_OPA,a01r_20200128_fc0_3_5_OPA',replace('                 30339905  COMPLETED          1        1 2023-10-06T14:02:57 2023-10-06T14:10:24 2023-10-06T14:10:35          1.06K                                                     \n           30339905.batch  COMPLETED          1        1 2023-10-06T14:10:24 2023-10-06T14:10:24 2023-10-06T14:10:35            824                      973K                      973K \n          30339905.extern  COMPLETED          1        1 2023-10-06T14:10:24 2023-10-06T14:10:24 2023-10-06T14:10:35          1.06K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(23,2,'a01r_20200128_fc0_2_3_OPA','2023-10-06-14:02:57','2023-10-06-14:02:57',1696593777,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',2,1,'MARENOSTRUM4',30339906,'',0,10,0.0,0.0,'','',0,'a01r_20200128_fc0_3_1_OPA,a01r_20200128_fc0_3_2_OPA,a01r_20200128_fc0_3_3_OPA,a01r_20200128_fc0_2_APP,a01r_20200128_fc0_3_4_OPA,a01r_20200128_fc0_3_5_OPA','');
INSERT INTO job_data VALUES(24,2,'a01r_20200128_fc0_2_4_OPA','2023-10-06-14:02:57','2023-10-06-14:02:57',1696593777,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',2,1,'MARENOSTRUM4',30339907,'',0,10,0.0,0.0,'','',0,'a01r_20200128_fc0_3_1_OPA,a01r_20200128_fc0_3_2_OPA,a01r_20200128_fc0_3_3_OPA,a01r_20200128_fc0_2_APP,a01r_20200128_fc0_3_4_OPA,a01r_20200128_fc0_3_5_OPA','');
INSERT INTO job_data VALUES(25,2,'a01r_20200128_fc0_2_5_OPA','2023-10-06-14:02:57','2023-10-06-14:02:57',1696593777,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',2,1,'MARENOSTRUM4',30339908,'',0,10,0.0,0.0,'','',0,'a01r_20200128_fc0_3_1_OPA,a01r_20200128_fc0_3_2_OPA,a01r_20200128_fc0_3_3_OPA,a01r_20200128_fc0_2_APP,a01r_20200128_fc0_3_4_OPA,a01r_20200128_fc0_3_5_OPA','');
INSERT INTO job_data VALUES(26,2,'a01r_20200128_fc0_4_DN','2023-10-06-14:05:05','2023-10-06-14:05:05',1696593905,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',4,1,'MARENOSTRUM4-LOGIN',30339992,'',0,10,0.0,0.0,'','',0,'a01r_20200128_fc0_4_2_OPA,a01r_20200128_fc0_4_3_OPA,a01r_20200128_fc0_4_4_OPA,a01r_20200128_fc0_4_5_OPA,a01r_20200128_fc0_5_DN,a01r_20200128_fc0_4_1_OPA','');
INSERT INTO job_data VALUES(27,3,'a01r_LOCAL_SETUP','2023-10-06-14:13:59','2023-10-06-14:24:30',1696594439,1696594439,1696594444,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',42958,'',0,12,0.0,0.0,'a01r_LOCAL_SETUP.20231006141411.out','a01r_LOCAL_SETUP.20231006141411.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(28,3,'a01r_SYNCHRONIZE','2023-10-06-14:14:12','2023-10-06-14:24:42',1696594452,1696594452,1696594457,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',43081,'',0,12,0.0,0.0,'a01r_SYNCHRONIZE.20231006141424.out','a01r_SYNCHRONIZE.20231006141424.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(29,3,'a01r_REMOTE_SETUP','2023-10-06-14:14:27','2023-10-06-14:24:58',1696594467,1696594829,1696594834,'COMPLETED',2,1,'00:05','debug',647,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30340022,'',1,12,0.0,0.0,'a01r_REMOTE_SETUP.20231006142044.out','a01r_REMOTE_SETUP.20231006142044.err',2,'a01r_20200128_fc0_1_DN',replace('                 30340022  COMPLETED          1        1 2023-10-06T14:14:27 2023-10-06T14:20:25 2023-10-06T14:20:35            647                                                     \n           30340022.batch  COMPLETED          1        1 2023-10-06T14:20:25 2023-10-06T14:20:25 2023-10-06T14:20:35            508                     1131K                     1131K \n          30340022.extern  COMPLETED          1        1 2023-10-06T14:20:25 2023-10-06T14:20:25 2023-10-06T14:20:35            647                      710K                      710K \n','\n',char(10)));
INSERT INTO job_data VALUES(30,3,'a01r_20200128_fc0_1_DN','2023-10-06-14:20:51','2023-10-06-14:41:07',1696594851,1696594953,1696594958,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30340032,'',0,12,0.0,0.0,'a01r_20200128_fc0_1_DN.20231006142234.out','a01r_20200128_fc0_1_DN.20231006142234.err',5,'a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_3_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_2_DN,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_1_OPA','');
INSERT INTO job_data VALUES(31,3,'a01r_20200128_fc0_2_DN','2023-10-06-14:22:56','2023-10-10-16:16:40',1696594975,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'MARENOSTRUM4-LOGIN',30340049,'',0,12,0.0,0.0,'','',0,'a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA,a01r_20200128_fc0_3_DN,a01r_20200128_fc0_2_1_OPA','');
INSERT INTO job_data VALUES(32,3,'a01r_20200128_fc0_1_1_OPA','2023-10-06-14:23:03','2023-10-06-14:45:18',1696594983,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340050,'',0,12,0.0,0.0,'','',0,'a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_1_APP,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA,a01r_20200128_fc0_2_1_OPA','');
INSERT INTO job_data VALUES(33,3,'a01r_20200128_fc0_1_2_OPA','2023-10-06-14:23:03','2023-10-06-14:45:18',1696594983,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340051,'',0,12,0.0,0.0,'','',0,'a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_1_APP,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA,a01r_20200128_fc0_2_1_OPA','');
INSERT INTO job_data VALUES(34,3,'a01r_20200128_fc0_1_3_OPA','2023-10-06-14:23:03','2023-10-06-14:45:18',1696594983,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340052,'',0,12,0.0,0.0,'','',0,'a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_1_APP,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA,a01r_20200128_fc0_2_1_OPA','');
INSERT INTO job_data VALUES(35,3,'a01r_20200128_fc0_1_4_OPA','2023-10-06-14:23:03','2023-10-06-14:45:19',1696594983,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340053,'',0,12,0.0,0.0,'','',0,'a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_1_APP,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA,a01r_20200128_fc0_2_1_OPA','');
INSERT INTO job_data VALUES(36,3,'a01r_20200128_fc0_1_5_OPA','2023-10-06-14:23:03','2023-10-06-14:45:19',1696594983,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340054,'',0,12,0.0,0.0,'','',0,'a01r_20200128_fc0_2_2_OPA,a01r_20200128_fc0_1_APP,a01r_20200128_fc0_2_3_OPA,a01r_20200128_fc0_2_4_OPA,a01r_20200128_fc0_2_5_OPA,a01r_20200128_fc0_2_1_OPA','');
INSERT INTO job_data VALUES(37,4,'a01r_LOCAL_SETUP','2023-10-06-14:24:30','2023-10-06-14:30:42',1696595070,1696595070,1696595075,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',44321,'',0,14,0.0,0.0,'a01r_LOCAL_SETUP.20231006142442.out','a01r_LOCAL_SETUP.20231006142442.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(38,4,'a01r_SYNCHRONIZE','2023-10-06-14:24:42','2023-10-06-14:31:12',1696595082,1696595082,1696595087,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',44359,'',0,14,0.0,0.0,'a01r_SYNCHRONIZE.20231006142454.out','a01r_SYNCHRONIZE.20231006142454.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(39,4,'a01r_REMOTE_SETUP','2023-10-06-14:24:58','2023-10-06-14:31:27',1696595098,0,0,'SUBMITTED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30340059,'',0,14,0.0,0.0,'','',0,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(40,5,'a01r_LOCAL_SETUP','2023-10-06-14:30:42','2023-10-06-14:31:00',1696595442,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',45202,'',0,16,0.0,0.0,'','',0,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(41,6,'a01r_LOCAL_SETUP','2023-10-06-14:31:00','2023-10-06-14:39:47',1696595460,1696595460,1696595465,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',45271,'',0,18,0.0,0.0,'a01r_LOCAL_SETUP.20231006143112.out','a01r_LOCAL_SETUP.20231006143112.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(42,6,'a01r_SYNCHRONIZE','2023-10-06-14:31:12','2023-10-06-14:40:03',1696595472,1696595472,1696595477,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',45313,'',0,18,0.0,0.0,'a01r_SYNCHRONIZE.20231006143124.out','a01r_SYNCHRONIZE.20231006143124.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(43,6,'a01r_REMOTE_SETUP','2023-10-06-14:31:27','2023-10-06-14:40:22',1696595487,0,0,'SUBMITTED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30340081,'',0,18,0.0,0.0,'','',0,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(44,7,'a01r_LOCAL_SETUP','2023-10-06-14:39:47','2023-10-06-14:51:19',1696595987,1696595987,1696595992,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',46194,'',0,20,0.0,0.0,'a01r_LOCAL_SETUP.20231006143959.out','a01r_LOCAL_SETUP.20231006143959.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(45,7,'a01r_SYNCHRONIZE','2023-10-06-14:40:03','2023-10-06-14:51:31',1696596003,1696596003,1696596008,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',46236,'',0,20,0.0,0.0,'a01r_SYNCHRONIZE.20231006144015.out','a01r_SYNCHRONIZE.20231006144015.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(46,7,'a01r_REMOTE_SETUP','2023-10-06-14:40:22','2023-10-06-14:51:47',1696596022,1696596036,1696596041,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30340097,'',0,20,0.0,0.0,'a01r_REMOTE_SETUP.20231006144041.out','a01r_REMOTE_SETUP.20231006144041.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(47,7,'a01r_20200128_fc0_1_DN','2023-10-06-14:41:07','2023-10-06-14:53:03',1696596067,1696596156,1696596161,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30340098,'',0,20,0.0,0.0,'a01r_20200128_fc0_1_DN.20231006144310.out','a01r_20200128_fc0_1_DN.20231006144310.err',5,'a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_1_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_3_OPA,a01r_20200128_fc0_1_5_OPA','');
INSERT INTO job_data VALUES(48,7,'a01r_20200128_fc0_1_1_OPA','2023-10-06-14:45:18','2023-10-06-15:07:53',1696596318,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340125,'',0,22,0.0,0.0,'','',0,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(49,7,'a01r_20200128_fc0_1_2_OPA','2023-10-06-14:45:18','2023-10-06-15:07:53',1696596318,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340126,'',0,22,0.0,0.0,'','',0,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(50,7,'a01r_20200128_fc0_1_3_OPA','2023-10-06-14:45:18','2023-10-06-15:07:53',1696596318,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340127,'',0,22,0.0,0.0,'','',0,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(51,7,'a01r_20200128_fc0_1_4_OPA','2023-10-06-14:45:19','2023-10-06-15:07:53',1696596318,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340128,'',0,22,0.0,0.0,'','',0,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(52,7,'a01r_20200128_fc0_1_5_OPA','2023-10-06-14:45:19','2023-10-06-15:07:53',1696596319,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340129,'',0,22,0.0,0.0,'','',0,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(53,8,'a01r_LOCAL_SETUP','2023-10-06-14:51:19','2023-10-06-15:27:03',1696596679,1696596679,1696596684,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',47736,'',0,25,0.0,0.0,'a01r_LOCAL_SETUP.20231006145131.out','a01r_LOCAL_SETUP.20231006145131.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(54,8,'a01r_SYNCHRONIZE','2023-10-06-14:51:31','2023-10-06-15:27:16',1696596691,1696596691,1696596696,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',47777,'',0,25,0.0,0.0,'a01r_SYNCHRONIZE.20231006145143.out','a01r_SYNCHRONIZE.20231006145143.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(55,8,'a01r_REMOTE_SETUP','2023-10-06-14:51:47','2023-10-06-15:27:32',1696596707,1696596759,1696596764,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30340135,'',0,25,0.0,0.0,'a01r_REMOTE_SETUP.20231006145254.out','a01r_REMOTE_SETUP.20231006145254.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(56,8,'a01r_20200128_fc0_1_DN','2023-10-06-14:53:03','2023-10-06-15:28:55',1696596783,1696596876,1696596881,'COMPLETED',2,1,'00:05','debug',1850,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30340141,'',1,26,0.0,0.0,'a01r_20200128_fc0_1_DN.20231006150748.out','a01r_20200128_fc0_1_DN.20231006150748.err',2,'a01r_20200128_fc0_1_1_OPA,a01r_20200128_fc0_1_3_OPA,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_2_OPA',replace('                 30340141  COMPLETED          1        1 2023-10-06T14:53:03 2023-10-06T14:54:33 2023-10-06T14:54:43          1.85K                                                     \n           30340141.batch  COMPLETED          1        1 2023-10-06T14:54:33 2023-10-06T14:54:33 2023-10-06T14:54:43          1.36K                      968K                      968K \n          30340141.extern  COMPLETED          1        1 2023-10-06T14:54:33 2023-10-06T14:54:33 2023-10-06T14:54:43          1.85K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(57,8,'a01r_20200128_fc0_1_1_OPA','2023-10-06-15:07:53','2023-10-06-15:31:03',1696597673,1696597719,1696597724,'COMPLETED',2,1,'00:05','debug',1570,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340188,'',1,27,0.0,0.0,'a01r_20200128_fc0_1_1_OPA.20231006150855.out','a01r_20200128_fc0_1_1_OPA.20231006150855.err',2,'a01r_20200128_fc0_1_APP',replace('                 30340188  COMPLETED          1        1 2023-10-06T15:07:52 2023-10-06T15:08:35 2023-10-06T15:08:45          1.57K                                                     \n           30340188.batch  COMPLETED          1        1 2023-10-06T15:08:35 2023-10-06T15:08:35 2023-10-06T15:08:45          1.34K                      973K                      973K \n          30340188.extern  COMPLETED          1        1 2023-10-06T15:08:35 2023-10-06T15:08:35 2023-10-06T15:08:45          1.57K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(58,8,'a01r_20200128_fc0_1_2_OPA','2023-10-06-15:07:53','2023-10-06-15:31:03',1696597673,1696597839,1696597844,'COMPLETED',2,1,'00:05','debug',1850,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340189,'',1,27,0.0,0.0,'a01r_20200128_fc0_1_2_OPA.20231006151044.out','a01r_20200128_fc0_1_2_OPA.20231006151044.err',2,'a01r_20200128_fc0_1_APP',replace('                 30340189  COMPLETED          1        1 2023-10-06T15:07:52 2023-10-06T15:10:36 2023-10-06T15:10:46          1.85K                                                     \n           30340189.batch  COMPLETED          1        1 2023-10-06T15:10:36 2023-10-06T15:10:36 2023-10-06T15:10:46          1.36K                      942K                      942K \n          30340189.extern  COMPLETED          1        1 2023-10-06T15:10:36 2023-10-06T15:10:36 2023-10-06T15:10:46          1.85K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(59,8,'a01r_20200128_fc0_1_3_OPA','2023-10-06-15:07:53','2023-10-06-15:31:03',1696597673,1696597963,1696597968,'COMPLETED',2,1,'00:05','debug',1650,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340190,'',1,27,0.0,0.0,'a01r_20200128_fc0_1_3_OPA.20231006151255.out','a01r_20200128_fc0_1_3_OPA.20231006151255.err',2,'a01r_20200128_fc0_1_APP',replace('                 30340190  COMPLETED          1        1 2023-10-06T15:07:52 2023-10-06T15:12:37 2023-10-06T15:12:49          1.65K                                                     \n           30340190.batch  COMPLETED          1        1 2023-10-06T15:12:37 2023-10-06T15:12:37 2023-10-06T15:12:49          1.29K                      972K                      972K \n          30340190.extern  COMPLETED          1        1 2023-10-06T15:12:37 2023-10-06T15:12:37 2023-10-06T15:12:49          1.65K                      710K                      710K \n','\n',char(10)));
INSERT INTO job_data VALUES(60,8,'a01r_20200128_fc0_1_4_OPA','2023-10-06-15:07:53','2023-10-06-15:31:03',1696597673,1696598080,1696598085,'COMPLETED',2,1,'00:05','debug',1660,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340191,'',1,27,0.0,0.0,'a01r_20200128_fc0_1_4_OPA.20231006151442.out','a01r_20200128_fc0_1_4_OPA.20231006151442.err',2,'a01r_20200128_fc0_1_APP',replace('                 30340191  COMPLETED          1        1 2023-10-06T15:07:53 2023-10-06T15:14:37 2023-10-06T15:14:47          1.66K                                                     \n           30340191.batch  COMPLETED          1        1 2023-10-06T15:14:37 2023-10-06T15:14:37 2023-10-06T15:14:47          1.18K                      934K                      934K \n          30340191.extern  COMPLETED          1        1 2023-10-06T15:14:37 2023-10-06T15:14:37 2023-10-06T15:14:47          1.66K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(61,8,'a01r_20200128_fc0_1_5_OPA','2023-10-06-15:07:53','2023-10-06-15:31:03',1696597673,1696598200,1696598205,'COMPLETED',2,1,'00:05','debug',1590,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340192,'',1,27,0.0,0.0,'a01r_20200128_fc0_1_5_OPA.20231006151650.out','a01r_20200128_fc0_1_5_OPA.20231006151650.err',2,'a01r_20200128_fc0_1_APP',replace('                 30340192  COMPLETED          1        1 2023-10-06T15:07:53 2023-10-06T15:16:37 2023-10-06T15:16:47          1.59K                                                     \n           30340192.batch  COMPLETED          1        1 2023-10-06T15:16:37 2023-10-06T15:16:37 2023-10-06T15:16:47          1.17K                      954K                      954K \n          30340192.extern  COMPLETED          1        1 2023-10-06T15:16:37 2023-10-06T15:16:37 2023-10-06T15:16:47          1.59K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(62,8,'a01r_20200128_fc0_1_APP','2023-10-06-15:16:55','2023-10-06-15:41:13',1696598215,1696598320,1696598325,'COMPLETED',2,1,'00:05','debug',1570,'2020-01-28 00:00:00','APP','fc0',1,0,'MARENOSTRUM4',30340205,'',1,27,0.0,0.0,'a01r_20200128_fc0_1_APP.20231006151857.out','a01r_20200128_fc0_1_APP.20231006151857.err',2,'',replace('                 30340205  COMPLETED          1        1 2023-10-06T15:16:54 2023-10-06T15:18:37 2023-10-06T15:18:47          1.57K                                                     \n           30340205.batch  COMPLETED          1        1 2023-10-06T15:18:37 2023-10-06T15:18:37 2023-10-06T15:18:47          1.14K                      975K                      975K \n          30340205.extern  COMPLETED          1        1 2023-10-06T15:18:37 2023-10-06T15:18:37 2023-10-06T15:18:47          1.57K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(63,9,'a01r_LOCAL_SETUP','2023-10-06-15:27:03','2023-10-09-08:41:51',1696598823,1696598823,1696598828,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',51247,'',0,28,0.0,0.0,'a01r_LOCAL_SETUP.20231006152716.out','a01r_LOCAL_SETUP.20231006152716.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(64,9,'a01r_SYNCHRONIZE','2023-10-06-15:27:16','2023-10-09-08:42:06',1696598836,1696598836,1696598841,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',51380,'',0,28,0.0,0.0,'a01r_SYNCHRONIZE.20231006152728.out','a01r_SYNCHRONIZE.20231006152728.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(65,9,'a01r_REMOTE_SETUP','2023-10-06-15:27:32','2023-10-09-08:44:33',1696598852,1696598920,1696598925,'COMPLETED',2,1,'00:05','debug',1400,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30340226,'',1,28,0.0,0.0,'a01r_REMOTE_SETUP.20231006152850.out','a01r_REMOTE_SETUP.20231006152850.err',2,'a01r_20200128_fc0_1_DN',replace('                 30340226  COMPLETED          1        1 2023-10-06T15:27:32 2023-10-06T15:28:37 2023-10-06T15:28:47          1.40K                                                     \n           30340226.batch  COMPLETED          1        1 2023-10-06T15:28:37 2023-10-06T15:28:37 2023-10-06T15:28:47          1.02K                      964K                      964K \n          30340226.extern  COMPLETED          1        1 2023-10-06T15:28:37 2023-10-06T15:28:37 2023-10-06T15:28:47          1.40K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(66,9,'a01r_20200128_fc0_1_DN','2023-10-06-15:28:55','2023-10-09-08:45:19',1696598935,1696599040,1696599045,'COMPLETED',2,1,'00:05','debug',1090,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30340231,'',1,28,0.0,0.0,'a01r_20200128_fc0_1_DN.20231006153055.out','a01r_20200128_fc0_1_DN.20231006153055.err',2,'a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_1_OPA,a01r_20200128_fc0_1_3_OPA',replace('                 30340231  COMPLETED          1        1 2023-10-06T15:28:54 2023-10-06T15:30:36 2023-10-06T15:30:46          1.09K                                                     \n           30340231.batch  COMPLETED          1        1 2023-10-06T15:30:36 2023-10-06T15:30:36 2023-10-06T15:30:46            998                      971K                      971K \n          30340231.extern  COMPLETED          1        1 2023-10-06T15:30:36 2023-10-06T15:30:36 2023-10-06T15:30:46          1.09K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(67,9,'a01r_20200128_fc0_1_1_OPA','2023-10-06-15:31:03','2023-10-09-09:01:31',1696599063,1696599160,1696599165,'COMPLETED',2,1,'00:05','debug',1280,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340250,'',1,28,0.0,0.0,'a01r_20200128_fc0_1_1_OPA.20231006153244.out','a01r_20200128_fc0_1_1_OPA.20231006153244.err',2,'a01r_20200128_fc0_1_APP',replace('                 30340250  COMPLETED          1        1 2023-10-06T15:31:01 2023-10-06T15:32:37 2023-10-06T15:32:47          1.28K                                                     \n           30340250.batch  COMPLETED          1        1 2023-10-06T15:32:37 2023-10-06T15:32:37 2023-10-06T15:32:47            990                      964K                      964K \n          30340250.extern  COMPLETED          1        1 2023-10-06T15:32:37 2023-10-06T15:32:37 2023-10-06T15:32:47          1.28K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(68,9,'a01r_20200128_fc0_1_2_OPA','2023-10-06-15:31:03','2023-10-09-09:01:31',1696599063,1696599280,1696599285,'COMPLETED',2,1,'00:05','debug',504,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340251,'',1,28,0.0,0.0,'a01r_20200128_fc0_1_2_OPA.20231006153448.out','a01r_20200128_fc0_1_2_OPA.20231006153448.err',2,'a01r_20200128_fc0_1_APP',replace('                 30340251  COMPLETED          1        1 2023-10-06T15:31:01 2023-10-06T15:34:37 2023-10-06T15:34:45            504                                                     \n           30340251.batch  COMPLETED          1        1 2023-10-06T15:34:37 2023-10-06T15:34:37 2023-10-06T15:34:45            489                     1131K                     1131K \n          30340251.extern  COMPLETED          1        1 2023-10-06T15:34:37 2023-10-06T15:34:37 2023-10-06T15:34:45            504                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(69,9,'a01r_20200128_fc0_1_3_OPA','2023-10-06-15:31:03','2023-10-09-09:01:31',1696599063,1696599400,1696599405,'COMPLETED',2,1,'00:05','debug',1400,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340252,'',1,28,0.0,0.0,'a01r_20200128_fc0_1_3_OPA.20231006153652.out','a01r_20200128_fc0_1_3_OPA.20231006153652.err',2,'a01r_20200128_fc0_1_APP',replace('                 30340252  COMPLETED          1        1 2023-10-06T15:31:01 2023-10-06T15:36:36 2023-10-06T15:36:47          1.40K                                                     \n           30340252.batch  COMPLETED          1        1 2023-10-06T15:36:36 2023-10-06T15:36:36 2023-10-06T15:36:47          1.02K                      943K                      943K \n          30340252.extern  COMPLETED          1        1 2023-10-06T15:36:36 2023-10-06T15:36:36 2023-10-06T15:36:47          1.40K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(70,9,'a01r_20200128_fc0_1_4_OPA','2023-10-06-15:31:03','2023-10-09-09:01:32',1696599063,1696599520,1696599525,'COMPLETED',2,1,'00:05','debug',881,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340253,'',1,28,0.0,0.0,'a01r_20200128_fc0_1_4_OPA.20231006153842.out','a01r_20200128_fc0_1_4_OPA.20231006153842.err',2,'a01r_20200128_fc0_1_APP',replace('                 30340253  COMPLETED          1        1 2023-10-06T15:31:03 2023-10-06T15:38:36 2023-10-06T15:38:47            881                                                     \n           30340253.batch  COMPLETED          1        1 2023-10-06T15:38:36 2023-10-06T15:38:36 2023-10-06T15:38:47            697                     1019K                     1019K \n          30340253.extern  COMPLETED          1        1 2023-10-06T15:38:36 2023-10-06T15:38:36 2023-10-06T15:38:47            881                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(71,9,'a01r_20200128_fc0_1_5_OPA','2023-10-06-15:31:03','2023-10-09-09:01:32',1696599063,1696599647,1696599652,'COMPLETED',2,1,'00:05','debug',1320,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30340254,'',1,28,0.0,0.0,'a01r_20200128_fc0_1_5_OPA.20231006154052.out','a01r_20200128_fc0_1_5_OPA.20231006154052.err',2,'a01r_20200128_fc0_1_APP',replace('                 30340254  COMPLETED          1        1 2023-10-06T15:31:03 2023-10-06T15:40:39 2023-10-06T15:40:53          1.32K                                                     \n           30340254.batch  COMPLETED          1        1 2023-10-06T15:40:39 2023-10-06T15:40:39 2023-10-06T15:40:53          1.03K                      964K                      964K \n          30340254.extern  COMPLETED          1        1 2023-10-06T15:40:39 2023-10-06T15:40:39 2023-10-06T15:40:53          1.32K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(72,9,'a01r_20200128_fc0_1_APP','2023-10-06-15:41:14','2023-10-09-09:17:28',1696599673,1696599763,1696599768,'COMPLETED',2,1,'00:05','debug',1340,'2020-01-28 00:00:00','APP','fc0',1,0,'MARENOSTRUM4',30340293,'',1,28,0.0,0.0,'a01r_20200128_fc0_1_APP.20231006154258.out','a01r_20200128_fc0_1_APP.20231006154258.err',2,'',replace('                 30340293  COMPLETED          1        1 2023-10-06T15:41:13 2023-10-06T15:42:39 2023-10-06T15:42:50          1.34K                                                     \n           30340293.batch  COMPLETED          1        1 2023-10-06T15:42:39 2023-10-06T15:42:39 2023-10-06T15:42:50          1.03K                      981K                      981K \n          30340293.extern  COMPLETED          1        1 2023-10-06T15:42:39 2023-10-06T15:42:39 2023-10-06T15:42:50          1.34K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(73,10,'a01r_LOCAL_SETUP','2023-10-09-08:41:51','2023-10-09-09:23:03',1696833711,1696833711,1696833716,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',10670,'',0,29,0.0,0.0,'a01r_LOCAL_SETUP.20231009084203.out','a01r_LOCAL_SETUP.20231009084203.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(74,10,'a01r_SYNCHRONIZE','2023-10-09-08:42:06','2023-10-09-09:23:15',1696833726,1696833726,1696833731,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',10706,'',0,29,0.0,0.0,'a01r_SYNCHRONIZE.20231009084343.out','a01r_SYNCHRONIZE.20231009084343.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(75,10,'a01r_REMOTE_SETUP','2023-10-09-08:44:33','2023-10-09-09:23:30',1696833873,1696833900,1696833905,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30350523,'',0,29,0.0,0.0,'a01r_REMOTE_SETUP.20231009084512.out','a01r_REMOTE_SETUP.20231009084512.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(76,10,'a01r_20200128_fc0_1_DN','2023-10-09-08:45:19','2023-10-09-09:25:38',1696833919,1696834020,1696834025,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30350525,'',0,29,0.0,0.0,'a01r_20200128_fc0_1_DN.20231009085059.out','a01r_20200128_fc0_1_DN.20231009085059.err',5,'a01r_20200128_fc0_1_1_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_3_OPA','');
INSERT INTO job_data VALUES(77,10,'a01r_20200128_fc0_1_1_OPA','2023-10-09-09:01:31','2023-10-09-09:27:38',1696834891,1696834980,1696834985,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350614,'',0,29,0.0,0.0,'a01r_20200128_fc0_1_1_OPA.20231009090312.out','a01r_20200128_fc0_1_1_OPA.20231009090312.err',5,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(78,10,'a01r_20200128_fc0_1_2_OPA','2023-10-09-09:01:31','2023-10-09-09:27:38',1696834891,1696835099,1696835104,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350615,'',0,29,0.0,0.0,'a01r_20200128_fc0_1_2_OPA.20231009091721.out','a01r_20200128_fc0_1_2_OPA.20231009091721.err',5,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(79,10,'a01r_20200128_fc0_1_3_OPA','2023-10-09-09:01:31','2023-10-09-09:27:38',1696834891,1696835222,1696835227,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350616,'',0,29,0.0,0.0,'a01r_20200128_fc0_1_3_OPA.20231009091722.out','a01r_20200128_fc0_1_3_OPA.20231009091722.err',5,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(80,10,'a01r_20200128_fc0_1_4_OPA','2023-10-09-09:01:32','2023-10-09-09:27:38',1696834891,1696835347,1696835352,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350617,'',0,29,0.0,0.0,'a01r_20200128_fc0_1_4_OPA.20231009091722.out','a01r_20200128_fc0_1_4_OPA.20231009091722.err',5,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(81,10,'a01r_20200128_fc0_1_5_OPA','2023-10-09-09:01:32','2023-10-09-09:27:38',1696834892,1696835469,1696835474,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350618,'',0,29,0.0,0.0,'a01r_20200128_fc0_1_5_OPA.20231009091723.out','a01r_20200128_fc0_1_5_OPA.20231009091723.err',5,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(82,10,'a01r_20200128_fc0_1_APP','2023-10-09-09:17:28','2023-10-09-09:37:36',1696835848,1696835949,1696835954,'COMPLETED',2,1,'00:05','debug',673,'2020-01-28 00:00:00','APP','fc0',1,0,'MARENOSTRUM4',30350668,'',1,30,0.0,0.0,'a01r_20200128_fc0_1_APP.20231009091923.out','a01r_20200128_fc0_1_APP.20231009091923.err',2,'',replace('                 30350668  COMPLETED          1        1 2023-10-09T09:17:28 2023-10-09T09:19:03 2023-10-09T09:19:15            673                                                     \n           30350668.batch  COMPLETED          1        1 2023-10-09T09:19:03 2023-10-09T09:19:03 2023-10-09T09:19:15            527                     1100K                     1100K \n          30350668.extern  COMPLETED          1        1 2023-10-09T09:19:03 2023-10-09T09:19:03 2023-10-09T09:19:15            673                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(83,11,'a01r_LOCAL_SETUP','2023-10-09-09:23:03','2023-10-09-09:46:21',1696836183,1696836183,1696836188,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',14929,'',0,31,0.0,0.0,'a01r_LOCAL_SETUP.20231009092315.out','a01r_LOCAL_SETUP.20231009092315.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(84,11,'a01r_SYNCHRONIZE','2023-10-09-09:23:15','2023-10-09-09:46:33',1696836195,1696836195,1696836200,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',14967,'',0,31,0.0,0.0,'a01r_SYNCHRONIZE.20231009092327.out','a01r_SYNCHRONIZE.20231009092327.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(85,11,'a01r_REMOTE_SETUP','2023-10-09-09:23:30','2023-10-09-09:46:49',1696836210,1696836311,1696836316,'COMPLETED',2,1,'00:05','debug',733,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30350673,'',1,31,0.0,0.0,'a01r_REMOTE_SETUP.20231009092516.out','a01r_REMOTE_SETUP.20231009092516.err',2,'a01r_20200128_fc0_1_DN',replace('                 30350673  COMPLETED          1        1 2023-10-09T09:23:30 2023-10-09T09:25:05 2023-10-09T09:25:18            733                                                     \n           30350673.batch  COMPLETED          1        1 2023-10-09T09:25:05 2023-10-09T09:25:05 2023-10-09T09:25:18            586                     1041K                     1041K \n          30350673.extern  COMPLETED          1        1 2023-10-09T09:25:05 2023-10-09T09:25:05 2023-10-09T09:25:18            733                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(86,11,'a01r_20200128_fc0_1_DN','2023-10-09-09:25:38','2023-10-09-09:47:33',1696836338,1696836429,1696836434,'COMPLETED',2,1,'00:05','debug',3300,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30350675,'',1,31,0.0,0.0,'a01r_20200128_fc0_1_DN.20231009092716.out','a01r_20200128_fc0_1_DN.20231009092716.err',2,'a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_1_OPA,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_3_OPA',replace('                 30350675  COMPLETED          1        1 2023-10-09T09:25:38 2023-10-09T09:27:04 2023-10-09T09:27:15          3.30K                                                     \n           30350675.batch  COMPLETED          1        1 2023-10-09T09:27:04 2023-10-09T09:27:04 2023-10-09T09:27:15          2.59K                      892K                      892K \n          30350675.extern  COMPLETED          1        1 2023-10-09T09:27:04 2023-10-09T09:27:04 2023-10-09T09:27:15          3.30K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(87,11,'a01r_20200128_fc0_1_1_OPA','2023-10-09-09:27:38','2023-10-09-09:49:42',1696836458,1696836549,1696836554,'COMPLETED',2,1,'00:05','debug',949,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350683,'',1,31,0.0,0.0,'a01r_20200128_fc0_1_1_OPA.20231009092919.out','a01r_20200128_fc0_1_1_OPA.20231009092919.err',2,'a01r_20200128_fc0_1_APP',replace('                 30350683  COMPLETED          1        1 2023-10-09T09:27:38 2023-10-09T09:29:05 2023-10-09T09:29:15            949                                                     \n           30350683.batch  COMPLETED          1        1 2023-10-09T09:29:05 2023-10-09T09:29:05 2023-10-09T09:29:15            758                     1120K                     1120K \n          30350683.extern  COMPLETED          1        1 2023-10-09T09:29:05 2023-10-09T09:29:05 2023-10-09T09:29:15            949                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(88,11,'a01r_20200128_fc0_1_2_OPA','2023-10-09-09:27:38','2023-10-09-09:49:42',1696836458,1696836669,1696836674,'COMPLETED',2,1,'00:05','debug',3310,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350684,'',1,31,0.0,0.0,'a01r_20200128_fc0_1_2_OPA.20231009093124.out','a01r_20200128_fc0_1_2_OPA.20231009093124.err',2,'a01r_20200128_fc0_1_APP',replace('                 30350684  COMPLETED          1        1 2023-10-09T09:27:38 2023-10-09T09:31:04 2023-10-09T09:31:16          3.31K                                                     \n           30350684.batch  COMPLETED          1        1 2023-10-09T09:31:04 2023-10-09T09:31:04 2023-10-09T09:31:16          2.58K                      908K                      908K \n          30350684.extern  COMPLETED          1        1 2023-10-09T09:31:04 2023-10-09T09:31:04 2023-10-09T09:31:16          3.31K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(89,11,'a01r_20200128_fc0_1_3_OPA','2023-10-09-09:27:38','2023-10-09-09:49:42',1696836458,1696836788,1696836793,'COMPLETED',2,1,'00:05','debug',808,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350685,'',1,31,0.0,0.0,'a01r_20200128_fc0_1_3_OPA.20231009093310.out','a01r_20200128_fc0_1_3_OPA.20231009093310.err',2,'a01r_20200128_fc0_1_APP',replace('                 30350685  COMPLETED          1        1 2023-10-09T09:27:38 2023-10-09T09:33:03 2023-10-09T09:33:15            808                                                     \n           30350685.batch  COMPLETED          1        1 2023-10-09T09:33:03 2023-10-09T09:33:03 2023-10-09T09:33:15            576                     1103K                     1103K \n          30350685.extern  COMPLETED          1        1 2023-10-09T09:33:03 2023-10-09T09:33:03 2023-10-09T09:33:15            808                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(90,11,'a01r_20200128_fc0_1_4_OPA','2023-10-09-09:27:38','2023-10-09-09:49:42',1696836458,1696836909,1696836914,'COMPLETED',2,1,'00:05','debug',944,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350686,'',1,31,0.0,0.0,'a01r_20200128_fc0_1_4_OPA.20231009093516.out','a01r_20200128_fc0_1_4_OPA.20231009093516.err',2,'a01r_20200128_fc0_1_APP',replace('                 30350686  COMPLETED          1        1 2023-10-09T09:27:38 2023-10-09T09:35:04 2023-10-09T09:35:15            944                                                     \n           30350686.batch  COMPLETED          1        1 2023-10-09T09:35:04 2023-10-09T09:35:04 2023-10-09T09:35:15            744                     1020K                     1020K \n          30350686.extern  COMPLETED          1        1 2023-10-09T09:35:04 2023-10-09T09:35:04 2023-10-09T09:35:15            944                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(91,11,'a01r_20200128_fc0_1_5_OPA','2023-10-09-09:27:38','2023-10-09-09:49:42',1696836458,1696837029,1696837034,'COMPLETED',2,1,'00:05','debug',645,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350687,'',1,31,0.0,0.0,'a01r_20200128_fc0_1_5_OPA.20231009093715.out','a01r_20200128_fc0_1_5_OPA.20231009093715.err',2,'a01r_20200128_fc0_1_APP',replace('                 30350687  COMPLETED          1        1 2023-10-09T09:27:38 2023-10-09T09:37:04 2023-10-09T09:37:15            645                                                     \n           30350687.batch  COMPLETED          1        1 2023-10-09T09:37:04 2023-10-09T09:37:04 2023-10-09T09:37:15            465                     1130K                     1130K \n          30350687.extern  COMPLETED          1        1 2023-10-09T09:37:04 2023-10-09T09:37:04 2023-10-09T09:37:15            645                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(92,11,'a01r_20200128_fc0_1_APP','2023-10-09-09:37:36','2023-10-09-10:19:58',1696837056,1696837148,1696837153,'COMPLETED',2,1,'00:05','debug',698,'2020-01-28 00:00:00','APP','fc0',1,0,'MARENOSTRUM4',30350722,'',1,31,0.0,0.0,'a01r_20200128_fc0_1_APP.20231009093917.out','a01r_20200128_fc0_1_APP.20231009093917.err',2,'',replace('                 30350722  COMPLETED          1        1 2023-10-09T09:37:36 2023-10-09T09:39:04 2023-10-09T09:39:15            698                                                     \n           30350722.batch  COMPLETED          1        1 2023-10-09T09:39:04 2023-10-09T09:39:04 2023-10-09T09:39:15            515                     1111K                     1111K \n          30350722.extern  COMPLETED          1        1 2023-10-09T09:39:04 2023-10-09T09:39:04 2023-10-09T09:39:15            698                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(93,12,'a01r_LOCAL_SETUP','2023-10-09-09:46:21','2023-10-09-10:24:39',1696837581,1696837581,1696837586,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',16004,'',0,32,0.0,0.0,'a01r_LOCAL_SETUP.20231009094633.out','a01r_LOCAL_SETUP.20231009094633.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(94,12,'a01r_SYNCHRONIZE','2023-10-09-09:46:33','2023-10-09-10:24:52',1696837593,1696837593,1696837598,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',16041,'',0,32,0.0,0.0,'a01r_SYNCHRONIZE.20231009094645.out','a01r_SYNCHRONIZE.20231009094645.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(95,12,'a01r_REMOTE_SETUP','2023-10-09-09:46:49','2023-10-09-10:25:08',1696837609,1696837629,1696837634,'COMPLETED',2,1,'00:05','debug',843,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30350739,'',1,32,0.0,0.0,'a01r_REMOTE_SETUP.20231009094711.out','a01r_REMOTE_SETUP.20231009094711.err',2,'a01r_20200128_fc0_1_DN',replace('                 30350739  COMPLETED          1        1 2023-10-09T09:46:49 2023-10-09T09:47:04 2023-10-09T09:47:15            843                                                     \n           30350739.batch  COMPLETED          1        1 2023-10-09T09:47:04 2023-10-09T09:47:04 2023-10-09T09:47:15            681                     1155K                     1155K \n          30350739.extern  COMPLETED          1        1 2023-10-09T09:47:04 2023-10-09T09:47:04 2023-10-09T09:47:15            843                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(96,12,'a01r_20200128_fc0_1_DN','2023-10-09-09:47:33','2023-10-09-10:25:48',1696837653,1696837757,1696837762,'COMPLETED',2,1,'00:05','debug',761,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30350743,'',1,32,0.0,0.0,'a01r_20200128_fc0_1_DN.20231009094918.out','a01r_20200128_fc0_1_DN.20231009094918.err',2,'a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_1_OPA,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_3_OPA',replace('                 30350743  COMPLETED          1        1 2023-10-09T09:47:33 2023-10-09T09:49:12 2023-10-09T09:49:24            761                                                     \n           30350743.batch  COMPLETED          1        1 2023-10-09T09:49:12 2023-10-09T09:49:12 2023-10-09T09:49:24            560                     1130K                     1130K \n          30350743.extern  COMPLETED          1        1 2023-10-09T09:49:12 2023-10-09T09:49:12 2023-10-09T09:49:24            761                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(97,12,'a01r_20200128_fc0_1_1_OPA','2023-10-09-09:49:42','2023-10-09-10:27:58',1696837782,1696837876,1696837881,'COMPLETED',2,1,'00:05','debug',835,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350761,'',1,32,0.0,0.0,'a01r_20200128_fc0_1_1_OPA.20231009095133.out','a01r_20200128_fc0_1_1_OPA.20231009095133.err',2,'a01r_20200128_fc0_1_APP',replace('                 30350761  COMPLETED          1        1 2023-10-09T09:49:41 2023-10-09T09:51:11 2023-10-09T09:51:23            835                                                     \n           30350761.batch  COMPLETED          1        1 2023-10-09T09:51:11 2023-10-09T09:51:11 2023-10-09T09:51:23            624                     1134K                     1134K \n          30350761.extern  COMPLETED          1        1 2023-10-09T09:51:11 2023-10-09T09:51:11 2023-10-09T09:51:23            835                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(98,12,'a01r_20200128_fc0_1_2_OPA','2023-10-09-09:49:42','2023-10-09-10:27:58',1696837782,1696837993,1696837998,'COMPLETED',2,1,'00:05','debug',807,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350762,'',1,32,0.0,0.0,'a01r_20200128_fc0_1_2_OPA.20231009095339.out','a01r_20200128_fc0_1_2_OPA.20231009095339.err',2,'a01r_20200128_fc0_1_APP',replace('                 30350762  COMPLETED          1        1 2023-10-09T09:49:41 2023-10-09T09:53:11 2023-10-09T09:53:19            807                                                     \n           30350762.batch  COMPLETED          1        1 2023-10-09T09:53:11 2023-10-09T09:53:11 2023-10-09T09:53:19            789                     1143K                     1143K \n          30350762.extern  COMPLETED          1        1 2023-10-09T09:53:11 2023-10-09T09:53:11 2023-10-09T09:53:19            807                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(99,12,'a01r_20200128_fc0_1_3_OPA','2023-10-09-09:49:42','2023-10-09-10:27:58',1696837782,1696838114,1696838119,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350763,'',0,32,0.0,0.0,'a01r_20200128_fc0_1_3_OPA.20231009101044.out','a01r_20200128_fc0_1_3_OPA.20231009101044.err',5,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(100,12,'a01r_20200128_fc0_1_4_OPA','2023-10-09-09:49:42','2023-10-09-10:27:58',1696837782,1696838237,1696838242,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350764,'',0,32,0.0,0.0,'a01r_20200128_fc0_1_4_OPA.20231009101047.out','a01r_20200128_fc0_1_4_OPA.20231009101047.err',5,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(101,12,'a01r_20200128_fc0_1_5_OPA','2023-10-09-09:49:42','2023-10-09-10:27:58',1696837782,1696838357,1696838362,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30350765,'',0,32,0.0,0.0,'a01r_20200128_fc0_1_5_OPA.20231009101054.out','a01r_20200128_fc0_1_5_OPA.20231009101054.err',5,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(102,12,'a01r_20200128_fc0_1_APP','2023-10-09-10:19:58','2023-10-09-10:37:52',1696839598,1696839684,1696839689,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','APP','fc0',1,0,'MARENOSTRUM4',30351098,'',0,33,0.0,0.0,'a01r_20200128_fc0_1_APP.20231009102141.out','a01r_20200128_fc0_1_APP.20231009102141.err',5,'','');
INSERT INTO job_data VALUES(103,13,'a01r_LOCAL_SETUP','2023-10-09-10:24:39','2023-10-09-10:59:11',1696839879,1696839879,1696839884,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',22012,'',0,34,0.0,0.0,'a01r_LOCAL_SETUP.20231009102451.out','a01r_LOCAL_SETUP.20231009102451.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(104,13,'a01r_SYNCHRONIZE','2023-10-09-10:24:52','2023-10-09-10:59:24',1696839892,1696839892,1696839897,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',22058,'',0,34,0.0,0.0,'a01r_SYNCHRONIZE.20231009102504.out','a01r_SYNCHRONIZE.20231009102504.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(105,13,'a01r_REMOTE_SETUP','2023-10-09-10:25:08','2023-10-09-10:59:42',1696839908,1696839924,1696839929,'COMPLETED',2,1,'00:05','debug',2140,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30351122,'',1,34,0.0,0.0,'a01r_REMOTE_SETUP.20231009102526.out','a01r_REMOTE_SETUP.20231009102526.err',2,'a01r_20200128_fc0_1_DN',replace('                 30351122  COMPLETED          1        1 2023-10-09T10:25:08 2023-10-09T10:25:19 2023-10-09T10:25:30          2.14K                                                     \n           30351122.batch  COMPLETED          1        1 2023-10-09T10:25:19 2023-10-09T10:25:19 2023-10-09T10:25:30          1.66K                      951K                      951K \n          30351122.extern  COMPLETED          1        1 2023-10-09T10:25:19 2023-10-09T10:25:19 2023-10-09T10:25:30          2.14K                      710K                      710K \n','\n',char(10)));
INSERT INTO job_data VALUES(106,13,'a01r_20200128_fc0_1_DN','2023-10-09-10:25:48','2023-10-09-11:02:02',1696839948,1696840046,1696840051,'COMPLETED',2,1,'00:05','debug',648,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30351125,'',1,34,0.0,0.0,'a01r_20200128_fc0_1_DN.20231009102731.out','a01r_20200128_fc0_1_DN.20231009102731.err',2,'a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_1_OPA,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_3_OPA',replace('                 30351125  COMPLETED          1        1 2023-10-09T10:25:48 2023-10-09T10:27:21 2023-10-09T10:27:32            648                                                     \n           30351125.batch  COMPLETED          1        1 2023-10-09T10:27:21 2023-10-09T10:27:21 2023-10-09T10:27:32            499                     1119K                     1119K \n          30351125.extern  COMPLETED          1        1 2023-10-09T10:27:21 2023-10-09T10:27:21 2023-10-09T10:27:32            648                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(107,13,'a01r_20200128_fc0_1_1_OPA','2023-10-09-10:27:58','2023-10-09-11:04:03',1696840078,1696840166,1696840171,'COMPLETED',2,1,'00:05','debug',973,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351136,'',1,34,0.0,0.0,'a01r_20200128_fc0_1_1_OPA.20231009102930.out','a01r_20200128_fc0_1_1_OPA.20231009102930.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351136  COMPLETED          1        1 2023-10-09T10:27:57 2023-10-09T10:29:21 2023-10-09T10:29:33            973                                                     \n           30351136.batch  COMPLETED          1        1 2023-10-09T10:29:21 2023-10-09T10:29:21 2023-10-09T10:29:33            757                     1032K                     1032K \n          30351136.extern  COMPLETED          1        1 2023-10-09T10:29:21 2023-10-09T10:29:21 2023-10-09T10:29:33            973                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(108,13,'a01r_20200128_fc0_1_2_OPA','2023-10-09-10:27:58','2023-10-09-11:04:03',1696840078,1696840286,1696840291,'COMPLETED',2,1,'00:05','debug',739,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351137,'',1,34,0.0,0.0,'a01r_20200128_fc0_1_2_OPA.20231009103144.out','a01r_20200128_fc0_1_2_OPA.20231009103144.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351137  COMPLETED          1        1 2023-10-09T10:27:57 2023-10-09T10:31:21 2023-10-09T10:31:32            739                                                     \n           30351137.batch  COMPLETED          1        1 2023-10-09T10:31:21 2023-10-09T10:31:21 2023-10-09T10:31:32            571                     1031K                     1031K \n          30351137.extern  COMPLETED          1        1 2023-10-09T10:31:21 2023-10-09T10:31:21 2023-10-09T10:31:32            739                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(109,13,'a01r_20200128_fc0_1_3_OPA','2023-10-09-10:27:58','2023-10-09-11:04:03',1696840078,1696840406,1696840411,'COMPLETED',2,1,'00:05','debug',603,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351138,'',1,34,0.0,0.0,'a01r_20200128_fc0_1_3_OPA.20231009103337.out','a01r_20200128_fc0_1_3_OPA.20231009103337.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351138  COMPLETED          1        1 2023-10-09T10:27:57 2023-10-09T10:33:21 2023-10-09T10:33:32            603                                                     \n           30351138.batch  COMPLETED          1        1 2023-10-09T10:33:21 2023-10-09T10:33:21 2023-10-09T10:33:32            467                     1131K                     1131K \n          30351138.extern  COMPLETED          1        1 2023-10-09T10:33:21 2023-10-09T10:33:21 2023-10-09T10:33:32            603                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(110,13,'a01r_20200128_fc0_1_4_OPA','2023-10-09-10:27:58','2023-10-09-11:04:03',1696840078,1696840528,1696840533,'COMPLETED',2,1,'00:05','debug',701,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351139,'',1,34,0.0,0.0,'a01r_20200128_fc0_1_4_OPA.20231009103545.out','a01r_20200128_fc0_1_4_OPA.20231009103545.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351139  COMPLETED          1        1 2023-10-09T10:27:57 2023-10-09T10:35:23 2023-10-09T10:35:34            701                                                     \n           30351139.batch  COMPLETED          1        1 2023-10-09T10:35:23 2023-10-09T10:35:23 2023-10-09T10:35:34            571                     1127K                     1127K \n          30351139.extern  COMPLETED          1        1 2023-10-09T10:35:23 2023-10-09T10:35:23 2023-10-09T10:35:34            701                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(111,13,'a01r_20200128_fc0_1_5_OPA','2023-10-09-10:27:58','2023-10-09-11:04:03',1696840078,1696840648,1696840653,'COMPLETED',2,1,'00:05','debug',727,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351140,'',1,34,0.0,0.0,'a01r_20200128_fc0_1_5_OPA.20231009103729.out','a01r_20200128_fc0_1_5_OPA.20231009103729.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351140  COMPLETED          1        1 2023-10-09T10:27:58 2023-10-09T10:37:23 2023-10-09T10:37:34            727                                                     \n           30351140.batch  COMPLETED          1        1 2023-10-09T10:37:23 2023-10-09T10:37:23 2023-10-09T10:37:34            558                     1132K                     1132K \n          30351140.extern  COMPLETED          1        1 2023-10-09T10:37:23 2023-10-09T10:37:23 2023-10-09T10:37:34            727                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(112,13,'a01r_20200128_fc0_1_APP','2023-10-09-10:37:52','2023-10-09-11:13:59',1696840672,1696840768,1696840773,'COMPLETED',2,1,'00:05','debug',865,'2020-01-28 00:00:00','APP','fc0',1,0,'MARENOSTRUM4',30351197,'',1,34,0.0,0.0,'a01r_20200128_fc0_1_APP.20231009103928.out','a01r_20200128_fc0_1_APP.20231009103928.err',2,'',replace('                 30351197  COMPLETED          1        1 2023-10-09T10:37:52 2023-10-09T10:39:23 2023-10-09T10:39:34            865                                                     \n           30351197.batch  COMPLETED          1        1 2023-10-09T10:39:23 2023-10-09T10:39:23 2023-10-09T10:39:34            717                     1137K                     1137K \n          30351197.extern  COMPLETED          1        1 2023-10-09T10:39:23 2023-10-09T10:39:23 2023-10-09T10:39:34            865                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(113,14,'a01r_LOCAL_SETUP','2023-10-09-10:59:11','2023-10-09-11:20:51',1696841951,1696841951,1696841956,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',27599,'',0,36,0.0,0.0,'a01r_LOCAL_SETUP.20231009105923.out','a01r_LOCAL_SETUP.20231009105923.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(114,14,'a01r_SYNCHRONIZE','2023-10-09-10:59:24','2023-10-09-11:21:04',1696841964,1696841964,1696841969,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',27728,'',0,36,0.0,0.0,'a01r_SYNCHRONIZE.20231009105936.out','a01r_SYNCHRONIZE.20231009105936.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(115,14,'a01r_REMOTE_SETUP','2023-10-09-10:59:42','2023-10-09-11:21:20',1696841982,1696842096,1696842101,'COMPLETED',2,1,'00:05','debug',3250,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30351308,'',1,36,0.0,0.0,'a01r_REMOTE_SETUP.20231009110140.out','a01r_REMOTE_SETUP.20231009110140.err',2,'a01r_20200128_fc0_1_DN',replace('                 30351308  COMPLETED          1        1 2023-10-09T10:59:42 2023-10-09T11:01:31 2023-10-09T11:01:42          3.25K                                                     \n           30351308.batch  COMPLETED          1        1 2023-10-09T11:01:31 2023-10-09T11:01:31 2023-10-09T11:01:42          2.55K                      961K                      961K \n          30351308.extern  COMPLETED          1        1 2023-10-09T11:01:31 2023-10-09T11:01:31 2023-10-09T11:01:42          3.25K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(116,14,'a01r_20200128_fc0_1_DN','2023-10-09-11:02:02','2023-10-09-11:22:05',1696842122,1696842218,1696842223,'COMPLETED',2,1,'00:05','debug',888,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30351330,'',1,36,0.0,0.0,'a01r_20200128_fc0_1_DN.20231009110339.out','a01r_20200128_fc0_1_DN.20231009110339.err',2,'a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_1_OPA,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_3_OPA',replace('                 30351330  COMPLETED          1        1 2023-10-09T11:02:02 2023-10-09T11:03:34 2023-10-09T11:03:45            888                                                     \n           30351330.batch  COMPLETED          1        1 2023-10-09T11:03:34 2023-10-09T11:03:34 2023-10-09T11:03:45            666                     1137K                     1137K \n          30351330.extern  COMPLETED          1        1 2023-10-09T11:03:34 2023-10-09T11:03:34 2023-10-09T11:03:45            888                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(117,14,'a01r_20200128_fc0_1_1_OPA','2023-10-09-11:04:03','2023-10-09-11:24:05',1696842243,1696842338,1696842343,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351342,'',0,36,0.0,0.0,'a01r_20200128_fc0_1_1_OPA.20231009110543.out','a01r_20200128_fc0_1_1_OPA.20231009110543.err',5,'a01r_20200128_fc0_1_APP','');
INSERT INTO job_data VALUES(118,14,'a01r_20200128_fc0_1_2_OPA','2023-10-09-11:04:03','2023-10-09-11:24:05',1696842243,1696842459,1696842464,'COMPLETED',2,1,'00:05','debug',855,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351343,'',1,36,0.0,0.0,'a01r_20200128_fc0_1_2_OPA.20231009110815.out','a01r_20200128_fc0_1_2_OPA.20231009110815.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351343  COMPLETED          1        1 2023-10-09T11:04:03 2023-10-09T11:07:33 2023-10-09T11:07:45            855                                                     \n           30351343.batch  COMPLETED          1        1 2023-10-09T11:07:33 2023-10-09T11:07:33 2023-10-09T11:07:45            675                     1128K                     1128K \n          30351343.extern  COMPLETED          1        1 2023-10-09T11:07:33 2023-10-09T11:07:33 2023-10-09T11:07:45            855                       68K                       68K \n','\n',char(10)));
INSERT INTO job_data VALUES(119,14,'a01r_20200128_fc0_1_3_OPA','2023-10-09-11:04:03','2023-10-09-11:24:05',1696842243,1696842578,1696842583,'COMPLETED',2,1,'00:05','debug',744,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351344,'',1,36,0.0,0.0,'a01r_20200128_fc0_1_3_OPA.20231009110955.out','a01r_20200128_fc0_1_3_OPA.20231009110955.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351344  COMPLETED          1        1 2023-10-09T11:04:03 2023-10-09T11:09:33 2023-10-09T11:09:45            744                                                     \n           30351344.batch  COMPLETED          1        1 2023-10-09T11:09:33 2023-10-09T11:09:33 2023-10-09T11:09:45            540                     1134K                     1134K \n          30351344.extern  COMPLETED          1        1 2023-10-09T11:09:33 2023-10-09T11:09:33 2023-10-09T11:09:45            744                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(120,14,'a01r_20200128_fc0_1_4_OPA','2023-10-09-11:04:03','2023-10-09-11:24:05',1696842243,1696842698,1696842703,'COMPLETED',2,1,'00:05','debug',538,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351345,'',1,36,0.0,0.0,'a01r_20200128_fc0_1_4_OPA.20231009111155.out','a01r_20200128_fc0_1_4_OPA.20231009111155.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351345  COMPLETED          1        1 2023-10-09T11:04:03 2023-10-09T11:11:33 2023-10-09T11:11:43            538                                                     \n           30351345.batch  COMPLETED          1        1 2023-10-09T11:11:33 2023-10-09T11:11:33 2023-10-09T11:11:43            527                     1133K                     1133K \n          30351345.extern  COMPLETED          1        1 2023-10-09T11:11:33 2023-10-09T11:11:33 2023-10-09T11:11:43            538                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(121,14,'a01r_20200128_fc0_1_5_OPA','2023-10-09-11:04:03','2023-10-09-11:24:05',1696842243,1696842817,1696842822,'COMPLETED',2,1,'00:05','debug',981,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351346,'',1,36,0.0,0.0,'a01r_20200128_fc0_1_5_OPA.20231009111354.out','a01r_20200128_fc0_1_5_OPA.20231009111354.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351346  COMPLETED          1        1 2023-10-09T11:04:03 2023-10-09T11:13:34 2023-10-09T11:13:44            981                                                     \n           30351346.batch  COMPLETED          1        1 2023-10-09T11:13:34 2023-10-09T11:13:34 2023-10-09T11:13:44            752                     1010K                     1010K \n          30351346.extern  COMPLETED          1        1 2023-10-09T11:13:34 2023-10-09T11:13:34 2023-10-09T11:13:44            981                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(122,14,'a01r_20200128_fc0_1_APP','2023-10-09-11:13:59','2023-10-09-11:34:05',1696842839,1696842935,1696842940,'COMPLETED',2,1,'00:05','debug',951,'2020-01-28 00:00:00','APP','fc0',1,0,'MARENOSTRUM4',30351397,'',1,37,0.0,0.0,'a01r_20200128_fc0_1_APP.20231009111540.out','a01r_20200128_fc0_1_APP.20231009111540.err',2,'',replace('                 30351397  COMPLETED          1        1 2023-10-09T11:13:59 2023-10-09T11:15:35 2023-10-09T11:15:41            951                                                     \n           30351397.batch  COMPLETED          1        1 2023-10-09T11:15:35 2023-10-09T11:15:35 2023-10-09T11:15:41            752                     1135K                     1135K \n          30351397.extern  COMPLETED          1        1 2023-10-09T11:15:35 2023-10-09T11:15:35 2023-10-09T11:15:41            951                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(123,15,'a01r_LOCAL_SETUP','2023-10-09-11:20:51','2023-10-09-12:43:59',1696843251,1696843251,1696843256,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',30180,'',0,38,0.0,0.0,'a01r_LOCAL_SETUP.20231009112103.out','a01r_LOCAL_SETUP.20231009112103.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(124,15,'a01r_SYNCHRONIZE','2023-10-09-11:21:04','2023-10-09-12:44:11',1696843264,1696843264,1696843269,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',30226,'',0,38,0.0,0.0,'a01r_SYNCHRONIZE.20231009112116.out','a01r_SYNCHRONIZE.20231009112116.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(125,15,'a01r_REMOTE_SETUP','2023-10-09-11:21:20','2023-10-09-12:44:27',1696843280,1696843301,1696843306,'COMPLETED',2,1,'00:05','debug',851,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30351446,'',1,38,0.0,0.0,'a01r_REMOTE_SETUP.20231009112143.out','a01r_REMOTE_SETUP.20231009112143.err',2,'a01r_20200128_fc0_1_DN',replace('                 30351446  COMPLETED          1        1 2023-10-09T11:21:20 2023-10-09T11:21:36 2023-10-09T11:21:47            851                                                     \n           30351446.batch  COMPLETED          1        1 2023-10-09T11:21:36 2023-10-09T11:21:36 2023-10-09T11:21:47            644                     1131K                     1131K \n          30351446.extern  COMPLETED          1        1 2023-10-09T11:21:36 2023-10-09T11:21:36 2023-10-09T11:21:47            851                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(126,15,'a01r_20200128_fc0_1_DN','2023-10-09-11:22:05','2023-10-09-12:46:30',1696843325,1696843421,1696843426,'COMPLETED',2,1,'00:05','debug',1030,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30351450,'',1,38,0.0,0.0,'a01r_20200128_fc0_1_DN.20231009112341.out','a01r_20200128_fc0_1_DN.20231009112341.err',2,'a01r_20200128_fc0_1_1_OPA,a01r_20200128_fc0_1_3_OPA,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_2_OPA',replace('                 30351450  COMPLETED          1        1 2023-10-09T11:22:05 2023-10-09T11:23:36 2023-10-09T11:23:48          1.03K                                                     \n           30351450.batch  COMPLETED          1        1 2023-10-09T11:23:36 2023-10-09T11:23:36 2023-10-09T11:23:48            786                     1025K                     1025K \n          30351450.extern  COMPLETED          1        1 2023-10-09T11:23:36 2023-10-09T11:23:36 2023-10-09T11:23:48          1.03K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(127,15,'a01r_20200128_fc0_1_1_OPA','2023-10-09-11:24:05','2023-10-09-12:48:30',1696843445,1696843541,1696843546,'COMPLETED',2,1,'00:05','debug',803,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351467,'',1,38,0.0,0.0,'a01r_20200128_fc0_1_1_OPA.20231009112545.out','a01r_20200128_fc0_1_1_OPA.20231009112545.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351467  COMPLETED          1        1 2023-10-09T11:24:05 2023-10-09T11:25:35 2023-10-09T11:25:47            803                                                     \n           30351467.batch  COMPLETED          1        1 2023-10-09T11:25:35 2023-10-09T11:25:35 2023-10-09T11:25:47            629                     1116K                     1116K \n          30351467.extern  COMPLETED          1        1 2023-10-09T11:25:35 2023-10-09T11:25:35 2023-10-09T11:25:47            803                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(128,15,'a01r_20200128_fc0_1_2_OPA','2023-10-09-11:24:05','2023-10-09-12:48:30',1696843445,1696843660,1696843665,'COMPLETED',2,1,'00:05','debug',853,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351468,'',1,38,0.0,0.0,'a01r_20200128_fc0_1_2_OPA.20231009112745.out','a01r_20200128_fc0_1_2_OPA.20231009112745.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351468  COMPLETED          1        1 2023-10-09T11:24:05 2023-10-09T11:27:35 2023-10-09T11:27:47            853                                                     \n           30351468.batch  COMPLETED          1        1 2023-10-09T11:27:35 2023-10-09T11:27:35 2023-10-09T11:27:47            622                     1133K                     1133K \n          30351468.extern  COMPLETED          1        1 2023-10-09T11:27:35 2023-10-09T11:27:35 2023-10-09T11:27:47            853                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(129,15,'a01r_20200128_fc0_1_3_OPA','2023-10-09-11:24:05','2023-10-09-12:48:30',1696843445,1696843781,1696843786,'COMPLETED',2,1,'00:05','debug',819,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351469,'',1,38,0.0,0.0,'a01r_20200128_fc0_1_3_OPA.20231009112945.out','a01r_20200128_fc0_1_3_OPA.20231009112945.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351469  COMPLETED          1        1 2023-10-09T11:24:05 2023-10-09T11:29:36 2023-10-09T11:29:47            819                                                     \n           30351469.batch  COMPLETED          1        1 2023-10-09T11:29:36 2023-10-09T11:29:36 2023-10-09T11:29:47            649                     1135K                     1135K \n          30351469.extern  COMPLETED          1        1 2023-10-09T11:29:36 2023-10-09T11:29:36 2023-10-09T11:29:47            819                       68K                       68K \n','\n',char(10)));
INSERT INTO job_data VALUES(130,15,'a01r_20200128_fc0_1_4_OPA','2023-10-09-11:24:05','2023-10-09-12:48:30',1696843445,1696843900,1696843905,'COMPLETED',2,1,'00:05','debug',744,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351470,'',1,38,0.0,0.0,'a01r_20200128_fc0_1_4_OPA.20231009113146.out','a01r_20200128_fc0_1_4_OPA.20231009113146.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351470  COMPLETED          1        1 2023-10-09T11:24:05 2023-10-09T11:31:35 2023-10-09T11:31:46            744                                                     \n           30351470.batch  COMPLETED          1        1 2023-10-09T11:31:35 2023-10-09T11:31:35 2023-10-09T11:31:46            636                     1134K                     1134K \n          30351470.extern  COMPLETED          1        1 2023-10-09T11:31:35 2023-10-09T11:31:35 2023-10-09T11:31:46            744                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(131,15,'a01r_20200128_fc0_1_5_OPA','2023-10-09-11:24:05','2023-10-09-12:48:30',1696843445,1696844018,1696844023,'COMPLETED',2,1,'00:05','debug',1060,'2020-01-28 00:00:00','OPA','fc0',1,0,'MARENOSTRUM4',30351471,'',1,38,0.0,0.0,'a01r_20200128_fc0_1_5_OPA.20231009113342.out','a01r_20200128_fc0_1_5_OPA.20231009113342.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351471  COMPLETED          1        1 2023-10-09T11:24:05 2023-10-09T11:33:35 2023-10-09T11:33:45          1.06K                                                     \n           30351471.batch  COMPLETED          1        1 2023-10-09T11:33:35 2023-10-09T11:33:35 2023-10-09T11:33:45            789                     1026K                     1026K \n          30351471.extern  COMPLETED          1        1 2023-10-09T11:33:35 2023-10-09T11:33:35 2023-10-09T11:33:45          1.06K                      710K                      710K \n','\n',char(10)));
INSERT INTO job_data VALUES(132,15,'a01r_20200128_fc0_1_APP','2023-10-09-11:34:05','2023-10-09-12:58:33',1696844045,1696844138,1696844143,'COMPLETED',2,1,'00:05','debug',1050,'2020-01-28 00:00:00','APP','fc0',1,0,'MARENOSTRUM4',30351505,'',1,38,0.0,0.0,'a01r_20200128_fc0_1_APP.20231009113541.out','a01r_20200128_fc0_1_APP.20231009113541.err',2,'',replace('                 30351505  COMPLETED          1        1 2023-10-09T11:34:05 2023-10-09T11:35:35 2023-10-09T11:35:45          1.05K                                                     \n           30351505.batch  COMPLETED          1        1 2023-10-09T11:35:35 2023-10-09T11:35:35 2023-10-09T11:35:45            780                      921K                      921K \n          30351505.extern  COMPLETED          1        1 2023-10-09T11:35:35 2023-10-09T11:35:35 2023-10-09T11:35:45          1.05K                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(133,16,'a01r_LOCAL_SETUP','2023-10-09-12:43:59','2023-10-09-12:44:11',1696848239,1696848239,1696848244,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,1,'LOCAL',39813,'',0,39,0.0,0.0,'a01r_LOCAL_SETUP.20231009124411.out','a01r_LOCAL_SETUP.20231009124411.err',5,'a01r_SYNCHRONIZE','');
INSERT INTO job_data VALUES(134,16,'a01r_SYNCHRONIZE','2023-10-09-12:44:12','2023-10-09-12:44:24',1696848251,1696848251,1696848256,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,1,'LOCAL',39854,'',0,39,0.0,0.0,'a01r_SYNCHRONIZE.20231009124424.out','a01r_SYNCHRONIZE.20231009124424.err',5,'a01r_REMOTE_SETUP','');
INSERT INTO job_data VALUES(135,16,'a01r_REMOTE_SETUP','2023-10-09-12:44:27','2023-10-10-16:13:09',1696848267,1696848363,1696848368,'COMPLETED',2,1,'00:05','debug',809,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4-LOGIN',30351749,'',1,39,0.0,0.0,'a01r_REMOTE_SETUP.20231009124608.out','a01r_REMOTE_SETUP.20231009124608.err',2,'a01r_20200128_fc0_1_DN',replace('                 30351749  COMPLETED          1        1 2023-10-09T12:44:27 2023-10-09T12:45:57 2023-10-09T12:46:09            809                                                     \n           30351749.batch  COMPLETED          1        1 2023-10-09T12:45:57 2023-10-09T12:45:57 2023-10-09T12:46:09            618                     1134K                     1134K \n          30351749.extern  COMPLETED          1        1 2023-10-09T12:45:57 2023-10-09T12:45:57 2023-10-09T12:46:09            809                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(136,16,'a01r_20200128_fc0_1_DN','2023-10-09-12:46:30','2023-10-10-16:14:35',1696848390,1696848483,1696848488,'COMPLETED',2,1,'00:05','debug',805,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4-LOGIN',30351752,'',1,39,0.0,0.0,'a01r_20200128_fc0_1_DN.20231009124806.out','a01r_20200128_fc0_1_DN.20231009124806.err',2,'a01r_20200128_fc0_1_2_OPA,a01r_20200128_fc0_1_5_OPA,a01r_20200128_fc0_1_1_OPA,a01r_20200128_fc0_1_4_OPA,a01r_20200128_fc0_1_3_OPA',replace('                 30351752  COMPLETED          1        1 2023-10-09T12:46:30 2023-10-09T12:47:58 2023-10-09T12:48:09            805                                                     \n           30351752.batch  COMPLETED          1        1 2023-10-09T12:47:58 2023-10-09T12:47:58 2023-10-09T12:48:09            630                     1134K                     1134K \n          30351752.extern  COMPLETED          1        1 2023-10-09T12:47:58 2023-10-09T12:47:58 2023-10-09T12:48:09            805                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(137,16,'a01r_20200128_fc0_1_1_OPA','2023-10-09-12:48:30','2023-10-09-12:51:37',1696848510,1696848610,1696848615,'COMPLETED',2,1,'00:05','debug',814,'2020-01-28 00:00:00','OPA','fc0',1,1,'MARENOSTRUM4',30351758,'',1,39,0.0,0.0,'a01r_20200128_fc0_1_1_OPA.20231009125014.out','a01r_20200128_fc0_1_1_OPA.20231009125014.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351758  COMPLETED          1        1 2023-10-09T12:48:29 2023-10-09T12:50:04 2023-10-09T12:50:16            814                                                     \n           30351758.batch  COMPLETED          1        1 2023-10-09T12:50:04 2023-10-09T12:50:04 2023-10-09T12:50:16            663                     1099K                     1099K \n          30351758.extern  COMPLETED          1        1 2023-10-09T12:50:04 2023-10-09T12:50:04 2023-10-09T12:50:16            814                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(138,16,'a01r_20200128_fc0_1_2_OPA','2023-10-09-12:48:30','2023-10-09-12:53:38',1696848510,1696848729,1696848734,'COMPLETED',2,1,'00:05','debug',970,'2020-01-28 00:00:00','OPA','fc0',1,1,'MARENOSTRUM4',30351759,'',1,39,0.0,0.0,'a01r_20200128_fc0_1_2_OPA.20231009125216.out','a01r_20200128_fc0_1_2_OPA.20231009125216.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351759  COMPLETED          1        1 2023-10-09T12:48:29 2023-10-09T12:52:03 2023-10-09T12:52:15            970                                                     \n           30351759.batch  COMPLETED          1        1 2023-10-09T12:52:03 2023-10-09T12:52:03 2023-10-09T12:52:15            816                     1110K                     1110K \n          30351759.extern  COMPLETED          1        1 2023-10-09T12:52:03 2023-10-09T12:52:03 2023-10-09T12:52:15            970                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(139,16,'a01r_20200128_fc0_1_3_OPA','2023-10-09-12:48:30','2023-10-09-12:55:18',1696848510,1696848844,1696848849,'COMPLETED',2,1,'00:05','debug',1120,'2020-01-28 00:00:00','OPA','fc0',1,1,'MARENOSTRUM4',30351760,'',1,39,0.0,0.0,'a01r_20200128_fc0_1_3_OPA.20231009125415.out','a01r_20200128_fc0_1_3_OPA.20231009125415.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351760  COMPLETED          1        1 2023-10-09T12:48:30 2023-10-09T12:54:03 2023-10-09T12:54:10          1.12K                                                     \n           30351760.batch  COMPLETED          1        1 2023-10-09T12:54:03 2023-10-09T12:54:03 2023-10-09T12:54:10            878                     1118K                     1118K \n          30351760.extern  COMPLETED          1        1 2023-10-09T12:54:03 2023-10-09T12:54:03 2023-10-09T12:54:10          1.12K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(140,16,'a01r_20200128_fc0_1_4_OPA','2023-10-09-12:48:30','2023-10-09-12:57:38',1696848510,1696848966,1696848971,'COMPLETED',2,1,'00:05','debug',1960,'2020-01-28 00:00:00','OPA','fc0',1,1,'MARENOSTRUM4',30351761,'',1,39,0.0,0.0,'a01r_20200128_fc0_1_4_OPA.20231009125616.out','a01r_20200128_fc0_1_4_OPA.20231009125616.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351761  COMPLETED          1        1 2023-10-09T12:48:30 2023-10-09T12:56:03 2023-10-09T12:56:13          1.96K                                                     \n           30351761.batch  COMPLETED          1        1 2023-10-09T12:56:03 2023-10-09T12:56:03 2023-10-09T12:56:13          1.48K                      985K                      985K \n          30351761.extern  COMPLETED          1        1 2023-10-09T12:56:03 2023-10-09T12:56:03 2023-10-09T12:56:13          1.96K                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(141,16,'a01r_20200128_fc0_1_5_OPA','2023-10-09-12:48:30','2023-10-09-12:59:32',1696848510,1696849089,1696849094,'COMPLETED',2,1,'00:05','debug',690,'2020-01-28 00:00:00','OPA','fc0',1,1,'MARENOSTRUM4',30351762,'',1,39,0.0,0.0,'a01r_20200128_fc0_1_5_OPA.20231009125812.out','a01r_20200128_fc0_1_5_OPA.20231009125812.err',2,'a01r_20200128_fc0_1_APP',replace('                 30351762  COMPLETED          1        1 2023-10-09T12:48:30 2023-10-09T12:58:04 2023-10-09T12:58:15            690                                                     \n           30351762.batch  COMPLETED          1        1 2023-10-09T12:58:04 2023-10-09T12:58:04 2023-10-09T12:58:15            546                     1137K                     1137K \n          30351762.extern  COMPLETED          1        1 2023-10-09T12:58:04 2023-10-09T12:58:04 2023-10-09T12:58:15            690                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(142,16,'a01r_20200128_fc0_1_APP','2023-10-09-12:58:33','2023-10-09-13:01:30',1696849113,1696849209,1696849214,'COMPLETED',2,1,'00:05','debug',724,'2020-01-28 00:00:00','APP','fc0',1,1,'MARENOSTRUM4',30351904,'',1,39,0.0,0.0,'a01r_20200128_fc0_1_APP.20231009130010.out','a01r_20200128_fc0_1_APP.20231009130010.err',2,'',replace('                 30351904  COMPLETED          1        1 2023-10-09T12:58:33 2023-10-09T13:00:05 2023-10-09T13:00:15            724                                                     \n           30351904.batch  COMPLETED          1        1 2023-10-09T13:00:05 2023-10-09T13:00:05 2023-10-09T13:00:15            585                     1116K                     1116K \n          30351904.extern  COMPLETED          1        1 2023-10-09T13:00:05 2023-10-09T13:00:05 2023-10-09T13:00:15            724                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(143,17,'a01r_REMOTE_SETUP','2023-10-10-16:13:09','2023-10-11-10:19:24',1696947189,1696947253,1696947258,'COMPLETED',2,1,'00:05','debug',982,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4',30359458,'',1,57,0.0,0.0,'a01r_REMOTE_SETUP.20231010161430.out','a01r_REMOTE_SETUP.20231010161430.err',2,'a01r_20200128_fc0_1_DN',replace('                 30359458  COMPLETED          1        1 2023-10-10T16:13:09 2023-10-10T16:14:08 2023-10-10T16:14:20            982                                                     \n           30359458.batch  COMPLETED          1        1 2023-10-10T16:14:08 2023-10-10T16:14:08 2023-10-10T16:14:20            747                     1113K                     1113K \n          30359458.extern  COMPLETED          1        1 2023-10-10T16:14:08 2023-10-10T16:14:08 2023-10-10T16:14:20            982                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(144,17,'a01r_20200128_fc0_1_DN','2023-10-10-16:14:35','2023-10-11-11:43:28',1696947275,1696947374,1696947379,'COMPLETED',2,1,'00:05','debug',1010,'2020-01-28 00:00:00','DN','fc0',1,0,'MARENOSTRUM4',30359470,'',1,57,0.0,0.0,'a01r_20200128_fc0_1_DN.20231010161619.out','a01r_20200128_fc0_1_DN.20231010161619.err',2,'a01r_20200128_fc0_2_DN',replace('                 30359470  COMPLETED          1        1 2023-10-10T16:14:35 2023-10-10T16:16:09 2023-10-10T16:16:20          1.01K                                                     \n           30359470.batch  COMPLETED          1        1 2023-10-10T16:16:09 2023-10-10T16:16:09 2023-10-10T16:16:20            805                     1028K                     1028K \n          30359470.extern  COMPLETED          1        1 2023-10-10T16:16:09 2023-10-10T16:16:09 2023-10-10T16:16:20          1.01K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(145,17,'a01r_20200128_fc0_2_DN','2023-10-10-16:16:40','2023-10-11-11:43:40',1696947400,1696947504,1696947509,'COMPLETED',2,1,'00:05','debug',2240,'2020-01-28 00:00:00','DN','fc0',2,0,'MARENOSTRUM4',30359475,'',1,57,0.0,0.0,'a01r_20200128_fc0_2_DN.20231010161827.out','a01r_20200128_fc0_2_DN.20231010161827.err',2,'a01r_20200128_fc0_3_DN',replace('                 30359475  COMPLETED          1        1 2023-10-10T16:16:40 2023-10-10T16:18:19 2023-10-10T16:18:30          2.24K                                                     \n           30359475.batch  COMPLETED          1        1 2023-10-10T16:18:19 2023-10-10T16:18:19 2023-10-10T16:18:30          1.73K                      891K                      891K \n          30359475.extern  COMPLETED          1        1 2023-10-10T16:18:19 2023-10-10T16:18:19 2023-10-10T16:18:30          2.24K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(146,17,'a01r_20200128_fc0_3_DN','2023-10-10-16:18:50','2023-10-11-11:43:52',1696947530,1696947623,1696947628,'COMPLETED',2,1,'00:05','debug',911,'2020-01-28 00:00:00','DN','fc0',3,0,'MARENOSTRUM4',30359478,'',1,57,0.0,0.0,'a01r_20200128_fc0_3_DN.20231010162035.out','a01r_20200128_fc0_3_DN.20231010162035.err',2,'',replace('                 30359478  COMPLETED          1        1 2023-10-10T16:18:50 2023-10-10T16:20:18 2023-10-10T16:20:30            911                                                     \n           30359478.batch  COMPLETED          1        1 2023-10-10T16:20:18 2023-10-10T16:20:18 2023-10-10T16:20:30            702                     1028K                     1028K \n          30359478.extern  COMPLETED          1        1 2023-10-10T16:20:18 2023-10-10T16:20:18 2023-10-10T16:20:30            911                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(147,18,'a01r_REMOTE_SETUP','2023-10-11-10:19:24','2023-10-11-10:20:17',1697012363,0,0,'SUBMITTED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4',30361649,'',0,57,0.0,0.0,'','',0,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(148,19,'a01r_REMOTE_SETUP','2023-10-11-10:20:17','2023-10-11-11:41:07',1697012417,0,0,'SUBMITTED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4',30361658,'',0,57,0.0,0.0,'','',0,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(149,20,'a01r_REMOTE_SETUP','2023-10-11-11:41:08','2023-10-11-11:42:32',1697017267,0,0,'SUBMITTED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4',30362132,'',0,58,0.0,0.0,'','',0,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(150,21,'a01r_REMOTE_SETUP','2023-10-11-11:42:32','2023-10-11-11:43:15',1697017352,0,0,'SUBMITTED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4',30362133,'',0,59,0.0,0.0,'','',0,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(151,22,'a01r_REMOTE_SETUP','2023-10-11-11:43:15','2023-10-11-11:50:09',1697017395,1697017395,1697017400,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',62341,'',0,60,0.0,0.0,'a01r_REMOTE_SETUP.20231011114327.out','a01r_REMOTE_SETUP.20231011114327.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(152,22,'a01r_20200128_fc0_1_DN','2023-10-11-11:43:28','2023-10-11-11:50:21',1697017408,1697017408,1697017413,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',62383,'',0,60,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011114340.out','a01r_20200128_fc0_1_DN.20231011114340.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(153,22,'a01r_20200128_fc0_2_DN','2023-10-11-11:43:40','2023-10-11-11:50:34',1697017420,1697017420,1697017425,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',62424,'',0,60,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011114352.out','a01r_20200128_fc0_2_DN.20231011114352.err',5,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(154,22,'a01r_20200128_fc0_3_DN','2023-10-11-11:43:52','2023-10-11-11:50:46',1697017432,1697017432,1697017437,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',62463,'',0,60,0.0,0.0,'a01r_20200128_fc0_3_DN.20231011114404.out','a01r_20200128_fc0_3_DN.20231011114404.err',5,'','');
INSERT INTO job_data VALUES(155,23,'a01r_REMOTE_SETUP','2023-10-11-11:50:09','2023-10-11-11:54:12',1697017809,1697017809,1697017814,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',64197,'',0,61,0.0,0.0,'a01r_REMOTE_SETUP.20231011115021.out','a01r_REMOTE_SETUP.20231011115021.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(156,23,'a01r_20200128_fc0_1_DN','2023-10-11-11:50:21','2023-10-11-11:54:24',1697017821,1697017821,1697017826,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',64248,'',0,61,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011115033.out','a01r_20200128_fc0_1_DN.20231011115033.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(157,23,'a01r_20200128_fc0_2_DN','2023-10-11-11:50:34','2023-10-11-11:54:36',1697017834,1697017834,1697017839,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',64284,'',0,61,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011115046.out','a01r_20200128_fc0_2_DN.20231011115046.err',5,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(158,23,'a01r_20200128_fc0_3_DN','2023-10-11-11:50:46','2023-10-11-11:54:49',1697017846,1697017846,1697017851,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',64325,'',0,61,0.0,0.0,'a01r_20200128_fc0_3_DN.20231011115058.out','a01r_20200128_fc0_3_DN.20231011115058.err',5,'','');
INSERT INTO job_data VALUES(159,24,'a01r_REMOTE_SETUP','2023-10-11-11:54:12','2023-10-11-11:59:56',1697018052,1697018052,1697018057,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',64639,'',0,62,0.0,0.0,'a01r_REMOTE_SETUP.20231011115424.out','a01r_REMOTE_SETUP.20231011115424.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(160,24,'a01r_20200128_fc0_1_DN','2023-10-11-11:54:24','2023-10-11-12:00:09',1697018064,1697018064,1697018069,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',64674,'',0,62,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011115436.out','a01r_20200128_fc0_1_DN.20231011115436.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(161,24,'a01r_20200128_fc0_2_DN','2023-10-11-11:54:36','2023-10-11-12:00:21',1697018076,1697018076,1697018081,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',64714,'',0,62,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011115448.out','a01r_20200128_fc0_2_DN.20231011115448.err',5,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(162,24,'a01r_20200128_fc0_3_DN','2023-10-11-11:54:49','2023-10-11-12:00:33',1697018089,1697018089,1697018094,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',64751,'',0,62,0.0,0.0,'a01r_20200128_fc0_3_DN.20231011115501.out','a01r_20200128_fc0_3_DN.20231011115501.err',5,'','');
INSERT INTO job_data VALUES(163,25,'a01r_REMOTE_SETUP','2023-10-11-11:59:56','2023-10-11-12:11:14',1697018396,1697018396,1697018401,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',64878,'',0,62,0.0,0.0,'a01r_REMOTE_SETUP.20231011120008.out','a01r_REMOTE_SETUP.20231011120008.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(164,25,'a01r_20200128_fc0_1_DN','2023-10-11-12:00:09','2023-10-11-12:11:26',1697018409,1697018409,1697018414,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',64926,'',0,62,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011120021.out','a01r_20200128_fc0_1_DN.20231011120021.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(165,25,'a01r_20200128_fc0_2_DN','2023-10-11-12:00:21','2023-10-11-12:11:39',1697018421,1697018421,1697018426,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',64967,'',0,62,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011120033.out','a01r_20200128_fc0_2_DN.20231011120033.err',5,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(166,25,'a01r_20200128_fc0_3_DN','2023-10-11-12:00:33','2023-10-11-12:11:51',1697018433,1697018433,1697018438,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',65006,'',0,62,0.0,0.0,'a01r_20200128_fc0_3_DN.20231011120046.out','a01r_20200128_fc0_3_DN.20231011120046.err',5,'','');
INSERT INTO job_data VALUES(167,26,'a01r_REMOTE_SETUP','2023-10-11-12:11:14','2023-10-11-12:13:12',1697019074,1697019074,1697019079,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',65370,'',0,62,0.0,0.0,'a01r_REMOTE_SETUP.20231011121126.out','a01r_REMOTE_SETUP.20231011121126.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(168,26,'a01r_20200128_fc0_1_DN','2023-10-11-12:11:26','2023-10-11-12:13:24',1697019086,1697019086,1697019091,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',65406,'',0,62,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011121138.out','a01r_20200128_fc0_1_DN.20231011121138.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(169,26,'a01r_20200128_fc0_2_DN','2023-10-11-12:11:39','2023-10-11-12:13:37',1697019099,1697019099,1697019104,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',65445,'',0,62,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011121151.out','a01r_20200128_fc0_2_DN.20231011121151.err',5,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(170,26,'a01r_20200128_fc0_3_DN','2023-10-11-12:11:51','2023-10-11-12:13:49',1697019111,1697019111,1697019116,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',65486,'',0,62,0.0,0.0,'a01r_20200128_fc0_3_DN.20231011121203.out','a01r_20200128_fc0_3_DN.20231011121203.err',5,'','');
INSERT INTO job_data VALUES(171,27,'a01r_REMOTE_SETUP','2023-10-11-12:13:12','2023-10-11-12:26:35',1697019192,1697019192,1697019197,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',65553,'',0,62,0.0,0.0,'a01r_REMOTE_SETUP.20231011121324.out','a01r_REMOTE_SETUP.20231011121324.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(172,27,'a01r_20200128_fc0_1_DN','2023-10-11-12:13:24','2023-10-11-12:26:47',1697019204,1697019204,1697019209,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',65602,'',0,62,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011121336.out','a01r_20200128_fc0_1_DN.20231011121336.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(173,27,'a01r_20200128_fc0_2_DN','2023-10-11-12:13:37','2023-10-11-14:09:06',1697019217,1697019217,1697019222,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',65654,'',0,62,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011121349.out','a01r_20200128_fc0_2_DN.20231011121349.err',5,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(174,27,'a01r_20200128_fc0_3_DN','2023-10-11-12:13:49','2023-10-11-14:09:20',1697019229,1697019229,1697019234,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',65690,'',0,62,0.0,0.0,'a01r_20200128_fc0_3_DN.20231011121401.out','a01r_20200128_fc0_3_DN.20231011121401.err',5,'','');
INSERT INTO job_data VALUES(175,28,'a01r_REMOTE_SETUP','2023-10-11-12:26:35','2023-10-11-14:08:26',1697019995,1697019995,1697020000,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',66384,'',0,62,0.0,0.0,'a01r_REMOTE_SETUP.20231011122647.out','a01r_REMOTE_SETUP.20231011122647.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(176,28,'a01r_20200128_fc0_1_DN','2023-10-11-12:26:47','2023-10-11-14:08:52',1697020007,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',66421,'',0,62,0.0,0.0,'','',0,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(177,29,'a01r_REMOTE_SETUP','2023-10-11-14:08:26','2023-10-11-18:05:21',1697026106,1697026106,1697026111,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',71324,'',0,63,0.0,0.0,'a01r_REMOTE_SETUP.20231011140849.out','a01r_REMOTE_SETUP.20231011140849.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(178,29,'a01r_20200128_fc0_1_DN','2023-10-11-14:08:52','2023-10-11-18:05:33',1697026132,1697026132,1697026137,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',71705,'',0,63,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011140904.out','a01r_20200128_fc0_1_DN.20231011140904.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(179,29,'a01r_20200128_fc0_2_DN','2023-10-11-14:09:06','2023-10-11-18:05:46',1697026146,1697026146,1697026151,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',71858,'',0,63,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011140918.out','a01r_20200128_fc0_2_DN.20231011140918.err',5,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(180,29,'a01r_20200128_fc0_3_DN','2023-10-11-14:09:20','2023-10-11-18:05:58',1697026160,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',72007,'',0,63,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(181,30,'a01r_REMOTE_SETUP','2023-10-11-18:05:21','2023-10-11-18:39:02',1697040321,1697040321,1697040326,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',84584,'',0,64,0.0,0.0,'a01r_REMOTE_SETUP.20231011180533.out','a01r_REMOTE_SETUP.20231011180533.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(182,30,'a01r_20200128_fc0_1_DN','2023-10-11-18:05:33','2023-10-11-18:39:14',1697040333,1697040333,1697040338,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',84625,'',0,64,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011180545.out','a01r_20200128_fc0_1_DN.20231011180545.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(183,30,'a01r_20200128_fc0_2_DN','2023-10-11-18:05:46','2023-10-11-18:39:27',1697040346,1697040346,1697040351,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',84663,'',0,64,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011180558.out','a01r_20200128_fc0_2_DN.20231011180558.err',5,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(184,30,'a01r_20200128_fc0_3_DN','2023-10-11-18:05:58','2023-10-11-18:39:39',1697040358,1697040358,1697040363,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',84704,'',0,64,0.0,0.0,'a01r_20200128_fc0_3_DN.20231011180610.out','a01r_20200128_fc0_3_DN.20231011180610.err',5,'','');
INSERT INTO job_data VALUES(185,31,'a01r_REMOTE_SETUP','2023-10-11-18:39:02','2023-10-11-19:49:55',1697042342,1697042342,1697042347,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',88220,'',0,64,0.0,0.0,'a01r_REMOTE_SETUP.20231011183914.out','a01r_REMOTE_SETUP.20231011183914.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(186,31,'a01r_20200128_fc0_1_DN','2023-10-11-18:39:14','2023-10-11-19:50:07',1697042354,1697042354,1697042359,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',88258,'',0,64,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011183927.out','a01r_20200128_fc0_1_DN.20231011183927.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(187,31,'a01r_20200128_fc0_2_DN','2023-10-11-18:39:27','2023-10-11-19:50:20',1697042367,1697042367,1697042372,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',88295,'',0,64,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011183939.out','a01r_20200128_fc0_2_DN.20231011183939.err',5,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(188,31,'a01r_20200128_fc0_3_DN','2023-10-11-18:39:39','2023-10-11-19:50:32',1697042379,1697042379,1697042384,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',88331,'',0,64,0.0,0.0,'a01r_20200128_fc0_3_DN.20231011183951.out','a01r_20200128_fc0_3_DN.20231011183951.err',5,'','');
INSERT INTO job_data VALUES(189,32,'a01r_REMOTE_SETUP','2023-10-11-19:49:55','2023-10-11-19:51:52',1697046595,1697046595,1697046600,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',95405,'',0,64,0.0,0.0,'a01r_REMOTE_SETUP.20231011195007.out','a01r_REMOTE_SETUP.20231011195007.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(190,32,'a01r_20200128_fc0_1_DN','2023-10-11-19:50:07','2023-10-11-19:52:05',1697046607,1697046607,1697046612,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',95440,'',0,64,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011195019.out','a01r_20200128_fc0_1_DN.20231011195019.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(191,32,'a01r_20200128_fc0_2_DN','2023-10-11-19:50:20','2023-10-11-19:52:17',1697046620,1697046620,1697046625,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',95478,'',0,64,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011195032.out','a01r_20200128_fc0_2_DN.20231011195032.err',5,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(192,32,'a01r_20200128_fc0_3_DN','2023-10-11-19:50:32','2023-10-11-19:56:49',1697046632,1697046632,1697046637,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',95514,'',0,64,0.0,0.0,'a01r_20200128_fc0_3_DN.20231011195044.out','a01r_20200128_fc0_3_DN.20231011195044.err',5,'','');
INSERT INTO job_data VALUES(193,33,'a01r_REMOTE_SETUP','2023-10-11-19:51:52','2023-10-11-19:56:49',1697046712,1697046712,1697046717,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',95606,'',0,64,0.0,0.0,'a01r_REMOTE_SETUP.20231011195204.out','a01r_REMOTE_SETUP.20231011195204.err',5,'a01r_20200128_fc0_1_DN','');
INSERT INTO job_data VALUES(194,33,'a01r_20200128_fc0_1_DN','2023-10-11-19:52:05','2023-10-11-19:56:48',1697046725,1697046725,1697046730,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',95707,'',0,64,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011195217.out','a01r_20200128_fc0_1_DN.20231011195217.err',5,'a01r_20200128_fc0_2_DN','');
INSERT INTO job_data VALUES(195,33,'a01r_20200128_fc0_2_DN','2023-10-11-19:52:17','2023-10-11-19:56:49',1697046737,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',95744,'',0,64,0.0,0.0,'','',0,'a01r_20200128_fc0_3_DN','');
INSERT INTO job_data VALUES(196,34,'a01r_20200128_fc0_1_DN','2023-10-11-19:56:48','2023-10-13-08:58:27',1697047008,1697047008,1697047013,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',96787,'',0,65,0.0,0.0,'a01r_20200128_fc0_1_DN.20231011195707.out','a01r_20200128_fc0_1_DN.20231011195707.err',5,'','');
INSERT INTO job_data VALUES(197,34,'a01r_20200128_fc0_2_DN','2023-10-11-19:56:49','2023-10-13-08:58:28',1697047009,1697047009,1697047014,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',96810,'',0,65,0.0,0.0,'a01r_20200128_fc0_2_DN.20231011195707.out','a01r_20200128_fc0_2_DN.20231011195707.err',5,'','');
INSERT INTO job_data VALUES(198,34,'a01r_20200128_fc0_3_DN','2023-10-11-19:56:49','2023-10-13-08:58:29',1697047009,1697047009,1697047014,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',96833,'',0,65,0.0,0.0,'a01r_20200128_fc0_3_DN.20231011195707.out','a01r_20200128_fc0_3_DN.20231011195707.err',5,'','');
INSERT INTO job_data VALUES(199,34,'a01r_REMOTE_SETUP','2023-10-11-19:56:49','2023-10-13-08:58:31',1697047009,1697047009,1697047014,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',96856,'',0,65,0.0,0.0,'a01r_REMOTE_SETUP.20231011195707.out','a01r_REMOTE_SETUP.20231011195707.err',5,'','');
INSERT INTO job_data VALUES(200,35,'a01r_20200128_fc0_1_DN','2023-10-13-08:58:27','2023-10-13-08:58:40',1697180307,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',108074,'',0,65,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(201,35,'a01r_20200128_fc0_2_DN','2023-10-13-08:58:28','2023-10-13-08:58:40',1697180308,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',108097,'',0,65,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(202,35,'a01r_20200128_fc0_3_DN','2023-10-13-08:58:29','2023-10-13-08:58:40',1697180309,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',108120,'',0,65,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(203,35,'a01r_REMOTE_SETUP','2023-10-13-08:58:31','2023-10-13-08:58:41',1697180311,0,0,'SUBMITTED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',108143,'',0,65,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(204,36,'a01r_20200128_fc0_1_DN','2023-10-13-08:58:40','2023-10-13-09:01:42',1697180320,1697180320,1697180325,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,0,'LOCAL',108196,'',0,66,0.0,0.0,'a01r_20200128_fc0_1_DN.20231013085859.out','a01r_20200128_fc0_1_DN.20231013085859.err',5,'','');
INSERT INTO job_data VALUES(205,36,'a01r_20200128_fc0_2_DN','2023-10-13-08:58:40','2023-10-13-09:01:42',1697180320,1697180320,1697180325,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,0,'LOCAL',108219,'',0,66,0.0,0.0,'a01r_20200128_fc0_2_DN.20231013085859.out','a01r_20200128_fc0_2_DN.20231013085859.err',5,'','');
INSERT INTO job_data VALUES(206,36,'a01r_20200128_fc0_3_DN','2023-10-13-08:58:41','2023-10-13-09:01:42',1697180320,1697180320,1697180326,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,0,'LOCAL',108242,'',0,66,0.0,0.0,'a01r_20200128_fc0_3_DN.20231013085859.out','a01r_20200128_fc0_3_DN.20231013085859.err',5,'','');
INSERT INTO job_data VALUES(207,36,'a01r_REMOTE_SETUP','2023-10-13-08:58:41','2023-10-13-09:01:42',1697180321,1697180321,1697180326,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',108265,'',0,66,0.0,0.0,'a01r_REMOTE_SETUP.20231013085859.out','a01r_REMOTE_SETUP.20231013085859.err',5,'','');
INSERT INTO job_data VALUES(208,37,'a01r_20200128_fc0_1_DN','2023-10-13-09:01:42','2023-10-13-09:02:00',1697180502,1697180502,1697180507,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',1,1,'LOCAL',108575,'',0,66,0.0,0.0,'a01r_20200128_fc0_1_DN.20231013090200.out','a01r_20200128_fc0_1_DN.20231013090200.err',5,'','');
INSERT INTO job_data VALUES(209,37,'a01r_20200128_fc0_2_DN','2023-10-13-09:01:42','2023-10-13-09:02:01',1697180502,1697180502,1697180507,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',2,1,'LOCAL',108598,'',0,66,0.0,0.0,'a01r_20200128_fc0_2_DN.20231013090201.out','a01r_20200128_fc0_2_DN.20231013090201.err',5,'','');
INSERT INTO job_data VALUES(210,37,'a01r_20200128_fc0_3_DN','2023-10-13-09:01:42','2023-10-13-09:02:01',1697180502,1697180502,1697180507,'COMPLETED',2,1,'00:05','debug',0,'2020-01-28 00:00:00','DN','fc0',3,1,'LOCAL',108621,'',0,66,0.0,0.0,'a01r_20200128_fc0_3_DN.20231013090201.out','a01r_20200128_fc0_3_DN.20231013090201.err',5,'','');
INSERT INTO job_data VALUES(211,37,'a01r_REMOTE_SETUP','2023-10-13-09:01:42','2023-10-13-09:02:00',1697180502,1697180502,1697180507,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,1,'LOCAL',108644,'',0,66,0.0,0.0,'a01r_REMOTE_SETUP.20231013090200.out','a01r_REMOTE_SETUP.20231013090200.err',5,'','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',68);
INSERT INTO sqlite_sequence VALUES('job_data',211);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
